@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef PLUGINEDITORCHECKBEFORESENDPARAMSTEST_H
-#define PLUGINEDITORCHECKBEFORESENDPARAMSTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,7 +13,7 @@ class PluginEditorCheckBeforeSendParamsTest : public QObject
     Q_OBJECT
 public:
     explicit PluginEditorCheckBeforeSendParamsTest(QObject *parent = nullptr);
-    ~PluginEditorCheckBeforeSendParamsTest();
+    ~PluginEditorCheckBeforeSendParamsTest() override;
 
 private Q_SLOTS:
     void shouldHaveDefaultValues();
@@ -22,4 +21,3 @@ private Q_SLOTS:
     void shouldAssignValue();
 };
 
-#endif // PLUGINEDITORCHECKBEFORESENDPARAMSTEST_H
