@@ -4,8 +4,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef REPLYSTRATEGY_TEST_H
-#define REPLYSTRATEGY_TEST_H
+#pragma once
 
 #include <KMime/Message>
 
@@ -13,7 +12,8 @@
 
 #include <MessageComposer/MessageFactoryNG>
 
-namespace KIdentityManagement {
+namespace KIdentityManagement
+{
 class IdentityManager;
 }
 
@@ -23,7 +23,7 @@ class ReplyStrategyTest : public QObject
 
 public:
     explicit ReplyStrategyTest(QObject *parent = nullptr);
-    ~ReplyStrategyTest();
+    ~ReplyStrategyTest() override;
 
 private Q_SLOTS:
     void initTestCase();
@@ -38,4 +38,3 @@ private:
     KIdentityManagement::IdentityManager *mIdentityManager;
 };
 
-#endif
