@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef SENDLATERINFOTEST_H
-#define SENDLATERINFOTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -22,4 +21,3 @@ private Q_SLOTS:
     void shouldCopyInfo();
 };
 
-#endif // SENDLATERINFOTEST_H
