@@ -4,8 +4,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef SIGNENCRYPTTEST_H
-#define SIGNENCRYPTTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -26,4 +25,3 @@ private Q_SLOTS:
     void testProtectedHeaders();
 };
 
-#endif
