@@ -1,20 +1,7 @@
 /*
-  Copyright (c) 2009 Constantin Berzan <exit3219@gmail.com>
+  SPDX-FileCopyrightText: 2009 Constantin Berzan <exit3219@gmail.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "skeletonmessagejobtest.h"
@@ -22,11 +9,11 @@
 #include <QDebug>
 #include <QTest>
 
-#include <kmime/kmime_message.h>
+#include <KMime/KMimeMessage>
 
 #include <MessageComposer/Composer>
-#include <MessageComposer/InfoPart>
 #include <MessageComposer/GlobalPart>
+#include <MessageComposer/InfoPart>
 #include <MessageComposer/SkeletonMessageJob>
 using namespace MessageComposer;
 
@@ -44,20 +31,22 @@ void SkeletonMessageJobTest::testSubject_data()
 void SkeletonMessageJobTest::testSubject()
 {
     // An InfoPart should belong to a Composer, even if we don't use the composer itself.
-    Composer *composer = new Composer;
+    auto composer = new Composer;
     InfoPart *infoPart = composer->infoPart();
     GlobalPart *globalPart = composer->globalPart();
     Q_ASSERT(infoPart);
 
     QFETCH(QString, subject);
-    //qDebug() << subject;
+    // qDebug() << subject;
     infoPart->setSubject(subject);
-    SkeletonMessageJob *sjob = new SkeletonMessageJob(infoPart, globalPart, composer);
+    auto sjob = new SkeletonMessageJob(infoPart, globalPart, composer);
     QVERIFY(sjob->exec());
     KMime::Message *message = sjob->message();
     QVERIFY(message->subject(false));
     qDebug() << message->subject()->asUnicodeString();
     QCOMPARE(subject, message->subject()->asUnicodeString());
+    delete message;
+    delete composer;
 }
 
 void SkeletonMessageJobTest::testAddresses_data()
@@ -133,7 +122,7 @@ void SkeletonMessageJobTest::testAddresses_data()
 void SkeletonMessageJobTest::testAddresses()
 {
     // An InfoPart should belong to a Composer, even if we don't use the composer itself.
-    Composer *composer = new Composer;
+    auto composer = new Composer;
     InfoPart *infoPart = composer->infoPart();
     GlobalPart *globalPart = composer->globalPart();
     Q_ASSERT(infoPart);
@@ -148,27 +137,28 @@ void SkeletonMessageJobTest::testAddresses()
     infoPart->setTo(to);
     infoPart->setCc(cc);
     infoPart->setBcc(bcc);
-    SkeletonMessageJob *sjob = new SkeletonMessageJob(infoPart, globalPart, composer);
+    auto sjob = new SkeletonMessageJob(infoPart, globalPart, composer);
     QVERIFY(sjob->exec());
     KMime::Message *message = sjob->message();
 
     {
         QVERIFY(message->from(false));
-        qDebug() << "From:" << message->from()->asUnicodeString();
+        // qDebug() << "From:" << message->from()->asUnicodeString();
         QCOMPARE(from, message->from()->asUnicodeString());
     }
 
     {
         QVERIFY(message->replyTo(false));
-        qDebug() << "Reply-To:" << message->replyTo()->asUnicodeString();
+        // qDebug() << "Reply-To:" << message->replyTo()->asUnicodeString();
         QCOMPARE(replyto.join(QLatin1Char(',')), message->replyTo()->asUnicodeString());
     }
 
     {
         QVERIFY(message->to(false));
-        qDebug() << "To:" << message->to()->asUnicodeString();
-        foreach (const auto &addr, message->to()->mailboxes()) {
-            qDebug() << addr.prettyAddress();
+        // qDebug() << "To:" << message->to()->asUnicodeString();
+        const auto mailboxes{message->to()->mailboxes()};
+        for (const auto &addr : mailboxes) {
+            // qDebug() << addr.prettyAddress();
             QVERIFY(to.contains(addr.prettyAddress()));
             to.removeOne(addr.prettyAddress());
         }
@@ -177,9 +167,10 @@ void SkeletonMessageJobTest::testAddresses()
 
     {
         QVERIFY(message->cc(false));
-        qDebug() << "Cc:" << message->cc()->asUnicodeString();
-        foreach (const auto &addr, message->cc()->mailboxes()) {
-            qDebug() << addr.prettyAddress();
+        // qDebug() << "Cc:" << message->cc()->asUnicodeString();
+        const auto mailboxes{message->cc()->mailboxes()};
+        for (const auto &addr : mailboxes) {
+            // qDebug() << addr.prettyAddress();
             QVERIFY(cc.contains(addr.prettyAddress()));
             cc.removeOne(addr.prettyAddress());
         }
@@ -188,28 +179,32 @@ void SkeletonMessageJobTest::testAddresses()
 
     {
         QVERIFY(message->bcc(false));
-        qDebug() << "Bcc:" << message->bcc()->asUnicodeString();
-        foreach (const auto &addr, message->bcc()->mailboxes()) {
-            qDebug() << addr.prettyAddress();
+        // qDebug() << "Bcc:" << message->bcc()->asUnicodeString();
+        const auto mailboxes{message->bcc()->mailboxes()};
+        for (const auto &addr : mailboxes) {
+            // qDebug() << addr.prettyAddress();
             QVERIFY(bcc.contains(addr.prettyAddress()));
             bcc.removeOne(addr.prettyAddress());
         }
         QVERIFY(bcc.isEmpty());
     }
+    delete message;
+    delete composer;
 }
 
 void SkeletonMessageJobTest::testMessageID()
 {
-    Composer *composer = new Composer();
+    auto composer = new Composer();
     InfoPart *infoPart = composer->infoPart();
     GlobalPart *globalPart = composer->globalPart();
     Q_ASSERT(infoPart);
 
-    SkeletonMessageJob *sjob = new SkeletonMessageJob(infoPart, globalPart, composer);
+    auto sjob = new SkeletonMessageJob(infoPart, globalPart, composer);
     QVERIFY(sjob->exec());
     KMime::Message *message = sjob->message();
     QVERIFY(message->messageID(false));
     QVERIFY(!message->messageID(false)->isEmpty());
+    delete message;
     delete sjob;
     delete composer;
 }
