@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef TEXTPARTTEST_H
-#define TEXTPARTTEST_H
+#pragma once
 #include <QObject>
 
 class TextPartTest : public QObject
@@ -13,9 +12,8 @@ class TextPartTest : public QObject
     Q_OBJECT
 public:
     explicit TextPartTest(QObject *parent = nullptr);
-    ~TextPartTest();
+    ~TextPartTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
 };
 
-#endif // TEXTPARTTEST_H
