@@ -1,15 +1,15 @@
 /*
   SPDX-FileCopyrightText: 2009 Constantin Berzan <exit3219@gmail.com>
-  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "utiltest.h"
 
-#include <QTextDocument>
-#include <QTest>
 #include <QStandardPaths>
+#include <QTest>
+#include <QTextDocument>
 
 #include <MessageComposer/Util>
 using namespace MessageComposer;
@@ -66,17 +66,18 @@ void UtilTest::shouldTestHasMissingAttachment_data()
     QTest::addColumn<QString>("body");
     QTest::addColumn<bool>("hasMissingAttachment");
 
-    QStringList lstDefaultAttachement{
-        QStringLiteral("attachment"), QStringLiteral("att2")
-    };
+    QStringList lstDefaultAttachement{QStringLiteral("attachment"), QStringLiteral("att2")};
     QTest::newRow("emptybody") << lstDefaultAttachement << QStringLiteral("foo") << QString() << false;
     QTest::newRow("emptybodyandsubject") << lstDefaultAttachement << QString() << QString() << false;
     QTest::newRow("subjectwithattachmentkeyword") << lstDefaultAttachement << QStringLiteral("attachment foo") << QString() << true;
     QTest::newRow("subjectwithattachmentkeywordonly") << lstDefaultAttachement << QStringLiteral("attachment") << QString() << true;
     QTest::newRow("subjectwithattachmentkeywordbutreply") << lstDefaultAttachement << QStringLiteral("Re: attachment") << QString() << false;
-    QTest::newRow("subjectwithattachmentkeywordbutreplywithoutattachement") << lstDefaultAttachement << QStringLiteral("Re: attachment") << QStringLiteral("foo bla\n bli") << false;
-    QTest::newRow("subjectwithattachmentkeywordbutreplywithattachement") << lstDefaultAttachement << QStringLiteral("Re: attachment") << QStringLiteral("foo bla\n attachment:") << true;
-    QTest::newRow("subjectwithattachmentkeywordbutreplywithattachement2") << lstDefaultAttachement << QStringLiteral("Re: attachment") << QStringLiteral("foo bla att2\n bli:") << true;
+    QTest::newRow("subjectwithattachmentkeywordbutreplywithoutattachement")
+        << lstDefaultAttachement << QStringLiteral("Re: attachment") << QStringLiteral("foo bla\n bli") << false;
+    QTest::newRow("subjectwithattachmentkeywordbutreplywithattachement")
+        << lstDefaultAttachement << QStringLiteral("Re: attachment") << QStringLiteral("foo bla\n attachment:") << true;
+    QTest::newRow("subjectwithattachmentkeywordbutreplywithattachement2")
+        << lstDefaultAttachement << QStringLiteral("Re: attachment") << QStringLiteral("foo bla att2\n bli:") << true;
     QTest::newRow("excludequotedstr") << lstDefaultAttachement << QStringLiteral("Re: attachment") << QStringLiteral("> foo bla att2\n bli:") << false;
     QTest::newRow("excludequotedstr2") << lstDefaultAttachement << QStringLiteral("Re: attachment") << QStringLiteral("> foo bla att2\n att2:") << true;
     QTest::newRow("excludequotedstr3") << lstDefaultAttachement << QStringLiteral("Re: attachment") << QStringLiteral("| foo bla att2\n att2:") << true;
