@@ -12,19 +12,18 @@
 
 #include "messagecomposer_debug.h"
 #include <KLocalizedString>
-#include <QTemporaryDir>
 #include <QFileDevice>
+#include <QTemporaryDir>
 
-#include <kmime/kmime_headers.h>
-#include <kmime/kmime_util.h>
-#include <AkonadiCore/item.h>
+#include <KMime/Headers>
+#include <KMime/Util>
 
 #include <KFormat>
 
 using namespace MessageComposer;
 using namespace MessageCore;
 
-static Qt::CheckState boolToCheckState(bool checked)   // local
+static Qt::CheckState boolToCheckState(bool checked) // local
 {
     if (checked) {
         return Qt::Checked;
@@ -33,11 +32,11 @@ static Qt::CheckState boolToCheckState(bool checked)   // local
     }
 }
 
-class Q_DECL_HIDDEN MessageComposer::AttachmentModel::Private
+class MessageComposer::AttachmentModel::AttachmentModelPrivate
 {
 public:
-    Private(AttachmentModel *qq);
-    ~Private();
+    AttachmentModelPrivate(AttachmentModel *qq);
+    ~AttachmentModelPrivate();
 
     AttachmentPart::List parts;
     QVector<QTemporaryDir *> tempDirs;
@@ -50,12 +49,12 @@ public:
     bool autoDisplayEnabled = false;
 };
 
-AttachmentModel::Private::Private(AttachmentModel *qq)
+AttachmentModel::AttachmentModelPrivate::AttachmentModelPrivate(AttachmentModel *qq)
     : q(qq)
 {
 }
 
-AttachmentModel::Private::~Private()
+AttachmentModel::AttachmentModelPrivate::~AttachmentModelPrivate()
 {
     // There should be an automatic way to manage the lifetime of these...
     qDeleteAll(tempDirs);
@@ -63,24 +62,19 @@ AttachmentModel::Private::~Private()
 
 AttachmentModel::AttachmentModel(QObject *parent)
     : QAbstractItemModel(parent)
-    , d(new Private(this))
+    , d(new AttachmentModelPrivate(this))
 {
 }
 
-AttachmentModel::~AttachmentModel()
-{
-    delete d;
-}
+AttachmentModel::~AttachmentModel() = default;
 
 bool AttachmentModel::dropMimeData(const QMimeData *data, Qt::DropAction action, int row, int column, const QModelIndex &parent)
 {
-    Q_UNUSED(row);
-    Q_UNUSED(column);
-    Q_UNUSED(parent);
+    Q_UNUSED(row)
+    Q_UNUSED(column)
+    Q_UNUSED(parent)
 
-    qCDebug(MESSAGECOMPOSER_LOG) << "data has formats" << data->formats()
-                                 << "urls" << data->urls()
-                                 << "action" << int(action);
+    qCDebug(MESSAGECOMPOSER_LOG) << "data has formats" << data->formats() << "urls" << data->urls() << "action" << int(action);
 
     if (action == Qt::IgnoreAction) {
         return true;
@@ -120,7 +114,7 @@ QMimeData *AttachmentModel::mimeData(const QModelIndexList &indexes) const
             continue;
         }
 
-        const AttachmentPart::Ptr part = d->parts[ index.row() ];
+        const AttachmentPart::Ptr part = d->parts[index.row()];
         QString attachmentName = part->fileName();
         if (attachmentName.isEmpty()) {
             attachmentName = part->name();
@@ -129,7 +123,7 @@ QMimeData *AttachmentModel::mimeData(const QModelIndexList &indexes) const
             attachmentName = i18n("unnamed attachment");
         }
 
-        QTemporaryDir *tempDir = new QTemporaryDir; // Will remove the directory on destruction.
+        auto tempDir = new QTemporaryDir; // Will remove the directory on destruction.
         d->tempDirs.append(tempDir);
         const QString fileName = tempDir->path() + QLatin1Char('/') + attachmentName;
         QFile f(fileName);
@@ -150,7 +144,7 @@ QMimeData *AttachmentModel::mimeData(const QModelIndexList &indexes) const
         urls.append(url);
     }
 
-    QMimeData *mimeData = new QMimeData;
+    auto mimeData = new QMimeData;
     mimeData->setUrls(urls);
     return mimeData;
 }
@@ -217,7 +211,7 @@ bool AttachmentModel::isEncryptSelected() const
 void AttachmentModel::setEncryptSelected(bool selected)
 {
     d->encryptSelected = selected;
-    for (AttachmentPart::Ptr part : qAsConst(d->parts)) {
+    for (AttachmentPart::Ptr part : std::as_const(d->parts)) {
         part->setEncrypted(selected);
     }
     Q_EMIT dataChanged(index(0, EncryptColumn), index(rowCount() - 1, EncryptColumn));
@@ -231,7 +225,7 @@ bool AttachmentModel::isSignSelected() const
 void AttachmentModel::setSignSelected(bool selected)
 {
     d->signSelected = selected;
-    for (AttachmentPart::Ptr part : qAsConst(d->parts)) {
+    for (AttachmentPart::Ptr part : std::as_const(d->parts)) {
         part->setSigned(selected);
     }
     Q_EMIT dataChanged(index(0, SignColumn), index(rowCount() - 1, SignColumn));
@@ -259,13 +253,12 @@ QVariant AttachmentModel::data(const QModelIndex &index, int role) const
             return QVariant();
         }
     } else if (role == Qt::ToolTipRole) {
-        return QVariant::fromValue(
-            i18nc("@info:tooltip",
-                  "Name: %1<br>Size: %2<br>Encoding: %3<br>MimeType=%4",
-                  part->name().isEmpty() ? part->fileName() : part->name(),
-                  KFormat().formatByteSize(part->size()),
-                  KMime::nameForEncoding(part->encoding()),
-                  QString::fromLatin1(part->mimeType().data())));
+        return QVariant::fromValue(i18nc("@info:tooltip",
+                                         "Name: %1<br>Size: %2<br>Encoding: %3<br>MimeType=%4",
+                                         part->name().isEmpty() ? part->fileName() : part->name(),
+                                         KFormat().formatByteSize(part->size()),
+                                         KMime::nameForEncoding(part->encoding()),
+                                         QString::fromLatin1(part->mimeType().data())));
     } else if (role == Qt::CheckStateRole) {
         switch (index.column()) {
         case CompressColumn:
@@ -310,7 +303,7 @@ QVariant AttachmentModel::data(const QModelIndex &index, int role) const
 bool AttachmentModel::setData(const QModelIndex &index, const QVariant &value, int role)
 {
     bool emitDataChanged = true;
-    AttachmentPart::Ptr part = d->parts[ index.row() ];
+    AttachmentPart::Ptr part = d->parts[index.row()];
 
     if (role == Qt::EditRole) {
         switch (index.column()) {
@@ -326,8 +319,7 @@ bool AttachmentModel::setData(const QModelIndex &index, const QVariant &value, i
         }
     } else if (role == Qt::CheckStateRole) {
         switch (index.column()) {
-        case CompressColumn:
-        {
+        case CompressColumn: {
             bool toZip = value.toBool();
             if (toZip != part->isCompressed()) {
                 Q_EMIT attachmentCompressRequested(part, toZip);
@@ -361,7 +353,7 @@ void AttachmentModel::addAttachment(const AttachmentPart::Ptr &part)
 {
     Q_ASSERT(!d->parts.contains(part));
     if (!part->url().isEmpty()) {
-        for (const AttachmentPart::Ptr &partElement : qAsConst(d->parts)) {
+        for (const AttachmentPart::Ptr &partElement : std::as_const(d->parts)) {
             if (partElement->url() == part->url()) {
                 return;
             }
@@ -394,7 +386,7 @@ bool AttachmentModel::replaceAttachment(const AttachmentPart::Ptr &oldPart, cons
         qCWarning(MESSAGECOMPOSER_LOG) << "Tried to replace non-existent part.";
         return false;
     }
-    d->parts[ idx ] = newPart;
+    d->parts[idx] = newPart;
     // Emit dataChanged() for the whole row.
     Q_EMIT dataChanged(index(idx, 0), index(idx, LastColumn - 1));
     return true;
@@ -428,10 +420,7 @@ Qt::ItemFlags AttachmentModel::flags(const QModelIndex &index) const
         return Qt::ItemIsDropEnabled | defaultFlags;
     }
 
-    if (index.column() == CompressColumn
-        || index.column() == EncryptColumn
-        || index.column() == SignColumn
-        || index.column() == AutoDisplayColumn) {
+    if (index.column() == CompressColumn || index.column() == EncryptColumn || index.column() == SignColumn || index.column() == AutoDisplayColumn) {
         return Qt::ItemIsDragEnabled | Qt::ItemIsDropEnabled | Qt::ItemIsUserCheckable | defaultFlags;
     } else if (index.column() == NameColumn) {
         return Qt::ItemIsDragEnabled | Qt::ItemIsDropEnabled | Qt::ItemIsEditable | defaultFlags;
@@ -486,7 +475,7 @@ QModelIndex AttachmentModel::index(int row, int column, const QModelIndex &paren
 
 QModelIndex AttachmentModel::parent(const QModelIndex &index) const
 {
-    Q_UNUSED(index);
+    Q_UNUSED(index)
     return QModelIndex(); // No parent.
 }
 
@@ -500,6 +489,6 @@ int AttachmentModel::rowCount(const QModelIndex &parent) const
 
 int AttachmentModel::columnCount(const QModelIndex &parent) const
 {
-    Q_UNUSED(parent);
+    Q_UNUSED(parent)
     return LastColumn;
 }
