@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef RICHTEXTCOMPOSERNGTEST_H
-#define RICHTEXTCOMPOSERNGTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,7 +13,7 @@ class RichTextComposerNgTest : public QObject
     Q_OBJECT
 public:
     explicit RichTextComposerNgTest(QObject *parent = nullptr);
-    ~RichTextComposerNgTest();
+    ~RichTextComposerNgTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldForceAutoCorrection_data();
@@ -39,6 +38,9 @@ private Q_SLOTS:
 
     void shouldLoadSignatureFromCommand_data();
     void shouldLoadSignatureFromCommand();
+
+    void fixHtmlFontSizeTest();
+
+    void toCleanHtmlRegexTest();
 };
 
-#endif // RICHTEXTCOMPOSERNGTEST_H
