@@ -1,19 +1,21 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "richtextcomposerng.h"
-#include <KPIMTextEdit/RichTextComposerControler>
-#include <KPIMTextEdit/RichTextComposerImages>
 #include "richtextcomposersignatures.h"
-#include <PimCommon/AutoCorrection>
-#include <part/textpart.h>
 #include "settings/messagecomposersettings.h"
-#include <KPIMTextEdit/TextHTMLBuilder>
 #include <KPIMTextEdit/MarkupDirector>
 #include <KPIMTextEdit/PlainTextMarkupBuilder>
+#include <KPIMTextEdit/RichTextComposerControler>
+#include <KPIMTextEdit/RichTextComposerImages>
+#include <KPIMTextEdit/TextHTMLBuilder>
+#include <PimCommon/AutoCorrection>
+#include <part/textpart.h>
+
+#include <QRegularExpression>
 
 #define USE_TEXTHTML_BUILDER 1
 
@@ -22,16 +24,16 @@ using namespace MessageComposer;
 class MessageComposer::RichTextComposerNgPrivate
 {
 public:
-    RichTextComposerNgPrivate(RichTextComposerNg *q)
+    explicit RichTextComposerNgPrivate(RichTextComposerNg *q)
         : richtextComposer(q)
     {
         richTextComposerSignatures = new MessageComposer::RichTextComposerSignatures(richtextComposer, richtextComposer);
     }
 
-    void fixHtmlFontSize(QString &cleanHtml);
+    void fixHtmlFontSize(QString &cleanHtml) const;
     Q_REQUIRED_RESULT QString toCleanHtml() const;
     PimCommon::AutoCorrection *autoCorrection = nullptr;
-    RichTextComposerNg * const richtextComposer;
+    RichTextComposerNg *const richtextComposer;
     MessageComposer::RichTextComposerSignatures *richTextComposerSignatures = nullptr;
 };
 
@@ -41,10 +43,7 @@ RichTextComposerNg::RichTextComposerNg(QWidget *parent)
 {
 }
 
-RichTextComposerNg::~RichTextComposerNg()
-{
-    delete d;
-}
+RichTextComposerNg::~RichTextComposerNg() = default;
 
 MessageComposer::RichTextComposerSignatures *RichTextComposerNg::composerSignature() const
 {
@@ -70,8 +69,8 @@ void RichTextComposerNg::setAutocorrectionLanguage(const QString &lang)
 
 static bool isSpecial(const QTextCharFormat &charFormat)
 {
-    return charFormat.isFrameFormat() || charFormat.isImageFormat()
-           || charFormat.isListFormat() || charFormat.isTableFormat() || charFormat.isTableCellFormat();
+    return charFormat.isFrameFormat() || charFormat.isImageFormat() || charFormat.isListFormat() || charFormat.isTableFormat()
+        || charFormat.isTableCellFormat();
 }
 
 bool RichTextComposerNg::processModifyText(QKeyEvent *e)
@@ -119,50 +118,51 @@ bool RichTextComposerNg::processModifyText(QKeyEvent *e)
     return false;
 }
 
-void RichTextComposerNgPrivate::fixHtmlFontSize(QString &cleanHtml)
+void RichTextComposerNgPrivate::fixHtmlFontSize(QString &cleanHtml) const
 {
-    static const QString FONTSTYLEREGEX = QStringLiteral("<span style=\".*font-size:(.*)pt;.*</span>");
-    QRegExp styleRegex(FONTSTYLEREGEX);
-    styleRegex.setMinimal(true);
+    // non-greedy matching
+    static const QRegularExpression styleRegex(QStringLiteral("<span style=\".*?font-size:(.*?)pt;.*?</span>"));
 
-    int offset = styleRegex.indexIn(cleanHtml, 0);
-    while (offset != -1) {
-        // replace all the matching text with the new line text
+    QRegularExpressionMatch rmatch;
+    int offset = 0;
+    while (cleanHtml.indexOf(styleRegex, offset, &rmatch) != -1) {
+        QString replacement;
         bool ok = false;
-        const QString fontSizeStr = styleRegex.cap(1);
-        const int ptValue = fontSizeStr.toInt(&ok);
+        const double ptValue = rmatch.captured(1).toDouble(&ok);
         if (ok) {
-            double emValue = static_cast<double>(ptValue) / 12;
-            const QString emValueStr = QString::number(emValue, 'g', 2);
-            cleanHtml.replace(styleRegex.pos(1), QString(fontSizeStr + QLatin1String("px")).length(), emValueStr + QLatin1String("em"));
+            const double emValue = ptValue / 12;
+            replacement = QString::number(emValue, 'g', 2);
+            const int capLen = rmatch.capturedLength(1);
+            cleanHtml.replace(rmatch.capturedStart(1), capLen + 2 /* QLatin1String("pt").size() */, replacement + QLatin1String("em"));
+            // advance the offset to just after the last replace
+            offset = rmatch.capturedEnd(0) - capLen + replacement.size();
+        } else {
+            // a match was found but the toDouble call failed, advance the offset to just after
+            // the entire match
+            offset = rmatch.capturedEnd(0);
         }
-        // advance the search offset to just beyond the last replace
-        offset += styleRegex.matchedLength();
-        // find the next occurrence
-        offset = styleRegex.indexIn(cleanHtml, offset);
     }
 }
 
 MessageComposer::PluginEditorConvertTextInterface::ConvertTextStatus RichTextComposerNg::convertPlainText(MessageComposer::TextPart *textPart)
 {
-    Q_UNUSED(textPart);
+    Q_UNUSED(textPart)
     return MessageComposer::PluginEditorConvertTextInterface::ConvertTextStatus::NotConverted;
 }
 
 void RichTextComposerNg::fillComposerTextPart(MessageComposer::TextPart *textPart)
 {
-    const bool wasConverted
-        = convertPlainText(textPart) == MessageComposer::PluginEditorConvertTextInterface::ConvertTextStatus::Converted;
+    const bool wasConverted = convertPlainText(textPart) == MessageComposer::PluginEditorConvertTextInterface::ConvertTextStatus::Converted;
     if (composerControler()->isFormattingUsed()) {
         if (!wasConverted) {
             if (MessageComposer::MessageComposerSettings::self()->improvePlainTextOfHtmlMessage()) {
-                KPIMTextEdit::PlainTextMarkupBuilder *pb = new KPIMTextEdit::PlainTextMarkupBuilder();
+                auto pb = new KPIMTextEdit::PlainTextMarkupBuilder();
 
-                KPIMTextEdit::MarkupDirector *pmd = new KPIMTextEdit::MarkupDirector(pb);
+                auto pmd = new KPIMTextEdit::MarkupDirector(pb);
                 pmd->processDocument(document());
                 const QString plainText = pb->getResult();
                 textPart->setCleanPlainText(composerControler()->toCleanPlainText(plainText));
-                QTextDocument *doc = new QTextDocument(plainText);
+                auto doc = new QTextDocument(plainText);
                 doc->adjustSize();
 
                 textPart->setWrappedPlainText(composerControler()->toWrappedPlainText(doc));
@@ -183,16 +183,19 @@ void RichTextComposerNg::fillComposerTextPart(MessageComposer::TextPart *textPar
     textPart->setWordWrappingEnabled(lineWrapMode() == QTextEdit::FixedColumnWidth);
     if (composerControler()->isFormattingUsed() && !wasConverted) {
 #ifdef USE_TEXTHTML_BUILDER
-        KPIMTextEdit::TextHTMLBuilder *pb = new KPIMTextEdit::TextHTMLBuilder();
+        auto pb = new KPIMTextEdit::TextHTMLBuilder();
 
-        KPIMTextEdit::MarkupDirector *pmd = new KPIMTextEdit::MarkupDirector(pb);
+        auto pmd = new KPIMTextEdit::MarkupDirector(pb);
         pmd->processDocument(document());
-        QString cleanHtml = QStringLiteral("<html>\n<head>\n<meta http-equiv=\"content-type\" content=\"text/html; charset=UTF-8\">\n</head>\n<body>%1</body>\n</html>").arg(pb->getResult());
+        QString cleanHtml =
+            QStringLiteral("<html>\n<head>\n<meta http-equiv=\"content-type\" content=\"text/html; charset=UTF-8\">\n</head>\n<body>%1</body>\n</html>")
+                .arg(pb->getResult());
         delete pmd;
         delete pb;
         d->fixHtmlFontSize(cleanHtml);
         textPart->setCleanHtml(cleanHtml);
-        //qDebug() << " cleanHtml  grantlee builder" << cleanHtml;
+        // qDebug() << " cleanHtml  grantlee builder" << cleanHtml;
+        // qDebug() << " d->toCleanHtml() " << d->toCleanHtml();
 #else
         QString cleanHtml = d->toCleanHtml();
         d->fixHtmlFontSize(cleanHtml);
@@ -213,39 +216,24 @@ QString RichTextComposerNgPrivate::toCleanHtml() const
 
     // Qt inserts various style properties based on the current mode of the editor (underline,
     // bold, etc), but only empty paragraphs *also* have qt-paragraph-type set to 'empty'.
-    static const QString EMPTYLINEREGEX = QStringLiteral(
-        "<p style=\"-qt-paragraph-type:empty;(.*)</p>");
+    // Minimal/non-greedy matching
+    static const QString EMPTYLINEREGEX = QStringLiteral("<p style=\"-qt-paragraph-type:empty;(?:.*?)</p>");
 
-    static const QString OLLISTPATTERNQT = QStringLiteral(
-        "<ol style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px;");
+    static const QString OLLISTPATTERNQT = QStringLiteral("<ol style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px;");
 
-    static const QString ULLISTPATTERNQT = QStringLiteral(
-        "<ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px;");
+    static const QString ULLISTPATTERNQT = QStringLiteral("<ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px;");
 
-    static const QString ORDEREDLISTHTML = QStringLiteral(
-        "<ol style=\"margin-top: 0px; margin-bottom: 0px;");
+    static const QString ORDEREDLISTHTML = QStringLiteral("<ol style=\"margin-top: 0px; margin-bottom: 0px;");
 
-    static const QString UNORDEREDLISTHTML = QStringLiteral(
-        "<ul style=\"margin-top: 0px; margin-bottom: 0px;");
+    static const QString UNORDEREDLISTHTML = QStringLiteral("<ul style=\"margin-top: 0px; margin-bottom: 0px;");
 
     // fix 1 - empty lines should show as empty lines - MS Outlook treats margin-top:0px; as
     // a non-existing line.
     // Although we can simply remove the margin-top style property, we still get unwanted results
     // if you have three or more empty lines. It's best to replace empty <p> elements with <p>&nbsp;</p>.
 
-    QRegExp emptyLineFinder(EMPTYLINEREGEX);
-    emptyLineFinder.setMinimal(true);
-
-    // find the first occurrence
-    int offset = emptyLineFinder.indexIn(result, 0);
-    while (offset != -1) {
-        // replace all the matching text with the new line text
-        result.replace(offset, emptyLineFinder.matchedLength(), EMPTYLINEHTML);
-        // advance the search offset to just beyond the last replace
-        offset += EMPTYLINEHTML.length();
-        // find the next occurrence
-        offset = emptyLineFinder.indexIn(result, offset);
-    }
+    // Replace all the matching text with the new line text
+    result.replace(QRegularExpression(EMPTYLINEREGEX), EMPTYLINEHTML);
 
     // fix 2a - ordered lists - MS Outlook treats margin-left:0px; as
     // a non-existing number; e.g: "1. First item" turns into "First Item"
@@ -265,7 +253,11 @@ static bool isCursorAtEndOfLine(const QTextCursor &cursor)
     return !testCursor.hasSelection();
 }
 
-static void insertSignatureHelper(const QString &signature, RichTextComposerNg *textEdit, KIdentityManagement::Signature::Placement placement, bool isHtml, bool addNewlines)
+static void insertSignatureHelper(const QString &signature,
+                                  RichTextComposerNg *textEdit,
+                                  KIdentityManagement::Signature::Placement placement,
+                                  bool isHtml,
+                                  bool addNewlines)
 {
     if (!signature.isEmpty()) {
         // Save the modified state of the document, as inserting a signature
@@ -348,7 +340,9 @@ static void insertSignatureHelper(const QString &signature, RichTextComposerNg *
     }
 }
 
-void RichTextComposerNg::insertSignature(const KIdentityManagement::Signature &signature, KIdentityManagement::Signature::Placement placement, KIdentityManagement::Signature::AddedText addedText)
+void RichTextComposerNg::insertSignature(const KIdentityManagement::Signature &signature,
+                                         KIdentityManagement::Signature::Placement placement,
+                                         KIdentityManagement::Signature::AddedText addedText)
 {
     if (signature.isEnabledSignature()) {
         QString signatureStr;
@@ -358,9 +352,10 @@ void RichTextComposerNg::insertSignature(const KIdentityManagement::Signature &s
             signatureStr = signature.rawText();
         }
 
-        insertSignatureHelper(signatureStr, this, placement,
-                              (signature.isInlinedHtml()
-                               && signature.type() == KIdentityManagement::Signature::Inlined),
+        insertSignatureHelper(signatureStr,
+                              this,
+                              placement,
+                              (signature.isInlinedHtml() && signature.type() == KIdentityManagement::Signature::Inlined),
                               (addedText & KIdentityManagement::Signature::AddNewLines));
 
         // We added the text of the signature above, now it is time to add the images as well.
@@ -378,6 +373,11 @@ QString RichTextComposerNg::toCleanHtml() const
     return d->toCleanHtml();
 }
 
+void RichTextComposerNg::fixHtmlFontSize(QString &cleanHtml) const
+{
+    d->fixHtmlFontSize(cleanHtml);
+}
+
 void RichTextComposerNg::forceAutoCorrection(bool selectedText)
 {
     if (document()->isEmpty()) {
