@@ -1,35 +1,25 @@
 /*
-   Copyright (C) 2015-2019 Montel Laurent <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MESSAGECOMPOSER_RICHTEXTCOMPOSERNG_H
-#define MESSAGECOMPOSER_RICHTEXTCOMPOSERNG_H
+#pragma once
 
 #include "messagecomposer_export.h"
-#include <kpimtextedit/richtextcomposer.h>
-#include <MessageComposer/PluginEditorConvertTextInterface>
 #include <KIdentityManagement/Signature>
+#include <KPIMTextEdit/RichTextComposer>
+#include <MessageComposer/PluginEditorConvertTextInterface>
 
-namespace PimCommon {
+class RichTextComposerNgTest;
+
+namespace PimCommon
+{
 class AutoCorrection;
 }
 
-namespace MessageComposer {
+namespace MessageComposer
+{
 class TextPart;
 class RichTextComposerSignatures;
 class RichTextComposerNgPrivate;
@@ -51,7 +41,9 @@ public:
     void fillComposerTextPart(MessageComposer::TextPart *textPart);
     Q_REQUIRED_RESULT MessageComposer::RichTextComposerSignatures *composerSignature() const;
 
-    void insertSignature(const KIdentityManagement::Signature &signature, KIdentityManagement::Signature::Placement placement, KIdentityManagement::Signature::AddedText addedText);
+    void insertSignature(const KIdentityManagement::Signature &signature,
+                         KIdentityManagement::Signature::Placement placement,
+                         KIdentityManagement::Signature::AddedText addedText);
     Q_REQUIRED_RESULT QString toCleanHtml() const;
 
     void forceAutoCorrection(bool selectedText = false) override;
@@ -62,7 +54,9 @@ protected:
     bool processModifyText(QKeyEvent *event) override;
 
 private:
-    RichTextComposerNgPrivate *const d;
+    std::unique_ptr<RichTextComposerNgPrivate> const d;
+
+    friend class ::RichTextComposerNgTest; // for fixHtmlFontSize
+    void fixHtmlFontSize(QString &cleanHtml) const;
 };
 }
-#endif
