@@ -1,19 +1,21 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MESSAGECOMPOSER_RICHTEXTCOMPOSERSIGNATURES_H
-#define MESSAGECOMPOSER_RICHTEXTCOMPOSERSIGNATURES_H
+#pragma once
 
-#include <QObject>
 #include "messagecomposer_export.h"
-namespace KIdentityManagement {
+#include <QObject>
+#include <memory>
+namespace KIdentityManagement
+{
 class Signature;
 }
 
-namespace MessageComposer {
+namespace MessageComposer
+{
 class RichTextComposerNg;
 /**
  * @brief The RichTextComposerSignatures class
@@ -24,14 +26,14 @@ class MESSAGECOMPOSER_EXPORT RichTextComposerSignatures : public QObject
     Q_OBJECT
 public:
     explicit RichTextComposerSignatures(MessageComposer::RichTextComposerNg *composer, QObject *parent = nullptr);
-    ~RichTextComposerSignatures();
+    ~RichTextComposerSignatures() override;
 
     void cleanWhitespace(const KIdentityManagement::Signature &sig);
 
     Q_REQUIRED_RESULT bool replaceSignature(const KIdentityManagement::Signature &oldSig, const KIdentityManagement::Signature &newSig);
+
 private:
     class RichTextComposerSignaturesPrivate;
-    RichTextComposerSignaturesPrivate *const d;
+    std::unique_ptr<RichTextComposerSignaturesPrivate> const d;
 };
 }
-#endif
