@@ -11,25 +11,21 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MESSAGECOMPOSER_KLEO_KEYRESOLVER_H
-#define MESSAGECOMPOSER_KLEO_KEYRESOLVER_H
+#pragma once
 
 #include "messagecomposer_export.h"
-#include <Libkleo/KeyApprovalDialog>
 #include <Libkleo/Enum>
+#include <Libkleo/KeyApprovalDialog>
 
 #include <gpgme++/key.h>
 
 #include <vector>
 
-class QStringList;
+#include <QStringList>
 
-namespace Kleo {
-enum Result {
-    Failure = 0,
-    Ok = 1,
-    Canceled = 2
-};
+namespace Kleo
+{
+enum Result { Failure = 0, Ok = 1, Canceled = 2 };
 /**
      \short A class to resolve signing/encryption keys w.r.t. per-recipient preferences
 
@@ -93,7 +89,7 @@ enum Result {
 
      This will return a list of recipient-list/key-list pairs that
      each describe a copy of the (possibly signed) message to be
-     encrypted independantly.
+     encrypted independently.
 
      Note that it's only necessary to sign the message once for each
      message format, although it might be necessary to create more
@@ -103,10 +99,18 @@ enum Result {
      a copy of it's own to hide the other secondary recipients.
     */
 
-class KeyResolver
+class MESSAGECOMPOSER_EXPORT KeyResolver
 {
 public:
-    KeyResolver(bool encToSelf, bool showApproval, bool oppEncryption, unsigned int format, int encrKeyNearExpiryThresholdDays, int signKeyNearExpiryThresholdDays, int encrRootCertNearExpiryThresholdDays, int signRootCertNearExpiryThresholdDays, int encrChainCertNearExpiryThresholdDays,
+    KeyResolver(bool encToSelf,
+                bool showApproval,
+                bool oppEncryption,
+                unsigned int format,
+                int encrKeyNearExpiryThresholdDays,
+                int signKeyNearExpiryThresholdDays,
+                int encrRootCertNearExpiryThresholdDays,
+                int signRootCertNearExpiryThresholdDays,
+                int encrChainCertNearExpiryThresholdDays,
                 int signChainCertNearExpiryThresholdDays);
 
     ~KeyResolver();
@@ -202,7 +206,8 @@ public:
         {
         }
 
-        SplitInfo(const QStringList &r) : recipients(r)
+        explicit SplitInfo(const QStringList &r)
+            : recipients(r)
         {
         }
 
@@ -221,6 +226,14 @@ public:
     */
     Q_REQUIRED_RESULT std::vector<SplitInfo> encryptionItems(CryptoMessageFormat f) const;
 
+    std::vector<GpgME::Key> encryptToSelfKeysFor(CryptoMessageFormat f) const;
+
+    /** If Autocrypt keys are used to find valid PGP Keys
+     */
+    void setAutocryptEnabled(bool autocryptEnabled);
+
+    std::map<QByteArray, QString> useAutocrypt() const;
+
 private:
     void dump() const;
     std::vector<Item> getEncryptionItems(const QStringList &recipients);
@@ -233,20 +246,24 @@ private:
     Kleo::Result resolveEncryptionKeys(bool signingRequested, bool &finalySendUnencrypted);
     Kleo::Result resolveSigningKeysForEncryption();
     Kleo::Result resolveSigningKeysForSigningOnly();
-    Kleo::Result checkKeyNearExpiry(const GpgME::Key &key, const char *dontAskAgainName, bool mine, bool sign, bool ca = false, int recurse_limit = 100, const GpgME::Key &orig_key = GpgME::Key::null) const;
+    Kleo::Result checkKeyNearExpiry(const GpgME::Key &key,
+                                    const char *dontAskAgainName,
+                                    bool mine,
+                                    bool sign,
+                                    bool ca = false,
+                                    int recurse_limit = 100,
+                                    const GpgME::Key &orig_key = GpgME::Key::null) const;
     void collapseAllSplitInfos();
     void addToAllSplitInfos(const std::vector<GpgME::Key> &keys, unsigned int formats);
     void addKeys(const std::vector<Item> &items, CryptoMessageFormat f);
     void addKeys(const std::vector<Item> &items);
     QStringList allRecipients() const;
     std::vector<GpgME::Key> signingKeysFor(CryptoMessageFormat f) const;
-    std::vector<GpgME::Key> encryptToSelfKeysFor(CryptoMessageFormat f) const;
 
     std::vector<GpgME::Key> lookup(const QStringList &patterns, bool secret = false) const;
 
-    bool haveTrustedEncryptionKey(const QString &person) const;
-
-    std::vector<GpgME::Key> selectKeys(const QString &person, const QString &msg, const std::vector<GpgME::Key> &selectedKeys = std::vector<GpgME::Key>()) const;
+    std::vector<GpgME::Key>
+    selectKeys(const QString &person, const QString &msg, const std::vector<GpgME::Key> &selectedKeys = std::vector<GpgME::Key>()) const;
 
     QStringList keysForAddress(const QString &address) const;
     void setKeysForAddress(const QString &address, const QStringList &pgpKeyFingerprints, const QStringList &smimeCertFingerprints) const;
@@ -272,8 +289,8 @@ private:
     class SigningPreferenceCounter;
     friend class ::Kleo::KeyResolver::SigningPreferenceCounter;
 
-    struct Private;
-    Private *const d;
+    struct KeyResolverPrivate;
+    std::unique_ptr<KeyResolverPrivate> const d;
 
     bool mEncryptToSelf;
     const bool mShowApprovalDialog : 1;
@@ -289,4 +306,3 @@ private:
 };
 } // namespace Kleo
 
-#endif
