@@ -1,23 +1,23 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MESSAGECOMPOSER_FOLLOWUPREMINDERCREATEJOB_H
-#define MESSAGECOMPOSER_FOLLOWUPREMINDERCREATEJOB_H
+#pragma once
 
-#include <QObject>
-#include <QDate>
-#include <AkonadiCore/Item>
-#include <AkonadiCore/Collection>
+#include <Akonadi/Collection>
+#include <Akonadi/Item>
 #include <KJob>
+#include <QDate>
+#include <QObject>
 
 #include "messagecomposer_export.h"
 
 #include <memory>
 
-namespace MessageComposer {
+namespace MessageComposer
+{
 class FollowupReminderCreateJobPrivate;
 /**
  * @brief The FollowupReminderCreateJob class
@@ -54,4 +54,3 @@ private:
 };
 }
 
-#endif
