@@ -1,25 +1,24 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "followupreminderselectdatedialog.h"
 
-#include <KLocalizedString>
-#include <KSharedConfig>
-#include <KMessageBox>
 #include <KDateComboBox>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KSharedConfig>
 
-#include <AkonadiWidgets/CollectionComboBox>
+#include <Akonadi/CollectionComboBox>
 
 #include <KCalendarCore/Todo>
 
-#include <QVBoxLayout>
 #include <QDialogButtonBox>
-#include <QPushButton>
 #include <QFormLayout>
 #include <QLineEdit>
+#include <QVBoxLayout>
 using namespace MessageComposer;
 class MessageComposer::FollowUpReminderSelectDateDialogPrivate
 {
@@ -34,9 +33,9 @@ FollowUpReminderSelectDateDialog::FollowUpReminderSelectDateDialog(QWidget *pare
     , d(new MessageComposer::FollowUpReminderSelectDateDialogPrivate)
 {
     setWindowTitle(i18nc("@title:window", "Select Date"));
-    QVBoxLayout *topLayout = new QVBoxLayout(this);
+    auto topLayout = new QVBoxLayout(this);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     d->mOkButton = buttonBox->button(QDialogButtonBox::Ok);
     d->mOkButton->setObjectName(QStringLiteral("ok_button"));
     d->mOkButton->setDefault(true);
@@ -45,13 +44,13 @@ FollowUpReminderSelectDateDialog::FollowUpReminderSelectDateDialog(QWidget *pare
     connect(buttonBox, &QDialogButtonBox::rejected, this, &FollowUpReminderSelectDateDialog::reject);
     setModal(true);
 
-    QWidget *mainWidget = new QWidget(this);
+    auto mainWidget = new QWidget(this);
     topLayout->addWidget(mainWidget);
     topLayout->addWidget(buttonBox);
-    QVBoxLayout *mainLayout = new QVBoxLayout(mainWidget);
-    mainLayout->setContentsMargins(0, 0, 0, 0);
-    QFormLayout *formLayout = new QFormLayout;
-    formLayout->setContentsMargins(0, 0, 0, 0);
+    auto mainLayout = new QVBoxLayout(mainWidget);
+    mainLayout->setContentsMargins({});
+    auto formLayout = new QFormLayout;
+    formLayout->setContentsMargins({});
     mainLayout->addLayout(formLayout);
 
     d->mDateComboBox = new KDateComboBox;
@@ -80,9 +79,7 @@ FollowUpReminderSelectDateDialog::~FollowUpReminderSelectDateDialog() = default;
 
 void FollowUpReminderSelectDateDialog::updateOkButton()
 {
-    d->mOkButton->setEnabled(!d->mDateComboBox->lineEdit()->text().isEmpty()
-                             && d->mDateComboBox->date().isValid()
-                             && (d->mCollectionCombobox->count() > 0)
+    d->mOkButton->setEnabled(!d->mDateComboBox->lineEdit()->text().isEmpty() && d->mDateComboBox->date().isValid() && (d->mCollectionCombobox->count() > 0)
                              && d->mCollectionCombobox->currentCollection().isValid());
 }
 
