@@ -1,37 +1,24 @@
 /*
-   Copyright (C) 2017-2019 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MESSAGECOMPOSER_MESSAGEFACTORYREPLYJOB_H
-#define MESSAGECOMPOSER_MESSAGEFACTORYREPLYJOB_H
+#pragma once
 
-#include <QObject>
-#include <KMime/Message>
+#include <Akonadi/Collection>
 #include <KIdentityManagement/IdentityManager>
-#include <AkonadiCore/Collection>
+#include <KMime/Message>
+#include <QObject>
 
-namespace MessageComposer {
+namespace MessageComposer
+{
 class MessageFactoryReplyJob : public QObject
 {
     Q_OBJECT
 public:
     explicit MessageFactoryReplyJob(QObject *parent = nullptr);
-    ~MessageFactoryReplyJob();
+    ~MessageFactoryReplyJob() override;
 
     void start();
 
@@ -49,6 +36,8 @@ public:
 
     void setCollection(const Akonadi::Collection &collection);
 
+    void setReplyAsHtml(bool replyAsHtml);
+
 Q_SIGNALS:
     void replyDone(const KMime::Message::Ptr &msg, bool replyAll);
 
@@ -60,7 +49,7 @@ private:
     KMime::Message::Ptr mOrigMsg = nullptr;
     Akonadi::Collection mCollection;
     bool mReplyAll = false;
+    bool mReplyAsHtml = false;
     KIdentityManagement::IdentityManager *mIdentityManager = nullptr;
 };
 }
-#endif
