@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef IMAGESCALINGTEST_H
-#define IMAGESCALINGTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,7 +13,7 @@ class ImageScalingTest : public QObject
     Q_OBJECT
 public:
     explicit ImageScalingTest(QObject *parent = nullptr);
-    ~ImageScalingTest();
+    ~ImageScalingTest() override;
 private Q_SLOTS:
     void initTestCase();
     void shouldHaveDefaultValue();
@@ -25,4 +24,3 @@ private Q_SLOTS:
     void shouldHaveChangeMimetype();
 };
 
-#endif // IMAGESCALINGTEST_H
