@@ -1,14 +1,14 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef IMAGESCALINGUTILS_H
-#define IMAGESCALINGUTILS_H
+#pragma once
 #include <MessageCore/AttachmentPart>
 
-namespace MessageComposer {
+namespace MessageComposer
+{
 class Utils
 {
 public:
@@ -20,4 +20,3 @@ public:
 };
 }
 
-#endif // IMAGESCALINGUTILS_H
