@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef TEST_IMAGESCALING_GUI_H
-#define TEST_IMAGESCALING_GUI_H
+#pragma once
 
 #include <QWidget>
 
@@ -14,7 +13,6 @@ class ImageScalingTestWidget : public QWidget
     Q_OBJECT
 public:
     explicit ImageScalingTestWidget(QWidget *parent = nullptr);
-    ~ImageScalingTestWidget();
+    ~ImageScalingTestWidget() override;
 };
 
-#endif
