@@ -1,14 +1,14 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "attachmentvcardfromaddressbookjob.h"
-#include <KLocalizedString>
 #include <KContacts/Addressee>
 #include <KContacts/ContactGroup>
 #include <KContacts/VCardConverter>
+#include <KLocalizedString>
 #include <akonadi/contact/contactgroupexpandjob.h>
 
 using namespace MessageComposer;
@@ -30,10 +30,7 @@ AttachmentVcardFromAddressBookJob::AttachmentVcardFromAddressBookJob(const Akona
 {
 }
 
-AttachmentVcardFromAddressBookJob::~AttachmentVcardFromAddressBookJob()
-{
-    delete d;
-}
+AttachmentVcardFromAddressBookJob::~AttachmentVcardFromAddressBookJob() = default;
 
 void AttachmentVcardFromAddressBookJob::addAttachment(const QByteArray &data, const QString &attachmentName)
 {
@@ -53,7 +50,7 @@ void AttachmentVcardFromAddressBookJob::doStart()
 {
     if (d->mItem.isValid()) {
         if (d->mItem.hasPayload<KContacts::Addressee>()) {
-            const KContacts::Addressee contact = d->mItem.payload<KContacts::Addressee>();
+            const auto contact = d->mItem.payload<KContacts::Addressee>();
             if (contact.isEmpty()) {
                 invalidContact();
             } else {
@@ -61,15 +58,15 @@ void AttachmentVcardFromAddressBookJob::doStart()
                 const QString attachmentName = (contactRealName.isEmpty() ? QStringLiteral("vcard") : contactRealName) + QLatin1String(".vcf");
 
                 QByteArray data = d->mItem.payloadData();
-                //Workaround about broken kaddressbook fields.
+                // Workaround about broken kaddressbook fields.
                 KContacts::adaptIMAttributes(data);
                 addAttachment(data, attachmentName);
             }
         } else if (d->mItem.hasPayload<KContacts::ContactGroup>()) {
-            const KContacts::ContactGroup group = d->mItem.payload<KContacts::ContactGroup>();
+            const auto group = d->mItem.payload<KContacts::ContactGroup>();
             const QString groupName(group.name());
             const QString attachmentName = (groupName.isEmpty() ? QStringLiteral("vcard") : groupName) + QLatin1String(".vcf");
-            Akonadi::ContactGroupExpandJob *expandJob = new Akonadi::ContactGroupExpandJob(group, this);
+            auto expandJob = new Akonadi::ContactGroupExpandJob(group, this);
             expandJob->setProperty("groupName", attachmentName);
             connect(expandJob, &KJob::result, this, &AttachmentVcardFromAddressBookJob::slotExpandGroupResult);
             expandJob->start();
@@ -92,7 +89,7 @@ void AttachmentVcardFromAddressBookJob::invalidContact()
 
 void AttachmentVcardFromAddressBookJob::slotExpandGroupResult(KJob *job)
 {
-    Akonadi::ContactGroupExpandJob *expandJob = qobject_cast<Akonadi::ContactGroupExpandJob *>(job);
+    auto expandJob = qobject_cast<Akonadi::ContactGroupExpandJob *>(job);
     Q_ASSERT(expandJob);
 
     const QString attachmentName = expandJob->property("groupName").toString();
