@@ -3,8 +3,7 @@
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  */
-#ifndef INSERTTEXTFILEJOB_H
-#define INSERTTEXTFILEJOB_H
+#pragma once
 
 #include "messagecomposer_export.h"
 
@@ -13,11 +12,13 @@
 
 class QTextEdit;
 
-namespace KIO {
+namespace KIO
+{
 class Job;
 }
 
-namespace MessageComposer {
+namespace MessageComposer
+{
 class InsertTextFileJobPrivate;
 /**
  * A job that downloads a given URL, interprets the result as a text file with the
@@ -28,7 +29,7 @@ class MESSAGECOMPOSER_EXPORT InsertTextFileJob : public KJob
     Q_OBJECT
 
 public:
-    InsertTextFileJob(QTextEdit *editor, const QUrl &url);
+    explicit InsertTextFileJob(QTextEdit *editor, const QUrl &url);
     ~InsertTextFileJob() override;
 
     void setEncoding(const QString &encoding);
@@ -41,8 +42,7 @@ private Q_SLOTS:
     void slotFileData(KIO::Job *job, const QByteArray &data);
 
 private:
-    InsertTextFileJobPrivate *const d;
+    std::unique_ptr<InsertTextFileJobPrivate> const d;
 };
 }
 
-#endif
