@@ -1,21 +1,24 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "savecontactpreferencejob.h"
 
-#include <QInputDialog>
+#include <KJob>
 #include <KLocalizedString>
 
+#include <QInputDialog>
+
+#include <Akonadi/CollectionDialog>
 #include <Akonadi/Contact/ContactSearchJob>
-#include <AkonadiWidgets/CollectionDialog>
-#include <AkonadiCore/ItemCreateJob>
-#include <AkonadiCore/ItemModifyJob>
+#include <Akonadi/ItemCreateJob>
+#include <Akonadi/ItemModifyJob>
 
-#include <QPointer>
 #include "messagecomposer_debug.h"
+#include <QPointer>
+#include <kcontacts_version.h>
 
 using namespace MessageComposer;
 
@@ -32,7 +35,7 @@ SaveContactPreferenceJob::~SaveContactPreferenceJob()
 
 void SaveContactPreferenceJob::start()
 {
-    auto *job = new Akonadi::ContactSearchJob(this);
+    auto job = new Akonadi::ContactSearchJob(this);
     connect(job, &Akonadi::ContactSearchJob::result, this, &SaveContactPreferenceJob::slotSearchContact);
     job->setLimit(1);
     job->setQuery(Akonadi::ContactSearchJob::Email, mEmail);
@@ -41,21 +44,24 @@ void SaveContactPreferenceJob::start()
 
 void SaveContactPreferenceJob::slotSearchContact(KJob *job)
 {
-    auto *contactSearchJob = qobject_cast<Akonadi::ContactSearchJob *>(job);
+    auto contactSearchJob = qobject_cast<Akonadi::ContactSearchJob *>(job);
 
     const Akonadi::Item::List items = contactSearchJob->items();
 
     if (items.isEmpty()) {
         bool ok = true;
-        const QString fullName
-            = QInputDialog::getText(nullptr, i18n("Name Selection"), i18n("Which name shall the contact '%1' have in your address book?", mEmail), QLineEdit::Normal, QString(), &ok);
+        const QString fullName = QInputDialog::getText(nullptr,
+                                                       i18n("Name Selection"),
+                                                       i18n("Which name shall the contact '%1' have in your address book?", mEmail),
+                                                       QLineEdit::Normal,
+                                                       QString(),
+                                                       &ok);
         if (!ok) {
             deleteLater();
             return;
         }
 
-        QPointer<Akonadi::CollectionDialog> dlg
-            = new Akonadi::CollectionDialog(Akonadi::CollectionDialog::KeepTreeExpanded);
+        QPointer<Akonadi::CollectionDialog> dlg = new Akonadi::CollectionDialog(Akonadi::CollectionDialog::KeepTreeExpanded);
         dlg->setMimeTypeFilter(QStringList() << KContacts::Addressee::mimeType());
         dlg->setAccessRightsFilter(Akonadi::Collection::CanCreateItem);
         dlg->setDescription(i18n("Select the address book folder to store the new contact in:"));
@@ -70,32 +76,44 @@ void SaveContactPreferenceJob::slotSearchContact(KJob *job)
 
         KContacts::Addressee contact;
         contact.setNameFromString(fullName);
+#if KContacts_VERSION < QT_VERSION_CHECK(5, 88, 0)
         contact.insertEmail(mEmail, true);
+#else
+        KContacts::Email email(mEmail);
+        email.setPreferred(true);
+        contact.addEmail(email);
+#endif
         writeCustomContactProperties(contact, mPref);
 
         Akonadi::Item item(KContacts::Addressee::mimeType());
         item.setPayload<KContacts::Addressee>(contact);
 
-        auto *job = new Akonadi::ItemCreateJob(item, targetCollection);
-        connect(job, &Akonadi::ContactSearchJob::result, this, &SaveContactPreferenceJob::slotModifyCreateItem);
+        auto createJob = new Akonadi::ItemCreateJob(item, targetCollection);
+        connect(createJob, &Akonadi::ContactSearchJob::result, this, &SaveContactPreferenceJob::slotModifyCreateItem);
     } else {
         Akonadi::Item item = items.first();
 
-        KContacts::Addressee contact = item.payload<KContacts::Addressee>();
+        auto contact = item.payload<KContacts::Addressee>();
         writeCustomContactProperties(contact, mPref);
 
         item.setPayload<KContacts::Addressee>(contact);
 
-        auto *job = new Akonadi::ItemModifyJob(item);
-        connect(job, &Akonadi::ContactSearchJob::result, this, &SaveContactPreferenceJob::slotModifyCreateItem);
+        auto itemModifyJob = new Akonadi::ItemModifyJob(item);
+        connect(itemModifyJob, &Akonadi::ContactSearchJob::result, this, &SaveContactPreferenceJob::slotModifyCreateItem);
     }
 }
 
 void SaveContactPreferenceJob::writeCustomContactProperties(KContacts::Addressee &contact, const Kleo::KeyResolver::ContactPreferences &pref) const
 {
-    contact.insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("CRYPTOENCRYPTPREF"), QLatin1String(Kleo::encryptionPreferenceToString(pref.encryptionPreference)));
-    contact.insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("CRYPTOSIGNPREF"), QLatin1String(Kleo::signingPreferenceToString(pref.signingPreference)));
-    contact.insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("CRYPTOPROTOPREF"), QLatin1String(cryptoMessageFormatToString(pref.cryptoMessageFormat)));
+    contact.insertCustom(QStringLiteral("KADDRESSBOOK"),
+                         QStringLiteral("CRYPTOENCRYPTPREF"),
+                         QLatin1String(Kleo::encryptionPreferenceToString(pref.encryptionPreference)));
+    contact.insertCustom(QStringLiteral("KADDRESSBOOK"),
+                         QStringLiteral("CRYPTOSIGNPREF"),
+                         QLatin1String(Kleo::signingPreferenceToString(pref.signingPreference)));
+    contact.insertCustom(QStringLiteral("KADDRESSBOOK"),
+                         QStringLiteral("CRYPTOPROTOPREF"),
+                         QLatin1String(cryptoMessageFormatToString(pref.cryptoMessageFormat)));
     contact.insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("OPENPGPFP"), pref.pgpKeyFingerprints.join(QLatin1Char(',')));
     contact.insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("SMIMEFP"), pref.smimeCertFingerprints.join(QLatin1Char(',')));
 }
