@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef PLUGINEDITORTEST_H
-#define PLUGINEDITORTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,9 +13,8 @@ class PluginEditorTest : public QObject
     Q_OBJECT
 public:
     explicit PluginEditorTest(QObject *parent = nullptr);
-    ~PluginEditorTest() = default;
+    ~PluginEditorTest() override = default;
 private Q_SLOTS:
     void shouldHaveDefaultValues();
 };
 
-#endif // PLUGINEDITORTEST_H
