@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -45,6 +45,10 @@ QString PluginActionType::actionXmlExtension(PluginActionType::Type type)
         return QStringLiteral("_toolbar_actions");
     case MessageComposer::PluginActionType::Options:
         return QStringLiteral("_plugins_options");
+    case MessageComposer::PluginActionType::Insert:
+        return QStringLiteral("_plugins_insert");
+    case MessageComposer::PluginActionType::View:
+        return QStringLiteral("_plugins_view");
     case MessageComposer::PluginActionType::None:
         return QString();
     }
