@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -24,10 +24,7 @@ PluginEditor::PluginEditor(QObject *parent)
 {
 }
 
-PluginEditor::~PluginEditor()
-{
-    delete d;
-}
+PluginEditor::~PluginEditor() = default;
 
 void PluginEditor::setOrder(int order)
 {
