@@ -1,11 +1,11 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include "plugincomposerinterface.h"
 #include "plugineditorinterface.h"
+#include "plugincomposerinterface.h"
 
 using namespace MessageComposer;
 
@@ -21,6 +21,7 @@ public:
         delete mComposerInterface;
     }
 
+    PluginEditorInterface::ApplyOnFieldTypes mApplyOnFieldTypes = {PluginEditorInterface::ApplyOnFieldType::All};
     PluginActionType mActionType;
     QWidget *mParentWidget = nullptr;
     KPIMTextEdit::RichTextEditor *mRichTextEditor = nullptr;
@@ -36,10 +37,7 @@ PluginEditorInterface::PluginEditorInterface(QObject *parent)
 {
 }
 
-PluginEditorInterface::~PluginEditorInterface()
-{
-    delete d;
-}
+PluginEditorInterface::~PluginEditorInterface() = default;
 
 void PluginEditorInterface::setActionType(PluginActionType type)
 {
@@ -93,6 +91,16 @@ void PluginEditorInterface::setComposerInterface(PluginComposerInterface *w)
 
 bool PluginEditorInterface::processProcessKeyEvent(QKeyEvent *event)
 {
-    Q_UNUSED(event);
+    Q_UNUSED(event)
     return false;
 }
+
+PluginEditorInterface::ApplyOnFieldTypes PluginEditorInterface::applyOnFieldTypes() const
+{
+    return d->mApplyOnFieldTypes;
+}
+
+void PluginEditorInterface::setApplyOnFieldTypes(PluginEditorInterface::ApplyOnFieldTypes types)
+{
+    d->mApplyOnFieldTypes = types;
+}
