@@ -1,16 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef PLUGINEDITORCONVERTTEXTMANAGER_H
-#define PLUGINEDITORCONVERTTEXTMANAGER_H
+#pragma once
 
-#include <QObject>
 #include "messagecomposer_export.h"
 #include <PimCommon/PluginUtil>
-namespace MessageComposer {
+#include <QObject>
+namespace MessageComposer
+{
 class PluginEditorConvertTextManagerPrivate;
 class PluginEditorConvertText;
 /**
@@ -22,7 +22,7 @@ class MESSAGECOMPOSER_EXPORT PluginEditorConvertTextManager : public QObject
     Q_OBJECT
 public:
     explicit PluginEditorConvertTextManager(QObject *parent = nullptr);
-    ~PluginEditorConvertTextManager();
+    ~PluginEditorConvertTextManager() override;
 
     static PluginEditorConvertTextManager *self();
 
@@ -32,8 +32,8 @@ public:
     Q_REQUIRED_RESULT QString configPrefixSettingKey() const;
     Q_REQUIRED_RESULT QVector<PimCommon::PluginUtilData> pluginsDataList() const;
     Q_REQUIRED_RESULT PluginEditorConvertText *pluginFromIdentifier(const QString &id);
+
 private:
-    PluginEditorConvertTextManagerPrivate *const d;
+    std::unique_ptr<PluginEditorConvertTextManagerPrivate> const d;
 };
 }
-#endif // PLUGINEDITORCONVERTTEXTMANAGER_H
