@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -20,10 +20,7 @@ PluginEditorGrammarCustomToolsViewInterface::PluginEditorGrammarCustomToolsViewI
 {
 }
 
-PluginEditorGrammarCustomToolsViewInterface::~PluginEditorGrammarCustomToolsViewInterface()
-{
-    delete d;
-}
+PluginEditorGrammarCustomToolsViewInterface::~PluginEditorGrammarCustomToolsViewInterface() = default;
 
 void PluginEditorGrammarCustomToolsViewInterface::setParentWidget(QWidget *parent)
 {
@@ -109,7 +106,7 @@ void PluginGrammarAction::setInfoUrls(const QStringList &urls)
     mInfoUrls = urls;
 }
 
-QDebug operator <<(QDebug d, const PluginGrammarAction &t)
+QDebug operator<<(QDebug d, const PluginGrammarAction &t)
 {
     d << "start " << t.start();
     d << "length " << t.length();
