@@ -1,18 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "plugineditorgrammarmanager.h"
-#include <PimCommon/CustomToolsPlugin>
 #include "messagecomposer_debug.h"
 #include "plugineditorgrammarcustomtoolsviewinterface.h"
-#include <QFileInfo>
-#include <QSet>
-#include <KPluginLoader>
-#include <KPluginMetaData>
 #include <KPluginFactory>
+#include <KPluginMetaData>
+#include <PimCommon/CustomToolsPlugin>
+#include <QFileInfo>
 
 using namespace MessageComposer;
 
@@ -26,12 +24,14 @@ public:
     PimCommon::PluginUtilData pluginData;
     QString metaDataFileNameBaseName;
     QString metaDataFileName;
+    KPluginMetaData data;
     PimCommon::CustomToolsPlugin *plugin = nullptr;
     bool isEnabled = true;
 };
 
-namespace {
-QString pluginVersion()
+namespace
+{
+QString pluginEditorGrammarVersion()
 {
     return QStringLiteral("1.0");
 }
@@ -54,6 +54,7 @@ public:
     Q_REQUIRED_RESULT QString configGroupName() const;
     Q_REQUIRED_RESULT QVector<PimCommon::PluginUtilData> pluginsDataList() const;
     PimCommon::CustomToolsPlugin *pluginFromIdentifier(const QString &id);
+
 private:
     QVector<PimCommon::PluginUtilData> mPluginDataList;
     PluginEditorGrammarManager *const q;
@@ -76,32 +77,28 @@ QVector<PimCommon::PluginUtilData> PluginEditorGrammarManagerPrivate::pluginsDat
 
 void PluginEditorGrammarManagerPrivate::initializePlugins()
 {
-    const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("kmail/plugineditorgrammar"));
+    const QVector<KPluginMetaData> plugins = KPluginMetaData::findPlugins(QStringLiteral("kmail/plugineditorgrammar"));
 
     const QPair<QStringList, QStringList> pair = PimCommon::PluginUtil::loadPluginSetting(configGroupName(), configPrefixSettingKey());
 
     QVectorIterator<KPluginMetaData> i(plugins);
     i.toBack();
-    QSet<QString> unique;
     while (i.hasPrevious()) {
         PluginEditorGrammarInfo info;
         const KPluginMetaData data = i.previous();
 
-        //1) get plugin data => name/description etc.
+        // 1) get plugin data => name/description etc.
         info.pluginData = PimCommon::PluginUtil::createPluginMetaData(data);
-        //2) look at if plugin is activated
-        const bool isPluginActivated = PimCommon::PluginUtil::isPluginActivated(pair.first, pair.second, info.pluginData.mEnableByDefault, info.pluginData.mIdentifier);
+        // 2) look at if plugin is activated
+        const bool isPluginActivated =
+            PimCommon::PluginUtil::isPluginActivated(pair.first, pair.second, info.pluginData.mEnableByDefault, info.pluginData.mIdentifier);
         info.isEnabled = isPluginActivated;
         info.metaDataFileNameBaseName = QFileInfo(data.fileName()).baseName();
         info.metaDataFileName = data.fileName();
-        if (pluginVersion() == data.version()) {
-            // only load plugins once, even if found multiple times!
-            if (unique.contains(info.metaDataFileNameBaseName)) {
-                continue;
-            }
+        info.data = data;
+        if (pluginEditorGrammarVersion() == data.version()) {
             info.plugin = nullptr;
             mPluginList.push_back(info);
-            unique.insert(info.metaDataFileNameBaseName);
         } else {
             qCWarning(MESSAGECOMPOSER_LOG) << "Plugin " << data.name() << " doesn't have correction plugin version. It will not be loaded.";
         }
@@ -114,9 +111,8 @@ void PluginEditorGrammarManagerPrivate::initializePlugins()
 
 void PluginEditorGrammarManagerPrivate::loadPlugin(PluginEditorGrammarInfo *item)
 {
-    KPluginLoader pluginLoader(item->metaDataFileName);
-    if (pluginLoader.factory()) {
-        item->plugin = pluginLoader.factory()->create<PimCommon::CustomToolsPlugin>(q, QVariantList() << item->metaDataFileNameBaseName);
+    if (auto plugin = KPluginFactory::instantiatePlugin<PimCommon::CustomToolsPlugin>(item->data, q, QVariantList() << item->metaDataFileName).plugin) {
+        item->plugin = plugin;
         item->plugin->setIsEnabled(item->isEnabled);
         item->pluginData.mHasConfigureDialog = item->plugin->hasConfigureDialog();
         mPluginDataList.append(item->pluginData);
@@ -153,10 +149,7 @@ PluginEditorGrammarManager::PluginEditorGrammarManager(QObject *parent)
     qRegisterMetaType<MessageComposer::PluginGrammarAction>();
 }
 
-PluginEditorGrammarManager::~PluginEditorGrammarManager()
-{
-    delete d;
-}
+PluginEditorGrammarManager::~PluginEditorGrammarManager() = default;
 
 PluginEditorGrammarManager *PluginEditorGrammarManager::self()
 {
