@@ -1,16 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef PLUGINEDITORINITMANAGER_H
-#define PLUGINEDITORINITMANAGER_H
+#pragma once
 
-#include <QObject>
 #include "messagecomposer_export.h"
 #include <PimCommon/PluginUtil>
-namespace MessageComposer {
+#include <QObject>
+#include <memory>
+namespace MessageComposer
+{
 class PluginEditorInitManagerPrivate;
 class PluginEditorInit;
 /**
@@ -22,7 +23,7 @@ class MESSAGECOMPOSER_EXPORT PluginEditorInitManager : public QObject
     Q_OBJECT
 public:
     explicit PluginEditorInitManager(QObject *parent = nullptr);
-    ~PluginEditorInitManager();
+    ~PluginEditorInitManager() override;
 
     static PluginEditorInitManager *self();
 
@@ -32,8 +33,8 @@ public:
     Q_REQUIRED_RESULT QString configPrefixSettingKey() const;
     Q_REQUIRED_RESULT QVector<PimCommon::PluginUtilData> pluginsDataList() const;
     Q_REQUIRED_RESULT PluginEditorInit *pluginFromIdentifier(const QString &id);
+
 private:
-    PluginEditorInitManagerPrivate *const d;
+    std::unique_ptr<PluginEditorInitManagerPrivate> const d;
 };
 }
-#endif // PLUGINEDITORINITMANAGER_H
