@@ -5,8 +5,7 @@
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef MESSAGECOMPOSER_DISTRIBUTIONLISTDIALOG_H
-#define MESSAGECOMPOSER_DISTRIBUTIONLISTDIALOG_H
+#pragma once
 
 #include <MessageComposer/Recipient>
 #include <QDialog>
@@ -16,13 +15,14 @@ class QLineEdit;
 class QTreeWidget;
 class QPushButton;
 
-namespace MessageComposer {
+namespace MessageComposer
+{
 class DistributionListDialog : public QDialog
 {
     Q_OBJECT
 public:
     explicit DistributionListDialog(QWidget *parent);
-    ~DistributionListDialog();
+    ~DistributionListDialog() override;
     void setRecipients(const Recipient::List &);
 
 public Q_SLOTS:
@@ -45,4 +45,3 @@ private:
 };
 }
 
-#endif
