@@ -9,11 +9,11 @@
 
 #include <MessageComposer/Recipient>
 
+#include <KContacts/Addressee>
 #include <QDialog>
-#include <kcontacts/addressee.h>
 
 class QPushButton;
-
+class QLabel;
 namespace PimCommon
 {
 class LdapSearchDialog;
@@ -60,7 +60,8 @@ protected Q_SLOTS:
     void slotSelectionChanged();
 
 private:
-    Akonadi::RecipientsPickerWidget *mView = nullptr;
+    void updateLabel(int nbSelected);
+    Akonadi::RecipientsPickerWidget *const mView;
 
     PimCommon::LdapSearchDialog *mLdapSearchDialog = nullptr;
 
@@ -69,6 +70,7 @@ private:
     QPushButton *mUser3Button = nullptr;
     QPushButton *mUser2Button = nullptr;
     QPushButton *mUser1Button = nullptr;
+    QLabel *const mSelectedLabel = nullptr;
 };
 }
 
