@@ -9,22 +9,21 @@
 
 #include "messagecomposer_debug.h"
 
+#include "MessageComposer/Util"
 #include "helper/messagehelper.h"
 #include "settings/messagecomposersettings.h"
-#include "MessageComposer/Util"
 #include "utils/util_p.h"
 
-#include <kmime/kmime_message.h>
 #include <Libkdepim/ProgressManager>
 
-#include <MailTransportAkonadi/DispatcherInterface>
-#include <MailTransportAkonadi/MessageQueueJob>
-#include <MailTransport/Transport>
-#include <MailTransport/TransportManager>
-#include <MessageCore/StringUtil>
+#include <KEmailAddress>
 #include <KIdentityManagement/Identity>
 #include <KIdentityManagement/IdentityManager>
-
+#include <MailTransport/Transport>
+#include <MailTransport/TransportManager>
+#include <MailTransportAkonadi/DispatcherInterface>
+#include <MailTransportAkonadi/MessageQueueJob>
+#include <MessageCore/StringUtil>
 using namespace KMime::Types;
 using namespace KPIM;
 using namespace MailTransport;
@@ -78,10 +77,7 @@ AkonadiSender::AkonadiSender(QObject *parent)
 {
 }
 
-AkonadiSender::~AkonadiSender()
-{
-    delete d;
-}
+AkonadiSender::~AkonadiSender() = default;
 
 bool AkonadiSender::doSend(const KMime::Message::Ptr &aMsg, short sendNow)
 {
@@ -105,7 +101,7 @@ bool AkonadiSender::doSendQueued(int customTransportId)
 
     d->mCustomTransportId = customTransportId;
 
-    DispatcherInterface *dispatcher = new DispatcherInterface();
+    auto dispatcher = new DispatcherInterface();
     if (d->mCustomTransportId == -1) {
         dispatcher->dispatchManually();
     } else {
@@ -120,38 +116,31 @@ void AkonadiSender::sendOrQueueMessage(const KMime::Message::Ptr &message, Messa
     Q_ASSERT(message);
     qCDebug(MESSAGECOMPOSER_LOG) << "KMime::Message: \n[\n" << message->encodedContent().left(1000) << "\n]\n";
 
-    MessageQueueJob *qjob = new MessageQueueJob(this);
+    auto qjob = new MessageQueueJob(this);
     if (message->hasHeader("X-KMail-FccDisabled")) {
         qjob->sentBehaviourAttribute().setSentBehaviour(MailTransport::SentBehaviourAttribute::Delete);
     } else if (auto hrd = message->headerByType("X-KMail-Fcc")) {
-        qjob->sentBehaviourAttribute().setSentBehaviour(
-            SentBehaviourAttribute::MoveToCollection);
+        qjob->sentBehaviourAttribute().setSentBehaviour(SentBehaviourAttribute::MoveToCollection);
         const int sentCollectionId = hrd->asUnicodeString().toInt();
-        qjob->sentBehaviourAttribute().setMoveToCollection(
-            Akonadi::Collection(sentCollectionId));
+        qjob->sentBehaviourAttribute().setMoveToCollection(Akonadi::Collection(sentCollectionId));
     } else if (auto hrd = message->headerByType("X-KMail-Identity")) {
         KIdentityManagement::IdentityManager *im = KIdentityManagement::IdentityManager::self();
         const QString identityStrId = hrd->asUnicodeString();
         const KIdentityManagement::Identity id = im->modifyIdentityForUoid(identityStrId.toUInt());
         const QString fccId = id.fcc();
-        qjob->sentBehaviourAttribute().setSentBehaviour(
-            SentBehaviourAttribute::MoveToCollection);
+        qjob->sentBehaviourAttribute().setSentBehaviour(SentBehaviourAttribute::MoveToCollection);
         const int sentCollectionId = fccId.toInt();
-        qjob->sentBehaviourAttribute().setMoveToCollection(
-            Akonadi::Collection(sentCollectionId));
+        qjob->sentBehaviourAttribute().setMoveToCollection(Akonadi::Collection(sentCollectionId));
     } else if (auto hrd = message->headerByType("X-KMail-Identity-Name")) {
         KIdentityManagement::IdentityManager *im = KIdentityManagement::IdentityManager::self();
         const QString identityStrName = hrd->asUnicodeString();
         const KIdentityManagement::Identity id = im->modifyIdentityForName(identityStrName);
         const QString fccId = id.fcc();
-        qjob->sentBehaviourAttribute().setSentBehaviour(
-            SentBehaviourAttribute::MoveToCollection);
+        qjob->sentBehaviourAttribute().setSentBehaviour(SentBehaviourAttribute::MoveToCollection);
         const int sentCollectionId = fccId.toInt();
-        qjob->sentBehaviourAttribute().setMoveToCollection(
-            Akonadi::Collection(sentCollectionId));
+        qjob->sentBehaviourAttribute().setMoveToCollection(Akonadi::Collection(sentCollectionId));
     } else {
-        qjob->sentBehaviourAttribute().setSentBehaviour(
-            MailTransport::SentBehaviourAttribute::MoveToDefaultSentCollection);
+        qjob->sentBehaviourAttribute().setSentBehaviour(MailTransport::SentBehaviourAttribute::MoveToDefaultSentCollection);
     }
     qjob->setMessage(message);
 
@@ -167,9 +156,12 @@ void AkonadiSender::sendOrQueueMessage(const KMime::Message::Ptr &message, Messa
     const Transport *transport = TransportManager::self()->transportById(transportId);
     if (!transport) {
         qCDebug(MESSAGECOMPOSER_LOG) << " No transport defined. Need to create it";
+        qjob->deleteLater();
         return;
     }
+
     if ((method == MessageComposer::MessageSender::SendImmediate) && !MessageComposer::Util::sendMailDispatcherIsOnline()) {
+        qjob->deleteLater();
         return;
     }
 
@@ -182,7 +174,9 @@ void AkonadiSender::sendOrQueueMessage(const KMime::Message::Ptr &message, Messa
     }
 
     // Get addresses.
-    QStringList to, cc, bcc;
+    QStringList to;
+    QStringList cc;
+    QStringList bcc;
     QString from;
     extractSenderToCCAndBcc(message, from, to, cc, bcc);
     qjob->addressAttribute().setFrom(from);
@@ -190,6 +184,19 @@ void AkonadiSender::sendOrQueueMessage(const KMime::Message::Ptr &message, Messa
     qjob->addressAttribute().setCc(cc);
     qjob->addressAttribute().setBcc(bcc);
 
+    if (qjob->addressAttribute().to().isEmpty()) {
+        qCWarning(MESSAGECOMPOSER_LOG) << " Impossible to specify TO! It's a bug";
+        qjob->deleteLater();
+        return;
+    }
+
+    if (transport && transport->specifySenderOverwriteAddress()) {
+        qjob->addressAttribute().setFrom(
+            KEmailAddress::extractEmailAddress(KEmailAddress::normalizeAddressesAndEncodeIdn(transport->senderOverwriteAddress())));
+    } else {
+        qjob->addressAttribute().setFrom(KEmailAddress::extractEmailAddress(KEmailAddress::normalizeAddressesAndEncodeIdn(message->from()->asUnicodeString())));
+    }
+
     MessageComposer::Util::addSendReplyForwardAction(message, qjob);
 
     MessageCore::StringUtil::removePrivateHeaderFields(message, false);
