@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MESSAGECOMPOSER_SENDLATERJOB_H
-#define MESSAGECOMPOSER_SENDLATERJOB_H
+#pragma once
 
 #include <KJob>
 #include <QDBusPendingReply>
@@ -14,15 +13,13 @@
 
 class OrgFreedesktopAkonadiSendLaterAgentInterface;
 
-namespace MessageComposer {
+namespace MessageComposer
+{
 class MESSAGECOMPOSER_EXPORT SendLaterJob : public KJob
 {
     Q_OBJECT
 public:
-    enum Error {
-        AgentNotAvailable = KJob::UserDefinedError,
-        CallFailed
-    };
+    enum Error { AgentNotAvailable = KJob::UserDefinedError, CallFailed };
 
     explicit SendLaterJob(QObject *parent = nullptr);
 
@@ -34,4 +31,3 @@ protected:
 };
 }
 
-#endif
