@@ -1,17 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "sendlaterutil.h"
-#include "sendlaterutil_p.h"
 #include "sendlaterinterface.h"
+#include "sendlaterutil_p.h"
 
-#include <AkonadiCore/ServerManager>
+#include <Akonadi/ServerManager>
 
-#include <QDBusInterface>
-#include <servermanager.h>
+#include <Akonadi/ServerManager>
 
 using namespace MessageComposer;
 
