@@ -1,14 +1,14 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "convertvariablesjobtest.h"
-#include "snippet/convertsnippetvariablesjob.h"
-#include <QTest>
 #include "composer/composerviewbase.h"
 #include "composer/composerviewinterface.h"
+#include "snippet/convertsnippetvariablesjob.h"
+#include <QTest>
 QTEST_GUILESS_MAIN(ConvertVariablesJobTest)
 
 ConvertVariablesJobTest::ConvertVariablesJobTest(QObject *parent)
@@ -31,7 +31,7 @@ void ConvertVariablesJobTest::shouldCanStart()
     job.setText(QStringLiteral("bla"));
     QVERIFY(!job.canStart());
     MessageComposer::ComposerViewBase b;
-    MessageComposer::ComposerViewInterface *interface = new MessageComposer::ComposerViewInterface(&b);
+    auto interface = new MessageComposer::ComposerViewInterface(&b);
     job.setComposerViewInterface(interface);
     QVERIFY(job.canStart());
 }
@@ -41,12 +41,12 @@ void ConvertVariablesJobTest::shouldConvertVariables()
     QFETCH(QString, original);
     QFETCH(QString, expected);
     MessageComposer::ComposerViewBase b;
-    MessageComposer::ComposerViewInterface *interface = new MessageComposer::ComposerViewInterface(&b);
+    auto interface = new MessageComposer::ComposerViewInterface(&b);
     MessageComposer::ConvertSnippetVariablesJob job;
     job.setComposerViewInterface(interface);
     b.setSubject(QStringLiteral("Subject!!!!"));
     b.setFrom(QStringLiteral("from!!"));
-    //TOOD add CC/BCC/TO
+    // TODO add CC/BCC/TO
 
     job.setText(original);
     QCOMPARE(job.convertVariables(interface, original), expected);
@@ -59,5 +59,5 @@ void ConvertVariablesJobTest::shouldConvertVariables_data()
     QTest::newRow("empty") << QString() << QString();
     QTest::newRow("novariable") << QStringLiteral("bla bli blo") << QStringLiteral("bla bli blo");
     QTest::newRow("subject") << QStringLiteral("bla bli blo %FULLSUBJECT") << QStringLiteral("bla bli blo Subject!!!!");
-    //TODO add more autotests !
+    // TODO add more autotests !
 }
