@@ -1,17 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "convertsnippetvariablesjob.h"
-#include "messagecomposer_debug.h"
 #include "composer/composerviewinterface.h"
+#include "messagecomposer_debug.h"
 #include "snippet/convertsnippetvariablesutil.h"
-#include <TemplateParser/TemplatesUtil>
 #include <KEmailAddress>
-#include <QDate>
 #include <KMime/Types>
+#include <TemplateParser/TemplatesUtil>
 using namespace MessageComposer;
 ConvertSnippetVariablesJob::ConvertSnippetVariablesJob(QObject *parent)
     : QObject(parent)
@@ -135,6 +134,22 @@ QString ConvertSnippetVariablesJob::convertVariables(MessageComposer::ComposerVi
                     i += strlen("CCNAME");
                     const QString str = getNameFromEmail(composerView->cc());
                     result.append(str);
+                } else if (cmd.startsWith(QLatin1String("BCCADDR"))) {
+                    i += strlen("BCCADDR");
+                    const QString str = composerView->bcc();
+                    result.append(str);
+                } else if (cmd.startsWith(QLatin1String("BCCFNAME"))) {
+                    i += strlen("BCCFNAME");
+                    const QString str = getFirstNameFromEmail(composerView->bcc());
+                    result.append(str);
+                } else if (cmd.startsWith(QLatin1String("BCCLNAME"))) {
+                    i += strlen("BCCLNAME");
+                    const QString str = getLastNameFromEmail(composerView->bcc());
+                    result.append(str);
+                } else if (cmd.startsWith(QLatin1String("BCCNAME"))) {
+                    i += strlen("BCCNAME");
+                    const QString str = getNameFromEmail(composerView->bcc());
+                    result.append(str);
                 } else if (cmd.startsWith(QLatin1String("FULLSUBJECT"))) {
                     i += strlen("FULLSUBJECT");
                     const QString str = composerView->subject();
@@ -225,9 +240,9 @@ QString ConvertSnippetVariablesJob::getNameFromEmail(const QString &address)
     const QStringList lst = address.split(QStringLiteral(", "));
     QStringList resultName;
     for (const QString &str : lst) {
-        KMime::Types::Mailbox address;
-        address.fromUnicodeString(KEmailAddress::normalizeAddressesAndEncodeIdn(str));
-        const QString firstName = address.name();
+        KMime::Types::Mailbox mailBoxAddress;
+        mailBoxAddress.fromUnicodeString(KEmailAddress::normalizeAddressesAndEncodeIdn(str));
+        const QString firstName = mailBoxAddress.name();
         if (!firstName.isEmpty()) {
             resultName << firstName;
         }
@@ -242,9 +257,9 @@ QString ConvertSnippetVariablesJob::getFirstNameFromEmail(const QString &address
     const QStringList lst = address.split(QStringLiteral(", "));
     QStringList resultName;
     for (const QString &str : lst) {
-        KMime::Types::Mailbox address;
-        address.fromUnicodeString(KEmailAddress::normalizeAddressesAndEncodeIdn(str));
-        const QString firstName = TemplateParser::Util::getLastNameFromEmail(address.name());
+        KMime::Types::Mailbox mailBoxAddress;
+        mailBoxAddress.fromUnicodeString(KEmailAddress::normalizeAddressesAndEncodeIdn(str));
+        const QString firstName = TemplateParser::Util::getFirstNameFromEmail(mailBoxAddress.name());
         if (!firstName.isEmpty()) {
             resultName << firstName;
         }
@@ -259,9 +274,9 @@ QString ConvertSnippetVariablesJob::getLastNameFromEmail(const QString &address)
     const QStringList lst = address.split(QStringLiteral(", "));
     QStringList resultName;
     for (const QString &str : lst) {
-        KMime::Types::Mailbox address;
-        address.fromUnicodeString(KEmailAddress::normalizeAddressesAndEncodeIdn(str));
-        const QString lastName = TemplateParser::Util::getLastNameFromEmail(address.name());
+        KMime::Types::Mailbox newAddress;
+        newAddress.fromUnicodeString(KEmailAddress::normalizeAddressesAndEncodeIdn(str));
+        const QString lastName = TemplateParser::Util::getLastNameFromEmail(newAddress.name());
         if (!lastName.isEmpty()) {
             resultName << lastName;
         }
