@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef StatusBarLabelToggledStateTEST_H
-#define StatusBarLabelToggledStateTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,7 +13,7 @@ class StatusBarLabelToggledStateTest : public QObject
     Q_OBJECT
 public:
     explicit StatusBarLabelToggledStateTest(QObject *parent = nullptr);
-    ~StatusBarLabelToggledStateTest();
+    ~StatusBarLabelToggledStateTest() override;
 
 private Q_SLOTS:
     void shouldHasDefaultValue();
@@ -25,4 +24,3 @@ private Q_SLOTS:
     void shouldChangeTestWhenStateChanged();
 };
 
-#endif // StatusBarLabelToggledStateTEST_H
