@@ -29,15 +29,9 @@ void AttachmentFromUrlJobTest::testAttachments_data()
     QTest::addColumn<QByteArray>("mimetype");
 
     // PATH_ATTACHMENTS is defined by CMake.
-    QTest::newRow("png image") << QUrl::fromLocalFile(PATH_ATTACHMENTS + QLatin1String("image.png"))
-                               << QStringLiteral("image.png")
-                               << QByteArray("image/png");
-    QTest::newRow("pdf doc") << QUrl::fromLocalFile(PATH_ATTACHMENTS + QLatin1String("doc.pdf"))
-                             << QStringLiteral("doc.pdf")
-                             << QByteArray("application/pdf");
-    QTest::newRow("text file") << QUrl::fromLocalFile(PATH_ATTACHMENTS + QLatin1String("file.txt"))
-                               << QStringLiteral("file.txt")
-                               << QByteArray("text/plain");
+    QTest::newRow("png image") << QUrl::fromLocalFile(PATH_ATTACHMENTS + QLatin1String("image.png")) << QStringLiteral("image.png") << QByteArray("image/png");
+    QTest::newRow("pdf doc") << QUrl::fromLocalFile(PATH_ATTACHMENTS + QLatin1String("doc.pdf")) << QStringLiteral("doc.pdf") << QByteArray("application/pdf");
+    QTest::newRow("text file") << QUrl::fromLocalFile(PATH_ATTACHMENTS + QLatin1String("file.txt")) << QStringLiteral("file.txt") << QByteArray("text/plain");
 }
 
 void AttachmentFromUrlJobTest::testAttachments()
@@ -51,7 +45,7 @@ void AttachmentFromUrlJobTest::testAttachments()
     QByteArray data = file.readAll();
     file.close();
 
-    AttachmentFromUrlJob *ljob = new AttachmentFromUrlJob(url, this);
+    auto ljob = new AttachmentFromUrlJob(url, this);
     VERIFYEXEC(ljob);
     AttachmentPart::Ptr part = ljob->attachmentPart();
     delete ljob;
@@ -68,8 +62,8 @@ void AttachmentFromUrlJobTest::testAttachmentTooBig()
 {
     const QUrl url = QUrl::fromLocalFile(PATH_ATTACHMENTS + QLatin1String("doc.pdf"));
 
-    AttachmentFromUrlJob *ljob = new AttachmentFromUrlJob(url, this);
-    ljob->setMaximumAllowedSize(1024);   // 1KiB, whereas the file is >9KiB.
+    auto ljob = new AttachmentFromUrlJob(url, this);
+    ljob->setMaximumAllowedSize(1024); // 1KiB, whereas the file is >9KiB.
     QVERIFY(!ljob->exec());
 }
 
@@ -80,7 +74,7 @@ void AttachmentFromUrlJobTest::testAttachmentCharset()
     QUrl url = QUrl::fromLocalFile(PATH_ATTACHMENTS + filename);
     MessageCore::StringUtil::setEncodingFile(url, QString::fromLatin1(charset));
 
-    AttachmentFromUrlJob *ljob = new AttachmentFromUrlJob(url, this);
+    auto ljob = new AttachmentFromUrlJob(url, this);
     VERIFYEXEC(ljob);
     AttachmentPart::Ptr part = ljob->attachmentPart();
     delete ljob;
