@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef ATTACHMENTUPDATEJOBTEST_H
-#define ATTACHMENTUPDATEJOBTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,7 +13,7 @@ class AttachmentUpdateJobTest : public QObject
     Q_OBJECT
 public:
     explicit AttachmentUpdateJobTest(QObject *parent = nullptr);
-    ~AttachmentUpdateJobTest();
+    ~AttachmentUpdateJobTest() override;
 
 private Q_SLOTS:
     void shouldHaveDefaultValue();
@@ -27,4 +26,3 @@ private Q_SLOTS:
     void shouldHaveSameInlineStatus();
 };
 
-#endif // ATTACHMENTUPDATEJOBTEST_H
