@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef MAILINGLISTTEST_H
-#define MAILINGLISTTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,7 +13,7 @@ class MailingListTest : public QObject
     Q_OBJECT
 public:
     explicit MailingListTest(QObject *parent = nullptr);
-    ~MailingListTest();
+    ~MailingListTest() override;
 
 private Q_SLOTS:
     void shouldHaveDefaultValue();
@@ -22,4 +21,3 @@ private Q_SLOTS:
     void shouldCopyReminderInfo();
 };
 
-#endif // MAILINGLISTTEST_H
