@@ -2,8 +2,7 @@
 
    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
-#ifndef STRINGUTILTEST_H
-#define STRINGUTILTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -20,6 +19,8 @@ private Q_SLOTS:
     void test_parseMailtoUrl_data();
     void test_parseMailtoUrl();
     void test_parseMailtoUrlExtra();
+    void test_replaceMessagePrefix_data();
+    void test_replaceMessagePrefix();
     void test_stripOffMessagePrefix_data();
     void test_stripOffMessagePrefix();
     void test_formatQuotePrefix_data();
@@ -32,6 +33,7 @@ private Q_SLOTS:
     void test_parseMailToWithUtf8QuotedEncoded();
     void test_crashXdgemail();
     void test_xdgemail();
+    void test_parseMailToBug206269();
+    void test_splitAddressField();
 };
 
-#endif
