@@ -9,10 +9,10 @@
 #include "attachmentfromurljob.h"
 
 #include "messagecore_debug.h"
+#include <KFormat>
 #include <KIO/Scheduler>
 #include <KIO/TransferJob>
 #include <KLocalizedString>
-#include <KFormat>
 
 #include <QFileInfo>
 #include <QMimeDatabase>
@@ -20,10 +20,10 @@
 
 using namespace MessageCore;
 
-class Q_DECL_HIDDEN MessageCore::AttachmentFromUrlJob::Private
+class MessageCore::AttachmentFromUrlJob::AttachmentLoadJobPrivate
 {
 public:
-    Private(AttachmentFromUrlJob *qq);
+    explicit AttachmentLoadJobPrivate(AttachmentFromUrlJob *qq);
 
     void transferJobData(KIO::Job *job, const QByteArray &jobData);
     void transferJobResult(KJob *job);
@@ -32,18 +32,18 @@ public:
     QByteArray mData;
 };
 
-AttachmentFromUrlJob::Private::Private(AttachmentFromUrlJob *qq)
+AttachmentFromUrlJob::AttachmentLoadJobPrivate::AttachmentLoadJobPrivate(AttachmentFromUrlJob *qq)
     : q(qq)
 {
 }
 
-void AttachmentFromUrlJob::Private::transferJobData(KIO::Job *job, const QByteArray &jobData)
+void AttachmentFromUrlJob::AttachmentLoadJobPrivate::transferJobData(KIO::Job *job, const QByteArray &jobData)
 {
-    Q_UNUSED(job);
+    Q_UNUSED(job)
     mData += jobData;
 }
 
-void AttachmentFromUrlJob::Private::transferJobResult(KJob *job)
+void AttachmentFromUrlJob::AttachmentLoadJobPrivate::transferJobResult(KJob *job)
 {
     if (job->error()) {
         // TODO this loses useful stuff from KIO, like detailed error descriptions, causes+solutions,
@@ -55,7 +55,7 @@ void AttachmentFromUrlJob::Private::transferJobResult(KJob *job)
     }
 
     Q_ASSERT(dynamic_cast<KIO::TransferJob *>(job));
-    KIO::TransferJob *transferJob = static_cast<KIO::TransferJob *>(job);
+    auto transferJob = static_cast<KIO::TransferJob *>(job);
 
     // Determine the MIME type and filename of the attachment.
     const QString mimeTypeName = transferJob->mimetype();
@@ -67,15 +67,14 @@ void AttachmentFromUrlJob::Private::transferJobResult(KJob *job)
         QMimeDatabase db;
         const auto mimeType = db.mimeTypeForName(mimeTypeName);
         if (mimeType.isValid()) {
-            fileName = i18nc("a file called 'unknown.ext'", "unknown%1",
-                             mimeType.preferredSuffix());
+            fileName = i18nc("a file called 'unknown.ext'", "unknown%1", mimeType.preferredSuffix());
         } else {
             fileName = i18nc("a file called 'unknown'", "unknown");
         }
     }
 
     // Create the AttachmentPart.
-    Q_ASSERT(q->attachmentPart() == nullptr);   // Not created before.
+    Q_ASSERT(q->attachmentPart() == nullptr); // Not created before.
 
     AttachmentPart::Ptr part = AttachmentPart::Ptr(new AttachmentPart);
     QUrlQuery query(q->url());
@@ -92,14 +91,11 @@ void AttachmentFromUrlJob::Private::transferJobResult(KJob *job)
 
 AttachmentFromUrlJob::AttachmentFromUrlJob(const QUrl &url, QObject *parent)
     : AttachmentFromUrlBaseJob(url, parent)
-    , d(new Private(this))
+    , d(new AttachmentLoadJobPrivate(this))
 {
 }
 
-AttachmentFromUrlJob::~AttachmentFromUrlJob()
-{
-    delete d;
-}
+AttachmentFromUrlJob::~AttachmentFromUrlJob() = default;
 
 void AttachmentFromUrlJob::doStart()
 {
@@ -114,17 +110,15 @@ void AttachmentFromUrlJob::doStart()
         const qint64 size = QFileInfo(url().toLocalFile()).size();
         if (size > maximumAllowedSize()) {
             setError(KJob::UserDefinedError);
-            setErrorText(i18n("You may not attach files bigger than %1. Share it with storage service.",
-                              KFormat().formatByteSize(maximumAllowedSize())));
+            setErrorText(i18n("You may not attach files bigger than %1. Share it with storage service.", KFormat().formatByteSize(maximumAllowedSize())));
             emitResult();
             return;
         }
     }
 
-    Q_ASSERT(d->mData.isEmpty());   // Not started twice.
+    Q_ASSERT(d->mData.isEmpty()); // Not started twice.
 
-    KIO::TransferJob *job = KIO::get(url(), KIO::NoReload,
-                                     (uiDelegate() ? KIO::DefaultFlags : KIO::HideProgressInfo));
+    KIO::TransferJob *job = KIO::get(url(), KIO::NoReload, (uiDelegate() ? KIO::DefaultFlags : KIO::HideProgressInfo));
     connect(job, &KIO::TransferJob::result, this, [this](KJob *job) {
         d->transferJobResult(job);
     });
