@@ -1,54 +1,41 @@
 /******************************************************************************
  *
- *  Copyright 2008 Szymon Tomasz Stefanek <pragma@kvirc.net>
+ *  SPDX-FileCopyrightText: 2008 Szymon Tomasz Stefanek <pragma@kvirc.net>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  *
  *******************************************************************************/
 
 #include "messageitem.h"
 #include "messageitem_p.h"
 
-#include "PimCommonAkonadi/AnnotationDialog"
-#include "theme.h"
+#include <PimCommonAkonadi/AnnotationDialog>
 
-#include <item.h>
-#include <entityannotationsattribute.h>
-#include <tagattribute.h>
-#include <tagfetchjob.h>
-#include <tagfetchscope.h>
+#include "messagelist_debug.h"
+#include <Akonadi/EntityAnnotationsAttribute>
+#include <Akonadi/Item>
+#include <Akonadi/TagAttribute>
+#include <Akonadi/TagFetchJob>
+#include <Akonadi/TagFetchScope>
 #include <KIconLoader>
 #include <KLocalizedString>
-#include <QPointer>
 #include <QIcon>
-#include "messagelist_debug.h"
+#include <QPointer>
 using namespace MessageList::Core;
 
 Q_GLOBAL_STATIC(TagCache, s_tagCache)
 
-class Q_DECL_HIDDEN MessageItem::Tag::Private
+class MessageItem::Tag::TagPrivate
 {
 public:
-    Private()
-        : mPriority(0)  //Initialize it
+    TagPrivate()
+        : mPriority(0) // Initialize it
     {
     }
 
     QPixmap mPixmap;
     QString mName;
-    QString mId;             ///< The unique id of this tag
+    QString mId; ///< The unique id of this tag
     QColor mTextColor;
     QColor mBackgroundColor;
     QFont mFont;
@@ -56,17 +43,14 @@ public:
 };
 
 MessageItem::Tag::Tag(const QPixmap &pix, const QString &tagName, const QString &tagId)
-    : d(new Private)
+    : d(new TagPrivate)
 {
     d->mPixmap = pix;
     d->mName = tagName;
     d->mId = tagId;
 }
 
-MessageItem::Tag::~Tag()
-{
-    delete d;
-}
+MessageItem::Tag::~Tag() = default;
 
 const QPixmap &MessageItem::Tag::pixmap() const
 {
@@ -175,7 +159,8 @@ void MessageItemPrivate::invalidateAnnotationCache()
 const MessageItem::Tag *MessageItemPrivate::bestTag() const
 {
     const MessageItem::Tag *best = nullptr;
-    foreach (const MessageItem::Tag *tag, getTagList()) {
+    const auto tagList{getTagList()};
+    for (const MessageItem::Tag *tag : tagList) {
         if (!best || tag->priority() < best->priority()) {
             best = tag;
         }
@@ -191,11 +176,11 @@ void MessageItemPrivate::fillTagList(const Akonadi::Tag::List &taglist)
     // TODO: The tag pointers here could be shared between all items, there really is no point in
     //       creating them for each item that has tags
 
-    //Priority sort this and make bestTag more efficient
+    // Priority sort this and make bestTag more efficient
 
     for (const Akonadi::Tag &tag : taglist) {
         QString symbol = QStringLiteral("mail-tagged");
-        auto attr = tag.attribute<Akonadi::TagAttribute>();
+        const auto attr = tag.attribute<Akonadi::TagAttribute>();
         if (attr) {
             if (!attr->iconName().isEmpty()) {
                 symbol = attr->iconName();
@@ -254,7 +239,7 @@ MessageItem::~MessageItem()
 {
 }
 
-QList< MessageItem::Tag * > MessageItem::tagList() const
+QList<MessageItem::Tag *> MessageItem::tagList() const
 {
     Q_D(const MessageItem);
     return d->getTagList();
@@ -263,7 +248,7 @@ QList< MessageItem::Tag * > MessageItem::tagList() const
 bool MessageItem::hasAnnotation() const
 {
     Q_D(const MessageItem);
-    //TODO check for note entry?
+    // TODO check for note entry?
     return d->mAkonadiItem.hasAttribute<Akonadi::EntityAnnotationsAttribute>();
 }
 
@@ -289,7 +274,7 @@ void MessageItem::editAnnotation(QWidget *parent)
 {
     Q_D(MessageItem);
     QPointer<PimCommon::AnnotationEditDialog> mAnnotationDialog = new PimCommon::AnnotationEditDialog(d->mAkonadiItem, parent);
-    //FIXME make async
+    // FIXME make async
     if (mAnnotationDialog->exec()) {
         // invalidate the cached mHasAnnotation value
     }
@@ -298,7 +283,8 @@ void MessageItem::editAnnotation(QWidget *parent)
 
 const MessageItem::Tag *MessageItemPrivate::findTagInternal(const QString &szTagId) const
 {
-    foreach (const MessageItem::Tag *tag, getTagList()) {
+    const auto tagList{getTagList()};
+    for (const MessageItem::Tag *tag : tagList) {
         if (tag->id() == szTagId) {
             return tag;
         }
@@ -316,7 +302,8 @@ QString MessageItem::tagListDescription() const
 {
     QString ret;
 
-    foreach (const Tag *tag, tagList()) {
+    const auto tags{tagList()};
+    for (const Tag *tag : tags) {
         if (!ret.isEmpty()) {
             ret += QLatin1String(", ");
         }
@@ -527,7 +514,7 @@ MessageItem *MessageItem::topmostMessage()
         return this;
     }
     if (parent()->type() == Item::Message) {
-        return static_cast< MessageItem * >(parent())->topmostMessage();
+        return static_cast<MessageItem *>(parent())->topmostMessage();
     }
     return this;
 }
@@ -569,11 +556,13 @@ QString MessageItem::accessibleText(const Theme *theme, int columnIndex)
         QStringList rightStrings;
         const auto leftItems = row->leftItems();
         leftStrings.reserve(leftItems.count());
-        for (Theme::ContentItem *contentItem : qAsConst(leftItems)) {
+        for (Theme::ContentItem *contentItem : std::as_const(leftItems)) {
             leftStrings.append(accessibleTextForField(contentItem->type()));
         }
 
-        Q_FOREACH (Theme::ContentItem *contentItem, row->rightItems()) {
+        const auto rightItems = row->rightItems();
+        rightStrings.reserve(rightItems.count());
+        for (Theme::ContentItem *contentItem : rightItems) {
             rightStrings.insert(rightStrings.begin(), accessibleTextForField(contentItem->type()));
         }
 
@@ -583,14 +572,14 @@ QString MessageItem::accessibleText(const Theme *theme, int columnIndex)
     return rowsTexts.join(QLatin1Char(' '));
 }
 
-void MessageItem::subTreeToList(QList< MessageItem * > &list)
+void MessageItem::subTreeToList(QVector<MessageItem *> &list)
 {
     list.append(this);
     const auto childList = childItems();
     if (!childList) {
         return;
     }
-    for (const auto child : qAsConst(*childList)) {
+    for (const auto child : std::as_const(*childList)) {
         Q_ASSERT(child->type() == Item::Message);
         static_cast<MessageItem *>(child)->subTreeToList(list);
     }
@@ -631,7 +620,8 @@ void MessageItem::setToDoMessageFont(const QFont &font)
     s_settings->mFontToDoMessage = font;
 }
 
-FakeItemPrivate::FakeItemPrivate(FakeItem *qq) : MessageItemPrivate(qq)
+FakeItemPrivate::FakeItemPrivate(FakeItem *qq)
+    : MessageItemPrivate(qq)
 {
 }
 
@@ -642,15 +632,17 @@ FakeItem::FakeItem()
 
 FakeItem::~FakeItem()
 {
+    Q_D(const FakeItem);
+    qDeleteAll(d->mFakeTags);
 }
 
-QList< MessageItem::Tag * > FakeItem::tagList() const
+QList<MessageItem::Tag *> FakeItem::tagList() const
 {
     Q_D(const FakeItem);
     return d->mFakeTags;
 }
 
-void FakeItem::setFakeTags(const QList< MessageItem::Tag * > &tagList)
+void FakeItem::setFakeTags(const QList<MessageItem::Tag *> &tagList)
 {
     Q_D(FakeItem);
     d->mFakeTags = tagList;
@@ -691,7 +683,7 @@ void TagCache::onTagRemoved(const Akonadi::Tag &tag)
 
 void TagCache::retrieveTags(const Akonadi::Tag::List &tags, MessageItemPrivate *m)
 {
-    //Retrieval is in progress
+    // Retrieval is in progress
     if (mRequests.key(m)) {
         return;
     }
@@ -704,7 +696,7 @@ void TagCache::retrieveTags(const Akonadi::Tag::List &tags, MessageItemPrivate *
             toFetch << tag;
         }
     }
-    //Because fillTagList expects to be called once we either fetch all or none
+    // Because fillTagList expects to be called once we either fetch all or none
     if (!toFetch.isEmpty()) {
         auto tagFetchJob = new Akonadi::TagFetchJob(tags, this);
         tagFetchJob->fetchScope().fetchAttribute<Akonadi::TagAttribute>();
@@ -718,7 +710,7 @@ void TagCache::retrieveTags(const Akonadi::Tag::List &tags, MessageItemPrivate *
 void TagCache::cancelRequest(MessageItemPrivate *m)
 {
     const QList<KJob *> keys = mRequests.keys(m);
-    Q_FOREACH (KJob *job, keys) { //Don't use for(...:...)
+    for (KJob *job : keys) {
         mRequests.remove(job);
     }
 }
@@ -730,7 +722,8 @@ void TagCache::onTagsFetched(KJob *job)
         return;
     }
     auto fetchJob = static_cast<Akonadi::TagFetchJob *>(job);
-    Q_FOREACH (const Akonadi::Tag &tag, fetchJob->tags()) {
+    const auto tags{fetchJob->tags()};
+    for (const Akonadi::Tag &tag : tags) {
         mCache.insert(tag.id(), new Akonadi::Tag(tag));
     }
     if (auto m = mRequests.take(fetchJob)) {
