@@ -6,25 +6,27 @@
  *
  *******************************************************************************/
 
-#ifndef MESSAGELIST_CORE_MESSAGEITEM_H
-#define MESSAGELIST_CORE_MESSAGEITEM_H
+#pragma once
 
 #include "core/item.h"
 #include "core/modelinvariantindex.h"
 
-#include <QPixmap>
-#include <QString>
+#include "theme.h"
 #include <QColor>
 #include <QFont>
+#include <QPixmap>
+#include <QString>
 #include <messagelist_export.h>
-#include "theme.h"
 
-namespace Akonadi {
+namespace Akonadi
+{
 class Item;
 }
 
-namespace MessageList {
-namespace Core {
+namespace MessageList
+{
+namespace Core
+{
 class MessageItemPrivate;
 /**
  * @brief The MessageItem class
@@ -51,38 +53,27 @@ public:
         void setPriority(int priority);
 
     private:
-        class Private;
-        Private *const d;
+        class TagPrivate;
+        std::unique_ptr<TagPrivate> const d;
     };
 
     enum ThreadingStatus {
-        PerfectParentFound,     ///< this message found a perfect parent to attach to
-        ImperfectParentFound,   ///< this message found an imperfect parent to attach to (might be fixed later)
-        ParentMissing,          ///< this message might belong to a thread but its parent is actually missing
-        NonThreadable           ///< this message does not look as being threadable
+        PerfectParentFound, ///< this message found a perfect parent to attach to
+        ImperfectParentFound, ///< this message found an imperfect parent to attach to (might be fixed later)
+        ParentMissing, ///< this message might belong to a thread but its parent is actually missing
+        NonThreadable ///< this message does not look as being threadable
     };
 
-    enum EncryptionState {
-        NotEncrypted,
-        PartiallyEncrypted,
-        FullyEncrypted,
-        EncryptionStateUnknown
-    };
+    enum EncryptionState { NotEncrypted, PartiallyEncrypted, FullyEncrypted, EncryptionStateUnknown };
 
-    enum SignatureState {
-        NotSigned,
-        PartiallySigned,
-        FullySigned,
-        SignatureStateUnknown
-    };
+    enum SignatureState { NotSigned, PartiallySigned, FullySigned, SignatureStateUnknown };
 
     explicit MessageItem();
-    virtual ~MessageItem();
+    ~MessageItem() override;
 
 public:
-
     /// Returns the list of tags for this item.
-    virtual QList< Tag * > tagList() const;
+    virtual QList<Tag *> tagList() const;
 
     /// Returns true if this message has an annotation.
     virtual bool hasAnnotation() const;
@@ -94,9 +85,9 @@ public:
     void editAnnotation(QWidget *parent);
 
     /**
-    * Returns Tag associated to this message that has the specified id or 0
-    * if no such tag exists. mTagList will be 0 in 99% of the cases.
-    */
+     * Returns Tag associated to this message that has the specified id or 0
+     * if no such tag exists. mTagList will be 0 in 99% of the cases.
+     */
     const Tag *findTag(const QString &szTagId) const;
 
     Q_REQUIRED_RESULT QString tagListDescription() const;
@@ -168,9 +159,9 @@ public:
     QString accessibleText(const MessageList::Core::Theme *theme, int columnIndex);
 
     /**
-    * Appends the whole subtree originating at this item
-    * to the specified list. This item is included!
-    */
+     * Appends the whole subtree originating at this item
+     * to the specified list. This item is included!
+     */
     void subTreeToList(QVector<MessageItem *> &list);
 
     //
@@ -189,6 +180,7 @@ public:
 
 protected:
     explicit MessageItem(MessageItemPrivate *dd);
+
 private:
     const QFont &font() const;
 
@@ -203,15 +195,14 @@ class FakeItemPrivate;
 class FakeItem : public MessageItem
 {
 public:
-
     explicit FakeItem();
-    ~FakeItem();
+    ~FakeItem() override;
 
     /// Reimplemented to return the fake tag list
-    QList< Tag * > tagList() const override;
+    QList<Tag *> tagList() const override;
 
     /// Sets a list of fake tags for this item
-    void setFakeTags(const QList< Tag * > &tagList);
+    void setFakeTags(const QList<Tag *> &tagList);
 
     /// Reimplemented to always return true
     bool hasAnnotation() const override;
@@ -222,4 +213,3 @@ private:
 } // namespace Core
 } // namespace MessageList
 
-#endif //!__MESSAGELIST_CORE_MESSAGEITEM_H
