@@ -6,17 +6,18 @@
  *
  *******************************************************************************/
 
-#ifndef MESSAGELIST_CORE_MESSAGEITEMSETMANAGER_H
-#define MESSAGELIST_CORE_MESSAGEITEMSETMANAGER_H
+#pragma once
 
 #include <QHash>
 #include <QList>
 
-namespace MessageList {
-namespace Core {
+namespace MessageList
+{
+namespace Core
+{
 class MessageItem;
 
-typedef long int MessageItemSetReference;
+using MessageItemSetReference = long;
 
 /**
  * This class manages sets of messageitem references.
@@ -36,18 +37,17 @@ public:
     ~MessageItemSetManager();
 
 private:
-    QHash< MessageItemSetReference, QHash< MessageItem *, MessageItem * > * > *mSets;
+    QHash<MessageItemSetReference, QHash<MessageItem *, MessageItem *> *> *mSets;
 
 public:
     void clearAllSets();
     Q_REQUIRED_RESULT int setCount() const;
     void removeSet(MessageItemSetReference ref);
     void removeMessageItemFromAllSets(MessageItem *mi);
-    Q_REQUIRED_RESULT QList< MessageItem * > messageItems(MessageItemSetReference ref);
+    Q_REQUIRED_RESULT QList<MessageItem *> messageItems(MessageItemSetReference ref);
     Q_REQUIRED_RESULT MessageItemSetReference createSet();
     Q_REQUIRED_RESULT bool addMessageItem(MessageItemSetReference ref, MessageItem *mi);
 };
 } // namespace Core
 } // namespace MessageList
 
-#endif //!__MESSAGELIST_CORE_MESSAGEITEMSETMANAGER_H
