@@ -6,24 +6,26 @@
  *
  *******************************************************************************/
 
-#ifndef MESSAGELIST_CORE_MODEL_P_H
-#define MESSAGELIST_CORE_MODEL_P_H
+#pragma once
 
 #include "model.h"
 #include "threadingcache.h"
-#include <config-messagelist.h>
 #include <QTimer>
+#include <config-messagelist.h>
 
 class QElapsedTimer;
-namespace MessageList {
-namespace Core {
+namespace MessageList
+{
+namespace Core
+{
 class ViewItemJob;
 class ModelInvariantRowMapper;
 class MessageItemSetManager;
 class ModelPrivate
 {
 public:
-    explicit ModelPrivate(Model *owner) : q(owner)
+    explicit ModelPrivate(Model *owner)
+        : q(owner)
     {
     }
 
@@ -53,19 +55,13 @@ public:
      */
     MessageItem *guessMessageParent(MessageItem *mi);
 
-    enum AttachOptions {
-        SkipCacheUpdate = 0,
-        StoreInCache = 1
-    };
+    enum AttachOptions { SkipCacheUpdate = 0, StoreInCache = 1 };
     void attachMessageToParent(Item *pParent, MessageItem *mi, AttachOptions attachOptions = StoreInCache);
     void messageDetachedUpdateParentProperties(Item *oldParent, MessageItem *mi);
     void attachMessageToGroupHeader(MessageItem *mi);
     void attachGroup(GroupHeaderItem *ghi);
 
-    enum ViewItemJobResult {
-        ViewItemJobCompleted,
-        ViewItemJobInterrupted
-    };
+    enum ViewItemJobResult { ViewItemJobCompleted, ViewItemJobInterrupted };
     ViewItemJobResult viewItemJobStepInternal();
     ViewItemJobResult viewItemJobStepInternalForJob(ViewItemJob *job, QElapsedTimer elapsedTimer);
 
@@ -170,27 +166,27 @@ public:
     /**
      * The currently set storage model: shallow pointer.
      */
-    StorageModel *mStorageModel;
+    StorageModel *mStorageModel = nullptr;
 
     /**
      * The currently set aggregation mode: shallow pointer set by Widget
      */
-    const Aggregation *mAggregation;
+    const Aggregation *mAggregation = nullptr;
 
     /**
      * The currently used theme: shallow pointer
      */
-    const Theme *mTheme;
+    const Theme *mTheme = nullptr;
 
     /**
      * The currently used sort order. Pointer not owned by us, but by the Widget.
      */
-    const SortOrder *mSortOrder;
+    const SortOrder *mSortOrder = nullptr;
 
     /**
      * The filter to apply on messages. Shallow. Never 0.
      */
-    const Filter *mFilter;
+    const Filter *mFilter = nullptr;
 
     /**
      * The timer involved in breaking the "fill" operation in steps
@@ -200,61 +196,61 @@ public:
     /**
      * Group Key (usually the label) -> GroupHeaderItem, used to quickly find groups, pointers are shallow copies
      */
-    QHash< QString, GroupHeaderItem * > mGroupHeaderItemHash;
+    QHash<QString, GroupHeaderItem *> mGroupHeaderItemHash;
 
     /**
      * Threading cache.
      * MessageIdMD5 -> MessageItem, pointers are shallow copies
      */
-    QHash< QByteArray, MessageItem * > mThreadingCacheMessageIdMD5ToMessageItem;
+    QHash<QByteArray, MessageItem *> mThreadingCacheMessageIdMD5ToMessageItem;
 
     /**
      * Threading cache.
      * MessageInReplyToIdMD5 -> MessageItem, pointers are shallow copies
      */
-    QMultiHash< QByteArray, MessageItem * > mThreadingCacheMessageInReplyToIdMD5ToMessageItem;
+    QMultiHash<QByteArray, MessageItem *> mThreadingCacheMessageInReplyToIdMD5ToMessageItem;
 
     /**
      * Threading cache.
      * ReferencesIdMD5 -> MessageItem, pointers are shallow copies
      */
-    QHash< QByteArray, QList< MessageItem * > * > mThreadingCacheMessageReferencesIdMD5ToMessageItem;
+    QHash<QByteArray, QList<MessageItem *> *> mThreadingCacheMessageReferencesIdMD5ToMessageItem;
 
     /**
      * Threading cache.
      * SubjectMD5 -> MessageItem, pointers are shallow copies
      */
-    QHash< QByteArray, QList< MessageItem * > * > mThreadingCacheMessageSubjectMD5ToMessageItem;
+    QHash<QByteArray, QList<MessageItem *> *> mThreadingCacheMessageSubjectMD5ToMessageItem;
 
     /**
      * List of group headers that either need to be re-sorted or must be removed because empty
      */
-    QHash< GroupHeaderItem *, GroupHeaderItem * > mGroupHeadersThatNeedUpdate;
+    QHash<GroupHeaderItem *, GroupHeaderItem *> mGroupHeadersThatNeedUpdate;
 
     /**
      * List of unassigned messages, used to handle threading in two passes, pointers are owned!
      */
-    QList< MessageItem * > mUnassignedMessageListForPass2;
+    QList<MessageItem *> mUnassignedMessageListForPass2;
 
     /**
      * List of unassigned messages, used to handle threading in two passes, pointers are owned!
      */
-    QList< MessageItem * > mUnassignedMessageListForPass3;
+    QList<MessageItem *> mUnassignedMessageListForPass3;
 
     /**
      * List of unassigned messages, used to handle threading in two passes, pointers are owned!
      */
-    QList< MessageItem * > mUnassignedMessageListForPass4;
+    QList<MessageItem *> mUnassignedMessageListForPass4;
 
     /**
      * Hash of orphan children used in Pass1Cleanup.
      */
-    QHash< MessageItem *, MessageItem * > mOrphanChildrenHash;
+    QHash<MessageItem *, MessageItem *> mOrphanChildrenHash;
 
     /**
      * Pending fill view jobs, pointers are owned
      */
-    QList< ViewItemJob * > mViewItemJobs;
+    QList<ViewItemJob *> mViewItemJobs;
 
     /**
      * The today's date. Set when the StorageModel is set and thus grouping is performed.
@@ -266,12 +262,12 @@ public:
      * Owned invisible root item, useful to implement algorithms that not need
      * to handle the special case of parentless items. This is never 0.
      */
-    Item *mRootItem;
+    Item *mRootItem = nullptr;
 
     /**
      * The view we're attached to. Shallow pointer (the View owns us).
      */
-    View *mView;
+    View *mView = nullptr;
 
     /**
      * The time at the current ViewItemJob step started. Used to compute the time we
@@ -301,7 +297,7 @@ public:
      *
      * \sa ModelInvariantRowMapper
      */
-    ModelInvariantRowMapper *mInvariantRowMapper;
+    ModelInvariantRowMapper *mInvariantRowMapper = nullptr;
 
     /**
      * The label for the "Today" group item, cached, so we don't translate it multiple times.
@@ -370,7 +366,7 @@ public:
      * and QTreeView will loose the current setting. We also use this to force the current
      * to a specific item after a cleanup job.
      */
-    Item *mCurrentItemToRestoreAfterViewItemJobStep;
+    Item *mCurrentItemToRestoreAfterViewItemJobStep = nullptr;
 
     /**
      * Set to true in the first large loading job.
@@ -394,8 +390,8 @@ public:
 
     // Oldest and newest item while loading the model
     // Not valid afterwards anymore. Used for pre-selection of the newest/oldest message
-    MessageItem *mOldestItem;
-    MessageItem *mNewestItem;
+    MessageItem *mOldestItem = nullptr;
+    MessageItem *mNewestItem = nullptr;
 
     /**
      * The id of the preselected ;essage is "translated" to a message pointer when it's fetched
@@ -404,7 +400,7 @@ public:
      *
      * See also setStorageModel() and abortMessagePreSelection()
      */
-    MessageItem *mLastSelectedMessageInFolder;
+    MessageItem *mLastSelectedMessageInFolder = nullptr;
 
     /**
      * The "persistent message item sets" are (guess what?) sets of messages
@@ -418,13 +414,13 @@ public:
      * So mPersistentSetManager is in fact the manager for the outstanding "user" jobs.
      * 0 if no jobs are pending (so there are no persistent sets at the moment).
      */
-    MessageItemSetManager *mPersistentSetManager;
+    MessageItemSetManager *mPersistentSetManager = nullptr;
 
     /**
      * This pointer is passed to the Item functions that insert children.
      * When we work with disconnected UI this pointer becomes 0.
      */
-    Model *mModelForItemFunctions;
+    Model *mModelForItemFunctions = nullptr;
 
     /**
      * The cached result of StorageModel::containsOutboundMessages().
@@ -448,4 +444,3 @@ public:
 } // namespace Core
 } // namespace MessageList
 
-#endif //!__MESSAGELIST_CORE_MODEL_P_H
