@@ -1,95 +1,77 @@
 /******************************************************************************
  *
- *  Copyright 2008 Szymon Tomasz Stefanek <pragma@kvirc.net>
+ *  SPDX-FileCopyrightText: 2008 Szymon Tomasz Stefanek <pragma@kvirc.net>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  *
  *******************************************************************************/
 
 #include "core/widgetbase.h"
+#include "core/aggregation.h"
+#include "core/filter.h"
+#include "core/filtersavedmanager.h"
+#include "core/manager.h"
+#include "core/messageitem.h"
+#include "core/model.h"
+#include "core/optionset.h"
+#include "core/storagemodelbase.h"
+#include "core/theme.h"
+#include "core/view.h"
 #include "core/widgets/quicksearchwarning.h"
 #include "core/widgets/searchcollectionindexingwarning.h"
-#include "core/aggregation.h"
-#include "core/theme.h"
-#include "core/filter.h"
-#include "core/manager.h"
-#include "core/optionset.h"
-#include "core/view.h"
-#include "core/model.h"
-#include "core/messageitem.h"
-#include "core/storagemodelbase.h"
-#include "widgets/searchlinestatus.h"
+#include "core/widgets/tablockedwarning.h"
 #include "messagelistsettings.h"
+#include "widgets/searchlinestatus.h"
 
 #include "utils/configureaggregationsdialog.h"
 #include "utils/configurethemesdialog.h"
 
-#include <QVBoxLayout>
 #include <QActionGroup>
 #include <QHeaderView>
+#include <QPointer>
 #include <QTimer>
+#include <QVBoxLayout>
 #include <QVariant>
 
-#include <QAction>
-#include <KComboBox>
 #include "messagelist_debug.h"
 #include <KLocalizedString>
+#include <KMessageBox>
+#include <QAction>
+#include <QComboBox>
 #include <QMenu>
 
-#include <QUrl>
 
-#include <collection.h>
+#include <Akonadi/Collection>
 #include <Akonadi/KMime/MessageStatus>
+#include <chrono>
+#include <core/widgets/filternamedialog.h>
+
+using namespace std::chrono_literals;
 
 using namespace MessageList::Core;
 
-class Widget::Private
+class Widget::WidgetPrivate
 {
 public:
-    Private(Widget *owner)
+    WidgetPrivate(Widget *owner)
         : q(owner)
-        , quickSearchWarning(nullptr)
-        , searchCollectionIndexingWarning(nullptr)
-        , quickSearchLine(nullptr)
-        , mView(nullptr)
-        , mSearchTimer(nullptr)
-        , mStorageModel(nullptr)
-        , mAggregation(nullptr)
-        , mTheme(nullptr)
-        , mFilter(nullptr)
-        , mStorageUsesPrivateTheme(false)
-        , mStorageUsesPrivateAggregation(false)
-        , mStorageUsesPrivateSortOrder(false)
-        , mStatusFilterComboPopulationInProgress(false)
     {
     }
 
     /**
-    * Small helper for switching SortOrder::MessageSorting and SortOrder::SortDirection
-    * on the fly.
-    * After doing this, the sort indicator in the header is updated.
-    */
+     * Small helper for switching SortOrder::MessageSorting and SortOrder::SortDirection
+     * on the fly.
+     * After doing this, the sort indicator in the header is updated.
+     */
     void switchMessageSorting(SortOrder::MessageSorting messageSorting, SortOrder::SortDirection sortDirection, int logicalHeaderColumnIndex);
 
     /**
-    * Check if our sort order can still be used with this aggregation.
-    * This can happen if the global aggregation changed, for example we can now
-    * have "most recent in subtree" sorting with an aggregation without threading.
-    * If this happens, reset to the default sort order and don't use the global sort
-    * order.
-    */
+     * Check if our sort order can still be used with this aggregation.
+     * This can happen if the global aggregation changed, for example we can now
+     * have "most recent in subtree" sorting with an aggregation without threading.
+     * If this happens, reset to the default sort order and don't use the global sort
+     * order.
+     */
     void checkSortOrder(const StorageModel *storageModel);
 
     void setDefaultAggregationForStorageModel(const StorageModel *storageModel);
@@ -99,43 +81,42 @@ public:
 
     Widget *const q;
 
-    QuickSearchWarning *quickSearchWarning;
-    SearchCollectionIndexingWarning *searchCollectionIndexingWarning;
-    QuickSearchLine *quickSearchLine;
-    View *mView;
+    QuickSearchWarning *quickSearchWarning = nullptr;
+    SearchCollectionIndexingWarning *searchCollectionIndexingWarning = nullptr;
+    TabLockedWarning *tabLockedWarning = nullptr;
+    QuickSearchLine *quickSearchLine = nullptr;
+    View *mView = nullptr;
     QString mLastAggregationId;
     QString mLastThemeId;
-    QTimer *mSearchTimer;
-    StorageModel *mStorageModel;           ///< The currently displayed storage. The storage itself
+    QTimer *mSearchTimer = nullptr;
+    StorageModel *mStorageModel = nullptr; ///< The currently displayed storage. The storage itself
     ///  is owned by MessageList::Widget.
-    Aggregation *mAggregation;             ///< The currently set aggregation mode, a deep copy
-    Theme *mTheme;                         ///< The currently set theme, a deep copy
-    SortOrder mSortOrder;                  ///< The currently set sort order
-    Filter *mFilter;                       ///< The currently applied filter, owned by us.
-    bool mStorageUsesPrivateTheme;         ///< true if the current folder does not use the global theme
-    bool mStorageUsesPrivateAggregation;   ///< true if the current folder does not use the global aggregation
-    bool mStorageUsesPrivateSortOrder;     ///< true if the current folder does not use the global sort order
-    QUrl mCurrentFolderUrl;                ///< The Akonadi URL of the current folder
-    Akonadi::Collection mCurrentFolder;    ///< The current folder
+    Aggregation *mAggregation = nullptr; ///< The currently set aggregation mode, a deep copy
+    Theme *mTheme = nullptr; ///< The currently set theme, a deep copy
+    SortOrder mSortOrder; ///< The currently set sort order
+    Filter *mFilter = nullptr; ///< The currently applied filter, owned by us.
+    bool mStorageUsesPrivateTheme = false; ///< true if the current folder does not use the global theme
+    bool mStorageUsesPrivateAggregation = false; ///< true if the current folder does not use the global aggregation
+    bool mStorageUsesPrivateSortOrder = false; ///< true if the current folder does not use the global sort order
+    Akonadi::Collection mCurrentFolder; ///< The current folder
     int mCurrentStatusFilterIndex = 0;
-    bool mStatusFilterComboPopulationInProgress;
+    bool mStatusFilterComboPopulationInProgress = false;
+    bool mLockTab = false;
 };
 
 Widget::Widget(QWidget *pParent)
     : QWidget(pParent)
-    , d(new Private(this))
+    , d(new WidgetPrivate(this))
 {
     Manager::registerWidget(this);
-    connect(Manager::instance(), &Manager::aggregationsChanged,
-            this, &Widget::aggregationsChanged);
-    connect(Manager::instance(), &Manager::themesChanged,
-            this, &Widget::themesChanged);
+    connect(Manager::instance(), &Manager::aggregationsChanged, this, &Widget::aggregationsChanged);
+    connect(Manager::instance(), &Manager::themesChanged, this, &Widget::themesChanged);
 
     setAutoFillBackground(true);
     setObjectName(QStringLiteral("messagelistwidget"));
 
-    QVBoxLayout *g = new QVBoxLayout(this);
-    g->setContentsMargins(0, 0, 0, 0);
+    auto g = new QVBoxLayout(this);
+    g->setContentsMargins({});
     g->setSpacing(0);
 
     d->quickSearchLine = new QuickSearchLine;
@@ -146,20 +127,29 @@ Widget::Widget(QWidget *pParent)
     connect(d->quickSearchLine, &QuickSearchLine::searchOptionChanged, this, &Widget::searchEditTextEdited);
     connect(d->quickSearchLine, &QuickSearchLine::statusButtonsClicked, this, &Widget::slotStatusButtonsClicked);
     connect(d->quickSearchLine, &QuickSearchLine::forceLostFocus, this, &Widget::forceLostFocus);
+    connect(d->quickSearchLine, &QuickSearchLine::saveFilter, this, &Widget::slotSaveFilter);
+    connect(d->quickSearchLine, &QuickSearchLine::activateFilter, this, &Widget::slotActivateFilter);
     g->addWidget(d->quickSearchLine, 0);
     d->quickSearchWarning = new QuickSearchWarning(this);
     g->addWidget(d->quickSearchWarning, 0);
     d->searchCollectionIndexingWarning = new SearchCollectionIndexingWarning(this);
     g->addWidget(d->searchCollectionIndexingWarning, 0);
 
+    d->tabLockedWarning = new TabLockedWarning(this);
+    g->addWidget(d->tabLockedWarning, 0);
+    connect(d->tabLockedWarning, &TabLockedWarning::unlockTabRequested, this, [this]() {
+        setLockTab(false);
+        Q_EMIT unlockTabRequested();
+        // Fix icon!
+    });
+
     d->mView = new View(this);
     d->mView->setFrameStyle(QFrame::NoFrame);
     d->mView->setSortOrder(&d->mSortOrder);
     d->mView->setObjectName(QStringLiteral("messagealistview"));
     g->addWidget(d->mView, 1);
 
-    connect(d->mView->header(), &QHeaderView::sectionClicked,
-            this, &Widget::slotViewHeaderSectionClicked);
+    connect(d->mView->header(), &QHeaderView::sectionClicked, this, &Widget::slotViewHeaderSectionClicked);
     d->mSearchTimer = nullptr;
 }
 
@@ -174,20 +164,40 @@ Widget::~Widget()
     delete d->mAggregation;
     delete d->mFilter;
     delete d->mStorageModel;
+}
 
-    delete d;
+void Widget::slotActivateFilter(Filter *f)
+{
+    setFilter(f);
+    d->quickSearchLine->searchEdit()->setText(f->searchString());
+    d->quickSearchLine->setSearchOptions(f->currentOptions());
+    d->quickSearchLine->setFilterMessageStatus(f->status());
+}
+
+void Widget::slotSaveFilter()
+{
+    if (d->mFilter) {
+        QPointer<FilterNameDialog> dlg = new FilterNameDialog(this);
+        dlg->setExistingFilterNames(FilterSavedManager::self()->existingFilterNames());
+        if (dlg->exec()) {
+            FilterSavedManager::self()->saveFilter(d->mFilter, dlg->filterName(), dlg->iconName());
+        }
+        delete dlg;
+    } else {
+        KMessageBox::information(this, i18n("Any filter defined."), i18n("Create Filter"));
+    }
 }
 
 void Widget::changeQuicksearchVisibility(bool show)
 {
     QLineEdit *const lineEdit = d->quickSearchLine->searchEdit();
     if (!show) {
-        //if we hide it we do not want to apply the filter,
-        //otherwise someone is maybe stuck with x new emails
-        //and cannot read it because of filter
+        // if we hide it we do not want to apply the filter,
+        // otherwise someone is maybe stuck with x new emails
+        // and cannot read it because of filter
         lineEdit->clear();
 
-        //we focus the message list if we hide the searchbar
+        // we focus the message list if we hide the searchbar
         d->mView->setFocus(Qt::OtherFocusReason);
     } else {
         // on show: we focus the lineedit for fast filtering
@@ -206,9 +216,9 @@ void Widget::populateStatusFilterCombo()
         return;
     }
     d->mStatusFilterComboPopulationInProgress = true;
-    KComboBox *tagFilterComboBox = d->quickSearchLine->tagFilterComboBox();
+    QComboBox *tagFilterComboBox = d->quickSearchLine->tagFilterComboBox();
     d->mCurrentStatusFilterIndex = (tagFilterComboBox->currentIndex() != -1) ? tagFilterComboBox->currentIndex() : 0;
-    disconnect(tagFilterComboBox, qOverload<int>(&KComboBox::currentIndexChanged), this, &Widget::statusSelected);
+    disconnect(tagFilterComboBox, qOverload<int>(&QComboBox::currentIndexChanged), this, &Widget::statusSelected);
 
     tagFilterComboBox->clear();
 
@@ -223,9 +233,9 @@ void Widget::addMessageTagItem(const QPixmap &icon, const QString &text, const Q
 void Widget::setCurrentStatusFilterItem()
 {
     d->quickSearchLine->updateComboboxVisibility();
-    connect(d->quickSearchLine->tagFilterComboBox(), qOverload<int>(&KComboBox::currentIndexChanged),
-            this, &Widget::statusSelected);
-    d->quickSearchLine->tagFilterComboBox()->setCurrentIndex(d->mCurrentStatusFilterIndex >= d->quickSearchLine->tagFilterComboBox()->count() ? 0 : d->mCurrentStatusFilterIndex);
+    connect(d->quickSearchLine->tagFilterComboBox(), qOverload<int>(&QComboBox::currentIndexChanged), this, &Widget::statusSelected);
+    d->quickSearchLine->tagFilterComboBox()->setCurrentIndex(
+        d->mCurrentStatusFilterIndex >= d->quickSearchLine->tagFilterComboBox()->count() ? 0 : d->mCurrentStatusFilterIndex);
     d->mStatusFilterComboPopulationInProgress = false;
 }
 
@@ -239,12 +249,12 @@ MessageList::Core::QuickSearchLine::SearchOptions Widget::currentOptions() const
     return d->quickSearchLine->searchOptions();
 }
 
-QList<Akonadi::MessageStatus> Widget::currentFilterStatus() const
+QVector<Akonadi::MessageStatus> Widget::currentFilterStatus() const
 {
     if (d->mFilter) {
         return d->mFilter->status();
     }
-    return QList<Akonadi::MessageStatus>();
+    return QVector<Akonadi::MessageStatus>();
 }
 
 QString Widget::currentFilterSearchString() const
@@ -264,7 +274,7 @@ QString Widget::currentFilterTagId() const
     return QString();
 }
 
-void Widget::Private::setDefaultAggregationForStorageModel(const StorageModel *storageModel)
+void Widget::WidgetPrivate::setDefaultAggregationForStorageModel(const StorageModel *storageModel)
 {
     const Aggregation *opt = Manager::instance()->aggregationForStorageModel(storageModel, &mStorageUsesPrivateAggregation);
 
@@ -278,7 +288,7 @@ void Widget::Private::setDefaultAggregationForStorageModel(const StorageModel *s
     mLastAggregationId = opt->id();
 }
 
-void Widget::Private::setDefaultThemeForStorageModel(const StorageModel *storageModel)
+void Widget::WidgetPrivate::setDefaultThemeForStorageModel(const StorageModel *storageModel)
 {
     const Theme *opt = Manager::instance()->themeForStorageModel(storageModel, &mStorageUsesPrivateTheme);
 
@@ -292,7 +302,7 @@ void Widget::Private::setDefaultThemeForStorageModel(const StorageModel *storage
     mLastThemeId = opt->id();
 }
 
-void Widget::Private::checkSortOrder(const StorageModel *storageModel)
+void Widget::WidgetPrivate::checkSortOrder(const StorageModel *storageModel)
 {
     if (storageModel && mAggregation && !mSortOrder.validForAggregation(mAggregation)) {
         qCDebug(MESSAGELIST_LOG) << "Could not restore sort order for folder" << storageModel->id();
@@ -304,14 +314,13 @@ void Widget::Private::checkSortOrder(const StorageModel *storageModel)
             mStorageUsesPrivateSortOrder = true;
         }
         if (mStorageModel) {
-            Manager::instance()->saveSortOrderForStorageModel(storageModel, mSortOrder,
-                                                              mStorageUsesPrivateSortOrder);
+            Manager::instance()->saveSortOrderForStorageModel(storageModel, mSortOrder, mStorageUsesPrivateSortOrder);
         }
         switchMessageSorting(mSortOrder.messageSorting(), mSortOrder.messageSortDirection(), -1);
     }
 }
 
-void Widget::Private::setDefaultSortOrderForStorageModel(const StorageModel *storageModel)
+void Widget::WidgetPrivate::setDefaultSortOrderForStorageModel(const StorageModel *storageModel)
 {
     // Load the sort order from config and update column headers
     mSortOrder = Manager::instance()->sortOrderForStorageModel(storageModel, &mStorageUsesPrivateSortOrder);
@@ -333,7 +342,7 @@ void Widget::saveCurrentSelection()
 void Widget::setStorageModel(StorageModel *storageModel, PreSelectionMode preSelectionMode)
 {
     if (storageModel == d->mStorageModel) {
-        return;    // nuthin to do here
+        return; // nuthin to do here
     }
 
     d->setDefaultAggregationForStorageModel(storageModel);
@@ -386,7 +395,7 @@ void Widget::themeMenuAboutToShow()
         return;
     }
 
-    QMenu *menu = qobject_cast< QMenu * >(sender());
+    auto menu = qobject_cast<QMenu *>(sender());
     if (!menu) {
         return;
     }
@@ -399,29 +408,27 @@ void Widget::themeMenuAboutToShow(QMenu *menu)
 
     menu->addSection(i18n("Theme"));
 
-    QActionGroup *grp = new QActionGroup(menu);
+    auto grp = new QActionGroup(menu);
 
-    QList< Theme * > sortedThemes = Manager::instance()->themes().values();
+    QList<Theme *> sortedThemes = Manager::instance()->themes().values();
 
     QAction *act;
 
     std::sort(sortedThemes.begin(), sortedThemes.end(), MessageList::Core::Theme::compareName);
 
-    for (const auto theme : qAsConst(sortedThemes)) {
+    for (const auto theme : std::as_const(sortedThemes)) {
         act = menu->addAction(theme->name());
         act->setCheckable(true);
         grp->addAction(act);
         act->setChecked(d->mLastThemeId == theme->id());
         act->setData(QVariant(theme->id()));
-        connect(act, &QAction::triggered,
-                this, &Widget::themeSelected);
+        connect(act, &QAction::triggered, this, &Widget::themeSelected);
     }
 
     menu->addSeparator();
 
     act = menu->addAction(i18n("Configure..."));
-    connect(act, &QAction::triggered,
-            this, &Widget::configureThemes);
+    connect(act, &QAction::triggered, this, &Widget::configureThemes);
 }
 
 void Widget::setPrivateSortOrderForStorage()
@@ -432,13 +439,12 @@ void Widget::setPrivateSortOrderForStorage()
 
     d->mStorageUsesPrivateSortOrder = !d->mStorageUsesPrivateSortOrder;
 
-    Manager::instance()->saveSortOrderForStorageModel(d->mStorageModel, d->mSortOrder,
-                                                      d->mStorageUsesPrivateSortOrder);
+    Manager::instance()->saveSortOrderForStorageModel(d->mStorageModel, d->mSortOrder, d->mStorageUsesPrivateSortOrder);
 }
 
 void Widget::configureThemes()
 {
-    Utils::ConfigureThemesDialog *dialog = new Utils::ConfigureThemesDialog(window());
+    auto dialog = new Utils::ConfigureThemesDialog(window());
     dialog->selectTheme(d->mLastThemeId);
     dialog->show();
 }
@@ -446,10 +452,10 @@ void Widget::configureThemes()
 void Widget::themeSelected(bool)
 {
     if (!d->mStorageModel) {
-        return;    // nuthin to do
+        return; // nuthin to do
     }
 
-    QAction *act = qobject_cast< QAction * >(sender());
+    auto act = qobject_cast<QAction *>(sender());
     if (!act) {
         return;
     }
@@ -470,7 +476,7 @@ void Widget::themeSelected(bool)
 
     d->mLastThemeId = opt->id();
 
-    //mStorageUsesPrivateTheme = false;
+    // mStorageUsesPrivateTheme = false;
 
     Manager::instance()->saveThemeForStorageModel(d->mStorageModel, opt->id(), d->mStorageUsesPrivateTheme);
 
@@ -479,7 +485,7 @@ void Widget::themeSelected(bool)
 
 void Widget::aggregationMenuAboutToShow()
 {
-    QMenu *menu = qobject_cast< QMenu * >(sender());
+    auto menu = qobject_cast<QMenu *>(sender());
     if (!menu) {
         return;
     }
@@ -492,35 +498,33 @@ void Widget::aggregationMenuAboutToShow(QMenu *menu)
 
     menu->addSection(i18n("Aggregation"));
 
-    QActionGroup *grp = new QActionGroup(menu);
+    auto grp = new QActionGroup(menu);
 
-    QList< Aggregation * > sortedAggregations = Manager::instance()->aggregations().values();
+    QList<Aggregation *> sortedAggregations = Manager::instance()->aggregations().values();
 
     QAction *act;
 
     std::sort(sortedAggregations.begin(), sortedAggregations.end(), MessageList::Core::Aggregation::compareName);
 
-    for (const auto agg : qAsConst(sortedAggregations)) {
+    for (const auto agg : std::as_const(sortedAggregations)) {
         act = menu->addAction(agg->name());
         act->setCheckable(true);
         grp->addAction(act);
         act->setChecked(d->mLastAggregationId == agg->id());
         act->setData(QVariant(agg->id()));
-        connect(act, &QAction::triggered,
-                this, &Widget::aggregationSelected);
+        connect(act, &QAction::triggered, this, &Widget::aggregationSelected);
     }
 
     menu->addSeparator();
 
     act = menu->addAction(i18n("Configure..."));
     act->setData(QVariant(QString()));
-    connect(act, &QAction::triggered,
-            this, &Widget::aggregationSelected);
+    connect(act, &QAction::triggered, this, &Widget::aggregationSelected);
 }
 
 void Widget::aggregationSelected(bool)
 {
-    QAction *act = qobject_cast< QAction * >(sender());
+    auto act = qobject_cast<QAction *>(sender());
     if (!act) {
         return;
     }
@@ -529,14 +533,14 @@ void Widget::aggregationSelected(bool)
     QString id = v.toString();
 
     if (id.isEmpty()) {
-        Utils::ConfigureAggregationsDialog *dialog = new Utils::ConfigureAggregationsDialog(window());
+        auto dialog = new Utils::ConfigureAggregationsDialog(window());
         dialog->selectAggregation(d->mLastAggregationId);
         dialog->show();
         return;
     }
 
     if (!d->mStorageModel) {
-        return;    // nuthin to do
+        return; // nuthin to do
     }
 
     const Aggregation *opt = Manager::instance()->aggregation(id);
@@ -548,7 +552,7 @@ void Widget::aggregationSelected(bool)
 
     d->mLastAggregationId = opt->id();
 
-    //mStorageUsesPrivateAggregation = false;
+    // mStorageUsesPrivateAggregation = false;
 
     Manager::instance()->saveAggregationForStorageModel(d->mStorageModel, opt->id(), d->mStorageUsesPrivateAggregation);
 
@@ -564,7 +568,7 @@ void Widget::sortOrderMenuAboutToShow()
         return;
     }
 
-    QMenu *menu = qobject_cast< QMenu * >(sender());
+    auto menu = qobject_cast<QMenu *>(sender());
     if (!menu) {
         return;
     }
@@ -579,12 +583,12 @@ void Widget::sortOrderMenuAboutToShow(QMenu *menu)
 
     QActionGroup *grp;
     QAction *act;
-    QList< QPair< QString, int > > options;
+    QVector<QPair<QString, int>> options;
 
     grp = new QActionGroup(menu);
 
     options = SortOrder::enumerateMessageSortingOptions(d->mAggregation->threading());
-    for (const auto &opt : qAsConst(options)) {
+    for (const auto &opt : std::as_const(options)) {
         act = menu->addAction(opt.first);
         act->setCheckable(true);
         grp->addAction(act);
@@ -592,8 +596,7 @@ void Widget::sortOrderMenuAboutToShow(QMenu *menu)
         act->setData(QVariant(opt.second));
     }
 
-    connect(grp, &QActionGroup::triggered,
-            this, &Widget::messageSortingSelected);
+    connect(grp, &QActionGroup::triggered, this, &Widget::messageSortingSelected);
 
     options = SortOrder::enumerateMessageSortDirectionOptions(d->mSortOrder.messageSorting());
 
@@ -601,7 +604,7 @@ void Widget::sortOrderMenuAboutToShow(QMenu *menu)
         menu->addSection(i18n("Message Sort Direction"));
 
         grp = new QActionGroup(menu);
-        for (const auto &opt : qAsConst(options)) {
+        for (const auto &opt : std::as_const(options)) {
             act = menu->addAction(opt.first);
             act->setCheckable(true);
             grp->addAction(act);
@@ -609,8 +612,7 @@ void Widget::sortOrderMenuAboutToShow(QMenu *menu)
             act->setData(QVariant(opt.second));
         }
 
-        connect(grp, &QActionGroup::triggered,
-                this, &Widget::messageSortDirectionSelected);
+        connect(grp, &QActionGroup::triggered, this, &Widget::messageSortDirectionSelected);
     }
 
     options = SortOrder::enumerateGroupSortingOptions(d->mAggregation->grouping());
@@ -619,7 +621,7 @@ void Widget::sortOrderMenuAboutToShow(QMenu *menu)
         menu->addSection(i18n("Group Sort Order"));
 
         grp = new QActionGroup(menu);
-        for (const auto &opt : qAsConst(options)) {
+        for (const auto &opt : std::as_const(options)) {
             act = menu->addAction(opt.first);
             act->setCheckable(true);
             grp->addAction(act);
@@ -627,18 +629,16 @@ void Widget::sortOrderMenuAboutToShow(QMenu *menu)
             act->setData(QVariant(opt.second));
         }
 
-        connect(grp, &QActionGroup::triggered,
-                this, &Widget::groupSortingSelected);
+        connect(grp, &QActionGroup::triggered, this, &Widget::groupSortingSelected);
     }
 
-    options = SortOrder::enumerateGroupSortDirectionOptions(d->mAggregation->grouping(),
-                                                            d->mSortOrder.groupSorting());
+    options = SortOrder::enumerateGroupSortDirectionOptions(d->mAggregation->grouping(), d->mSortOrder.groupSorting());
 
     if (options.size() >= 2) {
         menu->addSection(i18n("Group Sort Direction"));
 
         grp = new QActionGroup(menu);
-        for (const auto &opt : qAsConst(options)) {
+        for (const auto &opt : std::as_const(options)) {
             act = menu->addAction(opt.first);
             act->setCheckable(true);
             grp->addAction(act);
@@ -646,19 +646,17 @@ void Widget::sortOrderMenuAboutToShow(QMenu *menu)
             act->setData(QVariant(opt.second));
         }
 
-        connect(grp, &QActionGroup::triggered,
-                this, &Widget::groupSortDirectionSelected);
+        connect(grp, &QActionGroup::triggered, this, &Widget::groupSortDirectionSelected);
     }
 
     menu->addSeparator();
     act = menu->addAction(i18n("Folder Always Uses This Sort Order"));
     act->setCheckable(true);
     act->setChecked(d->mStorageUsesPrivateSortOrder);
-    connect(act, &QAction::triggered,
-            this, &Widget::setPrivateSortOrderForStorage);
+    connect(act, &QAction::triggered, this, &Widget::setPrivateSortOrderForStorage);
 }
 
-void Widget::Private::switchMessageSorting(SortOrder::MessageSorting messageSorting, SortOrder::SortDirection sortDirection, int logicalHeaderColumnIndex)
+void Widget::WidgetPrivate::switchMessageSorting(SortOrder::MessageSorting messageSorting, SortOrder::SortDirection sortDirection, int logicalHeaderColumnIndex)
 {
     mSortOrder.setMessageSorting(messageSorting);
     mSortOrder.setMessageSortDirection(sortDirection);
@@ -674,7 +672,7 @@ void Widget::Private::switchMessageSorting(SortOrder::MessageSorting messageSort
 
         // First try with a well defined message sorting.
 
-        for (const auto column : qAsConst(columns)) {
+        for (const auto column : std::as_const(columns)) {
             if (!mView->header()->isSectionHidden(idx)) {
                 if (column->messageSorting() == messageSorting) {
                     // found a visible column with this message sorting
@@ -688,20 +686,12 @@ void Widget::Private::switchMessageSorting(SortOrder::MessageSorting messageSort
         // if still not found, try again with a wider range
         if (logicalHeaderColumnIndex == -1) {
             idx = 0;
-            for (const auto column : qAsConst(columns)) {
+            for (const auto column : std::as_const(columns)) {
                 if (!mView->header()->isSectionHidden(idx)) {
-                    if (
-                        (
-                            (column->messageSorting() == SortOrder::SortMessagesBySenderOrReceiver)
-                            || (column->messageSorting() == SortOrder::SortMessagesByReceiver)
-                            || (column->messageSorting() == SortOrder::SortMessagesBySender)
-                        )
-                        && (
-                            (messageSorting == SortOrder::SortMessagesBySenderOrReceiver)
-                            || (messageSorting == SortOrder::SortMessagesByReceiver)
-                            || (messageSorting == SortOrder::SortMessagesBySender)
-                            )
-                        ) {
+                    if (((column->messageSorting() == SortOrder::SortMessagesBySenderOrReceiver)
+                         || (column->messageSorting() == SortOrder::SortMessagesByReceiver) || (column->messageSorting() == SortOrder::SortMessagesBySender))
+                        && ((messageSorting == SortOrder::SortMessagesBySenderOrReceiver) || (messageSorting == SortOrder::SortMessagesByReceiver)
+                            || (messageSorting == SortOrder::SortMessagesBySender))) {
                         // found a visible column with this message sorting
                         logicalHeaderColumnIndex = idx;
                         break;
@@ -741,15 +731,14 @@ void Widget::messageSortingSelected(QAction *action)
     }
 
     bool ok;
-    auto ord = static_cast< SortOrder::MessageSorting >(action->data().toInt(&ok));
+    auto ord = static_cast<SortOrder::MessageSorting>(action->data().toInt(&ok));
 
     if (!ok) {
         return;
     }
 
     d->switchMessageSorting(ord, d->mSortOrder.messageSortDirection(), -1);
-    Manager::instance()->saveSortOrderForStorageModel(d->mStorageModel, d->mSortOrder,
-                                                      d->mStorageUsesPrivateSortOrder);
+    Manager::instance()->saveSortOrderForStorageModel(d->mStorageModel, d->mSortOrder, d->mStorageUsesPrivateSortOrder);
 
     d->mView->reload();
 }
@@ -767,15 +756,14 @@ void Widget::messageSortDirectionSelected(QAction *action)
     }
 
     bool ok;
-    auto ord = static_cast< SortOrder::SortDirection >(action->data().toInt(&ok));
+    auto ord = static_cast<SortOrder::SortDirection>(action->data().toInt(&ok));
 
     if (!ok) {
         return;
     }
 
     d->switchMessageSorting(d->mSortOrder.messageSorting(), ord, -1);
-    Manager::instance()->saveSortOrderForStorageModel(d->mStorageModel, d->mSortOrder,
-                                                      d->mStorageUsesPrivateSortOrder);
+    Manager::instance()->saveSortOrderForStorageModel(d->mStorageModel, d->mSortOrder, d->mStorageUsesPrivateSortOrder);
 
     d->mView->reload();
 }
@@ -794,15 +782,14 @@ void Widget::groupSortingSelected(QAction *action)
     }
 
     bool ok;
-    auto ord = static_cast< SortOrder::GroupSorting >(action->data().toInt(&ok));
+    auto ord = static_cast<SortOrder::GroupSorting>(action->data().toInt(&ok));
 
     if (!ok) {
         return;
     }
 
     d->mSortOrder.setGroupSorting(ord);
-    Manager::instance()->saveSortOrderForStorageModel(d->mStorageModel, d->mSortOrder,
-                                                      d->mStorageUsesPrivateSortOrder);
+    Manager::instance()->saveSortOrderForStorageModel(d->mStorageModel, d->mSortOrder, d->mStorageUsesPrivateSortOrder);
 
     d->mView->reload();
 }
@@ -820,19 +807,26 @@ void Widget::groupSortDirectionSelected(QAction *action)
     }
 
     bool ok;
-    auto ord = static_cast< SortOrder::SortDirection >(action->data().toInt(&ok));
+    auto ord = static_cast<SortOrder::SortDirection>(action->data().toInt(&ok));
 
     if (!ok) {
         return;
     }
 
     d->mSortOrder.setGroupSortDirection(ord);
-    Manager::instance()->saveSortOrderForStorageModel(d->mStorageModel, d->mSortOrder,
-                                                      d->mStorageUsesPrivateSortOrder);
+    Manager::instance()->saveSortOrderForStorageModel(d->mStorageModel, d->mSortOrder, d->mStorageUsesPrivateSortOrder);
 
     d->mView->reload();
 }
 
+void Widget::setFilter(Filter *filter)
+{
+    resetFilter();
+    d->mFilter = filter;
+    // TODO
+    d->mView->model()->setFilter(d->mFilter);
+}
+
 void Widget::resetFilter()
 {
     delete d->mFilter;
@@ -862,11 +856,11 @@ void Widget::slotViewHeaderSectionClicked(int logicalIndex)
 
     auto column = d->mTheme->column(logicalIndex);
     if (!column) {
-        return;    // should never happen...
+        return; // should never happen...
     }
 
     if (column->messageSorting() == SortOrder::NoMessageSorting) {
-        return;    // this is a null op.
+        return; // this is a null op.
     }
 
     if (d->mSortOrder.messageSorting() == column->messageSorting()) {
@@ -880,8 +874,7 @@ void Widget::slotViewHeaderSectionClicked(int logicalIndex)
         // keep sort direction but switch sort order
         d->switchMessageSorting(column->messageSorting(), d->mSortOrder.messageSortDirection(), logicalIndex);
     }
-    Manager::instance()->saveSortOrderForStorageModel(d->mStorageModel, d->mSortOrder,
-                                                      d->mStorageUsesPrivateSortOrder);
+    Manager::instance()->saveSortOrderForStorageModel(d->mStorageModel, d->mSortOrder, d->mStorageUsesPrivateSortOrder);
 
     d->mView->reload();
 }
@@ -909,7 +902,7 @@ void Widget::fillMessageTagCombo()
 
 void Widget::tagIdSelected(const QVariant &data)
 {
-    QString tagId = data.toString();
+    const QString tagId = data.toString();
 
     if (tagId.isEmpty()) {
         if (d->mFilter) {
@@ -928,6 +921,21 @@ void Widget::tagIdSelected(const QVariant &data)
     d->mView->model()->setFilter(d->mFilter);
 }
 
+void Widget::setLockTab(bool lock)
+{
+    d->mLockTab = lock;
+    if (lock) {
+        d->tabLockedWarning->animatedShow();
+    } else {
+        d->tabLockedWarning->animatedHide();
+    }
+}
+
+bool Widget::isLocked() const
+{
+    return d->mLockTab;
+}
+
 void Widget::statusSelected(int index)
 {
     if (index == 0) {
@@ -947,14 +955,13 @@ void Widget::searchEditTextEdited()
 
     if (!d->mSearchTimer) {
         d->mSearchTimer = new QTimer(this);
-        connect(d->mSearchTimer, &QTimer::timeout,
-                this, &Widget::searchTimerFired);
+        connect(d->mSearchTimer, &QTimer::timeout, this, &Widget::searchTimerFired);
     } else {
         d->mSearchTimer->stop(); // eventually
     }
 
     d->mSearchTimer->setSingleShot(true);
-    d->mSearchTimer->start(1000);
+    d->mSearchTimer->start(1s);
 }
 
 void Widget::slotStatusButtonsClicked()
@@ -1038,7 +1045,7 @@ void Widget::viewSelectionChanged()
 {
 }
 
-void Widget::viewMessageListContextPopupRequest(const QList< MessageItem * > &, const QPoint &)
+void Widget::viewMessageListContextPopupRequest(const QVector<MessageItem *> &, const QPoint &)
 {
 }
 
@@ -1064,9 +1071,9 @@ void Widget::viewStartDragRequest()
 
 void Widget::viewMessageStatusChangeRequest(MessageItem *msg, Akonadi::MessageStatus set, Akonadi::MessageStatus clear)
 {
-    Q_UNUSED(msg);
-    Q_UNUSED(set);
-    Q_UNUSED(clear);
+    Q_UNUSED(msg)
+    Q_UNUSED(set)
+    Q_UNUSED(clear)
 }
 
 void Widget::focusQuickSearch(const QString &selectedText)
@@ -1091,8 +1098,10 @@ Akonadi::Collection Widget::currentFolder() const
 
 void Widget::setCurrentFolder(const Akonadi::Collection &collection)
 {
-    d->mCurrentFolder = collection;
-    d->searchCollectionIndexingWarning->setCollection(collection);
+    if (!d->mLockTab) {
+        d->mCurrentFolder = collection;
+        d->searchCollectionIndexingWarning->setCollection(collection);
+    }
 }
 
 bool Widget::searchEditHasFocus() const
