@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "quicksearchwarning.h"
@@ -30,7 +18,7 @@ QuickSearchWarning::QuickSearchWarning(QWidget *parent)
     setMessageType(Warning);
     setWordWrap(true);
     setText(i18n("The words less than 3 letters are ignored."));
-    QAction *action = new QAction(i18n("Do not show again"), this);
+    auto action = new QAction(i18n("Do not show again"), this);
     action->setObjectName(QStringLiteral("donotshowagain"));
     connect(action, &QAction::triggered, this, &QuickSearchWarning::slotDoNotRememberIt);
     addAction(action);
@@ -43,10 +31,10 @@ QuickSearchWarning::~QuickSearchWarning()
 void QuickSearchWarning::setSearchText(const QString &text)
 {
     if (!MessageList::MessageListSettings::quickSearchWarningDoNotShowAgain()) {
-        const QStringList lstText = text.split(QLatin1Char(' '), QString::SkipEmptyParts);
+        const QStringList lstText = text.split(QLatin1Char(' '), Qt::SkipEmptyParts);
         bool foundLessThanThreeCharacters = false;
-        for (const QString &text : lstText) {
-            if (text.trimmed().size() < 3) {
+        for (const QString &splitText : lstText) {
+            if (splitText.trimmed().size() < 3) {
                 foundLessThanThreeCharacters = true;
                 break;
             }
