@@ -1,22 +1,23 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef QUICKSEARCHWARNING_H
-#define QUICKSEARCHWARNING_H
+#pragma once
 
-#include <KMessageWidget>
 #include "messagelist_private_export.h"
-namespace MessageList {
-namespace Core {
+#include <KMessageWidget>
+namespace MessageList
+{
+namespace Core
+{
 class MESSAGELIST_TESTS_EXPORT QuickSearchWarning : public KMessageWidget
 {
     Q_OBJECT
 public:
     explicit QuickSearchWarning(QWidget *parent = nullptr);
-    ~QuickSearchWarning();
+    ~QuickSearchWarning() override;
     void setSearchText(const QString &text);
 
 private Q_SLOTS:
@@ -24,4 +25,3 @@ private Q_SLOTS:
 };
 }
 }
-#endif // QUICKSEARCHWARNING_H
