@@ -5,32 +5,37 @@
  *
  */
 
-#ifndef SEARCHCOLLECTIONINDEXINGWARNING_H
-#define SEARCHCOLLECTIONINDEXINGWARNING_H
+#pragma once
 
-#include <KMessageWidget>
-#include <AkonadiCore/Collection>
 #include "messagelist_private_export.h"
+#include <Akonadi/Collection>
+#include <KMessageWidget>
 class KJob;
 
-namespace Akonadi {
-namespace Search {
-namespace PIM {
+namespace Akonadi
+{
+namespace Search
+{
+namespace PIM
+{
 class IndexedItems;
 }
 }
 }
-namespace Akonadi {
+namespace Akonadi
+{
 class CollectionFetchJob;
 }
-namespace MessageList {
-namespace Core {
+namespace MessageList
+{
+namespace Core
+{
 class MESSAGELIST_TESTS_EXPORT SearchCollectionIndexingWarning : public KMessageWidget
 {
     Q_OBJECT
 public:
     explicit SearchCollectionIndexingWarning(QWidget *parent = nullptr);
-    ~SearchCollectionIndexingWarning();
+    ~SearchCollectionIndexingWarning() override;
 
     void setCollection(const Akonadi::Collection &collection);
 
@@ -44,9 +49,8 @@ private:
 
     Akonadi::Collection mCollection;
     Akonadi::Collection::List mCollections;
-    Akonadi::Search::PIM::IndexedItems *mIndexedItems = nullptr;
+    Akonadi::Search::PIM::IndexedItems *const mIndexedItems;
 };
 }
 }
 
-#endif // SEARCHCOLLECTIONINDEXINGWARNING_H
