@@ -1,31 +1,20 @@
 /*
   This file is part of KMail, the KDE mail client.
-  Copyright (c) 2011-2018 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
 
-  KMail is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  KMail is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "messagelistutil.h"
-#include "messagelistutil_p.h"
 #include "messagelistsettings.h"
+#include "messagelistutil_p.h"
 
+#include <Akonadi/Item>
+#include <KColorScheme>
 #include <KConfigGroup>
-#include <QMenu>
-#include <QIcon>
 #include <KLocalizedString>
 #include <KMime/Message>
-#include <Item>
-#include <KColorScheme>
+#include <QIcon>
+#include <QMenu>
 
 QString MessageList::Util::messageSortingConfigName()
 {
@@ -79,34 +68,30 @@ QString MessageList::Util::storageModelSelectedMessageGroup()
 
 void MessageList::Util::deleteConfig(const QString &collectionId)
 {
-    KConfigGroup confselectedMessage(MessageListSettings::self()->config(),
-                                     MessageList::Util::storageModelSelectedMessageGroup());
+    KConfigGroup confselectedMessage(MessageListSettings::self()->config(), MessageList::Util::storageModelSelectedMessageGroup());
     confselectedMessage.deleteEntry(MessageList::Util::messageUniqueIdConfigName().arg(collectionId));
 
-    KConfigGroup storageModelOrder(MessageListSettings::self()->config(),
-                                   MessageList::Util::storageModelSortOrderGroup());
+    KConfigGroup storageModelOrder(MessageListSettings::self()->config(), MessageList::Util::storageModelSortOrderGroup());
     storageModelOrder.deleteEntry(collectionId + groupSortDirectionConfigName());
     storageModelOrder.deleteEntry(collectionId + groupSortingConfigName());
     storageModelOrder.deleteEntry(collectionId + messageSortDirectionConfigName());
     storageModelOrder.deleteEntry(collectionId + messageSortingConfigName());
 
-    KConfigGroup storageModelTheme(MessageListSettings::self()->config(),
-                                   MessageList::Util::storageModelThemesGroup());
+    KConfigGroup storageModelTheme(MessageListSettings::self()->config(), MessageList::Util::storageModelThemesGroup());
     storageModelTheme.deleteEntry(collectionId + setForStorageModelConfigName());
 
-    KConfigGroup storageModelAggregation(MessageListSettings::self()->config(),
-                                         MessageList::Util::storageModelAggregationsGroup());
+    KConfigGroup storageModelAggregation(MessageListSettings::self()->config(), MessageList::Util::storageModelAggregationsGroup());
     storageModelAggregation.deleteEntry(collectionId + setForStorageModelConfigName());
 }
 
 QColor MessageList::Util::unreadDefaultMessageColor()
 {
-    return KColorScheme(QPalette::Active, KColorScheme::Complementary).decoration(KColorScheme::FocusColor).color();
+    return KColorScheme(QPalette::Active).foreground(KColorScheme::ActiveText).color();
 }
 
 QColor MessageList::Util::importantDefaultMessageColor()
 {
-    return KColorScheme(QPalette::Active).foreground(KColorScheme::NegativeText).color();
+    return KColorScheme(QPalette::Active).foreground(KColorScheme::NeutralText).color();
 }
 
 QColor MessageList::Util::todoDefaultMessageColor()
@@ -116,21 +101,20 @@ QColor MessageList::Util::todoDefaultMessageColor()
 
 void MessageList::Util::fillViewMenu(QMenu *menu, QObject *receiver)
 {
-    QMenu *sortingMenu = new QMenu(i18n("Sorting"), menu);
+    auto sortingMenu = new QMenu(i18n("Sorting"), menu);
     sortingMenu->setIcon(QIcon::fromTheme(QStringLiteral("view-sort-ascending")));
     menu->addMenu(sortingMenu);
     QObject::connect(sortingMenu, SIGNAL(aboutToShow()), receiver, SLOT(sortOrderMenuAboutToShow()));
 
-    QMenu *aggregationMenu = new QMenu(i18n("Aggregation"), menu);
+    auto aggregationMenu = new QMenu(i18n("Aggregation"), menu);
     aggregationMenu->setIcon(QIcon::fromTheme(QStringLiteral("view-process-tree")));
     menu->addMenu(aggregationMenu);
     QObject::connect(aggregationMenu, SIGNAL(aboutToShow()), receiver, SLOT(aggregationMenuAboutToShow()));
 
-    QMenu *themeMenu = new QMenu(i18n("Theme"), menu);
+    auto themeMenu = new QMenu(i18n("Theme"), menu);
     themeMenu->setIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-theme")));
     menu->addMenu(themeMenu);
-    QObject::connect(themeMenu, SIGNAL(aboutToShow()),
-                     receiver, SLOT(themeMenuAboutToShow()));
+    QObject::connect(themeMenu, SIGNAL(aboutToShow()), receiver, SLOT(themeMenuAboutToShow()));
 }
 
 QString MessageList::Util::contentSummary(const Akonadi::Item &item)
@@ -139,7 +123,7 @@ QString MessageList::Util::contentSummary(const Akonadi::Item &item)
         return QString();
     }
 
-    KMime::Message::Ptr message = item.payload<KMime::Message::Ptr>();
+    auto message = item.payload<KMime::Message::Ptr>();
     KMime::Content *textContent = message->textContent();
     if (!textContent) {
         return QString();
@@ -158,7 +142,6 @@ QString MessageList::Util::contentSummary(const Akonadi::Item &item)
     }
     if (lines.count() == 1 && content.length() > 100) {
         return content.left(100);
-
     }
     QString ret;
     for (const QString &line : lines) {
