@@ -8,54 +8,39 @@
 
 #include <KActionCollection>
 #include <KActionMenu>
-#include <QIcon>
 #include <KLocalizedString>
-#include <QMenu>
+#include <KToggleAction>
 #include <KXMLGUIClient>
 #include <QAction>
-#include <KToggleAction>
-#include <KStandardAction>
+#include <QIcon>
+#include <QMenu>
 
 #include <QAbstractItemModel>
 #include <QAbstractProxyModel>
+#include <QApplication>
+#include <QHeaderView>
 #include <QItemSelectionModel>
+#include <QMouseEvent>
+#include <QRegularExpression>
 #include <QTabBar>
 #include <QToolButton>
-#include <QMouseEvent>
-#include <QHeaderView>
-#include <QRegularExpression>
-#include <QVector>
-#include <QApplication>
 
-#include "storagemodel.h"
-#include "core/widgets/quicksearchline.h"
-#include "widget.h"
-#include "messagelistsettings.h"
 #include "core/manager.h"
-#include <Akonadi/KMime/MessageStatus>
 #include "core/model.h"
+#include "core/widgets/quicksearchline.h"
+#include "messagelistsettings.h"
 #include "messagelistutil_p.h"
+#include "storagemodel.h"
+#include "widget.h"
+#include <Akonadi/KMime/MessageStatus>
 
-namespace MessageList {
-class Q_DECL_HIDDEN Pane::Private
+namespace MessageList
+{
+class Pane::PanePrivate
 {
 public:
-    Private(Pane *owner)
+    PanePrivate(Pane *owner)
         : q(owner)
-        , mXmlGuiClient(nullptr)
-        , mActionMenu(nullptr)
-        , mModel(nullptr)
-        , mSelectionModel(nullptr)
-        , mPreSelectionMode(Core::PreSelectLastSelected)
-        , mNewTabButton(nullptr)
-        , mCloseTabButton(nullptr)
-        , mCloseTabAction(nullptr)
-        , mActivateNextTabAction(nullptr)
-        , mActivatePreviousTabAction(nullptr)
-        , mMoveTabLeftAction(nullptr)
-        , mMoveTabRightAction(nullptr)
-        , mPreferEmptyTab(false)
-        , mMaxTabCreated(0)
     {
     }
 
@@ -85,7 +70,7 @@ public:
 
     QAbstractItemModel *mModel = nullptr;
     QItemSelectionModel *mSelectionModel = nullptr;
-    Core::PreSelectionMode mPreSelectionMode;
+    Core::PreSelectionMode mPreSelectionMode = Core::PreSelectLastSelected;
 
     QHash<Widget *, QItemSelectionModel *> mWidgetSelectionHash;
     QVector<const QAbstractProxyModel *> mProxyStack;
@@ -97,8 +82,8 @@ public:
     QAction *mActivatePreviousTabAction = nullptr;
     QAction *mMoveTabLeftAction = nullptr;
     QAction *mMoveTabRightAction = nullptr;
-    bool mPreferEmptyTab;
-    int mMaxTabCreated;
+    bool mPreferEmptyTab = false;
+    int mMaxTabCreated = 0;
 };
 } // namespace MessageList
 
@@ -107,7 +92,7 @@ using namespace MessageList;
 
 Pane::Pane(bool restoreSession, QAbstractItemModel *model, QItemSelectionModel *selectionModel, QWidget *parent)
     : QTabWidget(parent)
-    , d(new Private(this))
+    , d(new PanePrivate(this))
 {
     setDocumentMode(true);
     d->mModel = model;
@@ -152,8 +137,7 @@ Pane::Pane(bool restoreSession, QAbstractItemModel *model, QItemSelectionModel *
     d->mCloseTabButton->setAccessibleName(i18n("Close tab"));
 #endif
     setCornerWidget(d->mCloseTabButton, Qt::TopRightCorner);
-    connect(d->mCloseTabButton, &QToolButton::clicked,
-            this, [this]() {
+    connect(d->mCloseTabButton, &QToolButton::clicked, this, [this]() {
         d->onCloseTabClicked();
     });
 
@@ -165,8 +149,7 @@ Pane::Pane(bool restoreSession, QAbstractItemModel *model, QItemSelectionModel *
     readConfig(restoreSession);
     setMovable(true);
 
-    connect(this, &Pane::currentChanged,
-            this, [this]() {
+    connect(this, &Pane::currentChanged, this, [this]() {
         d->onCurrentTabChanged();
     });
 
@@ -175,13 +158,11 @@ Pane::Pane(bool restoreSession, QAbstractItemModel *model, QItemSelectionModel *
         d->onTabContextMenuRequest(point);
     });
 
-    connect(MessageListSettings::self(), &MessageListSettings::configChanged,
-            this, [this]() {
+    connect(MessageListSettings::self(), &MessageListSettings::configChanged, this, [this]() {
         d->updateTabControls();
     });
 
-    connect(this, &QTabWidget::tabBarDoubleClicked,
-            this, &Pane::createNewTab);
+    connect(this, &QTabWidget::tabBarDoubleClicked, this, &Pane::createNewTab);
 
     tabBar()->installEventFilter(this);
 }
@@ -190,13 +171,12 @@ Pane::~Pane()
 {
     saveCurrentSelection();
     writeConfig(true);
-    delete d;
 }
 
-void Pane::Private::addActivateTabAction(int i)
+void Pane::PanePrivate::addActivateTabAction(int i)
 {
     const QString actionname = QString::asprintf("activate_tab_%02d", i);
-    QAction *action = new QAction(i18n("Activate Tab %1", i), q);
+    auto action = new QAction(i18n("Activate Tab %1", i), q);
     mXmlGuiClient->actionCollection()->addAction(actionname, action);
     mXmlGuiClient->actionCollection()->setDefaultShortcut(action, QKeySequence(QStringLiteral("Alt+%1").arg(i)));
     connect(action, &QAction::triggered, q, [this]() {
@@ -204,7 +184,7 @@ void Pane::Private::addActivateTabAction(int i)
     });
 }
 
-void Pane::Private::slotTabCloseRequested(int index)
+void Pane::PanePrivate::slotTabCloseRequested(int index)
 {
     QWidget *w = q->widget(index);
     if (w) {
@@ -216,8 +196,8 @@ void Pane::setXmlGuiClient(KXMLGUIClient *xmlGuiClient)
 {
     d->mXmlGuiClient = xmlGuiClient;
 
-    KToggleAction *const showHideQuicksearch = new KToggleAction(i18n("Show Quick Search Bar"), this);
-    d->mXmlGuiClient->actionCollection()->setDefaultShortcut(showHideQuicksearch, Qt::CTRL + Qt::Key_H);
+    auto const showHideQuicksearch = new KToggleAction(i18n("Show Quick Search Bar"), this);
+    d->mXmlGuiClient->actionCollection()->setDefaultShortcut(showHideQuicksearch, Qt::CTRL | Qt::Key_H);
     showHideQuicksearch->setChecked(MessageListSettings::showQuickSearch());
 
     d->mXmlGuiClient->actionCollection()->addAction(QStringLiteral("show_quick_search"), showHideQuicksearch);
@@ -226,7 +206,7 @@ void Pane::setXmlGuiClient(KXMLGUIClient *xmlGuiClient)
     });
 
     for (int i = 0; i < count(); ++i) {
-        Widget *w = qobject_cast<Widget *>(widget(i));
+        auto w = qobject_cast<Widget *>(widget(i));
         if (w) {
             w->setXmlGuiClient(d->mXmlGuiClient);
         }
@@ -243,9 +223,9 @@ void Pane::setXmlGuiClient(KXMLGUIClient *xmlGuiClient)
 
         d->mActionMenu->addSeparator();
 
-        QAction *action = new QAction(i18n("Create New Tab"), this);
+        auto action = new QAction(i18n("Create New Tab"), this);
         d->mXmlGuiClient->actionCollection()->addAction(QStringLiteral("create_new_tab"), action);
-        d->mXmlGuiClient->actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_O));
+        d->mXmlGuiClient->actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_O));
         connect(action, &QAction::triggered, this, [this]() {
             d->onNewTabClicked();
         });
@@ -260,7 +240,8 @@ void Pane::setXmlGuiClient(KXMLGUIClient *xmlGuiClient)
         QList<QKeySequence> nextShortcut;
         QList<QKeySequence> prevShortcut;
 
-        QString nextIcon, prevIcon;
+        QString nextIcon;
+        QString prevIcon;
         if (QApplication::isRightToLeft()) {
             nextShortcut.append(KStandardShortcut::tabPrev());
             prevShortcut.append(KStandardShortcut::tabNext());
@@ -315,7 +296,9 @@ void Pane::setXmlGuiClient(KXMLGUIClient *xmlGuiClient)
 
         d->mCloseTabAction = new QAction(i18n("Close Tab"), this);
         d->mXmlGuiClient->actionCollection()->addAction(QStringLiteral("close_current_tab"), d->mCloseTabAction);
-        d->mXmlGuiClient->actionCollection()->setDefaultShortcuts(d->mCloseTabAction, QList<QKeySequence>() << QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_W) << QKeySequence(Qt::CTRL + Qt::Key_W));
+        d->mXmlGuiClient->actionCollection()->setDefaultShortcuts(d->mCloseTabAction,
+                                                                  QList<QKeySequence>()
+                                                                      << QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_W) << QKeySequence(Qt::CTRL | Qt::Key_W));
         connect(d->mCloseTabAction, &QAction::triggered, this, [this]() {
             d->onCloseTabClicked();
         });
@@ -324,9 +307,12 @@ void Pane::setXmlGuiClient(KXMLGUIClient *xmlGuiClient)
     }
 }
 
-bool Pane::selectNextMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, MessageList::Core::ExistingSelectionBehaviour existingSelectionBehaviour, bool centerItem, bool loop)
+bool Pane::selectNextMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter,
+                                 MessageList::Core::ExistingSelectionBehaviour existingSelectionBehaviour,
+                                 bool centerItem,
+                                 bool loop)
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
+    auto w = static_cast<Widget *>(currentWidget());
 
     if (w) {
         if (w->view()->model()->isLoading()) {
@@ -339,9 +325,12 @@ bool Pane::selectNextMessageItem(MessageList::Core::MessageTypeFilter messageTyp
     }
 }
 
-bool Pane::selectPreviousMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, MessageList::Core::ExistingSelectionBehaviour existingSelectionBehaviour, bool centerItem, bool loop)
+bool Pane::selectPreviousMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter,
+                                     MessageList::Core::ExistingSelectionBehaviour existingSelectionBehaviour,
+                                     bool centerItem,
+                                     bool loop)
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
+    auto w = static_cast<Widget *>(currentWidget());
 
     if (w) {
         if (w->view()->model()->isLoading()) {
@@ -356,7 +345,7 @@ bool Pane::selectPreviousMessageItem(MessageList::Core::MessageTypeFilter messag
 
 bool Pane::focusNextMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, bool centerItem, bool loop)
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
+    auto w = static_cast<Widget *>(currentWidget());
 
     if (w) {
         if (w->view()->model()->isLoading()) {
@@ -371,7 +360,7 @@ bool Pane::focusNextMessageItem(MessageList::Core::MessageTypeFilter messageType
 
 bool Pane::focusPreviousMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, bool centerItem, bool loop)
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
+    auto w = static_cast<Widget *>(currentWidget());
 
     if (w) {
         if (w->view()->model()->isLoading()) {
@@ -386,7 +375,7 @@ bool Pane::focusPreviousMessageItem(MessageList::Core::MessageTypeFilter message
 
 void Pane::selectFocusedMessageItem(bool centerItem)
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
+    auto w = static_cast<Widget *>(currentWidget());
 
     if (w) {
         if (w->view()->model()->isLoading()) {
@@ -399,7 +388,7 @@ void Pane::selectFocusedMessageItem(bool centerItem)
 
 bool Pane::selectFirstMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, bool centerItem)
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
+    auto w = static_cast<Widget *>(currentWidget());
 
     if (w) {
         if (w->view()->model()->isLoading()) {
@@ -414,7 +403,7 @@ bool Pane::selectFirstMessageItem(MessageList::Core::MessageTypeFilter messageTy
 
 bool Pane::selectLastMessageItem(Core::MessageTypeFilter messageTypeFilter, bool centerItem)
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
+    auto w = static_cast<Widget *>(currentWidget());
 
     if (w) {
         if (w->view()->model()->isLoading()) {
@@ -429,7 +418,7 @@ bool Pane::selectLastMessageItem(Core::MessageTypeFilter messageTypeFilter, bool
 
 void Pane::selectAll()
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
+    auto w = static_cast<Widget *>(currentWidget());
 
     if (w) {
         if (w->view()->model()->isLoading()) {
@@ -442,7 +431,7 @@ void Pane::selectAll()
 
 void Pane::setCurrentThreadExpanded(bool expand)
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
+    auto w = static_cast<Widget *>(currentWidget());
 
     if (w) {
         if (w->view()->model()->isLoading()) {
@@ -455,7 +444,7 @@ void Pane::setCurrentThreadExpanded(bool expand)
 
 void Pane::setAllThreadsExpanded(bool expand)
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
+    auto w = static_cast<Widget *>(currentWidget());
 
     if (w) {
         if (w->view()->model()->isLoading()) {
@@ -468,7 +457,7 @@ void Pane::setAllThreadsExpanded(bool expand)
 
 void Pane::setAllGroupsExpanded(bool expand)
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
+    auto w = static_cast<Widget *>(currentWidget());
 
     if (w) {
         if (w->view()->model()->isLoading()) {
@@ -481,7 +470,7 @@ void Pane::setAllGroupsExpanded(bool expand)
 
 void Pane::focusQuickSearch(const QString &selectedText)
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
+    auto w = static_cast<Widget *>(currentWidget());
 
     if (w) {
         w->focusQuickSearch(selectedText);
@@ -490,20 +479,20 @@ void Pane::focusQuickSearch(const QString &selectedText)
 
 void Pane::setQuickSearchClickMessage(const QString &msg)
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
+    auto w = static_cast<Widget *>(currentWidget());
 
     if (w) {
         w->setQuickSearchClickMessage(msg);
     }
 }
 
-void Pane::Private::setCurrentFolder(const QModelIndex &etmIndex)
+void Pane::PanePrivate::setCurrentFolder(const QModelIndex &etmIndex)
 {
     if (mPreferEmptyTab) {
         q->createNewTab();
     }
 
-    Widget *w = static_cast<Widget *>(q->currentWidget());
+    auto w = static_cast<Widget *>(q->currentWidget());
     QItemSelectionModel *s = mWidgetSelectionHash[w];
 
     w->saveCurrentSelection();
@@ -544,18 +533,17 @@ void Pane::Private::setCurrentFolder(const QModelIndex &etmIndex)
     q->setTabIcon(index, icon);
     q->setTabToolTip(index, toolTip);
     if (mPreferEmptyTab) {
-        mSelectionModel->select(mapSelectionFromSource(s->selection()),
-                                QItemSelectionModel::ClearAndSelect);
+        mSelectionModel->select(mapSelectionFromSource(s->selection()), QItemSelectionModel::ClearAndSelect);
     }
     mPreferEmptyTab = false;
 }
 
-void Pane::Private::activateTab()
+void Pane::PanePrivate::activateTab()
 {
     q->tabBar()->setCurrentIndex(q->sender()->objectName().rightRef(2).toInt() - 1);
 }
 
-void Pane::Private::moveTabRight()
+void Pane::PanePrivate::moveTabRight()
 {
     const int numberOfTab = q->tabBar()->count();
     if (numberOfTab == 1) {
@@ -568,7 +556,7 @@ void Pane::Private::moveTabRight()
     }
 }
 
-void Pane::Private::moveTabLeft()
+void Pane::PanePrivate::moveTabLeft()
 {
     const int numberOfTab = q->tabBar()->count();
     if (numberOfTab == 1) {
@@ -581,7 +569,7 @@ void Pane::Private::moveTabLeft()
     }
 }
 
-void Pane::Private::moveTabForward()
+void Pane::PanePrivate::moveTabForward()
 {
     const int currentIndex = q->tabBar()->currentIndex();
     if (currentIndex == q->tabBar()->count() - 1) {
@@ -590,7 +578,7 @@ void Pane::Private::moveTabForward()
     q->tabBar()->moveTab(currentIndex, currentIndex + 1);
 }
 
-void Pane::Private::moveTabBackward()
+void Pane::PanePrivate::moveTabBackward()
 {
     const int currentIndex = q->tabBar()->currentIndex();
     if (currentIndex == 0) {
@@ -599,7 +587,7 @@ void Pane::Private::moveTabBackward()
     q->tabBar()->moveTab(currentIndex, currentIndex - 1);
 }
 
-void Pane::Private::activateNextTab()
+void Pane::PanePrivate::activateNextTab()
 {
     const int numberOfTab = q->tabBar()->count();
     if (numberOfTab == 1) {
@@ -615,7 +603,7 @@ void Pane::Private::activateNextTab()
     q->tabBar()->setCurrentIndex(indexTab);
 }
 
-void Pane::Private::activatePreviousTab()
+void Pane::PanePrivate::activatePreviousTab()
 {
     const int numberOfTab = q->tabBar()->count();
     if (numberOfTab == 1) {
@@ -631,23 +619,23 @@ void Pane::Private::activatePreviousTab()
     q->tabBar()->setCurrentIndex(indexTab);
 }
 
-void Pane::Private::onNewTabClicked()
+void Pane::PanePrivate::onNewTabClicked()
 {
     q->createNewTab();
 }
 
-void Pane::Private::onCloseTabClicked()
+void Pane::PanePrivate::onCloseTabClicked()
 {
     closeTab(q->currentWidget());
 }
 
-void Pane::Private::closeTab(QWidget *w)
+void Pane::PanePrivate::closeTab(QWidget *w)
 {
     if (!w || (q->count() < 2)) {
         return;
     }
 
-    Widget *wWidget = qobject_cast<Widget *>(w);
+    auto wWidget = qobject_cast<Widget *>(w);
     if (wWidget) {
         wWidget->saveCurrentSelection();
     }
@@ -656,10 +644,10 @@ void Pane::Private::closeTab(QWidget *w)
     updateTabControls();
 }
 
-void Pane::Private::changeQuicksearchVisibility(bool show)
+void Pane::PanePrivate::changeQuicksearchVisibility(bool show)
 {
     for (int i = 0; i < q->count(); ++i) {
-        Widget *w = qobject_cast<Widget *>(q->widget(i));
+        auto w = qobject_cast<Widget *>(q->widget(i));
         if (w) {
             w->changeQuicksearchVisibility(show);
         }
@@ -669,7 +657,7 @@ void Pane::Private::changeQuicksearchVisibility(bool show)
 bool Pane::eventFilter(QObject *object, QEvent *event)
 {
     if (event->type() == QEvent::MouseButtonPress) {
-        QMouseEvent *const mouseEvent = static_cast<QMouseEvent *>(event);
+        auto const mouseEvent = static_cast<QMouseEvent *>(event);
         if (mouseEvent->button() == Qt::MiddleButton) {
             return true;
         }
@@ -677,19 +665,18 @@ bool Pane::eventFilter(QObject *object, QEvent *event)
     return QTabWidget::eventFilter(object, event);
 }
 
-void Pane::Private::onCurrentTabChanged()
+void Pane::PanePrivate::onCurrentTabChanged()
 {
     Q_EMIT q->currentTabChanged();
 
-    Widget *w = static_cast<Widget *>(q->currentWidget());
+    auto w = static_cast<Widget *>(q->currentWidget());
 
     QItemSelectionModel *s = mWidgetSelectionHash[w];
 
-    mSelectionModel->select(mapSelectionFromSource(s->selection()),
-                            QItemSelectionModel::ClearAndSelect);
+    mSelectionModel->select(mapSelectionFromSource(s->selection()), QItemSelectionModel::ClearAndSelect);
 }
 
-void Pane::Private::onTabContextMenuRequest(const QPoint &pos)
+void Pane::PanePrivate::onTabContextMenuRequest(const QPoint &pos)
 {
     QTabBar *bar = q->tabBar();
     if (q->count() <= 1) {
@@ -701,7 +688,7 @@ void Pane::Private::onTabContextMenuRequest(const QPoint &pos)
         return;
     }
 
-    Widget *w = qobject_cast<Widget *>(q->widget(indexBar));
+    auto w = qobject_cast<Widget *>(q->widget(indexBar));
     if (!w) {
         return;
     }
@@ -711,27 +698,30 @@ void Pane::Private::onTabContextMenuRequest(const QPoint &pos)
     QAction *closeTabAction = menu.addAction(i18nc("@action:inmenu", "Close Tab"));
     closeTabAction->setIcon(QIcon::fromTheme(QStringLiteral("tab-close")));
 
-    QAction *allOther = menu.addAction(i18nc("@action:inmenu", "Close All Other Tabs"));
-    allOther->setIcon(QIcon::fromTheme(QStringLiteral("tab-close-other")));
+    QAction *allOtherAction = menu.addAction(i18nc("@action:inmenu", "Close All Other Tabs"));
+    allOtherAction->setIcon(QIcon::fromTheme(QStringLiteral("tab-close-other")));
+
+    QAction *lockTabAction = menu.addAction(w->isLocked() ? i18nc("@action:inmenu", "Unlock Tab") : i18nc("@action:inmenu", "Lock Tab"));
+    lockTabAction->setIcon(w->isLocked() ? QIcon::fromTheme(QStringLiteral("lock")) : QIcon::fromTheme(QStringLiteral("unlock")));
 
     QAction *action = menu.exec(q->mapToGlobal(pos));
 
-    if (action == allOther) {   // Close all other tabs
+    if (action == allOtherAction) { // Close all other tabs
         QVector<Widget *> widgets;
         const int index = q->indexOf(w);
 
         for (int i = 0; i < q->count(); ++i) {
             if (i == index) {
-                continue;    // Skip the current one
+                continue; // Skip the current one
             }
 
-            Widget *other = qobject_cast<Widget *>(q->widget(i));
+            auto other = qobject_cast<Widget *>(q->widget(i));
             if (other) {
                 widgets << other;
             }
         }
 
-        foreach (Widget *other, widgets) {
+        for (Widget *other : std::as_const(widgets)) {
             other->saveCurrentSelection();
             delete other;
         }
@@ -739,6 +729,11 @@ void Pane::Private::onTabContextMenuRequest(const QPoint &pos)
         updateTabControls();
     } else if (action == closeTabAction) {
         closeTab(q->widget(indexBar));
+    } else if (action == lockTabAction) {
+        auto tab = qobject_cast<Widget *>(q->widget(indexBar));
+        const bool isLocked = !tab->isLocked();
+        tab->setLockTab(isLocked);
+        q->setTabIcon(indexBar, isLocked ? QIcon::fromTheme(QStringLiteral("lock")) : QIcon::fromTheme(QStringLiteral("unlock")));
     }
 }
 
@@ -749,26 +744,32 @@ MessageList::StorageModel *Pane::createStorageModel(QAbstractItemModel *model, Q
 
 Akonadi::Collection Pane::currentFolder() const
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
+    auto w = static_cast<Widget *>(currentWidget());
     if (w) {
         return w->currentCollection();
     }
     return {};
 }
 
-void Pane::setCurrentFolder(const Akonadi::Collection &collection, const QModelIndex &etmIndex, bool, Core::PreSelectionMode preSelectionMode, const QString &overrideLabel)
+void Pane::setCurrentFolder(const Akonadi::Collection &collection,
+                            const QModelIndex &etmIndex,
+                            bool,
+                            Core::PreSelectionMode preSelectionMode,
+                            const QString &overrideLabel)
 {
-    d->setCurrentFolder(etmIndex);
-    d->mPreSelectionMode = preSelectionMode;
-    Widget *w = static_cast<Widget *>(currentWidget());
-    if (w) {
-        w->setCurrentFolder(collection);
-        QItemSelectionModel *s = d->mWidgetSelectionHash[w];
-        MessageList::StorageModel *m = createStorageModel(d->mModel, s, w);
-        w->setStorageModel(m, preSelectionMode);
-        if (!overrideLabel.isEmpty()) {
-            int index = indexOf(w);
-            setTabText(index, overrideLabel);
+    auto w = static_cast<Widget *>(currentWidget());
+    if (!w->isLocked()) {
+        d->setCurrentFolder(etmIndex);
+        d->mPreSelectionMode = preSelectionMode;
+        if (w) {
+            w->setCurrentFolder(collection);
+            QItemSelectionModel *s = d->mWidgetSelectionHash[w];
+            MessageList::StorageModel *m = createStorageModel(d->mModel, s, w);
+            w->setStorageModel(m, preSelectionMode);
+            if (!overrideLabel.isEmpty()) {
+                const int index = indexOf(w);
+                setTabText(index, overrideLabel);
+            }
         }
     }
 }
@@ -776,7 +777,7 @@ void Pane::setCurrentFolder(const Akonadi::Collection &collection, const QModelI
 void Pane::updateTabIconText(const Akonadi::Collection &collection, const QString &label, const QIcon &icon)
 {
     for (int i = 0; i < count(); ++i) {
-        Widget *w = qobject_cast<Widget *>(widget(i));
+        auto w = qobject_cast<Widget *>(widget(i));
         if (w && (w->currentCollection() == collection)) {
             const int index = indexOf(w);
             setTabText(index, label);
@@ -787,7 +788,7 @@ void Pane::updateTabIconText(const Akonadi::Collection &collection, const QStrin
 
 QItemSelectionModel *Pane::createNewTab()
 {
-    Widget *w = new Widget(this);
+    auto w = new Widget(this);
     w->setXmlGuiClient(d->mXmlGuiClient);
 
     addTab(w, i18nc("@title:tab Empty messagelist", "Empty"));
@@ -799,37 +800,38 @@ QItemSelectionModel *Pane::createNewTab()
         }
     }
 
-    QItemSelectionModel *s = new QItemSelectionModel(d->mModel, w);
+    auto s = new QItemSelectionModel(d->mModel, w);
     MessageList::StorageModel *m = createStorageModel(d->mModel, s, w);
     w->setStorageModel(m);
 
     d->mWidgetSelectionHash[w] = s;
 
-    connect(w, &Widget::messageSelected,
-            this, &Pane::messageSelected);
-    connect(w, &Widget::messageActivated,
-            this, &Pane::messageActivated);
-    connect(w, &Widget::selectionChanged,
-            this, &Pane::selectionChanged);
-    connect(w, &Widget::messageStatusChangeRequest,
-            this, &Pane::messageStatusChangeRequest);
+    connect(w, &Widget::messageSelected, this, &Pane::messageSelected);
+    connect(w, &Widget::messageActivated, this, &Pane::messageActivated);
+    connect(w, &Widget::selectionChanged, this, &Pane::selectionChanged);
+    connect(w, &Widget::messageStatusChangeRequest, this, &Pane::messageStatusChangeRequest);
 
-    connect(w, &Core::Widget::statusMessage,
-            this, &Pane::statusMessage);
+    connect(w, &Core::Widget::statusMessage, this, &Pane::statusMessage);
 
-    connect(w, &Core::Widget::forceLostFocus,
-            this, &Pane::forceLostFocus);
+    connect(w, &Core::Widget::forceLostFocus, this, &Pane::forceLostFocus);
+    connect(w, &Core::Widget::unlockTabRequested, this, [this, w]() {
+        for (int i = 0; i < count(); ++i) {
+            if (w == qobject_cast<Widget *>(widget(i))) {
+                setTabIcon(i, QIcon::fromTheme(QStringLiteral("unlock")));
+            }
+        }
+    });
 
     d->updateTabControls();
     setCurrentWidget(w);
     return s;
 }
 
-QItemSelection Pane::Private::mapSelectionFromSource(const QItemSelection &selection) const
+QItemSelection Pane::PanePrivate::mapSelectionFromSource(const QItemSelection &selection) const
 {
     QItemSelection result = selection;
 
-    typedef QVector<const QAbstractProxyModel *>::ConstIterator Iterator;
+    using Iterator = QVector<const QAbstractProxyModel *>::ConstIterator;
 
     for (Iterator it = mProxyStack.end() - 1; it != mProxyStack.begin(); --it) {
         result = (*it)->mapSelectionFromSource(result);
@@ -839,7 +841,7 @@ QItemSelection Pane::Private::mapSelectionFromSource(const QItemSelection &selec
     return result;
 }
 
-void Pane::Private::updateTabControls()
+void Pane::PanePrivate::updateTabControls()
 {
     const bool enableAction = (q->count() > 1);
     if (enableAction) {
@@ -881,12 +883,12 @@ void Pane::Private::updateTabControls()
     }
 }
 
-Item Pane::currentItem() const
+Akonadi::Item Pane::currentItem() const
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
+    auto w = static_cast<Widget *>(currentWidget());
 
-    if (w == nullptr) {
-        return Item();
+    if (!w) {
+        return Akonadi::Item();
     }
 
     return w->currentItem();
@@ -894,19 +896,19 @@ Item Pane::currentItem() const
 
 KMime::Message::Ptr Pane::currentMessage() const
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
+    auto w = static_cast<Widget *>(currentWidget());
 
-    if (w == nullptr) {
+    if (!w) {
         return KMime::Message::Ptr();
     }
 
     return w->currentMessage();
 }
 
-QVector<KMime::Message::Ptr > Pane::selectionAsMessageList(bool includeCollapsedChildren) const
+QVector<KMime::Message::Ptr> Pane::selectionAsMessageList(bool includeCollapsedChildren) const
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
-    if (w == nullptr) {
+    auto w = static_cast<Widget *>(currentWidget());
+    if (!w) {
         return QVector<KMime::Message::Ptr>();
     }
     return w->selectionAsMessageList(includeCollapsedChildren);
@@ -914,8 +916,8 @@ QVector<KMime::Message::Ptr > Pane::selectionAsMessageList(bool includeCollapsed
 
 Akonadi::Item::List Pane::selectionAsMessageItemList(bool includeCollapsedChildren) const
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
-    if (w == nullptr) {
+    auto w = static_cast<Widget *>(currentWidget());
+    if (!w) {
         return Akonadi::Item::List();
     }
     return w->selectionAsMessageItemList(includeCollapsedChildren);
@@ -923,8 +925,8 @@ Akonadi::Item::List Pane::selectionAsMessageItemList(bool includeCollapsedChildr
 
 QVector<Akonadi::Item::Id> Pane::selectionAsListMessageId(bool includeCollapsedChildren) const
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
-    if (w == nullptr) {
+    auto w = static_cast<Widget *>(currentWidget());
+    if (!w) {
         return QVector<Akonadi::Item::Id>();
     }
     return w->selectionAsListMessageId(includeCollapsedChildren);
@@ -932,8 +934,8 @@ QVector<Akonadi::Item::Id> Pane::selectionAsListMessageId(bool includeCollapsedC
 
 QVector<qlonglong> Pane::selectionAsMessageItemListId(bool includeCollapsedChildren) const
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
-    if (w == nullptr) {
+    auto w = static_cast<Widget *>(currentWidget());
+    if (!w) {
         return QVector<qlonglong>();
     }
     return w->selectionAsMessageItemListId(includeCollapsedChildren);
@@ -941,8 +943,8 @@ QVector<qlonglong> Pane::selectionAsMessageItemListId(bool includeCollapsedChild
 
 Akonadi::Item::List Pane::currentThreadAsMessageList() const
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
-    if (w == nullptr) {
+    auto w = static_cast<Widget *>(currentWidget());
+    if (!w) {
         return Akonadi::Item::List();
     }
     return w->currentThreadAsMessageList();
@@ -950,7 +952,7 @@ Akonadi::Item::List Pane::currentThreadAsMessageList() const
 
 Akonadi::Item::List Pane::itemListFromPersistentSet(MessageList::Core::MessageItemSetReference ref)
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
+    auto w = static_cast<Widget *>(currentWidget());
     if (w) {
         return w->itemListFromPersistentSet(ref);
     }
@@ -959,7 +961,7 @@ Akonadi::Item::List Pane::itemListFromPersistentSet(MessageList::Core::MessageIt
 
 void Pane::deletePersistentSet(MessageList::Core::MessageItemSetReference ref)
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
+    auto w = static_cast<Widget *>(currentWidget());
     if (w) {
         w->deletePersistentSet(ref);
     }
@@ -967,7 +969,7 @@ void Pane::deletePersistentSet(MessageList::Core::MessageItemSetReference ref)
 
 void Pane::markMessageItemsAsAboutToBeRemoved(MessageList::Core::MessageItemSetReference ref, bool bMark)
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
+    auto w = static_cast<Widget *>(currentWidget());
     if (w) {
         w->markMessageItemsAsAboutToBeRemoved(ref, bMark);
     }
@@ -975,8 +977,8 @@ void Pane::markMessageItemsAsAboutToBeRemoved(MessageList::Core::MessageItemSetR
 
 QVector<Akonadi::MessageStatus> Pane::currentFilterStatus() const
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
-    if (w == nullptr) {
+    auto w = static_cast<Widget *>(currentWidget());
+    if (!w) {
         return QVector<Akonadi::MessageStatus>();
     }
     return w->currentFilterStatus();
@@ -984,8 +986,8 @@ QVector<Akonadi::MessageStatus> Pane::currentFilterStatus() const
 
 Core::QuickSearchLine::SearchOptions Pane::currentOptions() const
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
-    if (w == nullptr) {
+    auto w = static_cast<Widget *>(currentWidget());
+    if (!w) {
         return Core::QuickSearchLine::SearchEveryWhere;
     }
     return w->currentOptions();
@@ -993,7 +995,7 @@ Core::QuickSearchLine::SearchOptions Pane::currentOptions() const
 
 QString Pane::currentFilterSearchString() const
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
+    auto w = static_cast<Widget *>(currentWidget());
     if (w) {
         return w->currentFilterSearchString();
     }
@@ -1002,7 +1004,7 @@ QString Pane::currentFilterSearchString() const
 
 bool Pane::isThreaded() const
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
+    auto w = static_cast<Widget *>(currentWidget());
     if (w) {
         return w->isThreaded();
     }
@@ -1011,29 +1013,29 @@ bool Pane::isThreaded() const
 
 bool Pane::selectionEmpty() const
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
+    auto w = static_cast<Widget *>(currentWidget());
     if (w) {
         return w->selectionEmpty();
     }
     return false;
 }
 
-bool Pane::getSelectionStats(Akonadi::Item::List &selectedItems, Akonadi::Item::List &selectedVisibleItems, bool *allSelectedBelongToSameThread, bool includeCollapsedChildren) const
+bool Pane::getSelectionStats(Akonadi::Item::List &selectedItems,
+                             Akonadi::Item::List &selectedVisibleItems,
+                             bool *allSelectedBelongToSameThread,
+                             bool includeCollapsedChildren) const
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
-    if (w == nullptr) {
+    auto w = static_cast<Widget *>(currentWidget());
+    if (!w) {
         return false;
     }
 
-    return w->getSelectionStats(
-        selectedItems, selectedVisibleItems,
-        allSelectedBelongToSameThread, includeCollapsedChildren
-        );
+    return w->getSelectionStats(selectedItems, selectedVisibleItems, allSelectedBelongToSameThread, includeCollapsedChildren);
 }
 
 MessageList::Core::MessageItemSetReference Pane::selectionAsPersistentSet(bool includeCollapsedChildren) const
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
+    auto w = static_cast<Widget *>(currentWidget());
     if (w) {
         return w->selectionAsPersistentSet(includeCollapsedChildren);
     }
@@ -1042,7 +1044,7 @@ MessageList::Core::MessageItemSetReference Pane::selectionAsPersistentSet(bool i
 
 MessageList::Core::MessageItemSetReference Pane::currentThreadAsPersistentSet() const
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
+    auto w = static_cast<Widget *>(currentWidget());
     if (w) {
         return w->currentThreadAsPersistentSet();
     }
@@ -1051,7 +1053,7 @@ MessageList::Core::MessageItemSetReference Pane::currentThreadAsPersistentSet()
 
 void Pane::focusView()
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
+    auto w = static_cast<Widget *>(currentWidget());
     if (w) {
         QWidget *view = w->view();
         if (view) {
@@ -1067,7 +1069,7 @@ void Pane::reloadGlobalConfiguration()
 
 QItemSelectionModel *Pane::currentItemSelectionModel()
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
+    auto w = static_cast<Widget *>(currentWidget());
     if (w) {
         return w->view()->selectionModel();
     }
@@ -1076,9 +1078,9 @@ QItemSelectionModel *Pane::currentItemSelectionModel()
 
 void Pane::resetModelStorage()
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
+    auto w = static_cast<Widget *>(currentWidget());
     if (w) {
-        MessageList::StorageModel *m = static_cast<MessageList::StorageModel *>(w->storageModel());
+        auto m = static_cast<MessageList::StorageModel *>(w->storageModel());
         if (m) {
             m->resetModelStorage();
         }
@@ -1093,7 +1095,7 @@ void Pane::setPreferEmptyTab(bool emptyTab)
 void Pane::saveCurrentSelection()
 {
     for (int i = 0; i < count(); ++i) {
-        Widget *w = qobject_cast<Widget *>(widget(i));
+        auto w = qobject_cast<Widget *>(widget(i));
         if (w) {
             w->saveCurrentSelection();
         }
@@ -1103,7 +1105,7 @@ void Pane::saveCurrentSelection()
 void Pane::updateTagComboBox()
 {
     for (int i = 0; i < count(); ++i) {
-        Widget *w = qobject_cast<Widget *>(widget(i));
+        auto w = qobject_cast<Widget *>(widget(i));
         if (w) {
             w->populateStatusFilterCombo();
         }
@@ -1125,7 +1127,7 @@ void Pane::writeConfig(bool restoreSession)
         conf.writeEntry(QStringLiteral("tabNumber"), count());
 
         for (int i = 0; i < count(); ++i) {
-            Widget *w = qobject_cast<Widget *>(widget(i));
+            auto w = qobject_cast<Widget *>(widget(i));
             if (w) {
                 KConfigGroup grp(MessageList::MessageListSettings::self()->config(), QStringLiteral("MessageListTab%1").arg(i));
                 grp.writeEntry(QStringLiteral("collectionId"), w->currentCollection().id());
@@ -1148,7 +1150,7 @@ void Pane::readConfig(bool restoreSession)
                 createNewTab();
                 restoreHeaderSettings(i);
                 if (restoreSession) {
-#if 0 //TODO fix me
+#if 0 // TODO fix me
                     Akonadi::Collection::Id id = grp.readEntry(QStringLiteral("collectionId"), -1);
                     ETMViewStateSaver *saver = new ETMViewStateSaver;
                     saver->setSelectionModel(selectionModel);
@@ -1175,7 +1177,7 @@ void Pane::restoreHeaderSettings(int index)
 {
     KConfigGroup grp(MessageList::MessageListSettings::self()->config(), QStringLiteral("MessageListTab%1").arg(index));
     if (grp.exists()) {
-        Widget *w = qobject_cast<Widget *>(widget(index));
+        auto w = qobject_cast<Widget *>(widget(index));
         if (w) {
             w->view()->header()->restoreState(grp.readEntry(QStringLiteral("HeaderState"), QByteArray()));
         }
@@ -1184,7 +1186,7 @@ void Pane::restoreHeaderSettings(int index)
 
 bool Pane::searchEditHasFocus() const
 {
-    Widget *w = static_cast<Widget *>(currentWidget());
+    auto w = static_cast<Widget *>(currentWidget());
     if (w) {
         return w->searchEditHasFocus();
     }
@@ -1193,7 +1195,7 @@ bool Pane::searchEditHasFocus() const
 
 void Pane::sortOrderMenuAboutToShow()
 {
-    QMenu *menu = qobject_cast< QMenu * >(sender());
+    auto menu = qobject_cast<QMenu *>(sender());
     if (!menu) {
         return;
     }
@@ -1203,7 +1205,7 @@ void Pane::sortOrderMenuAboutToShow()
 
 void Pane::aggregationMenuAboutToShow()
 {
-    QMenu *menu = qobject_cast< QMenu * >(sender());
+    auto menu = qobject_cast<QMenu *>(sender());
     if (!menu) {
         return;
     }
@@ -1213,7 +1215,7 @@ void Pane::aggregationMenuAboutToShow()
 
 void Pane::themeMenuAboutToShow()
 {
-    QMenu *menu = qobject_cast< QMenu * >(sender());
+    auto menu = qobject_cast<QMenu *>(sender());
     if (!menu) {
         return;
     }
@@ -1224,7 +1226,7 @@ void Pane::themeMenuAboutToShow()
 void Pane::populateStatusFilterCombo()
 {
     for (int i = 0; i < count(); ++i) {
-        Widget *w = qobject_cast<Widget *>(widget(i));
+        auto w = qobject_cast<Widget *>(widget(i));
         if (w) {
             w->populateStatusFilterCombo();
         }
