@@ -9,26 +9,28 @@
 #include "utils/configureaggregationsdialog.h"
 #include "utils/configureaggregationsdialog_p.h"
 
-#include "utils/aggregationeditor.h"
 #include "core/aggregation.h"
+#include "utils/aggregationeditor.h"
 
 #include "core/manager.h"
 
-#include <QGridLayout>
-#include <QPushButton>
 #include <QFrame>
+#include <QGridLayout>
 #include <QMap>
+#include <QPushButton>
 
-#include <KLocalizedString>
-#include <QIcon>
 #include <KConfig>
-#include <QFileDialog>
 #include <KConfigGroup>
+#include <KLocalizedString>
 #include <QDialogButtonBox>
+#include <QFileDialog>
+#include <QIcon>
 #include <QVBoxLayout>
 
-namespace MessageList {
-namespace Utils {
+namespace MessageList
+{
+namespace Utils
+{
 class AggregationListWidgetItem : public QListWidgetItem
 {
 private:
@@ -41,7 +43,7 @@ public:
         mAggregation = new Core::Aggregation(set);
     }
 
-    ~AggregationListWidgetItem()
+    ~AggregationListWidgetItem() override
     {
         delete mAggregation;
     }
@@ -72,7 +74,6 @@ public:
     }
 
 public:
-
     // need a larger but shorter QListWidget
     QSize sizeHint() const override
     {
@@ -87,23 +88,23 @@ using namespace MessageList::Utils;
 
 ConfigureAggregationsDialog::ConfigureAggregationsDialog(QWidget *parent)
     : QDialog(parent)
-    , d(new Private(this))
+    , d(new ConfigureAggregationsDialogPrivate(this))
 {
     setAttribute(Qt::WA_DeleteOnClose);
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto mainLayout = new QVBoxLayout(this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &ConfigureAggregationsDialog::reject);
     setWindowTitle(i18nc("@title:window", "Customize Message Aggregation Modes"));
 
-    QWidget *base = new QWidget(this);
+    auto base = new QWidget(this);
     mainLayout->addWidget(base);
     mainLayout->addWidget(buttonBox);
 
-    QGridLayout *g = new QGridLayout(base);
-    g->setContentsMargins(0, 0, 0, 0);
+    auto g = new QGridLayout(base);
+    g->setContentsMargins({});
 
     d->mAggregationList = new AggregationListWidget(base);
     d->mAggregationList->setSelectionMode(QAbstractItemView::ExtendedSelection);
@@ -130,7 +131,7 @@ ConfigureAggregationsDialog::ConfigureAggregationsDialog(QWidget *parent)
         d->cloneAggregationButtonClicked();
     });
 
-    QFrame *f = new QFrame(base);
+    auto f = new QFrame(base);
     f->setFrameStyle(QFrame::Sunken | QFrame::HLine);
     f->setMinimumHeight(24);
     g->addWidget(f, 2, 1, Qt::AlignVCenter);
@@ -178,10 +179,7 @@ ConfigureAggregationsDialog::ConfigureAggregationsDialog(QWidget *parent)
     d->fillAggregationList();
 }
 
-ConfigureAggregationsDialog::~ConfigureAggregationsDialog()
-{
-    delete d;
-}
+ConfigureAggregationsDialog::~ConfigureAggregationsDialog() = default;
 
 void ConfigureAggregationsDialog::selectAggregation(const QString &aggregationId)
 {
@@ -192,7 +190,7 @@ void ConfigureAggregationsDialog::selectAggregation(const QString &aggregationId
     }
 }
 
-void ConfigureAggregationsDialog::Private::okButtonClicked()
+void ConfigureAggregationsDialog::ConfigureAggregationsDialogPrivate::okButtonClicked()
 {
     if (Manager::instance()) {
         commitEditor();
@@ -202,7 +200,7 @@ void ConfigureAggregationsDialog::Private::okButtonClicked()
         const int c = mAggregationList->count();
         int i = 0;
         while (i < c) {
-            AggregationListWidgetItem *item = dynamic_cast< AggregationListWidgetItem * >(mAggregationList->item(i));
+            auto item = dynamic_cast<AggregationListWidgetItem *>(mAggregationList->item(i));
             if (item) {
                 Manager::instance()->addAggregation(item->aggregation());
                 item->forgetAggregation();
@@ -216,7 +214,7 @@ void ConfigureAggregationsDialog::Private::okButtonClicked()
     q->close(); // this will delete too
 }
 
-void ConfigureAggregationsDialog::Private::commitEditor()
+void ConfigureAggregationsDialog::ConfigureAggregationsDialogPrivate::commitEditor()
 {
     Aggregation *editedAggregation = mEditor->editedAggregation();
     if (!editedAggregation) {
@@ -234,7 +232,7 @@ void ConfigureAggregationsDialog::Private::commitEditor()
     editedItem->setText(goodName);
 }
 
-void ConfigureAggregationsDialog::Private::editedAggregationNameChanged()
+void ConfigureAggregationsDialog::ConfigureAggregationsDialogPrivate::editedAggregationNameChanged()
 {
     Aggregation *set = mEditor->editedAggregation();
     if (!set) {
@@ -251,45 +249,46 @@ void ConfigureAggregationsDialog::Private::editedAggregationNameChanged()
     it->setText(goodName);
 }
 
-void ConfigureAggregationsDialog::Private::fillAggregationList()
+void ConfigureAggregationsDialog::ConfigureAggregationsDialogPrivate::fillAggregationList()
 {
     if (!Manager::instance()) {
         return;
     }
-    const QMap< QString, Aggregation * > &sets = Manager::instance()->aggregations();
-    QMap< QString, Aggregation * >::ConstIterator end(sets.constEnd());
-    for (QMap< QString, Aggregation * >::ConstIterator it = sets.constBegin(); it != end; ++it) {
+    const QMap<QString, Aggregation *> &sets = Manager::instance()->aggregations();
+    QMap<QString, Aggregation *>::ConstIterator end(sets.constEnd());
+    for (QMap<QString, Aggregation *>::ConstIterator it = sets.constBegin(); it != end; ++it) {
         (void)new AggregationListWidgetItem(mAggregationList, *(*it));
     }
 }
 
-void ConfigureAggregationsDialog::Private::aggregationListItemClicked(QListWidgetItem *cur)
+void ConfigureAggregationsDialog::ConfigureAggregationsDialogPrivate::aggregationListItemClicked(QListWidgetItem *cur)
 {
     commitEditor();
     updateButton(cur);
 }
 
-void ConfigureAggregationsDialog::Private::updateButton(QListWidgetItem *cur)
+void ConfigureAggregationsDialog::ConfigureAggregationsDialogPrivate::updateButton(QListWidgetItem *cur)
 {
     const int numberOfSelectedItem(mAggregationList->selectedItems().count());
 
-    AggregationListWidgetItem *item = cur ? dynamic_cast< AggregationListWidgetItem * >(cur) : nullptr;
+    AggregationListWidgetItem *item = cur ? dynamic_cast<AggregationListWidgetItem *>(cur) : nullptr;
     mDeleteAggregationButton->setEnabled(item && !item->aggregation()->readOnly() && (mAggregationList->count() > 1));
 
     mCloneAggregationButton->setEnabled(numberOfSelectedItem == 1);
     mExportAggregationButton->setEnabled(numberOfSelectedItem > 0);
     mEditor->editAggregation(item ? item->aggregation() : nullptr);
     if (item && !item->isSelected()) {
-        item->setSelected(true);    // make sure it's true
+        item->setSelected(true); // make sure it's true
     }
 }
 
-AggregationListWidgetItem *ConfigureAggregationsDialog::Private::findAggregationItemByName(const QString &name, Aggregation *skipAggregation)
+AggregationListWidgetItem *ConfigureAggregationsDialog::ConfigureAggregationsDialogPrivate::findAggregationItemByName(const QString &name,
+                                                                                                                      Aggregation *skipAggregation)
 {
     const int c = mAggregationList->count();
     int i = 0;
     while (i < c) {
-        AggregationListWidgetItem *item = dynamic_cast< AggregationListWidgetItem * >(mAggregationList->item(i));
+        auto item = dynamic_cast<AggregationListWidgetItem *>(mAggregationList->item(i));
         if (item) {
             if (item->aggregation() != skipAggregation) {
                 if (item->aggregation()->name() == name) {
@@ -302,12 +301,12 @@ AggregationListWidgetItem *ConfigureAggregationsDialog::Private::findAggregation
     return nullptr;
 }
 
-AggregationListWidgetItem *ConfigureAggregationsDialog::Private::findAggregationItemById(const QString &aggregationId)
+AggregationListWidgetItem *ConfigureAggregationsDialog::ConfigureAggregationsDialogPrivate::findAggregationItemById(const QString &aggregationId)
 {
     const int c = mAggregationList->count();
     int i = 0;
     while (i < c) {
-        AggregationListWidgetItem *item = dynamic_cast< AggregationListWidgetItem * >(mAggregationList->item(i));
+        auto item = dynamic_cast<AggregationListWidgetItem *>(mAggregationList->item(i));
         if (item) {
             if (item->aggregation()->id() == aggregationId) {
                 return item;
@@ -318,12 +317,12 @@ AggregationListWidgetItem *ConfigureAggregationsDialog::Private::findAggregation
     return nullptr;
 }
 
-AggregationListWidgetItem *ConfigureAggregationsDialog::Private::findAggregationItemByAggregation(Aggregation *set)
+AggregationListWidgetItem *ConfigureAggregationsDialog::ConfigureAggregationsDialogPrivate::findAggregationItemByAggregation(Aggregation *set)
 {
     const int c = mAggregationList->count();
     int i = 0;
     while (i < c) {
-        AggregationListWidgetItem *item = dynamic_cast< AggregationListWidgetItem * >(mAggregationList->item(i));
+        auto item = dynamic_cast<AggregationListWidgetItem *>(mAggregationList->item(i));
         if (item) {
             if (item->aggregation() == set) {
                 return item;
@@ -334,7 +333,7 @@ AggregationListWidgetItem *ConfigureAggregationsDialog::Private::findAggregation
     return nullptr;
 }
 
-QString ConfigureAggregationsDialog::Private::uniqueNameForAggregation(const QString &baseName, Aggregation *skipAggregation)
+QString ConfigureAggregationsDialog::ConfigureAggregationsDialogPrivate::uniqueNameForAggregation(const QString &baseName, Aggregation *skipAggregation)
 {
     QString ret = baseName;
     if (ret.isEmpty()) {
@@ -352,19 +351,19 @@ QString ConfigureAggregationsDialog::Private::uniqueNameForAggregation(const QSt
     return ret;
 }
 
-void ConfigureAggregationsDialog::Private::newAggregationButtonClicked()
+void ConfigureAggregationsDialog::ConfigureAggregationsDialogPrivate::newAggregationButtonClicked()
 {
     Aggregation emptyAggregation;
     emptyAggregation.setName(uniqueNameForAggregation(i18n("New Aggregation")));
-    AggregationListWidgetItem *item = new AggregationListWidgetItem(mAggregationList, emptyAggregation);
+    auto item = new AggregationListWidgetItem(mAggregationList, emptyAggregation);
 
     mAggregationList->setCurrentItem(item);
     mDeleteAggregationButton->setEnabled(item && !item->aggregation()->readOnly());
 }
 
-void ConfigureAggregationsDialog::Private::cloneAggregationButtonClicked()
+void ConfigureAggregationsDialog::ConfigureAggregationsDialogPrivate::cloneAggregationButtonClicked()
 {
-    AggregationListWidgetItem *item = dynamic_cast< AggregationListWidgetItem * >(mAggregationList->currentItem());
+    auto item = dynamic_cast<AggregationListWidgetItem *>(mAggregationList->currentItem());
     if (!item) {
         return;
     }
@@ -380,16 +379,16 @@ void ConfigureAggregationsDialog::Private::cloneAggregationButtonClicked()
     aggregationListItemClicked(item);
 }
 
-void ConfigureAggregationsDialog::Private::deleteAggregationButtonClicked()
+void ConfigureAggregationsDialog::ConfigureAggregationsDialogPrivate::deleteAggregationButtonClicked()
 {
     const QList<QListWidgetItem *> list = mAggregationList->selectedItems();
     if (list.isEmpty()) {
         return;
     }
 
-    mEditor->editAggregation(nullptr);   // forget it
+    mEditor->editAggregation(nullptr); // forget it
     for (QListWidgetItem *it : list) {
-        AggregationListWidgetItem *item = dynamic_cast< AggregationListWidgetItem * >(it);
+        auto item = dynamic_cast<AggregationListWidgetItem *>(it);
         if (!item) {
             return;
         }
@@ -397,15 +396,15 @@ void ConfigureAggregationsDialog::Private::deleteAggregationButtonClicked()
             delete item; // this will trigger aggregationListCurrentItemChanged()
         }
         if (mAggregationList->count() < 2) {
-            break;    // no way: desperately try to keep at least one option set alive :)
+            break; // no way: desperately try to keep at least one option set alive :)
         }
     }
 
-    AggregationListWidgetItem *newItem = dynamic_cast< AggregationListWidgetItem * >(mAggregationList->currentItem());
+    auto newItem = dynamic_cast<AggregationListWidgetItem *>(mAggregationList->currentItem());
     updateButton(newItem);
 }
 
-void ConfigureAggregationsDialog::Private::importAggregationButtonClicked()
+void ConfigureAggregationsDialog::ConfigureAggregationsDialogPrivate::importAggregationButtonClicked()
 {
     const QString filename = QFileDialog::getOpenFileName(q, i18n("Import Aggregation"));
     if (!filename.isEmpty()) {
@@ -418,7 +417,7 @@ void ConfigureAggregationsDialog::Private::importAggregationButtonClicked()
             while (idx < cnt) {
                 const QString data = grp.readEntry(QStringLiteral("Set%1").arg(idx), QString());
                 if (!data.isEmpty()) {
-                    Aggregation *set = new Aggregation();
+                    auto set = new Aggregation();
                     if (set->loadFromString(data)) {
                         set->setReadOnly(false);
                         set->generateUniqueId(); // regenerate id so it becomes different
@@ -434,7 +433,7 @@ void ConfigureAggregationsDialog::Private::importAggregationButtonClicked()
     }
 }
 
-void ConfigureAggregationsDialog::Private::exportAggregationButtonClicked()
+void ConfigureAggregationsDialog::ConfigureAggregationsDialogPrivate::exportAggregationButtonClicked()
 {
     const QList<QListWidgetItem *> list = mAggregationList->selectedItems();
     if (list.isEmpty()) {
@@ -449,7 +448,7 @@ void ConfigureAggregationsDialog::Private::exportAggregationButtonClicked()
 
         int idx = 0;
         for (QListWidgetItem *item : list) {
-            AggregationListWidgetItem *themeItem = static_cast< AggregationListWidgetItem * >(item);
+            auto themeItem = static_cast<AggregationListWidgetItem *>(item);
             grp.writeEntry(QStringLiteral("Set%1").arg(idx), themeItem->aggregation()->saveToString());
             ++idx;
         }
