@@ -6,22 +6,23 @@
  *
  *******************************************************************************/
 
-#ifndef MESSAGELIST_UTILS_CONFIGURETHEMESDIALOG_H
-#define MESSAGELIST_UTILS_CONFIGURETHEMESDIALOG_H
+#pragma once
 
 #include <QDialog>
 
 #include <QListWidget>
 
-namespace MessageList {
-namespace Utils {
+namespace MessageList
+{
+namespace Utils
+{
 class ConfigureThemesDialog : public QDialog
 {
     Q_OBJECT
 
 public:
     explicit ConfigureThemesDialog(QWidget *parent = nullptr);
-    ~ConfigureThemesDialog();
+    ~ConfigureThemesDialog() override;
 
     void selectTheme(const QString &themeId);
 
@@ -29,10 +30,9 @@ Q_SIGNALS:
     void okClicked();
 
 private:
-    class Private;
-    Private *const d;
+    class ConfigureThemesDialogPrivate;
+    std::unique_ptr<ConfigureThemesDialogPrivate> const d;
 };
 } // namespace Utils
 } // namespace MessageList
 
-#endif //!__MESSAGELIST_UTILS_CONFIGURESKINSDIALOG_H
