@@ -4,11 +4,11 @@
 */
 #include "utils/themeconfigbutton.h"
 
+#include "core/manager.h"
 #include "core/theme.h"
+#include "utils/configurethemesdialog.h"
 #include "utils/themecombobox.h"
 #include "utils/themecombobox_p.h"
-#include "utils/configurethemesdialog.h"
-#include "core/manager.h"
 
 #include <KLocalizedString>
 
@@ -18,9 +18,8 @@ using namespace MessageList::Utils;
 class MessageList::Utils::ThemeConfigButtonPrivate
 {
 public:
-    ThemeConfigButtonPrivate(ThemeConfigButton *owner)
+    explicit ThemeConfigButtonPrivate(ThemeConfigButton *owner)
         : q(owner)
-        , mThemeComboBox(nullptr)
     {
     }
 
@@ -34,16 +33,15 @@ public:
 void ThemeConfigButtonPrivate::slotConfigureThemes()
 {
     QString currentThemeID;
-    if (mThemeComboBox != nullptr) {
+    if (mThemeComboBox) {
         currentThemeID = mThemeComboBox->currentTheme();
     }
 
-    ConfigureThemesDialog *dialog = new ConfigureThemesDialog(q->window());
+    auto dialog = new ConfigureThemesDialog(q->window());
     dialog->selectTheme(currentThemeID);
-
-    QObject::connect(dialog, &ConfigureThemesDialog::okClicked, q, &ThemeConfigButton::configureDialogCompleted);
-
-    dialog->show();
+    if (dialog->exec()) {
+        Q_EMIT q->configureDialogCompleted();
+    }
 }
 
 ThemeConfigButton::ThemeConfigButton(QWidget *parent, const ThemeComboBox *themeComboBox)
@@ -55,17 +53,13 @@ ThemeConfigButton::ThemeConfigButton(QWidget *parent, const ThemeComboBox *theme
         d->slotConfigureThemes();
     });
 
-    //Keep theme combo up-to-date with any changes made in the configure dialog.
-    if (d->mThemeComboBox != nullptr) {
-        connect(this, &ThemeConfigButton::configureDialogCompleted,
-                d->mThemeComboBox, &ThemeComboBox::slotLoadThemes);
+    // Keep theme combo up-to-date with any changes made in the configure dialog.
+    if (d->mThemeComboBox) {
+        connect(this, &ThemeConfigButton::configureDialogCompleted, d->mThemeComboBox, &ThemeComboBox::slotLoadThemes);
     }
     setEnabled(Manager::instance());
 }
 
-ThemeConfigButton::~ThemeConfigButton()
-{
-    delete d;
-}
+ThemeConfigButton::~ThemeConfigButton() = default;
 
 #include "moc_themeconfigbutton.cpp"
