@@ -6,14 +6,13 @@
 
 #include "widget.h"
 
-#include <collection.h>
-#include <item.h>
-#include <itemcopyjob.h>
-#include <itemmovejob.h>
+#include <Akonadi/Collection>
+#include <Akonadi/ItemCopyJob>
+#include <Akonadi/ItemMoveJob>
 
-#include "storagemodel.h"
 #include "core/messageitem.h"
 #include "core/view.h"
+#include "storagemodel.h"
 #include <messagelistsettings.h>
 
 #include <QAction>
@@ -25,30 +24,29 @@
 #include <QUrlQuery>
 
 #include "messagelist_debug.h"
-#include <QIcon>
+#include <KJob>
 #include <KLocalizedString>
-#include <QMenu>
 #include <KXMLGUIClient>
 #include <KXMLGUIFactory>
+#include <QIcon>
+#include <QMenu>
 #include <QUrl>
 
 #include "core/groupheaderitem.h"
 
-#include <Monitor>
-#include <Tag>
-#include <TagFetchJob>
-#include <TagFetchScope>
-#include <TagAttribute>
+#include <Akonadi/Monitor>
+#include <Akonadi/Tag>
+#include <Akonadi/TagAttribute>
+#include <Akonadi/TagFetchJob>
+#include <Akonadi/TagFetchScope>
 
-namespace MessageList {
-class Q_DECL_HIDDEN Widget::Private
+namespace MessageList
+{
+class MessageList::Widget::WidgetPrivate
 {
 public:
-    Private(Widget *owner)
+    WidgetPrivate(Widget *owner)
         : q(owner)
-        , mLastSelectedMessage(-1)
-        , mXmlGuiClient(nullptr)
-        , mMonitor(nullptr)
     {
     }
 
@@ -58,7 +56,7 @@ public:
 
     Widget *const q;
 
-    int mLastSelectedMessage;
+    int mLastSelectedMessage = -1;
     KXMLGUIClient *mXmlGuiClient = nullptr;
     QModelIndex mGroupHeaderItemIndex;
     Akonadi::Monitor *mMonitor = nullptr;
@@ -68,9 +66,9 @@ public:
 using namespace MessageList;
 using namespace Akonadi;
 
-Widget::Widget(QWidget *parent)
+MessageList::Widget::Widget(QWidget *parent)
     : Core::Widget(parent)
-    , d(new Private(this))
+    , d(new WidgetPrivate(this))
 {
     populateStatusFilterCombo();
 
@@ -82,37 +80,34 @@ Widget::Widget(QWidget *parent)
     connect(d->mMonitor, &Akonadi::Monitor::tagChanged, this, &Widget::populateStatusFilterCombo);
 }
 
-Widget::~Widget()
-{
-    delete d;
-}
+MessageList::Widget::~Widget() = default;
 
-void Widget::setXmlGuiClient(KXMLGUIClient *xmlGuiClient)
+void MessageList::Widget::setXmlGuiClient(KXMLGUIClient *xmlGuiClient)
 {
     d->mXmlGuiClient = xmlGuiClient;
 }
 
-bool Widget::canAcceptDrag(const QDropEvent *e)
+bool MessageList::Widget::canAcceptDrag(const QDropEvent *e)
 {
     if (e->source() == view()->viewport()) {
         return false;
     }
 
-    Collection::List collections = static_cast<const StorageModel *>(storageModel())->displayedCollections();
+    Collection::List collections = static_cast<const MessageList::StorageModel *>(storageModel())->displayedCollections();
     if (collections.size() != 1) {
-        return false;    // no folder here or too many (in case we can't decide where the drop will end)
+        return false; // no folder here or too many (in case we can't decide where the drop will end)
     }
 
     const Collection target = collections.first();
 
     if ((target.rights() & Collection::CanCreateItem) == 0) {
-        return false;    // no way to drag into
+        return false; // no way to drag into
     }
 
     const QList<QUrl> urls = e->mimeData()->urls();
     for (const QUrl &url : urls) {
         const Collection collection = Collection::fromUrl(url);
-        if (collection.isValid()) {   // You're not supposed to drop collections here
+        if (collection.isValid()) { // You're not supposed to drop collections here
             return false;
         } else { // Yay, this is an item!
             QUrlQuery query(url);
@@ -126,86 +121,92 @@ bool Widget::canAcceptDrag(const QDropEvent *e)
     return true;
 }
 
-bool Widget::selectNextMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, MessageList::Core::ExistingSelectionBehaviour existingSelectionBehaviour, bool centerItem, bool loop)
+bool MessageList::Widget::selectNextMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter,
+                                                MessageList::Core::ExistingSelectionBehaviour existingSelectionBehaviour,
+                                                bool centerItem,
+                                                bool loop)
 {
     return view()->selectNextMessageItem(messageTypeFilter, existingSelectionBehaviour, centerItem, loop);
 }
 
-bool Widget::selectPreviousMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, MessageList::Core::ExistingSelectionBehaviour existingSelectionBehaviour, bool centerItem, bool loop)
+bool MessageList::Widget::selectPreviousMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter,
+                                                    MessageList::Core::ExistingSelectionBehaviour existingSelectionBehaviour,
+                                                    bool centerItem,
+                                                    bool loop)
 {
     return view()->selectPreviousMessageItem(messageTypeFilter, existingSelectionBehaviour, centerItem, loop);
 }
 
-bool Widget::focusNextMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, bool centerItem, bool loop)
+bool MessageList::Widget::focusNextMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, bool centerItem, bool loop)
 {
     return view()->focusNextMessageItem(messageTypeFilter, centerItem, loop);
 }
 
-bool Widget::focusPreviousMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, bool centerItem, bool loop)
+bool MessageList::Widget::focusPreviousMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, bool centerItem, bool loop)
 {
     return view()->focusPreviousMessageItem(messageTypeFilter, centerItem, loop);
 }
 
-void Widget::selectFocusedMessageItem(bool centerItem)
+void MessageList::Widget::selectFocusedMessageItem(bool centerItem)
 {
     view()->selectFocusedMessageItem(centerItem);
 }
 
-bool Widget::selectFirstMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, bool centerItem)
+bool MessageList::Widget::selectFirstMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, bool centerItem)
 {
     return view()->selectFirstMessageItem(messageTypeFilter, centerItem);
 }
 
-bool Widget::selectLastMessageItem(Core::MessageTypeFilter messageTypeFilter, bool centerItem)
+bool MessageList::Widget::selectLastMessageItem(Core::MessageTypeFilter messageTypeFilter, bool centerItem)
 {
     return view()->selectLastMessageItem(messageTypeFilter, centerItem);
 }
 
-void Widget::selectAll()
+void MessageList::Widget::selectAll()
 {
     view()->setAllGroupsExpanded(true);
     view()->selectAll();
 }
 
-void Widget::setCurrentThreadExpanded(bool expand)
+void MessageList::Widget::setCurrentThreadExpanded(bool expand)
 {
     view()->setCurrentThreadExpanded(expand);
 }
 
-void Widget::setAllThreadsExpanded(bool expand)
+void MessageList::Widget::setAllThreadsExpanded(bool expand)
 {
     view()->setAllThreadsExpanded(expand);
 }
 
-void Widget::setAllGroupsExpanded(bool expand)
+void MessageList::Widget::setAllGroupsExpanded(bool expand)
 {
     view()->setAllGroupsExpanded(expand);
 }
 
-void Widget::focusQuickSearch(const QString &selectedText)
+void MessageList::Widget::focusQuickSearch(const QString &selectedText)
 {
     view()->focusQuickSearch(selectedText);
 }
 
-void Widget::setQuickSearchClickMessage(const QString &msg)
+void MessageList::Widget::setQuickSearchClickMessage(const QString &msg)
 {
     view()->setQuickSearchClickMessage(msg);
 }
 
-void Widget::fillMessageTagCombo()
+void MessageList::Widget::fillMessageTagCombo()
 {
-    Akonadi::TagFetchJob *fetchJob = new Akonadi::TagFetchJob(this);
+    auto fetchJob = new Akonadi::TagFetchJob(this);
     fetchJob->fetchScope().fetchAttribute<Akonadi::TagAttribute>();
     connect(fetchJob, &Akonadi::TagFetchJob::result, this, &Widget::slotTagsFetched);
 }
 
-void Widget::slotTagsFetched(KJob *job)
+void MessageList::Widget::slotTagsFetched(KJob *job)
 {
     if (job->error()) {
         qCWarning(MESSAGELIST_LOG) << "Failed to load tags " << job->errorString();
         return;
     }
-    Akonadi::TagFetchJob *fetchJob = static_cast<Akonadi::TagFetchJob *>(job);
+    auto fetchJob = static_cast<Akonadi::TagFetchJob *>(job);
 
     KConfigGroup conf(MessageList::MessageListSettings::self()->config(), "MessageListView");
     const QString tagSelected = conf.readEntry(QStringLiteral("TagSelected"));
@@ -215,16 +216,19 @@ void Widget::slotTagsFetched(KJob *job)
     }
     const QStringList tagSelectedLst = tagSelected.split(QLatin1Char(','));
 
-    addMessageTagItem(QIcon::fromTheme(QStringLiteral("mail-flag")).pixmap(16, 16), i18nc("Item in list of Akonadi tags, to show all e-mails", "All"), QString());
+    addMessageTagItem(QIcon::fromTheme(QStringLiteral("mail-flag")).pixmap(16, 16),
+                      i18nc("Item in list of Akonadi tags, to show all e-mails", "All"),
+                      QString());
 
     QStringList tagFound;
-    foreach (const Akonadi::Tag &akonadiTag, fetchJob->tags()) {
+    const auto tags{fetchJob->tags()};
+    for (const Akonadi::Tag &akonadiTag : tags) {
         if (tagSelectedLst.contains(akonadiTag.url().url())) {
             tagFound.append(akonadiTag.url().url());
             QString iconName = QStringLiteral("mail-tagged");
             const QString label = akonadiTag.name();
             const QString id = akonadiTag.url().url();
-            const Akonadi::TagAttribute *attr = akonadiTag.attribute<Akonadi::TagAttribute>();
+            const auto attr = akonadiTag.attribute<Akonadi::TagAttribute>();
             if (attr) {
                 iconName = attr->iconName();
             }
@@ -237,7 +241,7 @@ void Widget::slotTagsFetched(KJob *job)
     setCurrentStatusFilterItem();
 }
 
-void Widget::viewMessageSelected(MessageList::Core::MessageItem *msg)
+void MessageList::Widget::viewMessageSelected(MessageList::Core::MessageItem *msg)
 {
     int row = -1;
     if (msg) {
@@ -246,7 +250,7 @@ void Widget::viewMessageSelected(MessageList::Core::MessageItem *msg)
 
     if (!msg || !msg->isValid() || !storageModel()) {
         d->mLastSelectedMessage = -1;
-        Q_EMIT messageSelected(Item());
+        Q_EMIT messageSelected(Akonadi::Item());
         return;
     }
 
@@ -254,12 +258,12 @@ void Widget::viewMessageSelected(MessageList::Core::MessageItem *msg)
 
     d->mLastSelectedMessage = row;
 
-    Q_EMIT messageSelected(d->itemForRow(row));     // this MAY be null
+    Q_EMIT messageSelected(d->itemForRow(row)); // this MAY be null
 }
 
-void Widget::viewMessageActivated(MessageList::Core::MessageItem *msg)
+void MessageList::Widget::viewMessageActivated(MessageList::Core::MessageItem *msg)
 {
-    Q_ASSERT(msg);   // must not be null
+    Q_ASSERT(msg); // must not be null
     Q_ASSERT(storageModel());
 
     if (!msg->isValid()) {
@@ -271,7 +275,7 @@ void Widget::viewMessageActivated(MessageList::Core::MessageItem *msg)
 
     // The assert below may fail when quickly opening and closing a non-selected thread.
     // This will actually activate the item without selecting it...
-    //Q_ASSERT( d->mLastSelectedMessage == row );
+    // Q_ASSERT( d->mLastSelectedMessage == row );
 
     if (d->mLastSelectedMessage != row) {
         // Very ugly. We are activating a non selected message.
@@ -283,36 +287,34 @@ void Widget::viewMessageActivated(MessageList::Core::MessageItem *msg)
         return;
     }
 
-    Q_EMIT messageActivated(d->itemForRow(row));     // this MAY be null
+    Q_EMIT messageActivated(d->itemForRow(row)); // this MAY be null
 }
 
-void Widget::viewSelectionChanged()
+void MessageList::Widget::viewSelectionChanged()
 {
     Q_EMIT selectionChanged();
     if (!currentMessageItem()) {
-        Q_EMIT messageSelected(Item());
+        Q_EMIT messageSelected(Akonadi::Item());
     }
 }
 
-void Widget::viewMessageListContextPopupRequest(const QVector< MessageList::Core::MessageItem * > &selectedItems, const QPoint &globalPos)
+void MessageList::Widget::viewMessageListContextPopupRequest(const QVector<MessageList::Core::MessageItem *> &selectedItems, const QPoint &globalPos)
 {
-    Q_UNUSED(selectedItems);
+    Q_UNUSED(selectedItems)
 
     if (!d->mXmlGuiClient) {
         return;
     }
 
-    QMenu *popup = static_cast<QMenu *>(d->mXmlGuiClient->factory()->container(
-                                            QStringLiteral("akonadi_messagelist_contextmenu"),
-                                            d->mXmlGuiClient));
+    QMenu *popup = static_cast<QMenu *>(d->mXmlGuiClient->factory()->container(QStringLiteral("akonadi_messagelist_contextmenu"), d->mXmlGuiClient));
     if (popup) {
         popup->exec(globalPos);
     }
 }
 
-void Widget::viewMessageStatusChangeRequest(MessageList::Core::MessageItem *msg, Akonadi::MessageStatus set, Akonadi::MessageStatus clear)
+void MessageList::Widget::viewMessageStatusChangeRequest(MessageList::Core::MessageItem *msg, Akonadi::MessageStatus set, Akonadi::MessageStatus clear)
 {
-    Q_ASSERT(msg);   // must not be null
+    Q_ASSERT(msg); // must not be null
     Q_ASSERT(storageModel());
 
     if (!msg->isValid()) {
@@ -322,15 +324,15 @@ void Widget::viewMessageStatusChangeRequest(MessageList::Core::MessageItem *msg,
     int row = msg->currentModelIndexRow();
     Q_ASSERT(row >= 0);
 
-    Item item = d->itemForRow(row);
+    Akonadi::Item item = d->itemForRow(row);
     Q_ASSERT(item.isValid());
 
     Q_EMIT messageStatusChangeRequest(item, set, clear);
 }
 
-void Widget::viewGroupHeaderContextPopupRequest(MessageList::Core::GroupHeaderItem *ghi, const QPoint &globalPos)
+void MessageList::Widget::viewGroupHeaderContextPopupRequest(MessageList::Core::GroupHeaderItem *ghi, const QPoint &globalPos)
 {
-    Q_UNUSED(ghi);
+    Q_UNUSED(ghi)
 
     QMenu menu(this);
 
@@ -350,17 +352,15 @@ void Widget::viewGroupHeaderContextPopupRequest(MessageList::Core::GroupHeaderIt
     menu.addSeparator();
 
     act = menu.addAction(i18n("Expand All Groups"));
-    connect(act, &QAction::triggered,
-            view(), &Core::View::slotExpandAllGroups);
+    connect(act, &QAction::triggered, view(), &Core::View::slotExpandAllGroups);
 
     act = menu.addAction(i18n("Collapse All Groups"));
-    connect(act, &QAction::triggered,
-            view(), &Core::View::slotCollapseAllGroups);
+    connect(act, &QAction::triggered, view(), &Core::View::slotCollapseAllGroups);
 
     menu.exec(globalPos);
 }
 
-void Widget::viewDragEnterEvent(QDragEnterEvent *e)
+void MessageList::Widget::viewDragEnterEvent(QDragEnterEvent *e)
 {
     if (!canAcceptDrag(e)) {
         e->ignore();
@@ -370,7 +370,7 @@ void Widget::viewDragEnterEvent(QDragEnterEvent *e)
     e->accept();
 }
 
-void Widget::viewDragMoveEvent(QDragMoveEvent *e)
+void MessageList::Widget::viewDragMoveEvent(QDragMoveEvent *e)
 {
     if (!canAcceptDrag(e)) {
         e->ignore();
@@ -380,13 +380,9 @@ void Widget::viewDragMoveEvent(QDragMoveEvent *e)
     e->accept();
 }
 
-enum DragMode {
-    DragCopy,
-    DragMove,
-    DragCancel
-};
+enum DragMode { DragCopy, DragMove, DragCancel };
 
-void Widget::viewDropEvent(QDropEvent *e)
+void MessageList::Widget::viewDropEvent(QDropEvent *e)
 {
     if (!canAcceptDrag(e)) {
         e->ignore();
@@ -403,7 +399,7 @@ void Widget::viewDropEvent(QDropEvent *e)
     e->accept();
 
     int action;
-    if ((e->possibleActions() & Qt::MoveAction) == 0) {     // We can't move anyway
+    if ((e->possibleActions() & Qt::MoveAction) == 0) { // We can't move anyway
         action = DragCopy;
     } else {
         const auto keybstate = QApplication::keyboardModifiers();
@@ -413,7 +409,8 @@ void Widget::viewDropEvent(QDropEvent *e)
             action = DragMove;
         } else {
             QMenu menu;
-            QAction *moveAction = menu.addAction(QIcon::fromTheme(QStringLiteral("go-jump")), i18n("&Move Here"));
+            QAction *moveAction =
+                menu.addAction(QIcon::fromTheme(QStringLiteral("edit-move"), QIcon::fromTheme(QStringLiteral("go-jump"))), i18n("&Move Here"));
             QAction *copyAction = menu.addAction(QIcon::fromTheme(QStringLiteral("edit-copy")), i18n("&Copy Here"));
             menu.addSeparator();
             menu.addAction(QIcon::fromTheme(QStringLiteral("dialog-cancel")), i18n("C&ancel"));
@@ -432,12 +429,12 @@ void Widget::viewDropEvent(QDropEvent *e)
         return;
     }
 
-    Collection::List collections = static_cast<const StorageModel *>(storageModel())->displayedCollections();
+    Collection::List collections = static_cast<const MessageList::StorageModel *>(storageModel())->displayedCollections();
     Collection target = collections.at(0);
-    Item::List items;
+    Akonadi::Item::List items;
     items.reserve(urls.count());
-    for (const QUrl &url : qAsConst(urls)) {
-        items << Item::fromUrl(url);
+    for (const QUrl &url : std::as_const(urls)) {
+        items << Akonadi::Item::fromUrl(url);
     }
 
     if (action == DragCopy) {
@@ -447,12 +444,12 @@ void Widget::viewDropEvent(QDropEvent *e)
     }
 }
 
-void Widget::viewStartDragRequest()
+void MessageList::Widget::viewStartDragRequest()
 {
-    Collection::List collections = static_cast<const StorageModel *>(storageModel())->displayedCollections();
+    Collection::List collections = static_cast<const MessageList::StorageModel *>(storageModel())->displayedCollections();
 
     if (collections.isEmpty()) {
-        return;    // no folder here
+        return; // no folder here
     }
 
     const QVector<Core::MessageItem *> selection = view()->selectionAsMessageItemList();
@@ -462,7 +459,7 @@ void Widget::viewStartDragRequest()
 
     bool readOnly = false;
 
-    for (const Collection &c : qAsConst(collections)) {
+    for (const Collection &c : std::as_const(collections)) {
         // We won't be able to remove items from this collection
         if ((c.rights() & Collection::CanDeleteItem) == 0) {
             // So the drag will be read-only
@@ -474,18 +471,18 @@ void Widget::viewStartDragRequest()
     QList<QUrl> urls;
     urls.reserve(selection.count());
     for (Core::MessageItem *mi : selection) {
-        const Item i = d->itemForRow(mi->currentModelIndexRow());
-        QUrl url = i.url(Item::Item::Item::UrlWithMimeType);
+        const Akonadi::Item i = d->itemForRow(mi->currentModelIndexRow());
+        QUrl url = i.url(Akonadi::Item::UrlWithMimeType);
         QUrlQuery query(url);
         query.addQueryItem(QStringLiteral("parent"), QString::number(mi->parentCollectionId()));
         url.setQuery(query);
         urls << url;
     }
 
-    QMimeData *mimeData = new QMimeData;
+    auto mimeData = new QMimeData;
     mimeData->setUrls(urls);
 
-    QDrag *drag = new QDrag(view()->viewport());
+    auto drag = new QDrag(view()->viewport());
     drag->setMimeData(mimeData);
 
     // Set pixmap
@@ -509,14 +506,14 @@ void Widget::viewStartDragRequest()
     }
 }
 
-Item::List Widget::Private::selectionAsItems() const
+Akonadi::Item::List MessageList::Widget::WidgetPrivate::selectionAsItems() const
 {
-    Item::List res;
+    Akonadi::Item::List res;
     const QVector<Core::MessageItem *> selection = q->view()->selectionAsMessageItemList();
     res.reserve(selection.count());
 
-    for (Core::MessageItem *mi : qAsConst(selection)) {
-        Item i = itemForRow(mi->currentModelIndexRow());
+    for (Core::MessageItem *mi : std::as_const(selection)) {
+        Akonadi::Item i = itemForRow(mi->currentModelIndexRow());
         Q_ASSERT(i.isValid());
         res << i;
     }
@@ -524,28 +521,28 @@ Item::List Widget::Private::selectionAsItems() const
     return res;
 }
 
-Item Widget::Private::itemForRow(int row) const
+Akonadi::Item MessageList::Widget::WidgetPrivate::itemForRow(int row) const
 {
-    return static_cast<const StorageModel *>(q->storageModel())->itemForRow(row);
+    return static_cast<const MessageList::StorageModel *>(q->storageModel())->itemForRow(row);
 }
 
-KMime::Message::Ptr Widget::Private::messageForRow(int row) const
+KMime::Message::Ptr MessageList::Widget::WidgetPrivate::messageForRow(int row) const
 {
-    return static_cast<const StorageModel *>(q->storageModel())->messageForRow(row);
+    return static_cast<const MessageList::StorageModel *>(q->storageModel())->messageForRow(row);
 }
 
-Item Widget::currentItem() const
+Akonadi::Item MessageList::Widget::currentItem() const
 {
     Core::MessageItem *mi = view()->currentMessageItem();
 
     if (mi == nullptr) {
-        return Item();
+        return Akonadi::Item();
     }
 
     return d->itemForRow(mi->currentModelIndexRow());
 }
 
-KMime::Message::Ptr Widget::currentMessage() const
+KMime::Message::Ptr MessageList::Widget::currentMessage() const
 {
     Core::MessageItem *mi = view()->currentMessageItem();
 
@@ -556,7 +553,7 @@ KMime::Message::Ptr Widget::currentMessage() const
     return d->messageForRow(mi->currentModelIndexRow());
 }
 
-QVector<KMime::Message::Ptr > Widget::selectionAsMessageList(bool includeCollapsedChildren) const
+QVector<KMime::Message::Ptr> MessageList::Widget::selectionAsMessageList(bool includeCollapsedChildren) const
 {
     QVector<KMime::Message::Ptr> lstMiPtr;
     const QVector<Core::MessageItem *> lstMi = view()->selectionAsMessageItemList(includeCollapsedChildren);
@@ -564,13 +561,13 @@ QVector<KMime::Message::Ptr > Widget::selectionAsMessageList(bool includeCollaps
         return lstMiPtr;
     }
     lstMiPtr.reserve(lstMi.count());
-    for (Core::MessageItem *it : qAsConst(lstMi)) {
+    for (Core::MessageItem *it : std::as_const(lstMi)) {
         lstMiPtr.append(d->messageForRow(it->currentModelIndexRow()));
     }
     return lstMiPtr;
 }
 
-Akonadi::Item::List Widget::selectionAsMessageItemList(bool includeCollapsedChildren) const
+Akonadi::Item::List MessageList::Widget::selectionAsMessageItemList(bool includeCollapsedChildren) const
 {
     Akonadi::Item::List lstMiPtr;
     const QVector<Core::MessageItem *> lstMi = view()->selectionAsMessageItemList(includeCollapsedChildren);
@@ -578,13 +575,13 @@ Akonadi::Item::List Widget::selectionAsMessageItemList(bool includeCollapsedChil
         return lstMiPtr;
     }
     lstMiPtr.reserve(lstMi.count());
-    for (Core::MessageItem *it : qAsConst(lstMi)) {
+    for (Core::MessageItem *it : std::as_const(lstMi)) {
         lstMiPtr.append(d->itemForRow(it->currentModelIndexRow()));
     }
     return lstMiPtr;
 }
 
-QVector<qlonglong> Widget::selectionAsMessageItemListId(bool includeCollapsedChildren) const
+QVector<qlonglong> MessageList::Widget::selectionAsMessageItemListId(bool includeCollapsedChildren) const
 {
     QVector<qlonglong> lstMiPtr;
     const QVector<Core::MessageItem *> lstMi = view()->selectionAsMessageItemList(includeCollapsedChildren);
@@ -592,13 +589,13 @@ QVector<qlonglong> Widget::selectionAsMessageItemListId(bool includeCollapsedChi
         return lstMiPtr;
     }
     lstMiPtr.reserve(lstMi.count());
-    for (Core::MessageItem *it : qAsConst(lstMi)) {
+    for (Core::MessageItem *it : std::as_const(lstMi)) {
         lstMiPtr.append(d->itemForRow(it->currentModelIndexRow()).id());
     }
     return lstMiPtr;
 }
 
-QVector<Akonadi::Item::Id> Widget::selectionAsListMessageId(bool includeCollapsedChildren) const
+QVector<Akonadi::Item::Id> MessageList::Widget::selectionAsListMessageId(bool includeCollapsedChildren) const
 {
     QVector<qlonglong> lstMiPtr;
     const QVector<Core::MessageItem *> lstMi = view()->selectionAsMessageItemList(includeCollapsedChildren);
@@ -606,13 +603,13 @@ QVector<Akonadi::Item::Id> Widget::selectionAsListMessageId(bool includeCollapse
         return lstMiPtr;
     }
     lstMiPtr.reserve(lstMi.count());
-    for (Core::MessageItem *it : qAsConst(lstMi)) {
+    for (Core::MessageItem *it : std::as_const(lstMi)) {
         lstMiPtr.append(d->itemForRow(it->currentModelIndexRow()).id());
     }
     return lstMiPtr;
 }
 
-Akonadi::Item::List Widget::currentThreadAsMessageList() const
+Akonadi::Item::List MessageList::Widget::currentThreadAsMessageList() const
 {
     Akonadi::Item::List lstMiPtr;
     const QVector<Core::MessageItem *> lstMi = view()->currentThreadAsMessageItemList();
@@ -620,39 +617,41 @@ Akonadi::Item::List Widget::currentThreadAsMessageList() const
         return lstMiPtr;
     }
     lstMiPtr.reserve(lstMi.count());
-    for (Core::MessageItem *it : qAsConst(lstMi)) {
+    for (Core::MessageItem *it : std::as_const(lstMi)) {
         lstMiPtr.append(d->itemForRow(it->currentModelIndexRow()));
     }
     return lstMiPtr;
 }
 
-MessageList::Core::QuickSearchLine::SearchOptions Widget::currentOptions() const
+MessageList::Core::QuickSearchLine::SearchOptions MessageList::Widget::currentOptions() const
 {
     return view()->currentOptions();
 }
 
-QVector<Akonadi::MessageStatus> Widget::currentFilterStatus() const
+QVector<Akonadi::MessageStatus> MessageList::Widget::currentFilterStatus() const
 {
     return view()->currentFilterStatus();
 }
 
-QString Widget::currentFilterSearchString() const
+QString MessageList::Widget::currentFilterSearchString() const
 {
     return view()->currentFilterSearchString();
 }
 
-bool Widget::isThreaded() const
+bool MessageList::Widget::isThreaded() const
 {
     return view()->isThreaded();
 }
 
-bool Widget::selectionEmpty() const
+bool MessageList::Widget::selectionEmpty() const
 {
     return view()->selectionEmpty();
 }
 
-bool Widget::getSelectionStats(
-    Akonadi::Item::List &selectedItems, Akonadi::Item::List &selectedVisibleItems, bool *allSelectedBelongToSameThread, bool includeCollapsedChildren) const
+bool MessageList::Widget::getSelectionStats(Akonadi::Item::List &selectedItems,
+                                            Akonadi::Item::List &selectedVisibleItems,
+                                            bool *allSelectedBelongToSameThread,
+                                            bool includeCollapsedChildren) const
 {
     if (!storageModel()) {
         return false;
@@ -661,14 +660,14 @@ bool Widget::getSelectionStats(
     selectedItems.clear();
     selectedVisibleItems.clear();
 
-    const QVector< Core::MessageItem * > selected = view()->selectionAsMessageItemList(includeCollapsedChildren);
+    const QVector<Core::MessageItem *> selected = view()->selectionAsMessageItemList(includeCollapsedChildren);
 
     Core::MessageItem *topmost = nullptr;
 
     *allSelectedBelongToSameThread = true;
 
-    for (Core::MessageItem *it : qAsConst(selected)) {
-        const Item item = d->itemForRow(it->currentModelIndexRow());
+    for (Core::MessageItem *it : std::as_const(selected)) {
+        const Akonadi::Item item = d->itemForRow(it->currentModelIndexRow());
         selectedItems.append(item);
         if (view()->isDisplayedWithParentsExpanded(it)) {
             selectedVisibleItems.append(item);
@@ -684,33 +683,33 @@ bool Widget::getSelectionStats(
     return true;
 }
 
-void Widget::deletePersistentSet(MessageList::Core::MessageItemSetReference ref)
+void MessageList::Widget::deletePersistentSet(MessageList::Core::MessageItemSetReference ref)
 {
     view()->deletePersistentSet(ref);
 }
 
-void Widget::markMessageItemsAsAboutToBeRemoved(MessageList::Core::MessageItemSetReference ref, bool bMark)
+void MessageList::Widget::markMessageItemsAsAboutToBeRemoved(MessageList::Core::MessageItemSetReference ref, bool bMark)
 {
-    QList< Core::MessageItem * > lstPersistent = view()->persistentSetCurrentMessageItemList(ref);
+    QList<Core::MessageItem *> lstPersistent = view()->persistentSetCurrentMessageItemList(ref);
     if (!lstPersistent.isEmpty()) {
         view()->markMessageItemsAsAboutToBeRemoved(lstPersistent, bMark);
     }
 }
 
-Akonadi::Item::List Widget::itemListFromPersistentSet(MessageList::Core::MessageItemSetReference ref)
+Akonadi::Item::List MessageList::Widget::itemListFromPersistentSet(MessageList::Core::MessageItemSetReference ref)
 {
     Akonadi::Item::List lstItem;
-    const QList< Core::MessageItem * > refList = view()->persistentSetCurrentMessageItemList(ref);
+    const QList<Core::MessageItem *> refList = view()->persistentSetCurrentMessageItemList(ref);
     if (!refList.isEmpty()) {
         lstItem.reserve(refList.count());
-        for (Core::MessageItem *it : qAsConst(refList)) {
+        for (Core::MessageItem *it : std::as_const(refList)) {
             lstItem.append(d->itemForRow(it->currentModelIndexRow()));
         }
     }
     return lstItem;
 }
 
-MessageList::Core::MessageItemSetReference Widget::selectionAsPersistentSet(bool includeCollapsedChildren) const
+MessageList::Core::MessageItemSetReference MessageList::Widget::selectionAsPersistentSet(bool includeCollapsedChildren) const
 {
     QVector<Core::MessageItem *> lstMi = view()->selectionAsMessageItemList(includeCollapsedChildren);
     if (lstMi.isEmpty()) {
@@ -719,7 +718,7 @@ MessageList::Core::MessageItemSetReference Widget::selectionAsPersistentSet(bool
     return view()->createPersistentSet(lstMi);
 }
 
-MessageList::Core::MessageItemSetReference Widget::currentThreadAsPersistentSet() const
+MessageList::Core::MessageItemSetReference MessageList::Widget::currentThreadAsPersistentSet() const
 {
     QVector<Core::MessageItem *> lstMi = view()->currentThreadAsMessageItemList();
     if (lstMi.isEmpty()) {
@@ -728,21 +727,21 @@ MessageList::Core::MessageItemSetReference Widget::currentThreadAsPersistentSet(
     return view()->createPersistentSet(lstMi);
 }
 
-Akonadi::Collection Widget::currentCollection() const
+Akonadi::Collection MessageList::Widget::currentCollection() const
 {
-    Collection::List collections = static_cast<const StorageModel *>(storageModel())->displayedCollections();
+    Collection::List collections = static_cast<const MessageList::StorageModel *>(storageModel())->displayedCollections();
     if (collections.size() != 1) {
-        return Akonadi::Collection();    // no folder here or too many (in case we can't decide where the drop will end)
+        return Akonadi::Collection(); // no folder here or too many (in case we can't decide where the drop will end)
     }
     return collections.first();
 }
 
-void Widget::slotCollapseItem()
+void MessageList::Widget::slotCollapseItem()
 {
     view()->setCollapseItem(d->mGroupHeaderItemIndex);
 }
 
-void Widget::slotExpandItem()
+void MessageList::Widget::slotExpandItem()
 {
     view()->setExpandItem(d->mGroupHeaderItemIndex);
 }
