@@ -1,12 +1,12 @@
 /*
-  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "mailsourceviewtextbrowserwidgettest.h"
-#include "../src/widgets/mailsourceviewtextbrowserwidget.h"
 #include "../src/findbar/findbarsourceview.h"
+#include "../src/widgets/mailsourceviewtextbrowserwidget.h"
 #include <KPIMTextEdit/TextToSpeechWidget>
 #include <QTest>
 
@@ -23,17 +23,14 @@ void MailSourceViewTextBrowserWidgetTest::shouldHaveDefaultValue()
 {
     MessageViewer::MailSourceViewTextBrowserWidget widget(QStringLiteral("Email"));
 
-    MessageViewer::MailSourceViewTextBrowser *textbrowser
-        = widget.findChild<MessageViewer::MailSourceViewTextBrowser *>(QStringLiteral("textbrowser"));
+    auto textbrowser = widget.findChild<MessageViewer::MailSourceViewTextBrowser *>(QStringLiteral("textbrowser"));
     QVERIFY(textbrowser);
     QVERIFY(!textbrowser->isHidden());
-    MessageViewer::FindBarSourceView *findbar
-        = widget.findChild<MessageViewer::FindBarSourceView *>(QStringLiteral("findbar"));
+    auto findbar = widget.findChild<MessageViewer::FindBarSourceView *>(QStringLiteral("findbar"));
     QVERIFY(findbar);
     QVERIFY(findbar->isHidden());
 
-    KPIMTextEdit::TextToSpeechWidget *texttospeechwidget
-        = widget.findChild<KPIMTextEdit::TextToSpeechWidget *>(QStringLiteral("texttospeech"));
+    auto texttospeechwidget = widget.findChild<KPIMTextEdit::TextToSpeechWidget *>(QStringLiteral("texttospeech"));
     QVERIFY(texttospeechwidget);
     QVERIFY(texttospeechwidget->isHidden());
 }
