@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef DKIMAUTHENTICATIONSTATUSINFOTEST_H
-#define DKIMAUTHENTICATIONSTATUSINFOTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,7 +13,7 @@ class DKIMAuthenticationStatusInfoTest : public QObject
     Q_OBJECT
 public:
     explicit DKIMAuthenticationStatusInfoTest(QObject *parent = nullptr);
-    ~DKIMAuthenticationStatusInfoTest() = default;
+    ~DKIMAuthenticationStatusInfoTest() override = default;
 
 private Q_SLOTS:
     void shouldHaveDefaultValue();
@@ -22,4 +21,3 @@ private Q_SLOTS:
     void shouldParseKey_data();
 };
 
-#endif // DKIMAUTHENTICATIONSTATUSINFOTEST_H
