@@ -1,16 +1,19 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "dkimcheckauthenticationstatusjobtest.h"
-#include "dkim-verify/dkimcheckauthenticationstatusjob.h"
 #include "dkim-verify/dkimauthenticationstatusinfo.h"
+#include "dkim-verify/dkimcheckauthenticationstatusjob.h"
+#include <KMime/Message>
 #include <QSignalSpy>
 #include <QTest>
 #include <QTimer>
-#include <KMime/Message>
+#include <chrono>
+
+using namespace std::chrono_literals;
 
 QTEST_MAIN(DKIMCheckAuthenticationStatusJobTest)
 
@@ -38,12 +41,9 @@ void DKIMCheckAuthenticationStatusJobTest::shouldTestMail_data()
     QTest::addColumn<bool>("relaxedParsing");
     const QString curPath = QStringLiteral(DKIM_DATA_DIR "/");
 
-    QTest::addRow("dkim2") << QStringLiteral("dkim2.mbox")
-                           << curPath << false;
-    QTest::addRow("notsigned") << QStringLiteral("notsigned.mbox")
-                               << curPath << false;
-    QTest::addRow("broken1") << QStringLiteral("broken1.mbox")
-                             << curPath << false;
+    QTest::addRow("dkim2") << QStringLiteral("dkim2.mbox") << curPath << false;
+    QTest::addRow("notsigned") << QStringLiteral("notsigned.mbox") << curPath << false;
+    QTest::addRow("broken1") << QStringLiteral("broken1.mbox") << curPath << false;
 }
 
 void DKIMCheckAuthenticationStatusJobTest::shouldTestMail()
@@ -51,20 +51,20 @@ void DKIMCheckAuthenticationStatusJobTest::shouldTestMail()
     QFETCH(QString, fileName);
     QFETCH(QString, currentPath);
     QFETCH(bool, relaxedParsing);
-    KMime::Message *msg = new KMime::Message;
+    auto msg = new KMime::Message;
     QFile file(currentPath + fileName);
     QVERIFY(file.open(QIODevice::ReadOnly));
     msg->setContent(file.readAll());
     msg->parse();
 
-    MessageViewer::DKIMCheckAuthenticationStatusJob *job = new  MessageViewer::DKIMCheckAuthenticationStatusJob(this);
+    auto job = new MessageViewer::DKIMCheckAuthenticationStatusJob(this);
     MessageViewer::DKIMHeaderParser mHeaderParser;
     mHeaderParser.setHead(msg->head());
     mHeaderParser.parse();
     job->setHeaderParser(mHeaderParser);
     job->setUseRelaxedParsing(relaxedParsing);
     QSignalSpy dkimSignatureSpy(job, &MessageViewer::DKIMCheckAuthenticationStatusJob::result);
-    QTimer::singleShot(10, job, &MessageViewer::DKIMCheckAuthenticationStatusJob::start);
+    QTimer::singleShot(10ms, job, &MessageViewer::DKIMCheckAuthenticationStatusJob::start);
     QVERIFY(dkimSignatureSpy.wait());
     delete msg;
 }
