@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef DKIMHEADERPARSERTEST_H
-#define DKIMHEADERPARSERTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,11 +13,10 @@ class DKIMHeaderParserTest : public QObject
     Q_OBJECT
 public:
     explicit DKIMHeaderParserTest(QObject *parent = nullptr);
-    ~DKIMHeaderParserTest() = default;
+    ~DKIMHeaderParserTest() override = default;
 private Q_SLOTS:
     void shouldHaveDefaultValues();
     void shouldChangeWasAlreadyParsedBoolean();
     void shouldAssignElement();
 };
 
-#endif // DKIMHEADERPARSERTEST_H
