@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef DKIMINFOTEST_H
-#define DKIMINFOTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,7 +13,7 @@ class DKIMInfoTest : public QObject
     Q_OBJECT
 public:
     explicit DKIMInfoTest(QObject *parent = nullptr);
-    ~DKIMInfoTest() = default;
+    ~DKIMInfoTest() override = default;
 
 private Q_SLOTS:
     void shouldTestExtractDkimInfo();
@@ -22,4 +21,3 @@ private Q_SLOTS:
     void shouldHaveDefaultValue();
 };
 
-#endif // DKIMINFOTEST_H
