@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef DKIMMANAGERAUTHENTICATIONSERVERTEST_H
-#define DKIMMANAGERAUTHENTICATIONSERVERTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,9 +13,8 @@ class DKIMManagerAuthenticationServerTest : public QObject
     Q_OBJECT
 public:
     explicit DKIMManagerAuthenticationServerTest(QObject *parent = nullptr);
-    ~DKIMManagerAuthenticationServerTest() = default;
+    ~DKIMManagerAuthenticationServerTest() override = default;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
 };
 
-#endif // DKIMMANAGERAUTHENTICATIONSERVERTEST_H
