@@ -1,12 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "dkimmanagerkeytest.h"
 #include <QTest>
 
-QTEST_MAIN(DKIMManagerKeyTest)
+QTEST_GUILESS_MAIN(DKIMManagerKeyTest)
 
 DKIMManagerKeyTest::DKIMManagerKeyTest(QObject *parent)
     : QObject(parent)
