@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef DKIMMANAGERRULESTEST_H
-#define DKIMMANAGERRULESTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,11 +13,10 @@ class DKIMManagerRulesTest : public QObject
     Q_OBJECT
 public:
     explicit DKIMManagerRulesTest(QObject *parent = nullptr);
-    ~DKIMManagerRulesTest() = default;
+    ~DKIMManagerRulesTest() override = default;
 private Q_SLOTS:
     void shouldHaveDefaultValues();
     void shouldAddRules();
     void shouldClearRules();
 };
 
-#endif // DKIMMANAGERRULESTEST_H
