@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef DKIMMANAGERTEST_H
-#define DKIMMANAGERTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,7 +13,6 @@ class DKIMManagerTest : public QObject
     Q_OBJECT
 public:
     explicit DKIMManagerTest(QObject *parent = nullptr);
-    ~DKIMManagerTest() = default;
+    ~DKIMManagerTest() override = default;
 };
 
-#endif // DKIMMANAGERTEST_H
