@@ -1,15 +1,15 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "dkimwidgetinfotest.h"
 #include "dkim-verify/dkimwidgetinfo.h"
+#include <MessageViewer/DKIMCheckSignatureJob>
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QTest>
-#include <MessageViewer/DKIMCheckSignatureJob>
 
 QTEST_MAIN(DKIMWidgetInfoTest)
 DKIMWidgetInfoTest::DKIMWidgetInfoTest(QObject *parent)
@@ -21,11 +21,11 @@ void DKIMWidgetInfoTest::shouldHaveDefaultValues()
 {
     MessageViewer::DKIMWidgetInfo w;
 
-    auto *mainLayout = w.findChild<QHBoxLayout *>(QStringLiteral("mainLayout"));
+    auto mainLayout = w.findChild<QHBoxLayout *>(QStringLiteral("mainLayout"));
     QVERIFY(mainLayout);
     QCOMPARE(mainLayout->contentsMargins(), QMargins(0, 0, 0, 0));
 
-    auto *mLabel = w.findChild<QLabel *>(QStringLiteral("label"));
+    auto mLabel = w.findChild<QLabel *>(QStringLiteral("label"));
     QVERIFY(mLabel);
     QVERIFY(mLabel->text().isEmpty());
 
@@ -35,7 +35,7 @@ void DKIMWidgetInfoTest::shouldHaveDefaultValues()
 void DKIMWidgetInfoTest::shouldClearWidget()
 {
     MessageViewer::DKIMWidgetInfo w;
-    auto *mLabel = w.findChild<QLabel *>(QStringLiteral("label"));
+    auto mLabel = w.findChild<QLabel *>(QStringLiteral("label"));
     MessageViewer::DKIMCheckSignatureJob::CheckSignatureResult result;
     result.fromEmail = QStringLiteral("bla");
     result.sdid = QStringLiteral("bli");
