@@ -1,16 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef DKIMAUTHENTICATIONSTATUSINFO_H
-#define DKIMAUTHENTICATIONSTATUSINFO_H
+#pragma once
 
 #include "messageviewer_private_export.h"
-#include <QString>
 #include <QDebug>
-namespace MessageViewer {
+#include <QString>
+namespace MessageViewer
+{
 class MESSAGEVIEWER_TESTS_EXPORT DKIMAuthenticationStatusInfo
 {
 public:
@@ -27,8 +27,7 @@ public:
 
             Q_REQUIRED_RESULT bool operator==(const Property &other) const
             {
-                return other.type == type
-                       && other.value == value;
+                return other.type == type && other.value == value;
             }
         };
 
@@ -37,7 +36,7 @@ public:
         QString reason;
         int methodVersion = -1;
 
-        //Add Properties
+        // Add Properties
         QVector<Property> smtp;
         QVector<Property> header;
         QVector<Property> body;
@@ -73,6 +72,5 @@ private:
 }
 Q_DECLARE_METATYPE(MessageViewer::DKIMAuthenticationStatusInfo)
 Q_DECLARE_TYPEINFO(MessageViewer::DKIMAuthenticationStatusInfo::AuthStatusInfo, Q_MOVABLE_TYPE);
-MESSAGEVIEWER_EXPORT QDebug operator <<(QDebug d, const MessageViewer::DKIMAuthenticationStatusInfo &t);
+MESSAGEVIEWER_EXPORT QDebug operator<<(QDebug d, const MessageViewer::DKIMAuthenticationStatusInfo &t);
 
-#endif // DKIMAUTHENTICATIONSTATUSINFO_H
