@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    Code based on ARHParser.jsm from dkim_verifier (Copyright (c) Philippe Lieser)
    (This software is licensed under the terms of the MIT License.)
@@ -182,15 +182,8 @@ QString MessageViewer::DKIMAuthenticationStatusInfoUtil::domainName_p()
 // If match is found, removes it from str.
 QString MessageViewer::DKIMAuthenticationStatusInfoUtil::regexMatchO(const QString &regularExpressionStr)
 {
-    const QString regexp = (QLatin1Char('^')
-                            + DKIMAuthenticationStatusInfoUtil::cfws_op()
-                            + QStringLiteral("(?:")
-                            + regularExpressionStr
-                            + QLatin1Char(')')
-                            + QStringLiteral("(?:(?:")
-                            + DKIMAuthenticationStatusInfoUtil::cfws_op()
-                            + QStringLiteral("\r\n$)|(?=;)|(?=")
-                            + DKIMAuthenticationStatusInfoUtil::cfws_p()
-                            + QStringLiteral("))"));
+    const QString regexp = (QLatin1Char('^') + DKIMAuthenticationStatusInfoUtil::cfws_op() + QStringLiteral("(?:") + regularExpressionStr + QLatin1Char(')')
+                            + QStringLiteral("(?:(?:") + DKIMAuthenticationStatusInfoUtil::cfws_op() + QStringLiteral("\r\n$)|(?=;)|(?=")
+                            + DKIMAuthenticationStatusInfoUtil::cfws_p() + QStringLiteral("))"));
     return regexp;
 }
