@@ -1,17 +1,18 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef DKIMAUTHENTICATIONSTATUSINFOUTIL_H
-#define DKIMAUTHENTICATIONSTATUSINFOUTIL_H
+#pragma once
 
 #include "messageviewer_private_export.h"
 #include <QString>
 
-namespace MessageViewer {
-namespace DKIMAuthenticationStatusInfoUtil {
+namespace MessageViewer
+{
+namespace DKIMAuthenticationStatusInfoUtil
+{
 MESSAGEVIEWER_TESTS_EXPORT Q_REQUIRED_RESULT QString wsp_p();
 MESSAGEVIEWER_TESTS_EXPORT Q_REQUIRED_RESULT QString vchar_p();
 MESSAGEVIEWER_TESTS_EXPORT Q_REQUIRED_RESULT QString letDig_p();
@@ -43,4 +44,3 @@ MESSAGEVIEWER_TESTS_EXPORT Q_REQUIRED_RESULT QString regexMatchO(const QString &
 }
 }
 
-#endif // DKIMAUTHENTICATIONSTATUSINFOUTIL_H
