@@ -1,37 +1,25 @@
 /*
-   Copyright (C) 2018-2019 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "dkimchecksignaturejob.h"
 #include "dkimdownloadkeyjob.h"
-#include "dkimmanagerkey.h"
 #include "dkiminfo.h"
-#include "dkimutil.h"
 #include "dkimkeyrecord.h"
+#include "dkimmanagerkey.h"
+#include "dkimutil.h"
 #include "messageviewer_dkimcheckerdebug.h"
 
 #include <KEmailAddress>
-#include <QDateTime>
 #include <QCryptographicHash>
+#include <QDateTime>
 #include <QFile>
+#include <QRegularExpression>
 #include <qca_publickey.h>
 
-//see https://tools.ietf.org/html/rfc6376
+// see https://tools.ietf.org/html/rfc6376
 //#define DEBUG_SIGNATURE_DKIM 1
 using namespace MessageViewer;
 DKIMCheckSignatureJob::DKIMCheckSignatureJob(QObject *parent)
@@ -43,7 +31,7 @@ DKIMCheckSignatureJob::~DKIMCheckSignatureJob()
 {
 }
 
-MessageViewer::DKIMCheckSignatureJob::CheckSignatureResult DKIMCheckSignatureJob::createCheckResult()
+MessageViewer::DKIMCheckSignatureJob::CheckSignatureResult DKIMCheckSignatureJob::createCheckResult() const
 {
     MessageViewer::DKIMCheckSignatureJob::CheckSignatureResult result;
     result.error = mError;
@@ -52,6 +40,7 @@ MessageViewer::DKIMCheckSignatureJob::CheckSignatureResult DKIMCheckSignatureJob
     result.sdid = mDkimInfo.domain();
     result.auid = mDkimInfo.agentOrUserIdentifier();
     result.fromEmail = mFromEmail;
+    result.listSignatureAuthenticationResult = mCheckSignatureAuthenticationResult;
     return result;
 }
 
@@ -77,7 +66,7 @@ void DKIMCheckSignatureJob::start()
     if (auto hrd = mMessage->headerByType("DKIM-Signature")) {
         mDkimValue = hrd->asUnicodeString();
     }
-    //Store mFromEmail before looking at mDkimValue value. Otherwise we can return a from empty
+    // Store mFromEmail before looking at mDkimValue value. Otherwise we can return a from empty
     if (auto hrd = mMessage->from(false)) {
         mFromEmail = KEmailAddress::extractEmailAddress(hrd->asUnicodeString());
     }
@@ -103,7 +92,7 @@ void DKIMCheckSignatureJob::start()
         deleteLater();
         return;
     }
-    //ComputeBodyHash now.
+    // ComputeBodyHash now.
     switch (mDkimInfo.bodyCanonization()) {
     case MessageViewer::DKIMInfo::CanonicalizationType::Unknown:
         mError = MessageViewer::DKIMCheckSignatureJob::DKIMError::InvalidBodyCanonicalization;
@@ -118,12 +107,13 @@ void DKIMCheckSignatureJob::start()
         mBodyCanonizationResult = bodyCanonizationRelaxed();
         break;
     }
-    //qDebug() << " bodyCanonizationResult "<< mBodyCanonizationResult << " algorithm " << mDkimInfo.hashingAlgorithm() << mDkimInfo.bodyHash();
+    // qDebug() << " bodyCanonizationResult "<< mBodyCanonizationResult << " algorithm " << mDkimInfo.hashingAlgorithm() << mDkimInfo.bodyHash();
 
-    if (mDkimInfo.bodyLengthCount() != -1) { //Verify it.
+    if (mDkimInfo.bodyLengthCount() != -1) { // Verify it.
         if (mDkimInfo.bodyLengthCount() > mBodyCanonizationResult.length()) {
             // length tag exceeds body size
-            qCDebug(MESSAGEVIEWER_DKIMCHECKER_LOG) << " mDkimInfo.bodyLengthCount() " << mDkimInfo.bodyLengthCount() << " mBodyCanonizationResult.length() " << mBodyCanonizationResult.length();
+            qCDebug(MESSAGEVIEWER_DKIMCHECKER_LOG) << " mDkimInfo.bodyLengthCount() " << mDkimInfo.bodyLengthCount() << " mBodyCanonizationResult.length() "
+                                                   << mBodyCanonizationResult.length();
             mError = MessageViewer::DKIMCheckSignatureJob::DKIMError::SignatureTooLarge;
             mStatus = MessageViewer::DKIMCheckSignatureJob::DKIMStatus::Invalid;
             Q_EMIT result(createCheckResult());
@@ -135,8 +125,22 @@ void DKIMCheckSignatureJob::start()
         // truncated body to the length specified in the "l=" tag
         mBodyCanonizationResult = mBodyCanonizationResult.left(mDkimInfo.bodyLengthCount());
     }
-    if (mBodyCanonizationResult.startsWith(QLatin1String("\r\n"))) { //Remove it from start
-        mBodyCanonizationResult = mBodyCanonizationResult.right(mBodyCanonizationResult.length() -2);
+    if (mBodyCanonizationResult.startsWith(QLatin1String("\r\n"))) { // Remove it from start
+        mBodyCanonizationResult = mBodyCanonizationResult.right(mBodyCanonizationResult.length() - 2);
+    }
+    // It seems that kmail add a space before this line => it breaks check
+    if (mBodyCanonizationResult.startsWith(QLatin1String(" This is a multi-part message in MIME format"))) { // Remove it from start
+        mBodyCanonizationResult.replace(QStringLiteral(" This is a multi-part message in MIME format"),
+                                        QStringLiteral("This is a multi-part message in MIME format"));
+    }
+    // It seems that kmail add a space before this line => it breaks check
+    if (mBodyCanonizationResult.startsWith(QLatin1String(" This is a cryptographically signed message in MIME format."))) { // Remove it from start
+        mBodyCanonizationResult.replace(QStringLiteral(" This is a cryptographically signed message in MIME format."),
+                                        QStringLiteral("This is a cryptographically signed message in MIME format."));
+    }
+    if (mBodyCanonizationResult.startsWith(QLatin1String(" \r\n"))) { // Remove it from start
+        static const QRegularExpression reg{QStringLiteral("^ \r\n")};
+        mBodyCanonizationResult.remove(reg);
     }
 #ifdef DEBUG_SIGNATURE_DKIM
     QFile caFile(QStringLiteral("/tmp/bodycanon-kmail.txt"));
@@ -164,7 +168,9 @@ void DKIMCheckSignatureJob::start()
     }
 
     // compare body hash
-    qCWarning(MESSAGEVIEWER_DKIMCHECKER_LOG) << "resultHash "  << resultHash << "mDkimInfo.bodyHash()" << mDkimInfo.bodyHash();
+    qDebug(MESSAGEVIEWER_DKIMCHECKER_LOG)
+        << "resultHash " << resultHash << "mDkimInfo.bodyHash()"
+        << mDkimInfo.bodyHash();
     if (resultHash != mDkimInfo.bodyHash().toLatin1()) {
         qCWarning(MESSAGEVIEWER_DKIMCHECKER_LOG) << " Corrupted body hash";
         mError = MessageViewer::DKIMCheckSignatureJob::DKIMError::CorruptedBodyHash;
@@ -181,20 +187,21 @@ void DKIMCheckSignatureJob::start()
         deleteLater();
         return;
     }
-    //Parse message header
+    // Parse message header
     if (!mHeaderParser.wasAlreadyParsed()) {
         mHeaderParser.setHead(mMessage->head());
         mHeaderParser.parse();
     }
 
     computeHeaderCanonization(true);
-    if (mPolicy.saveKey()) {
+    if (mPolicy.saveKey() == MessageViewer::MessageViewerSettings::EnumSaveKey::Save) {
         const QString keyValue = MessageViewer::DKIMManagerKey::self()->keyValue(mDkimInfo.selector(), mDkimInfo.domain());
-        //qDebug() << " mDkimInfo.selector() " << mDkimInfo.selector() << "mDkimInfo.domain()  " << mDkimInfo.domain() << keyValue;
+        // qDebug() << " mDkimInfo.selector() " << mDkimInfo.selector() << "mDkimInfo.domain()  " << mDkimInfo.domain() << keyValue;
         if (keyValue.isEmpty()) {
             downloadKey(mDkimInfo);
         } else {
             parseDKIMKeyRecord(keyValue, mDkimInfo.domain(), mDkimInfo.selector(), false);
+            MessageViewer::DKIMManagerKey::self()->updateLastUsed(mDkimInfo.domain(), mDkimInfo.selector());
         }
     } else {
         downloadKey(mDkimInfo);
@@ -203,7 +210,7 @@ void DKIMCheckSignatureJob::start()
 
 void DKIMCheckSignatureJob::computeHeaderCanonization(bool removeQuoteOnContentType)
 {
-    //Compute Hash Header
+    // Compute Hash Header
     switch (mDkimInfo.headerCanonization()) {
     case MessageViewer::DKIMInfo::CanonicalizationType::Unknown:
         return;
@@ -232,7 +239,7 @@ void DKIMCheckSignatureJob::computeHeaderCanonization(bool removeQuoteOnContentT
     // add DKIM-Signature header to the hash input
     // with the value of the "b=" tag (including all surrounding whitespace) deleted
 
-    //Add dkim-signature as lowercase
+    // Add dkim-signature as lowercase
 
     QString dkimValue = mDkimValue;
     dkimValue = dkimValue.left(dkimValue.indexOf(QLatin1String("b=")) + 2);
@@ -240,10 +247,11 @@ void DKIMCheckSignatureJob::computeHeaderCanonization(bool removeQuoteOnContentT
     case MessageViewer::DKIMInfo::CanonicalizationType::Unknown:
         return;
     case MessageViewer::DKIMInfo::CanonicalizationType::Simple:
-        mHeaderCanonizationResult += QLatin1String("\r\n") + MessageViewer::DKIMUtil::headerCanonizationSimple(QLatin1String("dkim-signature"), dkimValue);
+        mHeaderCanonizationResult += QLatin1String("\r\n") + MessageViewer::DKIMUtil::headerCanonizationSimple(QStringLiteral("dkim-signature"), dkimValue);
         break;
     case MessageViewer::DKIMInfo::CanonicalizationType::Relaxed:
-        mHeaderCanonizationResult += QLatin1String("\r\n") + MessageViewer::DKIMUtil::headerCanonizationRelaxed(QLatin1String("dkim-signature"), dkimValue, removeQuoteOnContentType);
+        mHeaderCanonizationResult +=
+            QLatin1String("\r\n") + MessageViewer::DKIMUtil::headerCanonizationRelaxed(QStringLiteral("dkim-signature"), dkimValue, removeQuoteOnContentType);
         break;
     }
 #ifdef DEBUG_SIGNATURE_DKIM
@@ -260,6 +268,11 @@ void DKIMCheckSignatureJob::setHeaderParser(const DKIMHeaderParser &headerParser
     mHeaderParser = headerParser;
 }
 
+void DKIMCheckSignatureJob::setCheckSignatureAuthenticationResult(const QVector<DKIMCheckSignatureJob::DKIMCheckSignatureAuthenticationResult> &lst)
+{
+    mCheckSignatureAuthenticationResult = lst;
+}
+
 QString DKIMCheckSignatureJob::bodyCanonizationSimple() const
 {
     /*
@@ -311,7 +324,8 @@ QString DKIMCheckSignatureJob::headerCanonizationSimple() const
 
     DKIMHeaderParser parser = mHeaderParser;
 
-    for (const QString &header : mDkimInfo.listSignedHeader()) {
+    const auto listSignedHeader{mDkimInfo.listSignedHeader()};
+    for (const QString &header : listSignedHeader) {
         const QString str = parser.headerType(header.toLower());
         if (!str.isEmpty()) {
             if (!headers.isEmpty()) {
@@ -325,32 +339,33 @@ QString DKIMCheckSignatureJob::headerCanonizationSimple() const
 
 QString DKIMCheckSignatureJob::headerCanonizationRelaxed(bool removeQuoteOnContentType) const
 {
-//    The "relaxed" header canonicalization algorithm MUST apply the
-//       following steps in order:
+    //    The "relaxed" header canonicalization algorithm MUST apply the
+    //       following steps in order:
 
-//       o  Convert all header field names (not the header field values) to
-//          lowercase.  For example, convert "SUBJect: AbC" to "subject: AbC".
+    //       o  Convert all header field names (not the header field values) to
+    //          lowercase.  For example, convert "SUBJect: AbC" to "subject: AbC".
 
-//       o  Unfold all header field continuation lines as described in
-//          [RFC5322]; in particular, lines with terminators embedded in
-//          continued header field values (that is, CRLF sequences followed by
-//          WSP) MUST be interpreted without the CRLF.  Implementations MUST
-//          NOT remove the CRLF at the end of the header field value.
+    //       o  Unfold all header field continuation lines as described in
+    //          [RFC5322]; in particular, lines with terminators embedded in
+    //          continued header field values (that is, CRLF sequences followed by
+    //          WSP) MUST be interpreted without the CRLF.  Implementations MUST
+    //          NOT remove the CRLF at the end of the header field value.
 
-//       o  Convert all sequences of one or more WSP characters to a single SP
-//          character.  WSP characters here include those before and after a
-//          line folding boundary.
+    //       o  Convert all sequences of one or more WSP characters to a single SP
+    //          character.  WSP characters here include those before and after a
+    //          line folding boundary.
 
-//       o  Delete all WSP characters at the end of each unfolded header field
-//          value.
+    //       o  Delete all WSP characters at the end of each unfolded header field
+    //          value.
 
-//       o  Delete any WSP characters remaining before and after the colon
-//          separating the header field name from the header field value.  The
-//          colon separator MUST be retained.
+    //       o  Delete any WSP characters remaining before and after the colon
+    //          separating the header field name from the header field value.  The
+    //          colon separator MUST be retained.
 
     QString headers;
     DKIMHeaderParser parser = mHeaderParser;
-    for (const QString &header : mDkimInfo.listSignedHeader()) {
+    const auto listSignedHeader = mDkimInfo.listSignedHeader();
+    for (const QString &header : listSignedHeader) {
         const QString str = parser.headerType(header.toLower());
         if (!str.isEmpty()) {
             if (!headers.isEmpty()) {
@@ -364,7 +379,7 @@ QString DKIMCheckSignatureJob::headerCanonizationRelaxed(bool removeQuoteOnConte
 
 void DKIMCheckSignatureJob::downloadKey(const DKIMInfo &info)
 {
-    DKIMDownloadKeyJob *job = new DKIMDownloadKeyJob(this);
+    auto job = new DKIMDownloadKeyJob(this);
     job->setDomainName(info.domain());
     job->setSelectorName(info.selector());
     connect(job, &DKIMDownloadKeyJob::error, this, [this](const QString &errorString) {
@@ -392,7 +407,7 @@ void DKIMCheckSignatureJob::slotDownloadKeyDone(const QList<QByteArray> &lst, co
         for (const QByteArray &b : lst) {
             ba += b;
         }
-        qCWarning(MESSAGEVIEWER_DKIMCHECKER_LOG) << "Key result has more that 1 element" << lst;
+        // qCDebug(MESSAGEVIEWER_DKIMCHECKER_LOG) << "Key result has more that 1 element" << lst;
     } else {
         ba = lst.at(0);
     }
@@ -401,7 +416,8 @@ void DKIMCheckSignatureJob::slotDownloadKeyDone(const QList<QByteArray> &lst, co
 
 void DKIMCheckSignatureJob::parseDKIMKeyRecord(const QString &str, const QString &domain, const QString &selector, bool storeKeyValue)
 {
-    qCDebug(MESSAGEVIEWER_DKIMCHECKER_LOG) << "void DKIMCheckSignatureJob::parseDKIMKeyRecord(const QString &str, const QString &domain, const QString &selector, bool storeKeyValue) key:" << str;
+    qCDebug(MESSAGEVIEWER_DKIMCHECKER_LOG)
+        << "void DKIMCheckSignatureJob::parseDKIMKeyRecord(const QString &str, const QString &domain, const QString &selector, bool storeKeyValue) key:" << str;
     if (!mDkimKeyRecord.parseKey(str)) {
         qCWarning(MESSAGEVIEWER_DKIMCHECKER_LOG) << "Impossible to parse key record " << str;
         mStatus = MessageViewer::DKIMCheckSignatureJob::DKIMStatus::Invalid;
@@ -464,37 +480,46 @@ void DKIMCheckSignatureJob::parseDKIMKeyRecord(const QString &str, const QString
 void DKIMCheckSignatureJob::verifyRSASignature()
 {
     QCA::ConvertResult conversionResult;
-    //qDebug() << "mDkimKeyRecord.publicKey() " <<mDkimKeyRecord.publicKey() << " QCA::base64ToArray(mDkimKeyRecord.publicKey() " <<QCA::base64ToArray(mDkimKeyRecord.publicKey());
+    // qDebug() << "mDkimKeyRecord.publicKey() " <<mDkimKeyRecord.publicKey() << " QCA::base64ToArray(mDkimKeyRecord.publicKey() "
+    // <<QCA::base64ToArray(mDkimKeyRecord.publicKey());
     QCA::PublicKey publicKey = QCA::RSAPublicKey::fromDER(QCA::base64ToArray(mDkimKeyRecord.publicKey()), &conversionResult);
     if (QCA::ConvertGood != conversionResult) {
-        qCWarning(MESSAGEVIEWER_DKIMCHECKER_LOG) << "Public key read failed" << conversionResult << " public key" <<mDkimKeyRecord.publicKey();
+        qCWarning(MESSAGEVIEWER_DKIMCHECKER_LOG) << "Public key read failed" << conversionResult << " public key" << mDkimKeyRecord.publicKey();
         mError = MessageViewer::DKIMCheckSignatureJob::DKIMError::PublicKeyConversionError;
         mStatus = MessageViewer::DKIMCheckSignatureJob::DKIMStatus::Invalid;
         Q_EMIT result(createCheckResult());
         deleteLater();
         return;
     } else {
-        qCWarning(MESSAGEVIEWER_DKIMCHECKER_LOG) << "Success loading public key";
+      qDebug(MESSAGEVIEWER_DKIMCHECKER_LOG) << "Success loading public key";
     }
     QCA::RSAPublicKey rsaPublicKey = publicKey.toRSA();
-    //qDebug() << "publicKey.modulus" << rsaPublicKey.n().toString();
-    //qDebug() << "publicKey.exponent" << rsaPublicKey.e().toString();
+    // qDebug() << "publicKey.modulus" << rsaPublicKey.n().toString();
+    // qDebug() << "publicKey.exponent" << rsaPublicKey.e().toString();
 
     if (rsaPublicKey.e().toString().toLong() * 4 < 1024) {
-        mError = MessageViewer::DKIMCheckSignatureJob::DKIMError::PublicKeyTooSmall;
-        mStatus = MessageViewer::DKIMCheckSignatureJob::DKIMStatus::Invalid;
-        Q_EMIT result(createCheckResult());
-        deleteLater();
-        return;
+        const int publicRsaTooSmallPolicyValue = mPolicy.publicRsaTooSmallPolicy();
+        if (publicRsaTooSmallPolicyValue == MessageViewer::MessageViewerSettings::EnumPublicRsaTooSmall::Nothing) {
+            // Nothing
+        } else if (publicRsaTooSmallPolicyValue == MessageViewer::MessageViewerSettings::EnumPublicRsaTooSmall::Warning) {
+            mWarning = MessageViewer::DKIMCheckSignatureJob::DKIMWarning::PublicRsaKeyTooSmall;
+        } else if (publicRsaTooSmallPolicyValue == MessageViewer::MessageViewerSettings::EnumPublicRsaTooSmall::Error) {
+            mError = MessageViewer::DKIMCheckSignatureJob::DKIMError::PublicKeyTooSmall;
+            mStatus = MessageViewer::DKIMCheckSignatureJob::DKIMStatus::Invalid;
+            Q_EMIT result(createCheckResult());
+            deleteLater();
+            return;
+        }
+
     } else if (rsaPublicKey.e().toString().toLong() * 4 < 2048) {
-        //TODO
+        // TODO
     }
-    //qDebug() << "mHeaderCanonizationResult " << mHeaderCanonizationResult << " mDkimInfo.signature() " << mDkimInfo.signature();
+    // qDebug() << "mHeaderCanonizationResult " << mHeaderCanonizationResult << " mDkimInfo.signature() " << mDkimInfo.signature();
     if (rsaPublicKey.canVerify()) {
         const QString s = mDkimInfo.signature().remove(QLatin1Char(' '));
         QCA::SecureArray sec = mHeaderCanonizationResult.toLatin1();
         const QByteArray ba = QCA::base64ToArray(s);
-        //qDebug() << " s base ba" << ba;
+        // qDebug() << " s base ba" << ba;
         QCA::SignatureAlgorithm sigAlg;
         switch (mDkimInfo.hashingAlgorithm()) {
         case DKIMInfo::HashingAlgorithmType::Sha1:
@@ -504,9 +529,15 @@ void DKIMCheckSignatureJob::verifyRSASignature()
             sigAlg = QCA::EMSA3_SHA256;
             break;
         case DKIMInfo::HashingAlgorithmType::Any:
-        case DKIMInfo::HashingAlgorithmType::Unknown:
-            //Error !
-            break;
+        case DKIMInfo::HashingAlgorithmType::Unknown: {
+            // then signature is invalid
+            mError = MessageViewer::DKIMCheckSignatureJob::DKIMError::ImpossibleToVerifySignature;
+            mStatus = MessageViewer::DKIMCheckSignatureJob::DKIMStatus::Invalid;
+            Q_EMIT result(createCheckResult());
+            deleteLater();
+            qCWarning(MESSAGEVIEWER_DKIMCHECKER_LOG) << "DKIMInfo::HashingAlgorithmType undefined ! ";
+            return;
+        }
         }
         if (!rsaPublicKey.verifyMessage(sec, ba, sigAlg, QCA::DERSequence)) {
             computeHeaderCanonization(false);
@@ -549,7 +580,7 @@ DKIMCheckSignatureJob::DKIMWarning DKIMCheckSignatureJob::warning() const
     return mWarning;
 }
 
-void DKIMCheckSignatureJob::setWarning(const DKIMCheckSignatureJob::DKIMWarning &warning)
+void DKIMCheckSignatureJob::setWarning(DKIMCheckSignatureJob::DKIMWarning warning)
 {
     mWarning = warning;
 }
@@ -594,7 +625,8 @@ MessageViewer::DKIMCheckSignatureJob::DKIMStatus DKIMCheckSignatureJob::checkSig
         return MessageViewer::DKIMCheckSignatureJob::DKIMStatus::Invalid;
     }
 
-    if ((info.hashingAlgorithm() == MessageViewer::DKIMInfo::HashingAlgorithmType::Any) || (info.hashingAlgorithm() == MessageViewer::DKIMInfo::HashingAlgorithmType::Unknown)) {
+    if ((info.hashingAlgorithm() == MessageViewer::DKIMInfo::HashingAlgorithmType::Any)
+        || (info.hashingAlgorithm() == MessageViewer::DKIMInfo::HashingAlgorithmType::Unknown)) {
         qCWarning(MESSAGEVIEWER_DKIMCHECKER_LOG) << "body header algorithm is empty";
         mError = MessageViewer::DKIMCheckSignatureJob::DKIMError::InvalidBodyHashAlgorithm;
         return MessageViewer::DKIMCheckSignatureJob::DKIMStatus::Invalid;
@@ -607,7 +639,7 @@ MessageViewer::DKIMCheckSignatureJob::DKIMStatus DKIMCheckSignatureJob::checkSig
 
     if (info.hashingAlgorithm() == DKIMInfo::HashingAlgorithmType::Sha1) {
         if (mPolicy.rsaSha1Policy() == MessageViewer::MessageViewerSettings::EnumPolicyRsaSha1::Nothing) {
-            //nothing
+            // nothing
         } else if (mPolicy.rsaSha1Policy() == MessageViewer::MessageViewerSettings::EnumPolicyRsaSha1::Warning) {
             qCWarning(MESSAGEVIEWER_DKIMCHECKER_LOG) << "hash algorithm is not secure sha1 : Error";
             mWarning = MessageViewer::DKIMCheckSignatureJob::DKIMWarning::HashAlgorithmUnsafe;
@@ -618,14 +650,14 @@ MessageViewer::DKIMCheckSignatureJob::DKIMStatus DKIMCheckSignatureJob::checkSig
         }
     }
 
-    //qDebug() << "info.agentOrUserIdentifier() " << info.agentOrUserIdentifier() << " info.iDomain() " << info.iDomain();
+    // qDebug() << "info.agentOrUserIdentifier() " << info.agentOrUserIdentifier() << " info.iDomain() " << info.iDomain();
     if (!info.agentOrUserIdentifier().endsWith(info.iDomain())) {
         qCWarning(MESSAGEVIEWER_DKIMCHECKER_LOG) << "AUID is not in a subdomain of SDID";
         mError = MessageViewer::DKIMCheckSignatureJob::DKIMError::IDomainError;
         return MessageViewer::DKIMCheckSignatureJob::DKIMStatus::Invalid;
     }
-    //Add more test
-    //TODO check if info is valid
+    // Add more test
+    // TODO check if info is valid
     return MessageViewer::DKIMCheckSignatureJob::DKIMStatus::Valid;
 }
 
@@ -639,7 +671,7 @@ DKIMCheckSignatureJob::DKIMStatus DKIMCheckSignatureJob::status() const
     return mStatus;
 }
 
-void DKIMCheckSignatureJob::setStatus(const DKIMCheckSignatureJob::DKIMStatus &status)
+void DKIMCheckSignatureJob::setStatus(DKIMCheckSignatureJob::DKIMStatus status)
 {
     mStatus = status;
 }
@@ -656,12 +688,8 @@ bool DKIMCheckSignatureJob::CheckSignatureResult::isValid() const
 
 bool DKIMCheckSignatureJob::CheckSignatureResult::operator==(const DKIMCheckSignatureJob::CheckSignatureResult &other) const
 {
-    return error == other.error
-           && warning == other.warning
-           && status == other.status
-           && fromEmail == other.fromEmail
-            && auid == other.auid
-            && sdid == other.sdid;
+    return error == other.error && warning == other.warning && status == other.status && fromEmail == other.fromEmail && auid == other.auid
+        && sdid == other.sdid && listSignatureAuthenticationResult == other.listSignatureAuthenticationResult;
 }
 
 bool DKIMCheckSignatureJob::CheckSignatureResult::operator!=(const DKIMCheckSignatureJob::CheckSignatureResult &other) const
@@ -669,13 +697,37 @@ bool DKIMCheckSignatureJob::CheckSignatureResult::operator!=(const DKIMCheckSign
     return !CheckSignatureResult::operator==(other);
 }
 
-QDebug operator <<(QDebug d, const DKIMCheckSignatureJob::CheckSignatureResult &t)
+QDebug operator<<(QDebug d, const DKIMCheckSignatureJob::CheckSignatureResult &t)
 {
-    d << "error " << t.error;
-    d << "warning " << t.warning;
-    d << "status " << t.status;
-    d << "signedBy " << t.sdid;
-    d << "fromEmail " << t.fromEmail;
-    d << "auid " << t.auid;
+    d << " error " << t.error;
+    d << " warning " << t.warning;
+    d << " status " << t.status;
+    d << " signedBy " << t.sdid;
+    d << " fromEmail " << t.fromEmail;
+    d << " auid " << t.auid;
+    d << " authenticationResult " << t.listSignatureAuthenticationResult;
     return d;
 }
+
+QDebug operator<<(QDebug d, const DKIMCheckSignatureJob::DKIMCheckSignatureAuthenticationResult &t)
+{
+    d << " method " << t.method;
+    d << " errorStr " << t.errorStr;
+    d << " status " << t.status;
+    d << " sdid " << t.sdid;
+    d << " auid " << t.auid;
+    d << " inforesult " << t.infoResult;
+    return d;
+}
+
+bool DKIMCheckSignatureJob::DKIMCheckSignatureAuthenticationResult::operator==(const DKIMCheckSignatureJob::DKIMCheckSignatureAuthenticationResult &other) const
+{
+    return errorStr == other.errorStr && method == other.method && status == other.status && sdid == other.sdid && auid == other.auid
+        && infoResult == other.infoResult;
+}
+
+bool DKIMCheckSignatureJob::DKIMCheckSignatureAuthenticationResult::isValid() const
+{
+    // TODO improve it
+    return (method != AuthenticationMethod::Unknown);
+}
