@@ -1,30 +1,17 @@
 /*
-   Copyright (C) 2018-2019 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef DKIMINFO_H
-#define DKIMINFO_H
+#pragma once
 
 #include "messageviewer_export.h"
+#include <QObject>
 #include <QString>
 #include <QStringList>
-#include <QObject>
-namespace MessageViewer {
+namespace MessageViewer
+{
 /**
  * @brief The DKIMInfo class
  * @author Laurent Montel <montel@kde.org>
@@ -92,10 +79,10 @@ public:
     void setBodyLengthCount(int bodyLengthCount);
 
     Q_REQUIRED_RESULT CanonicalizationType headerCanonization() const;
-    void setHeaderCanonization(const CanonicalizationType &headerCanonization);
+    void setHeaderCanonization(CanonicalizationType headerCanonization);
 
     Q_REQUIRED_RESULT CanonicalizationType bodyCanonization() const;
-    void setBodyCanonization(const CanonicalizationType &bodyCanonization);
+    void setBodyCanonization(CanonicalizationType bodyCanonization);
 
     Q_REQUIRED_RESULT bool operator==(const DKIMInfo &other) const;
 
@@ -118,7 +105,7 @@ private:
     QString mAgentOrUserIdentifier;
     QString mIDomain;
     QStringList mListSignedHeader;
-    QStringList mCopiedHeaderField; //Default is empty
+    QStringList mCopiedHeaderField; // Default is empty
     qint64 mSignatureTimeStamp = -1;
     qint64 mExpireTime = -1;
     int mVersion = -1;
@@ -128,5 +115,4 @@ private:
 };
 }
 Q_DECLARE_METATYPE(MessageViewer::DKIMInfo)
-MESSAGEVIEWER_EXPORT QDebug operator <<(QDebug d, const MessageViewer::DKIMInfo &t);
-#endif // DKIMINFO_H
+MESSAGEVIEWER_EXPORT QDebug operator<<(QDebug d, const MessageViewer::DKIMInfo &t);
