@@ -1,20 +1,23 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "dkimmanager.h"
-#include "messageviewer_dkimcheckerdebug.h"
-#include "dkimresultattribute.h"
 #include "dkimcheckfulljob.h"
+#include "dkimmanagerkey.h"
+#include "dkimresultattribute.h"
+#include "messageviewer_dkimcheckerdebug.h"
 #include "settings/messageviewersettings.h"
-#include <AkonadiCore/AttributeFactory>
+#include <Akonadi/AttributeFactory>
 
 using namespace MessageViewer;
 DKIMManager::DKIMManager(QObject *parent)
     : QObject(parent)
 {
+    // Initialize QCA
+    MessageViewer::DKIMManagerKey::self();
     Akonadi::AttributeFactory::registerAttribute<MessageViewer::DKIMResultAttribute>();
 }
 
@@ -52,14 +55,14 @@ void DKIMManager::checkDKim(const Akonadi::Item &item)
 {
     if (mCheckPolicy.saveDkimResult()) {
         if (item.hasAttribute<MessageViewer::DKIMResultAttribute>()) {
-            const MessageViewer::DKIMResultAttribute *const attr
-                = item.attribute<MessageViewer::DKIMResultAttribute>();
+            const auto *const attr = item.attribute<MessageViewer::DKIMResultAttribute>();
             if (attr) {
                 DKIMCheckSignatureJob::CheckSignatureResult checkResult;
                 checkResult.error = static_cast<DKIMCheckSignatureJob::DKIMError>(attr->error());
                 checkResult.warning = static_cast<DKIMCheckSignatureJob::DKIMWarning>(attr->warning());
                 checkResult.status = static_cast<DKIMCheckSignatureJob::DKIMStatus>(attr->status());
-                qCDebug(MESSAGEVIEWER_DKIMCHECKER_LOG) << "result : status " << checkResult.status << " error : " << checkResult.error << " warning " << checkResult.warning;
+                qCDebug(MESSAGEVIEWER_DKIMCHECKER_LOG)
+                    << "result : status " << checkResult.status << " error : " << checkResult.error << " warning " << checkResult.warning;
                 Q_EMIT result(checkResult, item.id());
                 return;
             }
@@ -70,7 +73,7 @@ void DKIMManager::checkDKim(const Akonadi::Item &item)
 
 void DKIMManager::checkFullInfo(const Akonadi::Item &item)
 {
-    DKIMCheckFullJob *job = new DKIMCheckFullJob(this);
+    auto job = new DKIMCheckFullJob(this);
     job->setPolicy(mCheckPolicy);
     connect(job, &DKIMCheckFullJob::result, this, &DKIMManager::result);
     job->startCheckFullInfo(item);
@@ -78,7 +81,7 @@ void DKIMManager::checkFullInfo(const Akonadi::Item &item)
 
 void DKIMManager::checkDKim(const KMime::Message::Ptr &message)
 {
-    DKIMCheckFullJob *job = new DKIMCheckFullJob(this);
+    auto job = new DKIMCheckFullJob(this);
     job->setPolicy(mCheckPolicy);
     connect(job, &DKIMCheckFullJob::result, this, &DKIMManager::result);
     job->startCheckFullInfo(message);
