@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -25,10 +25,7 @@ DKIMResultAttribute::DKIMResultAttribute()
 {
 }
 
-DKIMResultAttribute::~DKIMResultAttribute()
-{
-    delete d;
-}
+DKIMResultAttribute::~DKIMResultAttribute() = default;
 
 QByteArray DKIMResultAttribute::type() const
 {
@@ -38,7 +35,7 @@ QByteArray DKIMResultAttribute::type() const
 
 DKIMResultAttribute *DKIMResultAttribute::clone() const
 {
-    DKIMResultAttribute *attr = new DKIMResultAttribute();
+    auto attr = new DKIMResultAttribute();
     attr->setWarning(warning());
     attr->setStatus(status());
     attr->setError(error());
@@ -71,9 +68,7 @@ void DKIMResultAttribute::deserialize(const QByteArray &data)
 
 bool DKIMResultAttribute::operator==(const DKIMResultAttribute &other) const
 {
-    return d->error == other.error()
-           && d->warning == other.warning()
-           && d->status == other.status();
+    return d->error == other.error() && d->warning == other.warning() && d->status == other.status();
 }
 
 void DKIMResultAttribute::setError(int err)
