@@ -1,21 +1,22 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef DKIMRESULTATTRIBUTE_H
-#define DKIMRESULTATTRIBUTE_H
+#pragma once
 
-#include <AkonadiCore/attribute.h>
 #include "messageviewer_private_export.h"
-namespace MessageViewer {
+#include <Akonadi/Attribute>
+#include <memory>
+namespace MessageViewer
+{
 class DKIMResultAttributePrivate;
 
 class MESSAGEVIEWER_TESTS_EXPORT DKIMResultAttribute : public Akonadi::Attribute
 {
 public:
     DKIMResultAttribute();
-    ~DKIMResultAttribute();
+    ~DKIMResultAttribute() override;
     Q_REQUIRED_RESULT DKIMResultAttribute *clone() const override;
     Q_REQUIRED_RESULT QByteArray type() const override;
     Q_REQUIRED_RESULT QByteArray serialized() const override;
@@ -34,8 +35,7 @@ public:
 
 private:
     friend class DKIMResultAttributePrivate;
-    DKIMResultAttributePrivate *const d;
+    std::unique_ptr<DKIMResultAttributePrivate> const d;
 };
 }
 
-#endif // DKIMRESULTATTRIBUTE_H
