@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,7 +7,7 @@
 #include "dkimstoreresultjob.h"
 #include "dkimresultattribute.h"
 #include "messageviewer_dkimcheckerdebug.h"
-#include <AkonadiCore/ItemModifyJob>
+#include <Akonadi/ItemModifyJob>
 
 using namespace MessageViewer;
 DKIMStoreResultJob::DKIMStoreResultJob(QObject *parent)
@@ -26,11 +26,11 @@ void DKIMStoreResultJob::start()
         deleteLater();
         return;
     }
-    MessageViewer::DKIMResultAttribute *attr = mItem.attribute<MessageViewer::DKIMResultAttribute>(Akonadi::Item::AddIfMissing);
+    auto attr = mItem.attribute<MessageViewer::DKIMResultAttribute>(Akonadi::Item::AddIfMissing);
     attr->setError(static_cast<int>(mResult.error));
     attr->setWarning(static_cast<int>(mResult.warning));
     attr->setStatus(static_cast<int>(mResult.status));
-    Akonadi::ItemModifyJob *modify = new Akonadi::ItemModifyJob(mItem);
+    auto modify = new Akonadi::ItemModifyJob(mItem);
     modify->setIgnorePayload(true);
     modify->disableRevisionCheck();
     connect(modify, &KJob::result, this, &DKIMStoreResultJob::slotModifyItemDone);
