@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,7 +7,6 @@
 #include "dkimutil.h"
 #include "messageviewer_dkimcheckerdebug.h"
 #include <QRegularExpression>
-#include <QCryptographicHash>
 
 QString MessageViewer::DKIMUtil::bodyCanonizationRelaxed(QString body)
 {
@@ -57,8 +56,9 @@ QString MessageViewer::DKIMUtil::bodyCanonizationSimple(QString body)
     //       Note that a completely empty or missing body is canonicalized as a
     //       single "CRLF"; that is, the canonicalized length will be 2 octets.
     body.replace(QStringLiteral("\n"), QStringLiteral("\r\n"));
-    body.replace(QRegularExpression(QStringLiteral("((\r\n)+)?$")), QStringLiteral("\r\n"));
-    if (body.endsWith(QLatin1String("\r\n"))) { //Remove it from start
+    static const QRegularExpression reg(QStringLiteral("((\r\n)+)?$"));
+    body.replace(reg, QStringLiteral("\r\n"));
+    if (body.endsWith(QLatin1String("\r\n"))) { // Remove it from start
         body.chop(2);
     }
     if (body.isEmpty()) {
@@ -74,7 +74,7 @@ QByteArray MessageViewer::DKIMUtil::generateHash(const QByteArray &body, QCrypto
 
 QString MessageViewer::DKIMUtil::headerCanonizationSimple(const QString &headerName, const QString &headerValue)
 {
-    //TODO verify it lower it ?
+    // TODO verify it lower it ?
     return headerName + QLatin1Char(':') + headerValue;
 }
 
@@ -104,24 +104,27 @@ QString MessageViewer::DKIMUtil::headerCanonizationRelaxed(const QString &header
     //          colon separator MUST be retained.
     QString newHeaderName = headerName.toLower();
     QString newHeaderValue = headerValue;
-    newHeaderValue.replace(QRegularExpression(QStringLiteral("\r\n[ \t]+")), QStringLiteral(" "));
-    newHeaderValue.replace(QRegularExpression(QStringLiteral("[ \t]+")), QStringLiteral(" "));
-    newHeaderValue.replace(QRegularExpression(QStringLiteral("[ \t]+\r\n")), QStringLiteral("\r\n"));
-    //Perhaps remove tab after headername and before value name
-    //newHeaderValue.replace(QRegularExpression(QStringLiteral("[ \t]*:[ \t]")), QStringLiteral(":"));
-    if (newHeaderName == QLatin1String("content-type") && removeQuoteOnContentType) { //Remove quote in charset
+    static const QRegularExpression reg1(QStringLiteral("\r\n[ \t]+"));
+    newHeaderValue.replace(reg1, QStringLiteral(" "));
+    static const QRegularExpression reg2(QStringLiteral("[ \t]+"));
+    newHeaderValue.replace(reg2, QStringLiteral(" "));
+    static const QRegularExpression reg3(QStringLiteral("[ \t]+\r\n"));
+    newHeaderValue.replace(reg3, QStringLiteral("\r\n"));
+    // Perhaps remove tab after headername and before value name
+    // newHeaderValue.replace(QRegularExpression(QStringLiteral("[ \t]*:[ \t]")), QStringLiteral(":"));
+    if (newHeaderName == QLatin1String("content-type") && removeQuoteOnContentType) { // Remove quote in charset
         if (newHeaderValue.contains(QLatin1String("charset=\""))) {
             newHeaderValue.remove(QLatin1Char('"'));
         }
     }
-    //Remove extra space.
+    // Remove extra space.
     newHeaderValue = newHeaderValue.trimmed();
     return newHeaderName + QLatin1Char(':') + newHeaderValue;
 }
 
 QString MessageViewer::DKIMUtil::cleanString(QString str)
 {
-    //Move as static ?
+    // Move as static ?
     // WSP help pattern as specified in Section 2.8 of RFC 6376
     const QString pattWSP = QStringLiteral("[ \t]");
     // FWS help pattern as specified in Section 2.8 of RFC 6376
