@@ -1,16 +1,14 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-
-#ifndef DMARCMANAGER_H
-#define DMARCMANAGER_H
+#pragma once
 
 #include <QStringList>
-namespace MessageViewer {
-
+namespace MessageViewer
+{
 class DMARCManager
 {
 public:
@@ -21,6 +19,7 @@ public:
 
     void addNoDMarcServerAddress(const QString &address);
     Q_REQUIRED_RESULT bool isNoDMarcServerAddress(const QString &address) const;
+
 private:
     void saveNoServerKeys();
     void loadNoServerKeys();
@@ -28,4 +27,3 @@ private:
 };
 }
 
-#endif // DMARCMANAGER_H
