@@ -1,16 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef DMARCPOLICYJOB_H
-#define DMARCPOLICYJOB_H
+#pragma once
 
-#include <QObject>
 #include "dmarcinfo.h"
 #include "messageviewer_private_export.h"
-namespace MessageViewer {
+#include <QObject>
+namespace MessageViewer
+{
 class MESSAGEVIEWER_TESTS_EXPORT DMARCPolicyJob : public QObject
 {
     Q_OBJECT
@@ -23,7 +23,8 @@ public:
 
         Q_REQUIRED_RESULT bool operator==(const DMARCPolicyJob::DMARCResult &other) const
         {
-            return mAdkim == other.mAdkim && mPolicy == other.mPolicy && mDomain == other.mDomain && mSource == other.mSource && mPercentage == other.mPercentage;
+            return mAdkim == other.mAdkim && mPolicy == other.mPolicy && mDomain == other.mDomain && mSource == other.mSource
+                && mPercentage == other.mPercentage;
         }
 
         Q_REQUIRED_RESULT bool operator!=(const DMARCPolicyJob::DMARCResult &other) const
@@ -39,7 +40,7 @@ public:
     };
 
     explicit DMARCPolicyJob(QObject *parent = nullptr);
-    ~DMARCPolicyJob();
+    ~DMARCPolicyJob() override;
 
     Q_REQUIRED_RESULT bool canStart() const;
     Q_REQUIRED_RESULT bool start();
@@ -60,4 +61,3 @@ private:
     QString mEmailAddress;
 };
 }
-#endif // DMARCPOLICYJOB_H
