@@ -1,14 +1,13 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef CHECKSIGNATURE_H
-#define CHECKSIGNATURE_H
+#pragma once
 
-#include <QObject>
 #include "dkim-verify/dkimchecksignaturejob.h"
+#include <QObject>
 #include <QtCrypto>
 
 class CheckSignature : public QObject
@@ -16,10 +15,10 @@ class CheckSignature : public QObject
     Q_OBJECT
 public:
     explicit CheckSignature(const QString &fileName, QObject *parent = nullptr);
-    ~CheckSignature();
+    ~CheckSignature() override;
+
 private:
     void slotResult(const MessageViewer::DKIMCheckSignatureJob::CheckSignatureResult &checkResult);
     QCA::Initializer *mQcaInitializer = nullptr;
 };
 
-#endif // CHECKSIGNATURE_H
