@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef DMARCLOOKUPKEY_H
-#define DMARCLOOKUPKEY_H
+#pragma once
 
 #include <QObject>
 
@@ -14,8 +13,7 @@ class DMarcLookUpKey : public QObject
     Q_OBJECT
 public:
     explicit DMarcLookUpKey(QObject *parent = nullptr);
-    ~DMarcLookUpKey();
+    ~DMarcLookUpKey() override;
     void lookUpDomain(const QString &domain);
 };
 
-#endif // DMARCLOOKUPKEY_H
