@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef LOOKUPKEY_H
-#define LOOKUPKEY_H
+#pragma once
 
 #include <QObject>
 class QDnsLookup;
@@ -14,12 +13,12 @@ class LookUpKey : public QObject
     Q_OBJECT
 public:
     explicit LookUpKey(QObject *parent = nullptr);
-    ~LookUpKey() = default;
+    ~LookUpKey() override = default;
     void lookUpServer(const QString &addr);
+
 private:
     void handleServers();
     QDnsLookup *mDnsLookup = nullptr;
     QString mAddress;
 };
 
-#endif // LOOKUPKEY_H
