@@ -1,16 +1,16 @@
 /*
- * SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "contactdisplaymessagememento.h"
-#include "messageviewer_debug.h"
-#include <Gravatar/GravatarResolvUrlJob>
 #include "gravatarsettings.h"
+#include "messageviewer_debug.h"
 #include "settings/messageviewersettings.h"
 #include <Akonadi/Contact/ContactSearchJob>
-#include <kio/transferjob.h>
+#include <Gravatar/GravatarResolvUrlJob>
+#include <KIO/TransferJob>
 
 using namespace MessageViewer;
 
@@ -20,11 +20,8 @@ ContactDisplayMessageMemento::ContactDisplayMessageMemento(const QString &emailA
 {
     if (!emailAddress.isEmpty()) {
         mSearchJob = new Akonadi::ContactSearchJob();
-        mSearchJob->setQuery(Akonadi::ContactSearchJob::Email,
-                             emailAddress.toLower(), Akonadi::ContactSearchJob::ExactMatch);
-        connect(
-            mSearchJob.data(), &Akonadi::ContactSearchJob::result, this,
-            &ContactDisplayMessageMemento::slotSearchJobFinished);
+        mSearchJob->setQuery(Akonadi::ContactSearchJob::Email, emailAddress.toLower(), Akonadi::ContactSearchJob::ExactMatch);
+        connect(mSearchJob.data(), &Akonadi::ContactSearchJob::result, this, &ContactDisplayMessageMemento::slotSearchJobFinished);
     } else {
         mFinished = true;
     }
@@ -33,9 +30,7 @@ ContactDisplayMessageMemento::ContactDisplayMessageMemento(const QString &emailA
 ContactDisplayMessageMemento::~ContactDisplayMessageMemento()
 {
     if (mSearchJob) {
-        disconnect(
-            mSearchJob.data(), &Akonadi::ContactSearchJob::result, this,
-            &ContactDisplayMessageMemento::slotSearchJobFinished);
+        disconnect(mSearchJob.data(), &Akonadi::ContactSearchJob::result, this, &ContactDisplayMessageMemento::slotSearchJobFinished);
         mSearchJob->kill();
     }
 }
@@ -43,7 +38,7 @@ ContactDisplayMessageMemento::~ContactDisplayMessageMemento()
 void ContactDisplayMessageMemento::slotSearchJobFinished(KJob *job)
 {
     mFinished = true;
-    Akonadi::ContactSearchJob *searchJob = static_cast<Akonadi::ContactSearchJob *>(job);
+    auto searchJob = static_cast<Akonadi::ContactSearchJob *>(job);
     if (searchJob->error()) {
         qCWarning(MESSAGEVIEWER_LOG) << "Unable to fetch contact:" << searchJob->errorText();
         Q_EMIT update(MimeTreeParser::Delayed);
@@ -58,9 +53,8 @@ void ContactDisplayMessageMemento::slotSearchJobFinished(KJob *job)
 
         const KContacts::Addressee addressee = searchJob->contacts().at(0);
         processAddress(addressee);
-        searchPhoto(searchJob->contacts());
-        if (!mPhoto.isEmpty()) {
-            //We have a data raw => we can update message
+        if (!searchPhoto(searchJob->contacts())) {
+            // We have a data raw => we can update message
             if (mPhoto.isIntern()) {
                 Q_EMIT update(MimeTreeParser::Delayed);
             } else {
@@ -75,12 +69,11 @@ void ContactDisplayMessageMemento::slotSearchJobFinished(KJob *job)
                         }
                     } else {
                         QByteArray imageData;
-                        KIO::TransferJob *job = KIO::get(url, KIO::NoReload);
-                        QObject::connect(job, &KIO::TransferJob::data,
-                                         [&imageData](KIO::Job *, const QByteArray &data) {
+                        KIO::TransferJob *jobTransfert = KIO::get(url, KIO::NoReload);
+                        QObject::connect(jobTransfert, &KIO::TransferJob::data, [&imageData](KIO::Job *, const QByteArray &data) {
                             imageData.append(data);
                         });
-                        if (job->exec()) {
+                        if (jobTransfert->exec()) {
                             if (image.loadFromData(imageData)) {
                                 ok = true;
                             }
@@ -97,18 +90,16 @@ void ContactDisplayMessageMemento::slotSearchJobFinished(KJob *job)
     if (mPhoto.isEmpty() && mPhoto.url().isEmpty()) {
         // No url, no photo => search gravatar
         if (Gravatar::GravatarSettings::self()->gravatarSupportEnabled()) {
-            Gravatar::GravatarResolvUrlJob *job = new Gravatar::GravatarResolvUrlJob(this);
-            job->setEmail(mEmailAddress);
-            job->setUseDefaultPixmap(
-                Gravatar::GravatarSettings::self()->gravatarUseDefaultImage());
-            job->setFallbackGravatar(Gravatar::GravatarSettings::self()->fallbackToGravatar());
-            job->setUseLibravatar(Gravatar::GravatarSettings::self()->libravatarSupportEnabled());
-            if (job->canStart()) {
-                connect(job, &Gravatar::GravatarResolvUrlJob::finished, this,
-                        &ContactDisplayMessageMemento::slotGravatarResolvUrlFinished);
-                job->start();
+            auto resolvUrljob = new Gravatar::GravatarResolvUrlJob(this);
+            resolvUrljob->setEmail(mEmailAddress);
+            resolvUrljob->setUseDefaultPixmap(Gravatar::GravatarSettings::self()->gravatarUseDefaultImage());
+            resolvUrljob->setFallbackGravatar(Gravatar::GravatarSettings::self()->fallbackToGravatar());
+            resolvUrljob->setUseLibravatar(Gravatar::GravatarSettings::self()->libravatarSupportEnabled());
+            if (resolvUrljob->canStart()) {
+                connect(resolvUrljob, &Gravatar::GravatarResolvUrlJob::finished, this, &ContactDisplayMessageMemento::slotGravatarResolvUrlFinished);
+                resolvUrljob->start();
             } else {
-                job->deleteLater();
+                resolvUrljob->deleteLater();
             }
         }
     }
@@ -122,8 +113,7 @@ bool ContactDisplayMessageMemento::finished() const
 void ContactDisplayMessageMemento::detach()
 {
     disconnect(this, SIGNAL(update(MimeTreeParser::UpdateMode)), nullptr, nullptr);
-    disconnect(this, SIGNAL(changeDisplayMail(Viewer::DisplayFormatMessage,bool)), nullptr,
-               nullptr);
+    disconnect(this, SIGNAL(changeDisplayMail(Viewer::DisplayFormatMessage, bool)), nullptr, nullptr);
 }
 
 bool ContactDisplayMessageMemento::searchPhoto(const KContacts::AddresseeList &list)
@@ -157,9 +147,7 @@ void ContactDisplayMessageMemento::processAddress(const KContacts::Addressee &ad
     const QStringList customs = addressee.customs();
     for (const QString &custom : customs) {
         if (custom.contains(QLatin1String("MailPreferedFormatting"))) {
-            const QString value
-                = addressee.custom(QStringLiteral("KADDRESSBOOK"), QStringLiteral(
-                                       "MailPreferedFormatting"));
+            const QString value = addressee.custom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("MailPreferedFormatting"));
             if (value == QLatin1String("TEXT")) {
                 forceDisplayTo = Viewer::Text;
             } else if (value == QLatin1String("HTML")) {
@@ -168,9 +156,7 @@ void ContactDisplayMessageMemento::processAddress(const KContacts::Addressee &ad
                 forceDisplayTo = Viewer::UseGlobalSetting;
             }
         } else if (custom.contains(QLatin1String("MailAllowToRemoteContent"))) {
-            const QString value
-                = addressee.custom(QStringLiteral("KADDRESSBOOK"), QStringLiteral(
-                                       "MailAllowToRemoteContent"));
+            const QString value = addressee.custom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("MailAllowToRemoteContent"));
             mailAllowToRemoteContent = (value == QLatin1String("TRUE"));
         }
     }
