@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -9,7 +9,7 @@
 #include "header/headerstrategy.h"
 #include <GrantleeTheme/GrantleeTheme>
 
-#include <kmime/kmime_message.h>
+#include <KMime/KMimeMessage>
 
 using namespace MessageViewer;
 class MessageViewer::GrantleeHeaderStylePrivate
@@ -34,10 +34,7 @@ GrantleeHeaderStyle::GrantleeHeaderStyle()
 {
 }
 
-GrantleeHeaderStyle::~GrantleeHeaderStyle()
-{
-    delete d;
-}
+GrantleeHeaderStyle::~GrantleeHeaderStyle() = default;
 
 const char *GrantleeHeaderStyle::name() const
 {
