@@ -7,13 +7,13 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MESSAGEVIEWER_HEADERSTRATEGY_H
-#define MESSAGEVIEWER_HEADERSTRATEGY_H
+#pragma once
 
 #include "messageviewer_export.h"
 #include <QStringList>
 
-namespace MessageViewer {
+namespace MessageViewer
+{
 //
 // Convenience function
 //
@@ -36,9 +36,7 @@ public:
     //
     // HeaderStrategy interface:
     //
-    enum DefaultPolicy {
-        Display, Hide
-    };
+    enum DefaultPolicy { Display, Hide };
 
     Q_REQUIRED_RESULT virtual QStringList headersToDisplay() const;
     Q_REQUIRED_RESULT virtual QStringList headersToHide() const;
@@ -48,4 +46,3 @@ public:
 };
 }
 
-#endif // MESSAGEVIEWER_HEADERSTRATEGY_H
