@@ -2,38 +2,16 @@
     headerstyle.cpp
 
     This file is part of KMail, the KDE mail client.
-    Copyright (c) 2003 Marc Mutz <mutz@kde.org>
+    SPDX-FileCopyrightText: 2003 Marc Mutz <mutz@kde.org>
 
-    Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-    KMail is free software; you can redistribute it and/or modify it
-    under the terms of the GNU General Public License, version 2, as
-    published by the Free Software Foundation.
-
-    KMail is distributed in the hope that it will be useful, but
-    WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "headerstyle.h"
 #include "messageviewer_debug.h"
-#include "grantleetheme/grantleetheme.h"
+#include <GrantleeTheme/GrantleeTheme>
 
 using namespace MessageViewer;
 //
@@ -47,10 +25,8 @@ public:
     }
 
     GrantleeTheme::Theme mTheme;
-    QString mMessagePath;
     const HeaderStrategy *mStrategy = nullptr;
     QString mVCardName;
-    QString mCollectionName;
     QString mAttachmentHtml;
     MimeTreeParser::NodeHelper *mNodeHelper = nullptr;
     QObject *mSourceObject = nullptr;
@@ -67,10 +43,7 @@ HeaderStyle::HeaderStyle()
 {
 }
 
-HeaderStyle::~HeaderStyle()
-{
-    delete d;
-}
+HeaderStyle::~HeaderStyle() = default;
 
 void HeaderStyle::setAttachmentHtml(const QString &html)
 {
@@ -82,16 +55,6 @@ QString HeaderStyle::attachmentHtml() const
     return d->mAttachmentHtml;
 }
 
-void HeaderStyle::setMessagePath(const QString &path)
-{
-    d->mMessagePath = path;
-}
-
-QString HeaderStyle::messagePath() const
-{
-    return d->mMessagePath;
-}
-
 void HeaderStyle::setHeaderStrategy(const HeaderStrategy *strategy)
 {
     d->mStrategy = strategy;
@@ -182,16 +145,6 @@ GrantleeTheme::Theme HeaderStyle::theme() const
     return d->mTheme;
 }
 
-void HeaderStyle::setCollectionName(const QString &name)
-{
-    d->mCollectionName = name;
-}
-
-QString HeaderStyle::collectionName() const
-{
-    return d->mCollectionName;
-}
-
 bool HeaderStyle::readOnlyMessage() const
 {
     return d->mReadOnlyMessage;
