@@ -1,16 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include "headerstyle.h"
 #include "headerstyleinterface.h"
+#include "headerstyle.h"
 #include "headerstyleplugin.h"
 #include "utils/messageviewerutil_p.h"
 #include <KActionMenu>
-#include <QAction>
 #include <KToggleAction>
+#include <QAction>
 using namespace MessageViewer;
 
 HeaderStyleInterface::HeaderStyleInterface(MessageViewer::HeaderStylePlugin *headerStylePlugin, QObject *parent)
@@ -35,7 +35,7 @@ void HeaderStyleInterface::addHelpTextAction(QAction *act, const QString &text)
 
 void HeaderStyleInterface::addActionToMenu(KActionMenu *menu, QActionGroup *actionGroup)
 {
-    for (KToggleAction *taction : qAsConst(mAction)) {
+    for (KToggleAction *taction : std::as_const(mAction)) {
         menu->addAction(taction);
         actionGroup->addAction(taction);
     }
