@@ -1,20 +1,20 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef HEADERSTYLEINTERFACE_H
-#define HEADERSTYLEINTERFACE_H
+#pragma once
 
-#include <QObject>
 #include "messageviewer_export.h"
+#include <QObject>
 class KToggleAction;
 class KActionCollection;
 class QAction;
 class QActionGroup;
 class KActionMenu;
-namespace MessageViewer {
+namespace MessageViewer
+{
 class HeaderStyle;
 class HeaderStylePlugin;
 /**
@@ -27,7 +27,7 @@ class MESSAGEVIEWER_EXPORT HeaderStyleInterface : public QObject
 public:
     explicit HeaderStyleInterface(MessageViewer::HeaderStylePlugin *, QObject *parent = nullptr);
     ~HeaderStyleInterface() override;
-    Q_REQUIRED_RESULT QList<KToggleAction * > action() const;
+    Q_REQUIRED_RESULT QList<KToggleAction *> action() const;
     virtual void createAction(KActionMenu *menu, QActionGroup *actionGroup, KActionCollection *ac) = 0;
     virtual void activateAction() = 0;
     Q_REQUIRED_RESULT HeaderStylePlugin *headerStylePlugin() const;
@@ -38,6 +38,7 @@ Q_SIGNALS:
 
 protected Q_SLOTS:
     void slotStyleChanged();
+
 protected:
     void addHelpTextAction(QAction *act, const QString &text);
     void addActionToMenu(KActionMenu *menu, QActionGroup *actionGroup);
@@ -45,4 +46,3 @@ protected:
     HeaderStylePlugin *const mHeaderStylePlugin;
 };
 }
-#endif // HEADERSTYLEINTERFACE_H
