@@ -20,7 +20,9 @@
 #include <stdlib.h>
 #include <string.h>
 
-#define GEN(g) F[h] ^= G.g[k]; break
+#define GEN(g)                                                                                                                                                 \
+    F[h] ^= G.g[k];                                                                                                                                            \
+    break
 
 #define BITSPERDIG 4
 #define DIGITS (PIXELS / BITSPERDIG)
@@ -44,10 +46,10 @@ static const int MAXLINELEN = 78;
 #define WORDCARRY (1 << BITSPERWORD)
 #define WORDMASK (WORDCARRY - 1)
 
-#define ERR_OK          0        /* successful completion */
-#define ERR_EXCESS      1        /* completed OK but some input was ignored */
-#define ERR_INSUFF     -1        /* insufficient input.  Bad face format? */
-#define ERR_INTERNAL   -2        /* Arithmetic overflow or buffer overflow */
+#define ERR_OK 0 /* successful completion */
+#define ERR_EXCESS 1 /* completed OK but some input was ignored */
+#define ERR_INSUFF -1 /* insufficient input.  Bad face format? */
+#define ERR_INTERNAL -2 /* Arithmetic overflow or buffer overflow */
 
 #define BLACK 0
 #define GREY 1
@@ -90,45 +92,45 @@ QString KXFace::fromImage(const QImage &image)
     for (int i = 0; i < len; ++i) {
         switch (tmp[i].toLatin1()) {
         case '1':
-            tmp[i] = '8';
+            tmp[i] = QLatin1Char('8');
             break;
         case '2':
-            tmp[i] = '4';
+            tmp[i] = QLatin1Char('4');
             break;
         case '3':
-            tmp[i] = 'c';
+            tmp[i] = QLatin1Char('c');
             break;
         case '4':
-            tmp[i] = '2';
+            tmp[i] = QLatin1Char('2');
             break;
         case '5':
-            tmp[i] = 'a';
+            tmp[i] = QLatin1Char('a');
             break;
         case '7':
-            tmp[i] = 'e';
+            tmp[i] = QLatin1Char('e');
             break;
         case '8':
-            tmp[i] = '1';
+            tmp[i] = QLatin1Char('1');
             break;
         case 'A':
         case 'a':
-            tmp[i] = '5';
+            tmp[i] = QLatin1Char('5');
             break;
         case 'B':
         case 'b':
-            tmp[i] = 'd';
+            tmp[i] = QLatin1Char('d');
             break;
         case 'C':
         case 'c':
-            tmp[i] = '3';
+            tmp[i] = QLatin1Char('3');
             break;
         case 'D':
         case 'd':
-            tmp[i] = 'b';
+            tmp[i] = QLatin1Char('b');
             break;
         case 'E':
         case 'e':
-            tmp[i] = '7';
+            tmp[i] = QLatin1Char('7');
             break;
         }
         if (i % 2) {
@@ -165,7 +167,7 @@ QImage KXFace::toImage(const QString &xface)
     strncpy(fbuf, xface.toLatin1().constData(), xface.length());
     QByteArray img;
     if (!(status = setjmp(comp_env))) {
-        UnCompAll(fbuf);  /* compress otherwise */
+        UnCompAll(fbuf); /* compress otherwise */
         UnGenFace();
         img = WriteFace();
     }
@@ -226,7 +228,7 @@ void KXFace::BigDiv(unsigned char a, unsigned char *r)
         *r = 0;
         return;
     }
-    if (a == 0) {      /* treat this as a == WORDCARRY */
+    if (a == 0) { /* treat this as a == WORDCARRY */
         /* and just shift everything right a WORD (unsigned char)*/
         i = --B.b_words;
         w = B.b_word;
@@ -242,7 +244,7 @@ void KXFace::BigDiv(unsigned char a, unsigned char *r)
     c = 0;
     while (i--) {
         c <<= BITSPERWORD;
-        c += (COMP)*--w;
+        c += (COMP) * --w;
         d = c / (COMP)a;
         c = c % (COMP)a;
         *w = (unsigned char)(d & WORDMASK);
@@ -265,7 +267,7 @@ void KXFace::BigMul(unsigned char a)
     if ((a == 1) || (B.b_words == 0)) {
         return;
     }
-    if (a == 0) {      /* treat this as a == WORDCARRY */
+    if (a == 0) { /* treat this as a == WORDCARRY */
         /* and just shift everything left a WORD (unsigned char) */
         if ((i = B.b_words++) >= MAXWORDS - 1) {
             longjmp(comp_env, ERR_INTERNAL);
@@ -331,11 +333,14 @@ void KXFace::BigClear()
 QByteArray KXFace::WriteFace()
 {
     char *s;
-    int i, j, bits, digits, words;
-    //int digsperword = DIGSPERWORD;
-    //int wordsperline = WORDSPERLINE;
-    QByteArray t(
-        "#define noname_width 48\n#define noname_height 48\nstatic char noname_bits[] = {\n ");
+    int i;
+    int j;
+    int bits;
+    int digits;
+    int words;
+    // int digsperword = DIGSPERWORD;
+    // int wordsperline = WORDSPERLINE;
+    QByteArray t("#define noname_width 48\n#define noname_height 48\nstatic char noname_bits[] = {\n ");
     j = t.length() - 1;
 
     s = F;
@@ -429,7 +434,7 @@ void KXFace::BigWrite(char *fbuf)
         BigDiv(NUMPRINTS, &tmp);
         *(s++) = tmp + FIRSTPRINT;
     }
-    i = 7;        // leave room for the field name on the first line
+    i = 7; // leave room for the field name on the first line
     *(fbuf++) = ' ';
     while (s-- > buf) {
         if (i == 0) {
@@ -463,8 +468,10 @@ void KXFace::BigRead(char *fbuf)
 
 void KXFace::ReadFace(char *fbuf)
 {
-    int c, i;
-    char *s, *t;
+    int c;
+    int i;
+    char *s;
+    char *t;
 
     t = s = fbuf;
     for (i = strlen(s); i > 0; --i) {
@@ -530,7 +537,12 @@ void KXFace::UnGenFace()
 // static
 void KXFace::Gen(char *f)
 {
-    int m, l, k, j, i, h;
+    int m;
+    int l;
+    int k;
+    int j;
+    int i;
+    int h;
 
     for (j = 0; j < HEIGHT; ++j) {
         for (i = 0; i < WIDTH; ++i) {
@@ -678,9 +690,7 @@ int KXFace::AllBlack(char *f, int wid, int hei)
     if (wid > 3) {
         wid /= 2;
         hei /= 2;
-        return AllBlack(f, wid, hei) && AllBlack(f + wid, wid, hei)
-               && AllBlack(f + WIDTH * hei, wid, hei)
-               && AllBlack(f + WIDTH * hei + wid, wid, hei);
+        return AllBlack(f, wid, hei) && AllBlack(f + wid, wid, hei) && AllBlack(f + WIDTH * hei, wid, hei) && AllBlack(f + WIDTH * hei + wid, wid, hei);
     } else {
         return *f || *(f + 1) || *(f + WIDTH) || *(f + WIDTH + 1);
     }
@@ -688,7 +698,8 @@ int KXFace::AllBlack(char *f, int wid, int hei)
 
 int KXFace::Same(char *f, int wid, int hei)
 {
-    char val, *row;
+    char val;
+    char *row;
     int x;
 
     val = *f;
@@ -715,7 +726,6 @@ void KXFace::PushGreys(char *f, int wid, int hei)
         PushGreys(f + WIDTH * hei, wid, hei);
         PushGreys(f + WIDTH * hei + wid, wid, hei);
     } else {
-        RevPush(freqs + *f + 2 * *(f + 1) + 4 * *(f + WIDTH)
-                +8 * *(f + WIDTH + 1));
+        RevPush(freqs + *f + 2 * *(f + 1) + 4 * *(f + WIDTH) + 8 * *(f + WIDTH + 1));
     }
 }
