@@ -1,15 +1,15 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef PLAINHEADERSTYLE_H
-#define PLAINHEADERSTYLE_H
+#pragma once
 
 #include "messageviewer/headerstyle.h"
 #include "messageviewer_export.h"
-namespace MessageViewer {
+namespace MessageViewer
+{
 class PlainHeaderStylePrivate;
 /**
  * @brief The PlainHeaderStyle class
@@ -27,7 +27,6 @@ public:
     Q_REQUIRED_RESULT QString format(KMime::Message *message) const override;
 
 private:
-    PlainHeaderStylePrivate *const d;
+    std::unique_ptr<PlainHeaderStylePrivate> const d;
 };
 }
-#endif // PLAINHEADERSTYLE_H
