@@ -1,24 +1,25 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MODIFYMESSAGEDISPLAYFORMATJOB_H
-#define MODIFYMESSAGEDISPLAYFORMATJOB_H
+#pragma once
 
-#include <QObject>
 #include "viewer/viewer_p.h"
-namespace Akonadi {
+#include <QObject>
+namespace Akonadi
+{
 class Session;
 }
-namespace MessageViewer {
+namespace MessageViewer
+{
 class ModifyMessageDisplayFormatJob : public QObject
 {
     Q_OBJECT
 public:
     explicit ModifyMessageDisplayFormatJob(Akonadi::Session *session, QObject *parent = nullptr);
-    ~ModifyMessageDisplayFormatJob();
+    ~ModifyMessageDisplayFormatJob() override;
 
     void setRemoteContent(bool remote);
     void setMessageFormat(Viewer::DisplayFormatMessage format);
@@ -39,4 +40,3 @@ private:
 };
 }
 
-#endif // MODIFYMESSAGEDISPLAYFORMATJOB_H
