@@ -1,14 +1,13 @@
-/* 
+/*
    SPDX-FileCopyrightText: 2010 Volker Krause <vkrause@kde.org>
    SPDX-FileCopyrightText: 2016 Sandro Knauß <sknauss@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
-#ifndef MESSAGEVIEWER_TEST_RENDERTEST_H
-#define MESSAGEVIEWER_TEST_RENDERTEST_H
+#pragma once
 
-#include <QObject>
 #include <MimeTreeParser/MessagePart>
+#include <QObject>
 
 class RenderTest : public QObject
 {
@@ -44,4 +43,3 @@ private:
     void testRenderTree(const MimeTreeParser::MessagePart::Ptr &messagePart);
 };
 
-#endif
