@@ -1,41 +1,27 @@
 /*
-  Copyright (C) 2010 Klaralvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
-  Copyright (c) 2010 Leo Franchi <lfranchi@kde.org>
+  SPDX-FileCopyrightText: 2010 Klaralvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  SPDX-FileCopyrightText: 2010 Leo Franchi <lfranchi@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MESSAGEVIEWER_TESTS_SETUPENV_H
-#define MESSAGEVIEWER_TESTS_SETUPENV_H
-
-#include <gpgme++/key.h>
+#pragma once
 
 #include <MimeTreeParser/BodyPartFormatterFactory>
 #include <MimeTreeParser/ObjectTreeSource>
+#include <gpgme++/key.h>
 
 #include <MessageViewer/AttachmentStrategy>
 #include <MessageViewer/ObjectTreeEmptySource>
 
-namespace MessageViewer {
-namespace Test {
+namespace MessageViewer
+{
+namespace Test
+{
 /**
-* setup a environment variables for tests:
-* * set LC_ALL to C
-* * set KDEHOME
-*/
+ * setup a environment variables for tests:
+ * * set LC_ALL to C
+ */
 void setupEnv();
 
 // We can't use EmptySource, since we need to control some elements of the source for tests to also test
@@ -144,8 +130,8 @@ public:
 
     void setHtmlMode(MimeTreeParser::Util::HtmlMode mode, const QList<MimeTreeParser::Util::HtmlMode> &availableModes) override
     {
-        Q_UNUSED(mode);
-        Q_UNUSED(availableModes);
+        Q_UNUSED(mode)
+        Q_UNUSED(availableModes)
     }
 
     MimeTreeParser::Util::HtmlMode preferredMode() const override
@@ -175,8 +161,8 @@ public:
 
     QString createMessageHeader(KMime::Message *message) override
     {
-        Q_UNUSED(message);
-        return QString(); //do nothing
+        Q_UNUSED(message)
+        return QString(); // do nothing
     }
 
 private:
@@ -195,4 +181,3 @@ private:
 }
 }
 
-#endif //__MESSAGEVIEWER_TESTS_SETUPENV_H
