@@ -45,13 +45,8 @@ void MessageViewer::Test::compareFile(const QString &outFile, const QString &ref
 
     // validate xml and pretty-print for comparison
     // TODO add proper cmake check for xmllint and diff
-    QStringList args = QStringList()
-                       << QStringLiteral("--format")
-                       << QStringLiteral("--encode")
-                       << QStringLiteral("UTF8")
-                       << QStringLiteral("--output")
-                       << htmlFile
-                       << outFile;
+    QStringList args = QStringList() << QStringLiteral("--format") << QStringLiteral("--encode") << QStringLiteral("UTF8") << QStringLiteral("--output")
+                                     << htmlFile << outFile;
     QCOMPARE(QProcess::execute(QStringLiteral("xmllint"), args), 0);
 
     // get rid of system dependent or random paths
@@ -60,12 +55,8 @@ void MessageViewer::Test::compareFile(const QString &outFile, const QString &ref
         QVERIFY(f.open(QIODevice::ReadOnly));
         QString content = QString::fromUtf8(f.readAll());
         f.close();
-        content.replace(QRegExp(QStringLiteral(
-                                    "\"file:[^\"]*[/(?:%2F)]([^\"/(?:%2F)]*)\"")),
-                        QStringLiteral("\"file:\\1\""));
-        content.replace(QRegExp(QStringLiteral(
-                                    "(file:///tmp/messageviewer)(_[^\"]+)(\\.index\\.[^\"]*)")),
-                        QStringLiteral("\\1\\3"));
+        content.replace(QRegExp(QStringLiteral("\"file:[^\"]*[/(?:%2F)]([^\"/(?:%2F)]*)\"")), QStringLiteral("\"file:\\1\""));
+        content.replace(QRegExp(QStringLiteral("(file:///tmp/messageviewer)(_[^\"]+)(\\.index\\.[^\"]*)")), QStringLiteral("\\1\\3"));
         content.replace(QLatin1String("NBSP_ENTITY_PLACEHOLDER"), QLatin1String("&nbsp;")); // undo above transformation for xmllint
         QVERIFY(f.open(QIODevice::WriteOnly | QIODevice::Truncate));
         f.write(content.toUtf8());
@@ -74,32 +65,25 @@ void MessageViewer::Test::compareFile(const QString &outFile, const QString &ref
 
     QProcess proc;
 #ifdef _WIN32
-    args = QStringList()
-            << QStringLiteral("Compare-Object")
-            << QString(QStringLiteral("(Get-Content %1)")).arg(referenceFile)
-            << QString(QStringLiteral("(Get-Content %1)")).arg(htmlFile);
+    args = QStringList() << QStringLiteral("Compare-Object") << QString(QStringLiteral("(Get-Content %1)")).arg(referenceFile)
+                         << QString(QStringLiteral("(Get-Content %1)")).arg(htmlFile);
 
     proc.start(QStringLiteral("powershell"), args);
     QVERIFY(proc.waitForFinished());
 
     auto pStdOut = proc.readAllStandardOutput();
     if (pStdOut.size()) {
-        qDebug() << "Files are different, diff output message:\n"
-                 << pStdOut.toStdString().c_str();
+        qDebug() << "Files are different, diff output message:\n" << pStdOut.toStdString().c_str();
     }
 
     QCOMPARE(pStdOut.size(), 0);
 #else
     // compare to reference file
-    args = QStringList()
-            << QStringLiteral("-u")
-            << referenceFile
-            << htmlFile;
+    args = QStringList() << QStringLiteral("-u") << referenceFile << htmlFile;
 
     proc.setProcessChannelMode(QProcess::ForwardedChannels);
     proc.start(QStringLiteral("diff"), args);
     QVERIFY(proc.waitForFinished());
     QCOMPARE(proc.exitCode(), 0);
 #endif
-
 }
