@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -7,10 +7,9 @@
 
 #include "converthtmltoplaintext.h"
 
-#include <KPIMTextEdit/PlainTextMarkupBuilder>
 #include <KPIMTextEdit/MarkupDirector>
+#include <KPIMTextEdit/PlainTextMarkupBuilder>
 #include <QTextDocument>
-#include <QDebug>
 
 using namespace MimeTreeParser;
 ConvertHtmlToPlainText::ConvertHtmlToPlainText()
@@ -31,10 +30,10 @@ QString ConvertHtmlToPlainText::generatePlainText()
     if (mHtmlString.isEmpty()) {
         return QString();
     }
-    KPIMTextEdit::PlainTextMarkupBuilder *pb = new KPIMTextEdit::PlainTextMarkupBuilder();
+    auto pb = new KPIMTextEdit::PlainTextMarkupBuilder();
 
-    KPIMTextEdit::MarkupDirector *pmd = new KPIMTextEdit::MarkupDirector(pb);
-    QTextDocument *doc = new QTextDocument;
+    auto pmd = new KPIMTextEdit::MarkupDirector(pb);
+    auto doc = new QTextDocument;
     doc->setHtml(mHtmlString);
 
     pmd->processDocument(doc);
@@ -52,7 +51,7 @@ QString ConvertHtmlToPlainText::htmlString() const
     return mHtmlString;
 }
 
-//Duplicate from kpimtextedit/textedit.h
+// Duplicate from kpimtextedit/textedit.h
 void ConvertHtmlToPlainText::toCleanPlainText(QString &text)
 {
     // Remove line separators. Normal \n chars are still there, so no linebreaks get lost here
