@@ -1,20 +1,7 @@
 /*
-   Copyright (c) 2016 Sandro Knauß <sknauss@kde.org>
+   SPDX-FileCopyrightText: 2016 Sandro Knauß <sknauss@kde.org>
 
-   This library is free software; you can redistribute it and/or modify it
-   under the terms of the GNU Library General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or (at your
-   option) any later version.
-
-   This library is distributed in the hope that it will be useful, but WITHOUT
-   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-   License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to the
-   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-   02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "textmessagepartrenderer.h"
@@ -23,8 +10,8 @@
 
 #include "../messagepartrenderermanager.h"
 
-#include <MessageCore/StringUtil>
 #include "interfaces/htmlwriter.h"
+#include <MessageCore/StringUtil>
 
 #include <grantlee/context.h>
 #include <grantlee/template.h>
@@ -41,7 +28,7 @@ TextMessagePartRenderer::~TextMessagePartRenderer()
 
 bool TextMessagePartRenderer::render(const MimeTreeParser::MessagePartPtr &msgPart, HtmlWriter *htmlWriter, RenderContext *context) const
 {
-    Q_UNUSED(context);
+    Q_UNUSED(context)
     auto mp = msgPart.dynamicCast<MimeTreeParser::TextMessagePart>();
     if (!mp) {
         return false;
@@ -61,8 +48,8 @@ bool TextMessagePartRenderer::render(const MimeTreeParser::MessagePartPtr &msgPa
     c.insert(QStringLiteral("block"), msgPart.data());
     c.insert(QStringLiteral("showOnlyOneMimePart"), context->showOnlyOneMimePart());
     c.insert(QStringLiteral("content"), QVariant::fromValue<GrantleeCallback>([mp, htmlWriter, context](Grantlee::OutputStream *) {
-        context->renderSubParts(mp, htmlWriter);
-    }));
+                 context->renderSubParts(mp, htmlWriter);
+             }));
     t = MessagePartRendererManager::self()->loadByName(QStringLiteral("textmessagepart.html"));
 
     Grantlee::OutputStream s(htmlWriter->stream());
