@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -21,13 +21,10 @@ MessageViewerConfigureSettingsPlugin::MessageViewerConfigureSettingsPlugin(QObje
 {
 }
 
-MessageViewerConfigureSettingsPlugin::~MessageViewerConfigureSettingsPlugin()
-{
-    delete d;
-}
+MessageViewerConfigureSettingsPlugin::~MessageViewerConfigureSettingsPlugin() = default;
 
 void MessageViewerConfigureSettingsPlugin::showConfigureDialog(QWidget *parent)
 {
-    Q_UNUSED(parent);
-    //Reimplement
+    Q_UNUSED(parent)
+    // Reimplement
 }
