@@ -1,16 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MESSAGEVIEWERCONFIGURESETTINGSPLUGIN_H
-#define MESSAGEVIEWERCONFIGURESETTINGSPLUGIN_H
-
-#include <QObject>
+#pragma once
 
 #include "messageviewer_export.h"
-namespace MessageViewer {
+#include <QObject>
+#include <memory>
+namespace MessageViewer
+{
 class MessageViewerConfigureSettingsPluginPrivate;
 /**
  * @brief The MessageViewerConfigureSettingsPlugin class
@@ -21,7 +21,7 @@ class MESSAGEVIEWER_EXPORT MessageViewerConfigureSettingsPlugin : public QObject
     Q_OBJECT
 public:
     explicit MessageViewerConfigureSettingsPlugin(QObject *parent = nullptr);
-    ~MessageViewerConfigureSettingsPlugin();
+    ~MessageViewerConfigureSettingsPlugin() override;
 
     virtual void showConfigureDialog(QWidget *parent);
 
@@ -29,7 +29,6 @@ Q_SIGNALS:
     void configChanged();
 
 private:
-    MessageViewerConfigureSettingsPluginPrivate *const d;
+    std::unique_ptr<MessageViewerConfigureSettingsPluginPrivate> const d;
 };
 }
-#endif // MESSAGEVIEWERCONFIGURESETTINGSPLUGIN_H
