@@ -1,17 +1,15 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "messageviewerconfiguresettingspluginmanager.h"
-#include "messageviewerconfiguresettingsplugin.h"
 #include "messageviewer_debug.h"
+#include "messageviewerconfiguresettingsplugin.h"
 #include <KPluginFactory>
-#include <KPluginLoader>
 #include <KPluginMetaData>
 #include <QFileInfo>
-#include <QSet>
 
 using namespace MessageViewer;
 
@@ -22,6 +20,7 @@ public:
     {
     }
 
+    KPluginMetaData data;
     PimCommon::PluginUtilData pluginData;
     QString metaDataFileNameBaseName;
     QString metaDataFileName;
@@ -43,14 +42,16 @@ public:
     QString configGroupName() const;
     QString configPrefixSettingKey() const;
     MessageViewerConfigureSettingsPlugin *pluginFromIdentifier(const QString &id);
+
 private:
     QVector<PimCommon::PluginUtilData> mPluginDataList;
     QVector<ConfigureSettingsPluginInfo> mPluginList;
     MessageViewerConfigureSettingsPluginManager *const q;
 };
 
-namespace {
-QString pluginVersion()
+namespace
+{
+QString configurePluginVersion()
 {
     return QStringLiteral("1.0");
 }
@@ -73,33 +74,26 @@ QString MessageViewerConfigureSettingsPluginManagerPrivate::configPrefixSettingK
 
 void MessageViewerConfigureSettingsPluginManagerPrivate::initializePluginList()
 {
-    const QVector<KPluginMetaData> plugins
-        = KPluginLoader::findPlugins(QStringLiteral("messageviewer/configuresettings"));
+    const QVector<KPluginMetaData> plugins = KPluginMetaData::findPlugins(QStringLiteral("messageviewer/configuresettings"));
 
     QVectorIterator<KPluginMetaData> i(plugins);
     i.toBack();
-    const QPair<QStringList, QStringList> pair = PimCommon::PluginUtil::loadPluginSetting(
-        configGroupName(), configPrefixSettingKey());
-    QSet<QString> unique;
+    const QPair<QStringList, QStringList> pair = PimCommon::PluginUtil::loadPluginSetting(configGroupName(), configPrefixSettingKey());
     QVector<int> listOrder;
     while (i.hasPrevious()) {
         ConfigureSettingsPluginInfo info;
 
         const KPluginMetaData data = i.previous();
 
-        //1) get plugin data => name/description etc.
+        // 1) get plugin data => name/description etc.
         info.pluginData = PimCommon::PluginUtil::createPluginMetaData(data);
-        //2) look at if plugin is activated
+        // 2) look at if plugin is activated
         info.metaDataFileNameBaseName = QFileInfo(data.fileName()).baseName();
         info.metaDataFileName = data.fileName();
+        info.data = data;
         const QString version = data.version();
-        if (pluginVersion() == version) {
-            // only load plugins once, even if found multiple times!
-            if (unique.contains(info.metaDataFileNameBaseName)) {
-                continue;
-            }
-            const QVariant p
-                = data.rawData().value(QStringLiteral("X-KDE-MessageViewer-Configure-Order")).toVariant();
+        if (configurePluginVersion() == version) {
+            const QVariant p = data.rawData().value(QStringLiteral("X-KDE-MessageViewer-Configure-Order")).toVariant();
             int order = -1;
             if (p.isValid()) {
                 order = p.toInt();
@@ -115,11 +109,8 @@ void MessageViewerConfigureSettingsPluginManagerPrivate::initializePluginList()
             listOrder.insert(pos, order);
             info.plugin = nullptr;
             mPluginList.insert(pos, info);
-            unique.insert(info.metaDataFileNameBaseName);
         } else {
-            qCWarning(MESSAGEVIEWER_LOG) << "Plugin " << data.name()
-                                         <<
-                " doesn't have correction plugin version. It will not be loaded.";
+            qCWarning(MESSAGEVIEWER_LOG) << "Plugin " << data.name() << " doesn't have correction plugin version. It will not be loaded.";
         }
     }
     QVector<ConfigureSettingsPluginInfo>::iterator end(mPluginList.end());
@@ -132,8 +123,7 @@ QVector<MessageViewer::MessageViewerConfigureSettingsPlugin *> MessageViewerConf
 {
     QVector<MessageViewer::MessageViewerConfigureSettingsPlugin *> lst;
     QVector<ConfigureSettingsPluginInfo>::ConstIterator end(mPluginList.constEnd());
-    for (QVector<ConfigureSettingsPluginInfo>::ConstIterator it = mPluginList.constBegin(); it != end;
-         ++it) {
+    for (QVector<ConfigureSettingsPluginInfo>::ConstIterator it = mPluginList.constBegin(); it != end; ++it) {
         if (auto plugin = (*it).plugin) {
             lst << plugin;
         }
@@ -143,12 +133,11 @@ QVector<MessageViewer::MessageViewerConfigureSettingsPlugin *> MessageViewerConf
 
 void MessageViewerConfigureSettingsPluginManagerPrivate::loadPlugin(ConfigureSettingsPluginInfo *item)
 {
-    KPluginLoader pluginLoader(item->metaDataFileName);
-    if (pluginLoader.factory()) {
-        item->plugin = pluginLoader.factory()->create<MessageViewer::MessageViewerConfigureSettingsPlugin>(q,
-                                                                                                           QVariantList()
-                                                                                                           << item->metaDataFileNameBaseName);
-        //By default it's true
+    if (auto plugin =
+            KPluginFactory::instantiatePlugin<MessageViewer::MessageViewerConfigureSettingsPlugin>(item->data, q, QVariantList() << item->metaDataFileName)
+                .plugin) {
+        item->plugin = plugin;
+        // By default it's true
         item->pluginData.mHasConfigureDialog = true;
         mPluginDataList.append(item->pluginData);
     }
@@ -178,10 +167,7 @@ MessageViewerConfigureSettingsPluginManager::MessageViewerConfigureSettingsPlugi
     d->initializePluginList();
 }
 
-MessageViewerConfigureSettingsPluginManager::~MessageViewerConfigureSettingsPluginManager()
-{
-    delete d;
-}
+MessageViewerConfigureSettingsPluginManager::~MessageViewerConfigureSettingsPluginManager() = default;
 
 QVector<MessageViewer::MessageViewerConfigureSettingsPlugin *> MessageViewerConfigureSettingsPluginManager::pluginsList() const
 {
