@@ -1,16 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MESSAGEVIEWERCONFIGURESETTINGSPLUGINMANAGER_H
-#define MESSAGEVIEWERCONFIGURESETTINGSPLUGINMANAGER_H
+#pragma once
 
-#include <QObject>
 #include "messageviewer_export.h"
 #include <PimCommon/PluginUtil>
-namespace MessageViewer {
+#include <QObject>
+namespace MessageViewer
+{
 class MessageViewerConfigureSettingsPlugin;
 class MessageViewerConfigureSettingsPluginManagerPrivate;
 /**
@@ -24,16 +24,16 @@ public:
     static MessageViewerConfigureSettingsPluginManager *self();
 
     explicit MessageViewerConfigureSettingsPluginManager(QObject *parent = nullptr);
-    ~MessageViewerConfigureSettingsPluginManager();
+    ~MessageViewerConfigureSettingsPluginManager() override;
 
     Q_REQUIRED_RESULT QVector<MessageViewer::MessageViewerConfigureSettingsPlugin *> pluginsList() const;
 
     Q_REQUIRED_RESULT QVector<PimCommon::PluginUtilData> pluginsDataList() const;
     Q_REQUIRED_RESULT QString configPrefixSettingKey() const;
     Q_REQUIRED_RESULT QString configGroupName() const;
-    MessageViewerConfigureSettingsPlugin *pluginFromIdentifier(const QString &id);
+    Q_REQUIRED_RESULT MessageViewerConfigureSettingsPlugin *pluginFromIdentifier(const QString &id);
+
 private:
-    MessageViewerConfigureSettingsPluginManagerPrivate *const d;
+    std::unique_ptr<MessageViewerConfigureSettingsPluginManagerPrivate> const d;
 };
 }
-#endif // MESSAGEVIEWERCONFIGURESETTINGSPLUGINMANAGER_H
