@@ -1,12 +1,11 @@
 /*
-  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
-#ifndef SCAMATTRIBUTETEST_H
-#define SCAMATTRIBUTETEST_H
+#pragma once
 
 #include <QObject>
 
@@ -15,7 +14,7 @@ class ScamAttributeTest : public QObject
     Q_OBJECT
 public:
     explicit ScamAttributeTest(QObject *parent = nullptr);
-    ~ScamAttributeTest();
+    ~ScamAttributeTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldAffectValue();
@@ -24,4 +23,3 @@ private Q_SLOTS:
     void shouldHaveType();
 };
 
-#endif // SCAMATTRIBUTETEST_H
