@@ -1,16 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef SCAMDETECTIONWEBENGINETEST_H
-#define SCAMDETECTIONWEBENGINETEST_H
+#pragma once
 
 #include <QObject>
 #include <QWidget>
 
-namespace MessageViewer {
+namespace MessageViewer
+{
 class ScamDetectionWebEngine;
 }
 class QWebEngineView;
@@ -19,7 +19,7 @@ class TestWebEngineScamDetection : public QWidget
     Q_OBJECT
 public:
     explicit TestWebEngineScamDetection(QWidget *parent = nullptr);
-    ~TestWebEngineScamDetection();
+    ~TestWebEngineScamDetection() override;
 
     void setHtml(const QString &html);
 private Q_SLOTS:
@@ -28,8 +28,8 @@ Q_SIGNALS:
     void resultScanDetection(bool result);
 
 private:
-    QWebEngineView *mEngineView = nullptr;
-    MessageViewer::ScamDetectionWebEngine *mScamDetectionWebEngine = nullptr;
+    QWebEngineView *const mEngineView;
+    MessageViewer::ScamDetectionWebEngine *const mScamDetectionWebEngine;
 };
 
 class ScamDetectionWebEngineTest : public QObject
@@ -37,10 +37,9 @@ class ScamDetectionWebEngineTest : public QObject
     Q_OBJECT
 public:
     explicit ScamDetectionWebEngineTest(QObject *parent = nullptr);
-    ~ScamDetectionWebEngineTest();
+    ~ScamDetectionWebEngineTest() override;
 private Q_SLOTS:
     void scamtest_data();
     void scamtest();
 };
 
-#endif // SCAMDETECTIONWEBENGINETEST_H
