@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -7,8 +7,8 @@
 
 #include "scamattribute.h"
 #include <QByteArray>
-#include <QIODevice>
 #include <QDataStream>
+#include <QIODevice>
 
 using namespace MessageViewer;
 
@@ -27,14 +27,11 @@ ScamAttribute::ScamAttribute()
 {
 }
 
-ScamAttribute::~ScamAttribute()
-{
-    delete d;
-}
+ScamAttribute::~ScamAttribute() = default;
 
 ScamAttribute *ScamAttribute::clone() const
 {
-    ScamAttribute *attr = new ScamAttribute();
+    auto attr = new ScamAttribute();
     attr->setIsAScam(isAScam());
     return attr;
 }
