@@ -1,15 +1,16 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
-#ifndef SCAMATTRIBUTE_H
-#define SCAMATTRIBUTE_H
+#pragma once
 
-#include <AkonadiCore/attribute.h>
-namespace MessageViewer {
+#include <Akonadi/Attribute>
+#include <memory>
+namespace MessageViewer
+{
 class ScamAttributePrivate;
 
 class ScamAttribute : public Akonadi::Attribute
@@ -30,8 +31,7 @@ public:
 
 private:
     friend class ScamAttributePrivate;
-    ScamAttributePrivate *const d;
+    std::unique_ptr<ScamAttributePrivate> const d;
 };
 }
 
-#endif // SCAMATTRIBUTE_H
