@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -18,31 +18,34 @@
 #include <KStandardGuiItem>
 #include <QFileDialog>
 
-#include <QTextStream>
-#include <QDialogButtonBox>
 #include <KConfigGroup>
-#include <QPushButton>
 #include <KGuiItem>
+#include <QDialogButtonBox>
+#include <QPushButton>
+#include <QTextStream>
 #include <QVBoxLayout>
 #include <memory>
 
 using namespace MessageViewer;
-
+namespace
+{
+static const char myScamDetectionDetailsDialogConfigGroupName[] = "ScamDetectionDetailsDialog";
+}
 ScamDetectionDetailsDialog::ScamDetectionDetailsDialog(QWidget *parent)
     : QDialog(parent)
+    , mDetails(new KPIMTextEdit::RichTextEditorWidget(this))
 {
     setWindowTitle(i18nc("@title:window", "Details"));
     setAttribute(Qt::WA_DeleteOnClose);
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
-    QPushButton *user1Button = new QPushButton(this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
+    auto user1Button = new QPushButton(this);
     buttonBox->addButton(user1Button, QDialogButtonBox::ActionRole);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &ScamDetectionDetailsDialog::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &ScamDetectionDetailsDialog::reject);
     KGuiItem::assign(user1Button, KStandardGuiItem::saveAs());
     setModal(false);
-    mDetails = new KPIMTextEdit::RichTextEditorWidget(this);
     mainLayout->addWidget(mDetails);
     mainLayout->addWidget(buttonBox);
     mDetails->setReadOnly(true);
@@ -71,12 +74,13 @@ void ScamDetectionDetailsDialog::slotSaveAs()
                 return;
             }
             QTextStream ts(&file);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             ts.setCodec("UTF-8");
+#endif
             QString htmlStr = mDetails->toHtml();
-            htmlStr.replace(QLatin1String("meta name=\"qrichtext\" content=\"1\""),
-                            QLatin1String(
-                                "meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\""));
-            ts <<  htmlStr;
+            htmlStr.replace(QLatin1String(R"(meta name="qrichtext" content="1")"),
+                            QLatin1String(R"(meta http-equiv="Content-Type" content="text/html; charset=UTF-8")"));
+            ts << htmlStr;
             file.close();
         }
     }
@@ -89,8 +93,7 @@ void ScamDetectionDetailsDialog::setDetails(const QString &details)
 
 void ScamDetectionDetailsDialog::readConfig()
 {
-    KConfigGroup group(
-        KSharedConfig::openConfig(), "ScamDetectionDetailsDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), myScamDetectionDetailsDialogConfigGroupName);
     const QSize size = group.readEntry("Size", QSize(600, 400));
     if (size.isValid()) {
         resize(size);
@@ -99,8 +102,7 @@ void ScamDetectionDetailsDialog::readConfig()
 
 void ScamDetectionDetailsDialog::writeConfig()
 {
-    KConfigGroup group(
-        KSharedConfig::openConfig(), "ScamDetectionDetailsDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), myScamDetectionDetailsDialogConfigGroupName);
     group.writeEntry("Size", size());
     group.sync();
 }
