@@ -1,18 +1,19 @@
 /*
-  SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
-#ifndef SCAMDETECTIONWEBENGINE_H
-#define SCAMDETECTIONWEBENGINE_H
+#pragma once
 
+#include "messageviewer_export.h"
 #include <QObject>
 #include <QVariant>
-#include "messageviewer_export.h"
+#include <memory>
 class QWebEnginePage;
-namespace MessageViewer {
+namespace MessageViewer
+{
 class ScamDetectionWebEnginePrivate;
 /**
  * @brief The ScamDetectionWebEngine class
@@ -23,7 +24,7 @@ class MESSAGEVIEWER_EXPORT ScamDetectionWebEngine : public QObject
     Q_OBJECT
 public:
     explicit ScamDetectionWebEngine(QObject *parent = nullptr);
-    ~ScamDetectionWebEngine();
+    ~ScamDetectionWebEngine() override;
 
     void scanPage(QWebEnginePage *page);
 
@@ -38,7 +39,6 @@ Q_SIGNALS:
     void resultScanDetection(bool foundScam);
 
 private:
-    ScamDetectionWebEnginePrivate *const d;
+    std::unique_ptr<ScamDetectionWebEnginePrivate> const d;
 };
 }
-#endif // SCAMDETECTIONWEBENGINE_H
