@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,14 +8,14 @@
 #include "scamdetection/scamdetectionwarningwidget.h"
 #include "scamdetection/scamdetectionwebengine.h"
 
-#include <QUrl>
-#include <QStandardPaths>
-#include <QVBoxLayout>
-#include <QPushButton>
-#include <QFileDialog>
 #include <QApplication>
-#include <QCommandLineParser>
 #include <QCommandLineOption>
+#include <QCommandLineParser>
+#include <QFileDialog>
+#include <QPushButton>
+#include <QStandardPaths>
+#include <QUrl>
+#include <QVBoxLayout>
 #include <QWebEngineView>
 
 ScamDetectionWebEngineTestWidget::ScamDetectionWebEngineTestWidget(const QString &filename, QWidget *parent)
@@ -23,25 +23,25 @@ ScamDetectionWebEngineTestWidget::ScamDetectionWebEngineTestWidget(const QString
 {
     mScamDetection = new MessageViewer::ScamDetectionWebEngine(this);
 
-    QVBoxLayout *lay = new QVBoxLayout(this);
+    auto lay = new QVBoxLayout(this);
     mScamWarningWidget = new MessageViewer::ScamDetectionWarningWidget();
     mScamWarningWidget->setUseInTestApps(true);
     lay->addWidget(mScamWarningWidget);
 
     mWebEngineView = new QWebEngineView;
-    connect(mWebEngineView, &QWebEngineView::loadFinished, this,
-            &ScamDetectionWebEngineTestWidget::slotLoadFinished);
+    connect(mWebEngineView, &QWebEngineView::loadFinished, this, &ScamDetectionWebEngineTestWidget::slotLoadFinished);
     lay->addWidget(mWebEngineView);
 
-    connect(mScamDetection, &MessageViewer::ScamDetectionWebEngine::messageMayBeAScam,
-            mScamWarningWidget, &MessageViewer::ScamDetectionWarningWidget::slotShowWarning);
-    connect(mScamWarningWidget, &MessageViewer::ScamDetectionWarningWidget::showDetails,
-            mScamDetection, &MessageViewer::ScamDetectionWebEngine::showDetails);
+    connect(mScamDetection,
+            &MessageViewer::ScamDetectionWebEngine::messageMayBeAScam,
+            mScamWarningWidget,
+            &MessageViewer::ScamDetectionWarningWidget::slotShowWarning);
+    connect(mScamWarningWidget, &MessageViewer::ScamDetectionWarningWidget::showDetails, mScamDetection, &MessageViewer::ScamDetectionWebEngine::showDetails);
 
     mWebEngineView->load(QUrl::fromLocalFile(filename));
 
-    QHBoxLayout *hbox = new QHBoxLayout;
-    QPushButton *openFile = new QPushButton(QStringLiteral("Open html..."));
+    auto hbox = new QHBoxLayout;
+    auto openFile = new QPushButton(QStringLiteral("Open html..."));
     connect(openFile, &QPushButton::clicked, this, &ScamDetectionWebEngineTestWidget::slotOpenHtml);
     hbox->addWidget(openFile);
     lay->addLayout(hbox);
@@ -58,8 +58,7 @@ void ScamDetectionWebEngineTestWidget::slotLoadFinished()
 
 void ScamDetectionWebEngineTestWidget::slotOpenHtml()
 {
-    const QString fileName = QFileDialog::getOpenFileName(nullptr, QString(),
-                                                          QString(), QStringLiteral("*.html"));
+    const QString fileName = QFileDialog::getOpenFileName(nullptr, QString(), QString(), QStringLiteral("*.html"));
     if (!fileName.isEmpty()) {
         mScamWarningWidget->setVisible(false);
         mWebEngineView->load(QUrl::fromLocalFile(fileName));
@@ -74,23 +73,20 @@ int main(int argc, char **argv)
     QCommandLineParser parser;
     parser.addVersionOption();
     parser.addHelpOption();
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("+[url]"),
-                                        QStringLiteral("URL of an html file to be opened")));
+    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("+[url]"), QStringLiteral("URL of an html file to be opened")));
     parser.process(app);
 
     QString fileName;
     if (!parser.positionalArguments().isEmpty()) {
         fileName = parser.positionalArguments().at(0);
     } else {
-        fileName
-            = QFileDialog::getOpenFileName(nullptr, QString(), QString(),
-                                           QStringLiteral("HTML File (*.html)"));
+        fileName = QFileDialog::getOpenFileName(nullptr, QString(), QString(), QStringLiteral("HTML File (*.html)"));
     }
     if (fileName.isEmpty()) {
         return 0;
     }
 
-    ScamDetectionWebEngineTestWidget *w = new ScamDetectionWebEngineTestWidget(fileName);
+    auto w = new ScamDetectionWebEngineTestWidget(fileName);
 
     w->show();
     app.exec();
