@@ -6,8 +6,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MESSAGEVIEWER_MARKMESSAGEREADHANDLER_H
-#define MESSAGEVIEWER_MARKMESSAGEREADHANDLER_H
+#pragma once
 
 #include "messageviewer_export.h"
 
@@ -15,7 +14,8 @@
 
 #include <QObject>
 
-namespace MessageViewer {
+namespace MessageViewer
+{
 /**
  * @short A viewer handler to mark viewed messages as read.
  */
@@ -43,11 +43,10 @@ public:
 
 private:
     //@cond PRIVATE
-    class Private;
-    friend class Private;
-    Private *const d;
+    class MarkMessageReadHandlerPrivate;
+    friend class MarkMessageReadHandlerPrivate;
+    std::unique_ptr<MarkMessageReadHandlerPrivate> const d;
     //@endcond
 };
 }
 
-#endif
