@@ -6,8 +6,8 @@
 */
 
 #include "utils/mimetype.h"
-#include "utils/iconnamecache.h"
 #include "messageviewer_debug.h"
+#include "utils/iconnamecache.h"
 
 #include <MimeTreeParser/NodeHelper>
 #include <MimeTreeParser/Util>
@@ -17,20 +17,15 @@
 
 QString MessageViewer::Util::iconPathForMimetype(const QString &mimeType, int iconSize, const QString &fallbackFileName1, const QString &fallbackFileName2)
 {
-    return IconNameCache::instance()->iconPath(MimeTreeParser::Util::iconNameForMimetype(mimeType,
-                                                                                         fallbackFileName1,
-                                                                                         fallbackFileName2),
-                                               iconSize);
+    return IconNameCache::instance()->iconPath(MimeTreeParser::Util::iconNameForMimetype(mimeType, fallbackFileName1, fallbackFileName2), iconSize);
 }
 
 QString MessageViewer::Util::iconPathForContent(KMime::Content *node, int size)
 {
-    return IconNameCache::instance()->iconPath(MimeTreeParser::Util::iconNameForContent(node),
-                                               size);
+    return IconNameCache::instance()->iconPath(MimeTreeParser::Util::iconNameForContent(node), size);
 }
 
-MessageViewer::Util::AttachmentDisplayInfo MessageViewer::Util::attachmentDisplayInfo(
-    KMime::Content *node)
+MessageViewer::Util::AttachmentDisplayInfo MessageViewer::Util::attachmentDisplayInfo(KMime::Content *node)
 {
     AttachmentDisplayInfo info;
     info.icon = iconPathForContent(node, KIconLoader::Small);
