@@ -9,17 +9,18 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MESSAGEVIEWER_ATTACHMENTSTRATEGY_H
-#define MESSAGEVIEWER_ATTACHMENTSTRATEGY_H
+#pragma once
 
 #include "messageviewer_export.h"
 
 class QString;
-namespace KMime {
+namespace KMime
+{
 class Content;
 }
 
-namespace MessageViewer {
+namespace MessageViewer
+{
 /**
  * @brief The AttachmentStrategy class
  */
@@ -33,9 +34,7 @@ public:
     //
     // Factory methods:
     //
-    enum Type {
-        Iconic, Smart, Inlined, Hidden, HeaderOnly
-    };
+    enum Type { Iconic, Smart, Inlined, Hidden, HeaderOnly };
 
     static const AttachmentStrategy *create(Type type);
     static const AttachmentStrategy *create(const QString &type);
@@ -56,9 +55,7 @@ public:
     // Behavioral:
     //
 
-    enum Display {
-        None, AsIcon, Inline
-    };
+    enum Display { None, AsIcon, Inline };
 
     virtual bool inlineNestedMessages() const = 0;
     virtual Display defaultDisplay(KMime::Content *node) const = 0;
@@ -66,4 +63,3 @@ public:
 };
 }
 
-#endif // MIMETREEPARSER_ATTACHMENTSTRATEGY_H
