@@ -1,32 +1,20 @@
 /*
-    Copyright (c) 2007 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2007 Volker Krause <vkrause@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#include <config-messageviewer.h>
 #include "editorwatcher.h"
+#include <config-messageviewer.h>
 
 #include "messageviewer_debug.h"
 
-#include <KLocalizedString>
-#include <kmessagebox.h>
-#include <kopenwithdialog.h>
-#include <kprocess.h>
-#include <kmimetypetrader.h>
+#include <KApplicationTrader>
 #include <KIO/DesktopExecParser>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KOpenWithDialog>
+#include <KProcess>
 
 #include <QSocketNotifier>
 
@@ -35,10 +23,10 @@
 
 // inotify stuff taken from kdelibs/kio/kio/kdirwatch.cpp
 #ifdef HAVE_SYS_INOTIFY_H
-#include <unistd.h>
 #include <fcntl.h>
 #include <sys/inotify.h>
 #include <sys/ioctl.h>
+#include <unistd.h>
 #endif
 
 using namespace MessageViewer;
@@ -67,11 +55,9 @@ EditorWatcher::ErrorEditorWatcher EditorWatcher::start()
     // find an editor
     QList<QUrl> list;
     list.append(mUrl);
-    KService::Ptr offer
-        = KMimeTypeTrader::self()->preferredService(mMimeType, QStringLiteral("Application"));
+    KService::Ptr offer = KApplicationTrader::preferredService(mMimeType);
     if ((mOpenWithOption == OpenWithDialog) || !offer) {
-        std::unique_ptr<KOpenWithDialog> dlg(new KOpenWithDialog(list, i18n("Edit with:"),
-                                                                 QString(), mParentWidget));
+        std::unique_ptr<KOpenWithDialog> dlg(new KOpenWithDialog(list, i18n("Edit with:"), QString(), mParentWidget));
         const int dlgrc = dlg->exec();
         if (dlgrc && dlg) {
             offer = dlg->service();
@@ -89,11 +75,9 @@ EditorWatcher::ErrorEditorWatcher EditorWatcher::start()
     mInotifyFd = inotify_init();
     if (mInotifyFd > 0) {
         (void)fcntl(mInotifyFd, F_SETFD, FD_CLOEXEC);
-        mInotifyWatch = inotify_add_watch(mInotifyFd,
-                                          mUrl.path().toLatin1().constData(),
-                                          IN_CLOSE | IN_OPEN | IN_MODIFY | IN_ATTRIB);
+        mInotifyWatch = inotify_add_watch(mInotifyFd, mUrl.path().toLatin1().constData(), IN_CLOSE | IN_OPEN | IN_MODIFY | IN_ATTRIB);
         if (mInotifyWatch >= 0) {
-            QSocketNotifier *sn = new QSocketNotifier(mInotifyFd, QSocketNotifier::Read, this);
+            auto sn = new QSocketNotifier(mInotifyFd, QSocketNotifier::Read, this);
             connect(sn, &QSocketNotifier::activated, this, &EditorWatcher::inotifyEvent);
             mHaveInotify = true;
             mFileModified = false;
@@ -109,8 +93,7 @@ EditorWatcher::ErrorEditorWatcher EditorWatcher::start()
     const QStringList params = parser.resultingArguments();
     mEditor = new KProcess(this);
     mEditor->setProgram(params);
-    connect(mEditor, qOverload<int, QProcess::ExitStatus>(&KProcess::finished),
-            this, &EditorWatcher::editorExited);
+    connect(mEditor, qOverload<int, QProcess::ExitStatus>(&KProcess::finished), this, &EditorWatcher::editorExited);
     mEditor->start();
     if (!mEditor->waitForStarted()) {
         return CannotStart;
@@ -194,8 +177,7 @@ void EditorWatcher::checkEditDone()
 
     static QStringList readOnlyMimeTypes;
     if (readOnlyMimeTypes.isEmpty()) {
-        readOnlyMimeTypes << QStringLiteral("message/rfc822")
-                          << QStringLiteral("application/pdf");
+        readOnlyMimeTypes << QStringLiteral("message/rfc822") << QStringLiteral("application/pdf");
     }
 
     // protect us against double-deletion by calling this method again while
@@ -203,8 +185,7 @@ void EditorWatcher::checkEditDone()
     mDone = true;
 
     // check if it's a mime type that's mostly handled read-only
-    const bool isReadOnlyMimeType = (readOnlyMimeTypes.contains(mMimeType)
-                                     || mMimeType.startsWith(QLatin1String("image/")));
+    const bool isReadOnlyMimeType = (readOnlyMimeTypes.contains(mMimeType) || mMimeType.startsWith(QLatin1String("image/")));
 
     // nobody can edit that fast, we seem to be unable to detect
     // when the editor will be closed
