@@ -1,17 +1,17 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
-#ifndef MESSAGEDISPLAYFORMATATTRIBUTE_H
-#define MESSAGEDISPLAYFORMATATTRIBUTE_H
+#pragma once
 
-#include <AkonadiCore/attribute.h>
-#include "messageviewer_export.h"
 #include "messageviewer/viewer.h"
-namespace MessageViewer {
+#include "messageviewer_export.h"
+#include <Akonadi/Attribute>
+namespace MessageViewer
+{
 class MessageDisplayFormatAttributePrivate;
 /**
  * @brief The MessageDisplayFormatAttribute class
@@ -38,8 +38,7 @@ public:
 
 private:
     friend class MessageDisplayFormatAttributePrivate;
-    MessageDisplayFormatAttributePrivate *const d;
+    std::unique_ptr<MessageDisplayFormatAttributePrivate> const d;
 };
 }
 
-#endif // MESSAGEDISPLAYFORMATATTRIBUTE_H
