@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    Code based on ARHParser.jsm from dkim_verifier (Copyright (c) Philippe Lieser)
    (This software is licensed under the terms of the MIT License.)
@@ -7,12 +7,12 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MESSAGEVIEWERRENDERER_H
-#define MESSAGEVIEWERRENDERER_H
+#pragma once
 
 #include "messageviewer_private_export.h"
 #include <QWidget>
-namespace MessageViewer {
+namespace MessageViewer
+{
 class CSSHelper;
 class MESSAGEVIEWER_TESTS_EXPORT MessageViewerRenderer
 {
@@ -26,10 +26,10 @@ public:
     void setCurrentWidget(QWidget *currentWidget);
 
     void recreateCssHelper();
+
 private:
     CSSHelper *mCSSHelper = nullptr;
     QWidget *mCurrentWidget = nullptr;
 };
 }
 
-#endif // MESSAGEVIEWERRENDERER_H
