@@ -7,13 +7,12 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef KDEPIM_MESSAGEVIEWER_STL_UTIL_H
-#define KDEPIM_MESSAGEVIEWER_STL_UTIL_H
+#pragma once
 
-namespace MessageViewer {
-template<typename T>
-struct DeleteAndSetToZero {
-    void operator()(const T * &t)
+namespace MessageViewer
+{
+template<typename T> struct DeleteAndSetToZero {
+    void operator()(const T *&t)
     {
         delete t;
         t = nullptr;
@@ -21,4 +20,3 @@ struct DeleteAndSetToZero {
 };
 }
 
-#endif // KDEPIM__MESSAGEVIEWER__STL_UTIL_H
