@@ -1,23 +1,11 @@
 /*
   This file is part of KMail, the KDE mail client.
-  Copyright (c) 1997 Markus Wuebben <markus.wuebben@kde.org>
-  Copyright (C) 2009 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-  Copyright (c) 2009 Andras Mantia <andras@kdab.net>
-  Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 1997 Markus Wuebben <markus.wuebben@kde.org>
+  SPDX-FileCopyrightText: 2009 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
+  SPDX-FileCopyrightText: 2009 Andras Mantia <andras@kdab.net>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 // define this to copy all html that is written to the readerwindow to
@@ -25,44 +13,42 @@
 //#define KMAIL_READER_HTML_DEBUG 1
 
 #include "viewer.h"
+#include "csshelper.h"
+#include "dkim-verify/dkimwidgetinfo.h"
+#include "settings/messageviewersettings.h"
+#include "viewer/mimeparttree/mimeparttreeview.h"
+#include "viewer/mimeparttree/mimetreemodel.h"
+#include "viewer/webengine/mailwebengineview.h"
 #include "viewer_p.h"
 #include "widgets/configurewidget.h"
-#include "csshelper.h"
-#include "settings/messageviewersettings.h"
-#include "viewer/webengine/mailwebengineview.h"
-#include <WebEngineViewer/WebHitTestResult>
-#include <WebEngineViewer/WebEngineManageScript>
-#include "viewer/mimeparttree/mimetreemodel.h"
-#include "viewer/mimeparttree/mimeparttreeview.h"
 #include "widgets/zoomactionmenu.h"
-
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
 #include <Akonadi/KMime/MessageParts>
-#include <AkonadiCore/itemfetchjob.h>
-#include <AkonadiCore/itemfetchscope.h>
 #include <QUrl>
+#include <WebEngineViewer/WebEngineManageScript>
+#include <WebEngineViewer/WebHitTestResult>
 
-#include <mailtransportakonadi/errorattribute.h>
+#include <MailTransportAkonadi/ErrorAttribute>
 
 #include <KLocalizedString>
 
 #include <QAction>
 
-namespace MessageViewer {
-class AbstractMessageLoadedHandler::Private
+namespace MessageViewer
+{
+class AbstractMessageLoadedHandler::AbstractMessageLoadedHandlerPrivate
 {
 public:
     Akonadi::Session *mSession = nullptr;
 };
 
 AbstractMessageLoadedHandler::AbstractMessageLoadedHandler()
-    : d(new Private)
+    : d(new AbstractMessageLoadedHandlerPrivate)
 {
 }
 
-AbstractMessageLoadedHandler::~AbstractMessageLoadedHandler()
-{
-    delete d;
-}
+AbstractMessageLoadedHandler::~AbstractMessageLoadedHandler() = default;
 
 void AbstractMessageLoadedHandler::setSession(Akonadi::Session *session)
 {
@@ -83,31 +69,29 @@ Viewer::Viewer(QWidget *aParent, QWidget *mainWindow, KActionCollection *actionC
 
 Viewer::~Viewer()
 {
-    //the d_ptr is automatically deleted
+    // the d_ptr is automatically deleted
 }
 
 void Viewer::initialize()
 {
-    connect(d_ptr, &ViewerPrivate::displayPopupMenu,
-            this, &Viewer::displayPopupMenu);
-    connect(d_ptr, &ViewerPrivate::popupMenu,
-            this, &Viewer::popupMenu);
-    connect(d_ptr, SIGNAL(urlClicked(Akonadi::Item,QUrl)),
-            SIGNAL(urlClicked(Akonadi::Item,QUrl)));
+    connect(d_ptr, &ViewerPrivate::displayPopupMenu, this, &Viewer::displayPopupMenu);
+    connect(d_ptr, &ViewerPrivate::popupMenu, this, &Viewer::popupMenu);
+    connect(d_ptr, SIGNAL(urlClicked(Akonadi::Item, QUrl)), SIGNAL(urlClicked(Akonadi::Item, QUrl)));
     connect(d_ptr, &ViewerPrivate::requestConfigSync, this, &Viewer::requestConfigSync);
     connect(d_ptr, &ViewerPrivate::makeResourceOnline, this, &Viewer::makeResourceOnline);
-    connect(d_ptr, &ViewerPrivate::showReader,
-            this, &Viewer::showReader);
+    connect(d_ptr, &ViewerPrivate::showReader, this, &Viewer::showReader);
     connect(d_ptr, &ViewerPrivate::showMessage, this, &Viewer::showMessage);
     connect(d_ptr, &ViewerPrivate::replyMessageTo, this, &Viewer::replyMessageTo);
-    connect(d_ptr, &ViewerPrivate::showStatusBarMessage,
-            this, &Viewer::showStatusBarMessage);
-    connect(d_ptr, &ViewerPrivate::itemRemoved,
-            this, &Viewer::itemRemoved);
+    connect(d_ptr, &ViewerPrivate::showStatusBarMessage, this, &Viewer::showStatusBarMessage);
+    connect(d_ptr, &ViewerPrivate::itemRemoved, this, &Viewer::itemRemoved);
     connect(d_ptr, &ViewerPrivate::changeDisplayMail, this, &Viewer::slotChangeDisplayMail);
     connect(d_ptr, &ViewerPrivate::moveMessageToTrash, this, &Viewer::moveMessageToTrash);
     connect(d_ptr, &ViewerPrivate::pageIsScrolledToBottom, this, &Viewer::pageIsScrolledToBottom);
     connect(d_ptr, &ViewerPrivate::printingFinished, this, &Viewer::printingFinished);
+    connect(d_ptr, &ViewerPrivate::zoomChanged, this, &Viewer::zoomChanged);
+
+    connect(d_ptr, &ViewerPrivate::showNextMessage, this, &Viewer::showNextMessage);
+    connect(d_ptr, &ViewerPrivate::showPreviousMessage, this, &Viewer::showPreviousMessage);
 
     setMessage(KMime::Message::Ptr(), MimeTreeParser::Delayed);
 }
@@ -140,9 +124,9 @@ void Viewer::setMessageItem(const Akonadi::Item &item, MimeTreeParser::UpdateMod
         d->setMessageItem(item, updateMode);
     } else {
         Akonadi::ItemFetchJob *job = createFetchJob(item);
-        connect(job, &Akonadi::ItemFetchJob::result, [this, d](KJob *job) {
-                d->itemFetchResult(job);
-            });
+        connect(job, &Akonadi::ItemFetchJob::result, [d](KJob *job) {
+            d->itemFetchResult(job);
+        });
         d->displaySplashPage(i18n("Loading message..."));
     }
 }
@@ -356,8 +340,7 @@ bool Viewer::event(QEvent *e)
 {
     Q_D(Viewer);
     if (e->type() == QEvent::PaletteChange) {
-        delete d->mCSSHelper;
-        d->mCSSHelper = new CSSHelper(d->mViewer);
+        d->recreateCssHelper();
         d->update(MimeTreeParser::Force);
         e->accept();
         return true;
@@ -528,21 +511,17 @@ void Viewer::readConfig()
 
 QAbstractItemModel *Viewer::messageTreeModel() const
 {
-#ifndef QT_NO_TREEVIEW
     return d_func()->mMimePartTree->mimePartModel();
-#else
-    return nullptr;
-#endif
 }
 
 Akonadi::ItemFetchJob *Viewer::createFetchJob(const Akonadi::Item &item)
 {
     Q_D(Viewer);
-    Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob(item, d->mSession);
+    auto job = new Akonadi::ItemFetchJob(item, d->mSession);
     job->fetchScope().fetchAllAttributes();
     job->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
     job->fetchScope().fetchFullPayload(true);
-    job->fetchScope().setFetchRelations(true);   // needed to know if we have notes or not
+    job->fetchScope().setFetchRelations(true); // needed to know if we have notes or not
     job->fetchScope().fetchAttribute<MailTransport::ErrorAttribute>();
     return job;
 }
@@ -614,11 +593,19 @@ QAction *Viewer::findInMessageAction() const
     return d->mFindInMessageAction;
 }
 
+QAction *Viewer::shareTextAction() const
+{
+    Q_D(const Viewer);
+    return d->mShareTextAction;
+}
+
 void Viewer::slotChangeDisplayMail(Viewer::DisplayFormatMessage mode, bool loadExternal)
 {
-    setHtmlLoadExtOverride(loadExternal);
-    setDisplayFormatMessageOverwrite(mode);
-    update(MimeTreeParser::Force);
+    if ((htmlLoadExtOverride() != loadExternal) || (displayFormatMessageOverwrite() != mode)) {
+        setHtmlLoadExtOverride(loadExternal);
+        setDisplayFormatMessageOverwrite(mode);
+        update(MimeTreeParser::Force);
+    }
 }
 
 QAction *Viewer::saveMessageDisplayFormatAction() const
@@ -633,6 +620,12 @@ QAction *Viewer::resetMessageDisplayFormatAction() const
     return d->mResetMessageDisplayFormat;
 }
 
+QAction *Viewer::developmentToolsAction() const
+{
+    Q_D(const Viewer);
+    return d->mDevelopmentToolsAction;
+}
+
 KToggleAction *Viewer::disableEmoticonAction() const
 {
     Q_D(const Viewer);
@@ -642,7 +635,7 @@ KToggleAction *Viewer::disableEmoticonAction() const
 void Viewer::saveMainFrameScreenshotInFile(const QString &filename)
 {
     Q_D(Viewer);
-    return d->saveMainFrameScreenshotInFile(filename);
+    d->saveMainFrameScreenshotInFile(filename);
 }
 
 KActionMenu *Viewer::shareServiceUrlMenu() const
@@ -657,16 +650,28 @@ HeaderStylePlugin *Viewer::headerStylePlugin() const
     return d->mHeaderStylePlugin;
 }
 
+DKIMViewerMenu *Viewer::dkimViewerMenu()
+{
+    Q_D(Viewer);
+    return d->dkimViewerMenu();
+}
+
+RemoteContentMenu *Viewer::remoteContentMenu() const
+{
+    Q_D(const Viewer);
+    return d->remoteContentMenu();
+}
+
 void Viewer::setPluginName(const QString &pluginName)
 {
     Q_D(Viewer);
-    return d->setPluginName(pluginName);
+    d->setPluginName(pluginName);
 }
 
 void Viewer::showOpenAttachmentFolderWidget(const QList<QUrl> &urls)
 {
     Q_D(Viewer);
-    d->showOpenAttachmentFolderWidget(urls);
+    d->showSavedFileFolderWidget(urls, MessageViewer::OpenSavedFileFolderWidget::FileType::Attachment);
 }
 
 QList<QAction *> Viewer::viewerPluginActionList(ViewerPluginInterface::SpecificFeatureTypes features)
@@ -675,8 +680,7 @@ QList<QAction *> Viewer::viewerPluginActionList(ViewerPluginInterface::SpecificF
     return d->viewerPluginActionList(features);
 }
 
-QList<QAction *> Viewer::interceptorUrlActions(const WebEngineViewer::WebHitTestResult &result)
-const
+QList<QAction *> Viewer::interceptorUrlActions(const WebEngineViewer::WebHitTestResult &result) const
 {
     Q_D(const Viewer);
     return d->interceptorUrlActions(result);
@@ -693,4 +697,83 @@ void Viewer::setPrintElementBackground(bool printElementBackground)
     Q_D(Viewer);
     d->mViewer->setPrintElementBackground(printElementBackground);
 }
+
+bool Viewer::showSignatureDetails() const
+{
+    Q_D(const Viewer);
+    return d->showSignatureDetails();
+}
+
+void Viewer::setShowSignatureDetails(bool showDetails)
+{
+    Q_D(Viewer);
+    d->setShowSignatureDetails(showDetails);
+}
+
+bool Viewer::showEncryptionDetails() const
+{
+    Q_D(const Viewer);
+    return d->showEncryptionDetails();
+}
+
+void Viewer::hasMultiMessages(bool messages)
+{
+    Q_D(Viewer);
+    d->hasMultiMessages(messages);
+}
+
+void Viewer::updateShowMultiMessagesButton(bool enablePreviousButton, bool enableNextButton)
+{
+    Q_D(Viewer);
+    d->updateShowMultiMessagesButton(enablePreviousButton, enableNextButton);
+}
+
+void Viewer::setShowEncryptionDetails(bool showDetails)
+{
+    Q_D(Viewer);
+    d->setShowEncryptionDetails(showDetails);
+}
+
+qreal Viewer::webViewZoomFactor() const
+{
+    Q_D(const Viewer);
+    return d->webViewZoomFactor();
+}
+
+void Viewer::setWebViewZoomFactor(qreal factor)
+{
+    Q_D(Viewer);
+    d->setWebViewZoomFactor(factor);
+}
+
+MessageViewer::DKIMWidgetInfo *Viewer::dkimWidgetInfo()
+{
+    Q_D(Viewer);
+    return d->mDkimWidgetInfo;
+}
+
+void Viewer::exportToPdf(const QString &fileName)
+{
+    Q_D(Viewer);
+    d->exportToPdf(fileName);
+}
+
+void Viewer::showDevelopmentTools()
+{
+    Q_D(Viewer);
+    d->slotShowDevelopmentTools();
+}
+
+void Viewer::setIdentityManager(KIdentityManagement::IdentityManager *ident)
+{
+    Q_D(Viewer);
+    d->setIdentityManager(ident);
+}
+
+void Viewer::setFolderIdentity(uint folderIdentity)
+{
+    Q_D(Viewer);
+    d->setFolderIdentity(folderIdentity);
+}
+
 }
