@@ -1,47 +1,36 @@
 /*
-  Copyright (c) 1997 Markus Wuebben <markus.wuebben@kde.org>
-  Copyright (C) 2009 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-  Copyright (c) 2009 Andras Mantia <andras@kdab.net>
+  SPDX-FileCopyrightText: 1997 Markus Wuebben <markus.wuebben@kde.org>
+  SPDX-FileCopyrightText: 2009 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
+  SPDX-FileCopyrightText: 2009 Andras Mantia <andras@kdab.net>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAILVIEWER_P_H
-#define MAILVIEWER_P_H
+#pragma once
 
-#include <MimeTreeParser/NodeHelper>
 #include "config-messageviewer.h"
-#include "viewer.h" //not so nice, it is actually for the enums from MailViewer
-#include "PimCommon/ShareServiceUrlManager"
 #include "messageviewer/viewerplugininterface.h"
-#include <WebEngineViewer/CheckPhishingUrlJob>
+#include "messageviewer_private_export.h"
+#include "viewer.h" //not so nice, it is actually for the enums from MailViewer
+#include "widgets/opensavedfilefolderwidget.h"
+#include <PimCommon/ShareServiceUrlManager>
+#include <WebEngineViewer/CheckPhishingUrlUtil>
 
-#include <AkonadiCore/item.h>
-#include <AkonadiCore/monitor.h>
-#include <AkonadiCore/session.h>
-#include <kio/job.h>
+#include <Akonadi/Item>
+#include <Akonadi/Monitor>
+#include <Akonadi/Session>
+#include <KIO/Job>
 #include <KMime/Message>
-#include <kservice.h>
-#include <ksharedconfig.h>
+#include <KService>
 #include <QPointer>
 #include <QUrl>
+#include <QVector>
 
 #include <QObject>
 #include <QTimer>
 
-namespace KIO {
+namespace KIO
+{
 class Job;
 }
 
@@ -57,40 +46,54 @@ class QSplitter;
 class QModelIndex;
 class QPrinter;
 
-namespace KPIMTextEdit {
+namespace KIdentityManagement
+{
+class IdentityManager;
+}
+
+namespace KPIMTextEdit
+{
 class SlideContainer;
 class TextToSpeechWidget;
 }
-namespace PimCommon {
-class ShareServiceUrlManager;
-}
 
-namespace MimeTreeParser {
-class AttachmentStrategy;
-class HtmlWriter;
+namespace MimeTreeParser
+{
 class ObjectTreeParser;
+class NodeHelper;
 }
-
-namespace WebEngineViewer {
+namespace MessageViewer
+{
+class DKIMWidgetInfo;
+class DKIMViewerMenu;
+}
+namespace WebEngineViewer
+{
 class WebHitTestResult;
 class FindBarWebEngineView;
 class ZoomActionMenu;
 class LocalDataBaseManager;
+class TrackingWarningWidget;
+class DeveloperToolDialog;
+class SubmittedFormWarningWidget;
 }
-namespace MessageViewer {
+namespace MessageViewer
+{
+class AttachmentStrategy;
 class HeaderStylePlugin;
+class HtmlWriter;
 class CSSHelper;
+class MessageViewerRenderer;
 class MailWebEngineView;
 class WebEnginePartHtmlWriter;
 class HtmlStatusBar;
 class ScamDetectionWarningWidget;
 class MimePartTreeView;
-class OpenAttachmentFolderWidget;
 class HeaderStyleMenuManager;
 class ViewerPluginToolManager;
-class ViewerPluginInterface;
-class SubmittedFormWarningWidget;
 class MailSourceWebEngineViewer;
+class ShowNextMessageWidget;
+class RemoteContentMenu;
 /**
 \brief Private class for the Viewer, the main widget in the messageviewer library.
 
@@ -119,15 +122,15 @@ update() is just a thin wrapper that calls updateReaderWin(). The only differenc
 has a timer that prevents too many slow calls to updateReaderWin() in a short time frame.
 updateReaderWin() again is only a thin wrapper that resets some state and then calls
 displayMessage().
-displayMessage() itself is again a thin wrapper, which starts the MimeTreeParser::HtmlWriter and then calls
+displayMessage() itself is again a thin wrapper, which starts the HtmlWriter and then calls
 parseMsg().
-Finally, parseMsg() does the real work. It uses MimeTreeParser::ObjectTreeParser ::parseObjectTree() to let the
+Finally, parseMsg() does the real work. It uses MimeTreeParser::ObjectTreeParser parseObjectTree() to let the
 MimeTreeParser::ObjectTreeParser parse the message and generate the HTML code for it.
 As mentioned before, it can happen that the MimeTreeParser::ObjectTreeParser needs to do some operation that happens
 async, for example decrypting. In this case, the MimeTreeParser::ObjectTreeParser will create a BodyPartMemento,
 which basically is a wrapper around the job that does the async operation. Once the async operation
 is finished. the BodyPartMemento will trigger an update() of ViewerPrivate, so that
-MimeTreeParser::ObjectTreeParser ::parseObjectTree() gets called again and the MimeTreeParser::ObjectTreeParser then can generate
+MimeTreeParser::ObjectTreeParser parseObjectTree() gets called again and the MimeTreeParser::ObjectTreeParser then can generate
 HTML which has the decrypted content of the message. Again, see the documentation of MimeTreeParser::ObjectTreeParser for the details.
 Additionally, parseMsg() does some evil hack for saving unencrypted messages should the config
 option for that be set.
@@ -175,7 +178,7 @@ writes out a placeholder for the attachment list when it creates the HTML for th
 MimeTreeParser::ObjectTreeParser is finished with the message, injectAttachments() is called. injectAttachments()
 searches for the placeholder and replaces that with the real HTML code for the attachments.
 
-One of the attachment actions is to scoll to the attachment. That action is only available when
+One of the attachment actions is to scroll to the attachment. That action is only available when
 right-clicking the header. The action scrolls to the attachment in the body and draws a yellow frame
 around the attachment. This is done in scrollToAttachment(). The attachment in the body and the div
 which is used for the colored frame are both created by the MimeTreeParser::ObjectTreeParser .
@@ -183,60 +186,58 @@ which is used for the colored frame are both created by the MimeTreeParser::Obje
 \par Misc
 
 ViewerPrivate holds the MimeTreeParser::NodeHelper, which is passed on to the MimeTreeParser::ObjectTreeParser when it needs it.
-It also holds the HeaderStyle, HeaderStrategy, MimeTreeParser::AttachmentStrategy, CSSHelper, MimeTreeParser::HtmlWriter and more,
+It also holds the HeaderStyle, HeaderStrategy, MimeTreeParser::AttachmentStrategy, CSSHelper, HtmlWriter and more,
 some of them again passed to the MimeTreeParser::ObjectTreeParser when it needs it.
 
 @author andras@kdab.net
  */
-class ViewerPrivate : public QObject
+class MESSAGEVIEWER_TESTS_EXPORT ViewerPrivate : public QObject
 {
     Q_OBJECT
 public:
-
     ViewerPrivate(Viewer *aParent, QWidget *mainWindow, KActionCollection *actionCollection);
 
-    virtual ~ViewerPrivate();
+    ~ViewerPrivate() override;
 
     /** Returns message part from given URL or null if invalid. The URL's path is a KMime::ContentIndex path, or an index for the extra nodes,
     followed by : and the ContentIndex path. */
-    KMime::Content *nodeFromUrl(const QUrl &url) const;
+    Q_REQUIRED_RESULT KMime::Content *nodeFromUrl(const QUrl &url) const;
 
     /** Open the attachment pointed to the node.
-    * @param fileName - if not empty, use this file to load the attachment content
-    */
+     * @param node the node
+     * @param url - if not empty, use this file to load the attachment content
+     */
     void openAttachment(KMime::Content *node, const QUrl &url);
 
-    /** Delete the attachment the @param node points to. Returns false if the user
+    /** Delete the attachment the @p node points to. Returns false if the user
     cancelled the deletion, true in all other cases (including failure to delete
-    the attachment!) */
-    bool deleteAttachment(KMime::Content *node, bool showWarning = true);
+    the attachment!)
+    * @param node the node
+    * @param showWarning whether some warning should be shown
+    */
+    Q_REQUIRED_RESULT bool deleteAttachment(KMime::Content *node, bool showWarning = true);
 
     void attachmentProperties(KMime::Content *node);
     void attachmentCopy(const KMime::Content::List &contents);
 
-    /** Edit the attachment the @param node points to. Returns false if the user
-    cancelled the editing, true in all other cases! */
-    void editAttachment(KMime::Content *node, bool showWarning = true);
-
     void scrollToAnchor(const QString &anchor);
 
     void showAttachmentPopup(KMime::Content *node, const QString &name, const QPoint &p);
 
     /**
-    * Sets the current attachment ID and the current attachment temporary filename
-    * to the given values.
-    * Call this so that slotHandleAttachment() knows which attachment to handle.
-    */
+     * Sets the current attachment ID and the current attachment temporary filename
+     * to the given values.
+     * Call this so that slotHandleAttachment() knows which attachment to handle.
+     */
     void prepareHandleAttachment(KMime::Content *node);
 
-    QString createAtmFileLink(const QString &atmFileName) const;
-    KService::Ptr getServiceOffer(KMime::Content *content);
-    KMime::Content::List selectedContents();
+    Q_REQUIRED_RESULT KService::Ptr getServiceOffer(KMime::Content *content);
+    Q_REQUIRED_RESULT KMime::Content::List selectedContents() const;
     void attachmentOpenWith(KMime::Content *node, const KService::Ptr &offer = KService::Ptr());
     void attachmentOpen(KMime::Content *node);
 
-    /** Return the MimeTreeParser::HtmlWriter connected to the MailWebView we use */
-    MimeTreeParser::HtmlWriter *htmlWriter() const;
+    /** Return the HtmlWriter connected to the MailWebView we use */
+    HtmlWriter *htmlWriter() const;
 
     HeaderStylePlugin *headerStylePlugin() const;
 
@@ -246,12 +247,12 @@ public:
 
     Viewer *viewer() const;
 
-    Akonadi::Item messageItem() const;
+    Q_REQUIRED_RESULT Akonadi::Item messageItem() const;
 
-    KMime::Message::Ptr message() const;
+    Q_REQUIRED_RESULT KMime::Message::Ptr message() const;
 
-    /** Returns whether the message should be decryted. */
-    bool decryptMessage() const;
+    /** Returns whether the message should be decrypted. */
+    Q_REQUIRED_RESULT bool decryptMessage() const;
 
     /** Display a generic HTML splash page instead of a message. */
     void displaySplashPage(const QString &templateName, const QVariantHash &data, const QByteArray &domain = QByteArray());
@@ -270,18 +271,23 @@ public:
 
     /** Creates a nice mail header depending on the current selected
     header style. */
-    QString writeMsgHeader(KMime::Message *aMsg, KMime::Content *vCardNode = nullptr, bool topLevel = false);
+    Q_REQUIRED_RESULT QString writeMessageHeader(KMime::Message *aMsg, KMime::Content *vCardNode, bool topLevel);
 
     /** show window containing information about a vCard. */
     void showVCard(KMime::Content *msgPart);
 
     void saveMainFrameScreenshotInFile(const QString &filename);
 
+    void exportToPdf(const QString &fileName);
+
 private:
     /** HTML initialization. */
     void initHtmlWidget();
     void createOpenWithMenu(QMenu *topMenu, const QString &contentTypeStr, bool fromCurrentContent);
+
 public:
+    void itemFetchResult(KJob *job);
+
     /** Read settings from app's config file. */
     void readConfig();
 
@@ -289,20 +295,20 @@ public:
     void writeConfig(bool withSync = true);
 
     /** Get/set the message attachment strategy. */
-    const MimeTreeParser::AttachmentStrategy *attachmentStrategy() const;
-    void setAttachmentStrategy(const MimeTreeParser::AttachmentStrategy *strategy);
+    const AttachmentStrategy *attachmentStrategy() const;
+    void setAttachmentStrategy(const AttachmentStrategy *strategy);
 
     /** Get selected override character encoding.
       @return The encoding selected by the user or an empty string if auto-detection
       is selected. */
-    QString overrideEncoding() const;
+    Q_REQUIRED_RESULT QString overrideEncoding() const;
 
     /** Set the override character encoding. */
     void setOverrideEncoding(const QString &encoding);
 
     /** Set printing mode */
     void setPrinting(bool enable);
-    bool printingMode() const;
+    Q_REQUIRED_RESULT bool printingMode() const;
 
     /** Print message. */
     void printMessage(const Akonadi::Item &msg);
@@ -313,16 +319,16 @@ public:
     void setMessageInternal(const KMime::Message::Ptr &message, MimeTreeParser::UpdateMode updateMode);
 
     /** Set the Akonadi item that will be displayed.
-    *  @param item - the Akonadi item to be displayed. If it doesn't hold a mail (KMime::Message::Ptr as payload data),
-    *                an empty page is shown.
-    *  @param updateMode - update the display immediately or not. See MailViewer::UpdateMode.
-    */
-    void setMessageItem(const Akonadi::Item &item, MimeTreeParser::UpdateMode updateMode = MimeTreeParser::Delayed);
+     *  @param item - the Akonadi item to be displayed. If it doesn't hold a mail (KMime::Message::Ptr as payload data),
+     *                an empty page is shown.
+     *  @param updateMode - update the display immediately or not. See MailViewer::UpdateMode.
+     */
+    void setMessageItem(const Akonadi::Item &item, MimeTreeParser::UpdateMode updateMode = MimeTreeParser::Delayed, bool forceHtmlLoadExtOverride = false);
 
     /** Set the message that shall be shown.
-    * @param msg - the message to be shown. If 0, an empty page is displayed.
-    * @param updateMode - update the display immediately or not. See MailViewer::UpdateMode.
-    */
+     * @param msg - the message to be shown. If 0, an empty page is displayed.
+     * @param updateMode - update the display immediately or not. See MailViewer::UpdateMode.
+     */
     void setMessage(const KMime::Message::Ptr &msg, MimeTreeParser::UpdateMode updateMode = MimeTreeParser::Delayed);
 
     /** Instead of settings a message to be shown sets a message part
@@ -334,7 +340,7 @@ public:
     void showHideMimeTree();
 
     /** View message part of type message/RFC822 in extra viewer window. */
-    void atmViewMsg(const KMime::Message::Ptr &message);
+    void attachmentViewMessage(const KMime::Message::Ptr &message);
 
     void adjustLayout();
     void createWidgets();
@@ -342,7 +348,7 @@ public:
 
     void showContextMenu(KMime::Content *content, const QPoint &point);
 
-    KToggleAction *actionForAttachmentStrategy(const MimeTreeParser::AttachmentStrategy *);
+    KToggleAction *actionForAttachmentStrategy(const AttachmentStrategy *);
     /** Read override codec from configuration */
     void readGlobalOverrideCodec();
 
@@ -350,80 +356,92 @@ public:
       @return The override codec or 0 if auto-detection is selected. */
     const QTextCodec *overrideCodec() const;
 
-    QString renderAttachments(KMime::Content *node, const QColor &bgColor) const;
+    Q_REQUIRED_RESULT QString renderAttachments(KMime::Content *node, const QColor &bgColor) const;
 
-    KMime::Content *findContentByType(KMime::Content *content, const QByteArray &type); //TODO(Andras) move to MimeTreeParser::NodeHelper
-
-    /** Return a QTextCodec for the specified charset.
-    * This function is a bit more tolerant, than QTextCodec::codecForName */
-    static const QTextCodec *codecForName(const QByteArray &_str); //TODO(Andras) move to a utility class?
+    KMime::Content *findContentByType(KMime::Content *content, const QByteArray &type); // TODO(Andras) move to MimeTreeParser::NodeHelper
 
     /** Saves the relative position of the scroll view. Call this before calling update()
       if you want to preserve the current view. */
     void saveRelativePosition();
 
-    bool htmlMail() const;
-    bool htmlLoadExternal() const;
+    Q_REQUIRED_RESULT bool htmlMail() const;
+    Q_REQUIRED_RESULT bool htmlLoadExternal() const;
 
-    bool htmlMailGlobalSetting() const;
+    Q_REQUIRED_RESULT bool htmlMailGlobalSetting() const;
 
     /** Get the html override setting */
-    Viewer::DisplayFormatMessage displayFormatMessageOverwrite() const;
+    Q_REQUIRED_RESULT Viewer::DisplayFormatMessage displayFormatMessageOverwrite() const;
 
     /** Override default html mail setting */
     void setDisplayFormatMessageOverwrite(Viewer::DisplayFormatMessage format);
 
     /** Get the load external references override setting */
-    bool htmlLoadExtOverride() const;
+    Q_REQUIRED_RESULT bool htmlLoadExtOverride() const;
 
-    /** Override default load external references setting */
-    void setHtmlLoadExtOverride(bool override);
+    /** Default behavior for loading external references.
+     *  Use this for specifying the external reference loading behavior as
+     *  specified in the user settings.
+     *  @see setHtmlLoadExtOverride
+     */
+    void setHtmlLoadExtDefault(bool loadExtDefault);
+
+    /** Override default load external references setting
+     *  @warning This must only be called when the user has explicitly
+     *  been asked to retrieve external references!
+     *  @see setHtmlLoadExtDefault
+     */
+    void setHtmlLoadExtOverride(bool loadExtOverride);
 
     /** Enforce message decryption. */
     void setDecryptMessageOverwrite(bool overwrite = true);
 
     /** Show signature details. */
-    bool showSignatureDetails() const;
+    Q_REQUIRED_RESULT bool showSignatureDetails() const;
 
     /** Show signature details. */
     void setShowSignatureDetails(bool showDetails = true);
 
-    /* show or hide the list that points to the attachments */
-    void setShowAttachmentQuicklist(bool showAttachmentQuicklist = true);
-
     /* show or hide encryption details */
-    void setHideEncryptionDetails(bool encDetails = true);
+    void setShowEncryptionDetails(bool showEncDetails);
+
+    Q_REQUIRED_RESULT bool showEncryptionDetails() const;
 
     void scrollToAttachment(KMime::Content *node);
     void setUseFixedFont(bool useFixedFont);
 
     void attachmentView(KMime::Content *atmNode);
-    void setFullToAddressList(bool showFullTo);
-    void setFullCcAddressList(bool showFullCc);
-
-    /** Show/Hide the field with id "field" */
-    void toggleFullAddressList(const QString &field);
 
     void setZoomFactor(qreal zoomFactor);
 
     void goOnline();
     void goResourceOnline();
 
-    void showOpenAttachmentFolderWidget(const QUrl &url);
+    void showSavedFileFolderWidget(const QList<QUrl> &urls, MessageViewer::OpenSavedFileFolderWidget::FileType fileType);
 
-    bool mimePartTreeIsEmpty() const;
+    Q_REQUIRED_RESULT bool mimePartTreeIsEmpty() const;
 
     void setPluginName(const QString &pluginName);
 
-    QList<QAction *> viewerPluginActionList(
-        MessageViewer::ViewerPluginInterface::SpecificFeatureTypes features);
-    QList<QAction *> interceptorUrlActions(const WebEngineViewer::WebHitTestResult &result) const;
+    Q_REQUIRED_RESULT QList<QAction *> viewerPluginActionList(MessageViewer::ViewerPluginInterface::SpecificFeatureTypes features);
+    Q_REQUIRED_RESULT QList<QAction *> interceptorUrlActions(const WebEngineViewer::WebHitTestResult &result) const;
 
     void setPrintElementBackground(bool printElementBackground);
-    bool showEmoticons() const;
+    Q_REQUIRED_RESULT bool showEmoticons() const;
     void checkPhishingUrl();
     void executeRunner(const QUrl &url);
-    QUrl imageUrl() const;
+    Q_REQUIRED_RESULT QUrl imageUrl() const;
+    Q_REQUIRED_RESULT qreal webViewZoomFactor() const;
+    void setWebViewZoomFactor(qreal factor);
+    void recreateCssHelper();
+    void hasMultiMessages(bool messages);
+    void updateShowMultiMessagesButton(bool enablePreviousButton, bool enableNextButton);
+    MessageViewer::DKIMViewerMenu *dkimViewerMenu();
+
+    Q_REQUIRED_RESULT bool isAutocryptEnabled(KMime::Message *message);
+    void setIdentityManager(KIdentityManagement::IdentityManager *ident);
+    void setFolderIdentity(uint folderIdentity);
+
+    RemoteContentMenu *remoteContentMenu() const;
 
 private Q_SLOTS:
     void slotActivatePlugin(MessageViewer::ViewerPluginInterface *interface);
@@ -431,13 +449,6 @@ private Q_SLOTS:
     void slotMessageMayBeAScam();
     void slotMessageIsNotAScam();
     void slotAddToWhiteList();
-    void slotFormSubmittedForbidden();
-
-    /** Show hide all fields specified inside this function */
-    void toggleFullAddressList();
-
-    void itemFetchResult(KJob *job);
-
     void slotItemChanged(const Akonadi::Item &item, const QSet<QByteArray> &partIdentifiers);
     void slotItemMoved(const Akonadi::Item &, const Akonadi::Collection &, const Akonadi::Collection &);
 
@@ -467,6 +478,7 @@ private Q_SLOTS:
     void slotExportHtmlPageSuccess(const QString &filename);
     void slotHandlePagePrinted(bool result);
     void slotToggleEmoticons();
+
 public Q_SLOTS:
     /** An URL has been activate with a click. */
     void slotUrlOpen(const QUrl &url = QUrl());
@@ -521,7 +533,6 @@ public Q_SLOTS:
     void slotAttachmentProperties();
     void slotAttachmentCopy();
     void slotAttachmentDelete();
-    void slotAttachmentEdit();
     void slotLevelQuote(int l);
 
     /** Toggle display mode between HTML and plain text. */
@@ -529,12 +540,12 @@ public Q_SLOTS:
     void slotLoadExternalReference();
 
     /**
-    * Does an action for the current attachment.
-    * The action is defined by the KMHandleAttachmentCommand::AttachmentAction
-    * enum.
-    * prepareHandleAttachment() needs to be called before calling this to set the
-    * correct attachment ID.
-    */
+     * Does an action for the current attachment.
+     * The action is defined by the KMHandleAttachmentCommand::AttachmentAction
+     * enum.
+     * prepareHandleAttachment() needs to be called before calling this to set the
+     * correct attachment ID.
+     */
     void slotHandleAttachment(int action);
     /** Copy the selected text to the clipboard */
     void slotCopySelectedText();
@@ -557,6 +568,7 @@ public Q_SLOTS:
     void slotResetMessageDisplayFormat();
 
     void slotGeneralFontChanged();
+    void slotShowDevelopmentTools();
 
 Q_SIGNALS:
     void showStatusBarMessage(const QString &message);
@@ -575,54 +587,58 @@ Q_SIGNALS:
     void moveMessageToTrash();
     void pageIsScrolledToBottom(bool);
     void printingFinished();
-private:
-    QString attachmentInjectionHtml();
-    QString recipientsQuickListLinkHtml(const QString &);
+    void zoomChanged(qreal zoomFactor);
+    void showNextMessage();
+    void showPreviousMessage();
 
-    Akonadi::Relation relatedNoteRelation() const;
-    void addHelpTextAction(QAction *act, const QString &text);
-    void readGravatarConfig();
+private:
+    Q_REQUIRED_RESULT QString attachmentHtml();
+    void initializeColorFromScheme();
 
     void replyMessageToAuthor(KMime::Content *atmNode);
     void replyMessageToAll(KMime::Content *atmNode);
-    bool urlIsAMalwareButContinue();
+    void replyMessage(KMime::Content *atmNode, bool replyToAll);
+    Q_REQUIRED_RESULT bool urlIsAMalwareButContinue();
+    Q_REQUIRED_RESULT bool messageIsInSpecialFolder() const;
 
     void slotCheckedUrlFinished(const QUrl &url, WebEngineViewer::CheckPhishingUrlUtil::UrlStatus status);
 
-    MimeTreeParser::NodeHelper *mNodeHelper = nullptr;
     void slotDelayPrintPreview();
+    void applyZoomValue(qreal factor, bool saveConfig = true);
+    void slotZoomChanged(qreal zoom);
+    void assignMessageItem(const Akonadi::Item &item);
+    void slotPdfPrintingFinished(const QString &filePath, bool success);
+    MimeTreeParser::NodeHelper *mNodeHelper = nullptr;
+    bool mHtmlMailGlobalSetting = false;
+    bool mHtmlLoadExternalDefaultSetting = false;
+    bool mHtmlLoadExtOverride = false;
+    void slotUrlBlocked(const QUrl &url);
+
 public:
-    bool mHtmlMailGlobalSetting;
-    bool mHtmlLoadExternalGlobalSetting;
-    bool mHtmlLoadExtOverride;
-    KMime::Message::Ptr mMessage; //the current message, if it was set manually
-    Akonadi::Item mMessageItem; //the message item from Akonadi
+    KMime::Message::Ptr mMessage; // the current message, if it was set manually
+    Akonadi::Item mMessageItem; // the message item from Akonadi
     // widgets:
     QSplitter *mSplitter = nullptr;
     QWidget *mBox = nullptr;
     HtmlStatusBar *mColorBar = nullptr;
-#ifndef QT_NO_TREEVIEW
     MimePartTreeView *mMimePartTree = nullptr;
-#endif
     MailWebEngineView *mViewer = nullptr;
     WebEngineViewer::FindBarWebEngineView *mFindBar = nullptr;
 
-    const MimeTreeParser::AttachmentStrategy *mAttachmentStrategy = nullptr;
+    const AttachmentStrategy *mAttachmentStrategy = nullptr;
     QTimer mUpdateReaderWinTimer;
     QTimer mResizeTimer;
     QString mOverrideEncoding;
     QString mOldGlobalOverrideEncoding; // used to detect changes of the global override character encoding
-    QString mPicsPath;
 
     /// This is true if the viewer currently is displaying a message. Can be false, for example when
     /// the splash/busy page is displayed.
-    bool mMsgDisplay;
+    bool mMsgDisplay = true;
 
-    CSSHelper *mCSSHelper = nullptr;
-    bool mUseFixedFont;
-    bool mPrinting;
+    bool mUseFixedFont = false;
+    bool mPrinting = false;
     QWidget *mMainWindow = nullptr;
-    KActionCollection *mActionCollection = nullptr;
+    KActionCollection *const mActionCollection;
     QAction *mCopyAction = nullptr;
     QAction *mCopyURLAction = nullptr;
     QAction *mUrlOpenAction = nullptr;
@@ -642,40 +658,43 @@ public:
     KToggleAction *mToggleFixFontAction = nullptr;
     KToggleAction *mToggleDisplayModeAction = nullptr;
     KToggleAction *mToggleMimePartTreeAction = nullptr;
+    QAction *mDevelopmentToolsAction = nullptr;
     QAction *mSpeakTextAction = nullptr;
     QAction *mCopyImageLocation = nullptr;
-    QUrl mHoveredUrl;
+    QAction *mShareTextAction = nullptr;
     QUrl mClickedUrl;
     QUrl mImageUrl;
-    QPoint mLastClickPosition;
-    bool mCanStartDrag;
-    MimeTreeParser::HtmlWriter *mHtmlWriter;
+    HtmlWriter *mHtmlWriter = nullptr;
     /** Used only to be able to connect and disconnect finished() signal
       in printMsg() and slotPrintMsg() since mHtmlWriter points only to abstract non-QObject class. */
     QPointer<WebEnginePartHtmlWriter> mPartHtmlWriter;
+    QPointer<WebEngineViewer::DeveloperToolDialog> mDeveloperToolDialog;
 
     int mLevelQuote;
-    bool mDecrytMessageOverwrite;
-    bool mShowSignatureDetails;
-    bool mShowAttachmentQuicklist;
-    bool mForceEmoticons;
-    int mRecursionCountForDisplayMessage;
+    bool mDecrytMessageOverwrite = false;
+    bool mShowSignatureDetails = false;
+    bool mShowEncryptionDetails = false;
+    bool mForceEmoticons = true;
+    int mRecursionCountForDisplayMessage = 0;
+    uint mFolderIdentity = 0;
     KMime::Content *mCurrentContent = nullptr;
     KMime::Content *mMessagePartNode = nullptr;
     QString mMessagePath;
 
     QColor mForegroundError;
     QColor mBackgroundError;
+    QColor mBackgroundAttachment;
 
     Viewer *const q;
     Akonadi::Session *mSession = nullptr;
     Akonadi::Monitor mMonitor;
     QSet<AbstractMessageLoadedHandler *> mMessageLoadedHandlers;
-    Akonadi::Item::Id mPreviouslyViewedItem;
+    Akonadi::Item::Id mPreviouslyViewedItemId = -1;
 
     MessageViewer::ScamDetectionWarningWidget *mScamDetectionWarning = nullptr;
-    MessageViewer::OpenAttachmentFolderWidget *mOpenAttachmentFolderWidget = nullptr;
-    MessageViewer::SubmittedFormWarningWidget *mSubmittedFormWarning = nullptr;
+    MessageViewer::OpenSavedFileFolderWidget *mOpenSavedFileFolderWidget = nullptr;
+    WebEngineViewer::SubmittedFormWarningWidget *mSubmittedFormWarning = nullptr;
+    WebEngineViewer::TrackingWarningWidget *mMailTrackingWarning = nullptr;
     KPIMTextEdit::TextToSpeechWidget *mTextToSpeechWidget = nullptr;
     Viewer::DisplayFormatMessage mDisplayFormatMessageOverwrite;
     KPIMTextEdit::SlideContainer *mSliderContainer = nullptr;
@@ -686,9 +705,14 @@ public:
     MessageViewer::ViewerPluginToolManager *mViewerPluginToolManager = nullptr;
     WebEngineViewer::ZoomActionMenu *mZoomActionMenu = nullptr;
     QPrinter *mCurrentPrinter = nullptr;
-    QList<QPointer<MessageViewer::MailSourceWebEngineViewer> > mListMailSourceViewer;
+    QVector<QPointer<MessageViewer::MailSourceWebEngineViewer>> mListMailSourceViewer;
     WebEngineViewer::LocalDataBaseManager *mPhishingDatabase = nullptr;
+    MessageViewer::ShowNextMessageWidget *mShowNextMessageWidget = nullptr;
+    MessageViewer::DKIMWidgetInfo *mDkimWidgetInfo = nullptr;
+    MessageViewer::DKIMViewerMenu *mDkimViewerMenu = nullptr;
+    MessageViewer::MessageViewerRenderer *mMessageViewerRenderer = nullptr;
+    KIdentityManagement::IdentityManager *mIdentityManager = nullptr;
+    RemoteContentMenu *mRemoteContentMenu = nullptr;
 };
 }
 
-#endif
