@@ -1,14 +1,14 @@
 /*
-  SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef VIEWERPURPOSEMENUWIDGET_H
-#define VIEWERPURPOSEMENUWIDGET_H
+#pragma once
 
 #include <PimCommon/PurposeMenuWidget>
-namespace MessageViewer {
+namespace MessageViewer
+{
 class MailWebEngineView;
 class MailfilterPurposeMenuWidget : public PimCommon::PurposeMenuWidget
 {
@@ -25,4 +25,3 @@ private:
 };
 }
 
-#endif
