@@ -1,23 +1,22 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef TESTMAILMBOXWEBENGINE_H
-#define TESTMAILMBOXWEBENGINE_H
+#pragma once
 
-#include <QWidget>
 #include <KMime/Message>
+#include <QWidget>
 
 class TestMailMBoxWebEngine : public QWidget
 {
     Q_OBJECT
 public:
     explicit TestMailMBoxWebEngine(QWidget *parent = nullptr);
-    ~TestMailMBoxWebEngine();
+    ~TestMailMBoxWebEngine() override;
+
 private:
     KMime::Message::Ptr readAndParseMail(const QString &mailFile);
 };
 
-#endif // TESTMAILMBOXWEBENGINE_H
