@@ -1,15 +1,15 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef TESTMAILWEBENGINESELECTION_H
-#define TESTMAILWEBENGINESELECTION_H
+#pragma once
 
 #include <QWidget>
 
-namespace MessageViewer {
+namespace MessageViewer
+{
 class MailWebEngineView;
 }
 
@@ -18,14 +18,14 @@ class TestMailWebEngineSelection : public QWidget
     Q_OBJECT
 public:
     explicit TestMailWebEngineSelection(QWidget *parent = nullptr);
-    ~TestMailWebEngineSelection();
+    ~TestMailWebEngineSelection() override;
 private Q_SLOTS:
     void slotOpenUrl(const QUrl &url);
     void slotSwitchHtml();
     void slotShowSelection();
+
 private:
     MessageViewer::MailWebEngineView *mTestWebEngine;
     int mNumber;
 };
 
-#endif // TESTMAILWEBENGINE_H
