@@ -1,13 +1,13 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef TESTWEBENGINEACCESSKEY_H
-#define TESTWEBENGINEACCESSKEY_H
+#pragma once
 
 #include <QWidget>
-namespace WebEngineViewer {
+namespace WebEngineViewer
+{
 class MailWebEngineView;
 }
 
@@ -30,7 +30,6 @@ private Q_SLOTS:
     void slotShowAccessKey();
 
 private:
-    WebEngineViewer::MailWebEngineView *mTestWebEngine;
+    WebEngineViewer::MailWebEngineView *mTestWebEngine = nullptr;
 };
 
-#endif // TESTWEBENGINEACCESSKEY_H
