@@ -1,14 +1,14 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef TESTWEBENGINESCROLLADDATTACHMENT_H
-#define TESTWEBENGINESCROLLADDATTACHMENT_H
+#pragma once
 
 #include <QWidget>
-namespace MessageViewer {
+namespace MessageViewer
+{
 class MailWebEngineView;
 }
 class TestWebEngineScrollAddAttachment : public QWidget
@@ -19,8 +19,8 @@ public:
 
 private Q_SLOTS:
     void slotScrollToAttachment();
+
 private:
     MessageViewer::MailWebEngineView *mTestWebEngine;
 };
 
-#endif // TESTWEBENGINESCROLLADDATTACHMENT_H
