@@ -1,19 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "viewerpluginmanager.h"
-#include "viewerplugin.h"
 #include "messageviewer_debug.h"
+#include "viewerplugin.h"
 
-#include <KSharedConfig>
-#include <KPluginMetaData>
-#include <KPluginLoader>
 #include <KPluginFactory>
+#include <KPluginMetaData>
+#include <KSharedConfig>
 #include <QFileInfo>
-#include <QSet>
 
 using namespace MessageViewer;
 
@@ -24,6 +22,7 @@ public:
     {
     }
 
+    KPluginMetaData data;
     QString metaDataFileNameBaseName;
     QString metaDataFileName;
     PimCommon::PluginUtilData pluginData;
@@ -50,13 +49,15 @@ public:
     QString configGroupName() const;
     QString configPrefixSettingKey() const;
     ViewerPlugin *pluginFromIdentifier(const QString &id);
+
 private:
     QVector<ViewerPluginInfo> mPluginList;
     QVector<PimCommon::PluginUtilData> mPluginDataList;
     ViewerPluginManager *const q;
 };
 
-namespace {
+namespace
+{
 QString pluginVersion()
 {
     return QStringLiteral("2.0");
@@ -82,45 +83,34 @@ bool ViewerPluginManagerPrivate::initializePluginList()
         return false;
     }
 
-    QVector<KPluginMetaData> plugins
-        = KPluginLoader::findPlugins(pluginDirectory);
+    QVector<KPluginMetaData> plugins = KPluginMetaData::findPlugins(pluginDirectory);
 
     // We need common plugin to avoid to duplicate code between akregator/kmail
-    plugins
-        += KPluginLoader::findPlugins(QStringLiteral("messageviewer/viewercommonplugin"));
+    plugins += KPluginMetaData::findPlugins(QStringLiteral("messageviewer/viewercommonplugin"));
 
-    const QPair<QStringList, QStringList> pair = PimCommon::PluginUtil::loadPluginSetting(
-        configGroupName(), configPrefixSettingKey());
+    const QPair<QStringList, QStringList> pair = PimCommon::PluginUtil::loadPluginSetting(configGroupName(), configPrefixSettingKey());
     QVectorIterator<KPluginMetaData> i(plugins);
     i.toBack();
-    QSet<QString> unique;
     while (i.hasPrevious()) {
         ViewerPluginInfo info;
 
         const KPluginMetaData data = i.previous();
 
-        //1) get plugin data => name/description etc.
+        // 1) get plugin data => name/description etc.
         info.pluginData = PimCommon::PluginUtil::createPluginMetaData(data);
-        //2) look at if plugin is activated
-        const bool isPluginActivated = PimCommon::PluginUtil::isPluginActivated(pair.first,
-                                                                                pair.second,
-                                                                                info.pluginData.mEnableByDefault,
-                                                                                info.pluginData.mIdentifier);
+        // 2) look at if plugin is activated
+        const bool isPluginActivated =
+            PimCommon::PluginUtil::isPluginActivated(pair.first, pair.second, info.pluginData.mEnableByDefault, info.pluginData.mIdentifier);
         info.isEnabled = isPluginActivated;
         info.metaDataFileNameBaseName = QFileInfo(data.fileName()).baseName();
         info.metaDataFileName = data.fileName();
+        info.data = data;
 
         if (pluginVersion() == data.version()) {
-            // only load plugins once, even if found multiple times!
-            if (unique.contains(info.metaDataFileNameBaseName)) {
-                continue;
-            }
             info.plugin = nullptr;
             mPluginList.push_back(info);
-            unique.insert(info.metaDataFileNameBaseName);
         } else {
-            qCWarning(MESSAGEVIEWER_LOG) << "Plugin name :" << data.name()
-                                         << " doesn't have correct plugin version. Please update it";
+            qCWarning(MESSAGEVIEWER_LOG) << "Plugin name :" << data.name() << " doesn't have correct plugin version. Please update it";
         }
     }
     QVector<ViewerPluginInfo>::iterator end(mPluginList.end());
@@ -132,11 +122,8 @@ bool ViewerPluginManagerPrivate::initializePluginList()
 
 void ViewerPluginManagerPrivate::loadPlugin(ViewerPluginInfo *item)
 {
-    KPluginLoader pluginLoader(item->metaDataFileName);
-    if (pluginLoader.factory()) {
-        item->plugin = pluginLoader.factory()->create<MessageViewer::ViewerPlugin>(q,
-                                                                                   QVariantList()
-                                                                                   << item->metaDataFileNameBaseName);
+    if (auto plugin = KPluginFactory::instantiatePlugin<MessageViewer::ViewerPlugin>(item->data, q, QVariantList() << item->metaDataFileName).plugin) {
+        item->plugin = plugin;
         item->plugin->setIsEnabled(item->isEnabled);
         item->pluginData.mHasConfigureDialog = item->plugin->hasConfigureDialog();
         mPluginDataList.append(item->pluginData);
@@ -177,10 +164,7 @@ ViewerPluginManager::ViewerPluginManager(QObject *parent)
 {
 }
 
-MessageViewer::ViewerPluginManager::~ViewerPluginManager()
-{
-    delete d;
-}
+MessageViewer::ViewerPluginManager::~ViewerPluginManager() = default;
 
 bool ViewerPluginManager::initializePluginList()
 {
@@ -237,4 +221,3 @@ QString ViewerPluginManager::pluginName() const
 {
     return d->pluginName;
 }
-
