@@ -2,14 +2,14 @@
     SPDX-License-Identifier: BSL-1.0
 */
 
-#ifndef MESSAGEVIEWER_INVITATIONSETTINGS_H
-#define MESSAGEVIEWER_INVITATIONSETTINGS_H
+#pragma once
 
 #include "messageviewer_export.h"
 
 #include <QWidget>
 
-namespace MessageViewer {
+namespace MessageViewer
+{
 class InvitationSettingsPrivate;
 /**
  * @brief The InvitationSettings class
@@ -19,7 +19,7 @@ class MESSAGEVIEWER_EXPORT InvitationSettings : public QWidget
     Q_OBJECT
 public:
     explicit InvitationSettings(QWidget *parent = nullptr);
-    ~InvitationSettings();
+    ~InvitationSettings() override;
     void save();
     Q_REQUIRED_RESULT QString helpAnchor() const;
     void doLoadFromGlobalSettings();
@@ -30,8 +30,7 @@ Q_SIGNALS:
 
 private:
     void slotLegacyBodyInvitesToggled(bool on);
-    InvitationSettingsPrivate *const d;
+    std::unique_ptr<InvitationSettingsPrivate> const d;
 };
 }
 
-#endif // MESSAGEVIEWER_INVITATIONSETTINGS_H
