@@ -1,40 +1,25 @@
 /*
-   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "mailsourcewebengineviewer.h"
 
 using namespace MessageViewer;
 
+#include "findbar/findbarsourceview.h"
 #include "mailsourceviewtextbrowserwidget.h"
 #include "messageviewer/messageviewerutil.h"
-#include "findbar/findbarsourceview.h"
-#include "kpimtextedit/slidecontainer.h"
+#include <KPIMTextEdit/SlideContainer>
 
-#include <KSyntaxHighlighting/SyntaxHighlighter>
 #include <KSyntaxHighlighting/Definition>
+#include <KSyntaxHighlighting/SyntaxHighlighter>
 #include <KSyntaxHighlighting/Theme>
 
-#include "PimCommon/PimUtil"
-#include <kiconloader.h>
 #include <KLocalizedString>
+#include <PimCommon/PimUtil>
 #include <QTabWidget>
-#include <QApplication>
 
 #include <KConfigGroup>
 #include <QShortcut>
@@ -46,12 +31,15 @@ using namespace MessageViewer;
 #include <QWebEnginePage>
 
 using namespace MessageViewer;
-
+namespace
+{
+static const char myMailSourceWebEngineViewerConfigGroupName[] = "MailSourceWebEngineViewer";
+}
 MailSourceWebEngineViewer::MailSourceWebEngineViewer(QWidget *parent)
     : QDialog(parent)
 {
     setAttribute(Qt::WA_DeleteOnClose);
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     mRawBrowser = new MailSourceViewTextBrowserWidget(QStringLiteral("Email"), this);
 #ifndef NDEBUG
     mShowHtmlSource = true;
@@ -62,9 +50,7 @@ MailSourceWebEngineViewer::MailSourceWebEngineViewer(QWidget *parent)
         mainLayout->addWidget(mTabWidget);
 
         mTabWidget->addTab(mRawBrowser, i18nc("Unchanged mail message", "Raw Source"));
-        mTabWidget->setTabToolTip(0,
-                                  i18n(
-                                      "Raw, unmodified mail as it is stored on the filesystem or on the server"));
+        mTabWidget->setTabToolTip(0, i18n("Raw, unmodified mail as it is stored on the filesystem or on the server"));
 
         mHtmlBrowser = new MailSourceViewTextBrowserWidget(QStringLiteral("HTML"), this);
         mTabWidget->addTab(mHtmlBrowser, i18nc("Mail message as shown, in HTML format", "HTML Source"));
@@ -76,19 +62,17 @@ MailSourceWebEngineViewer::MailSourceWebEngineViewer(QWidget *parent)
     }
 
     // combining the shortcuts in one qkeysequence() did not work...
-    QShortcut *shortcut = new QShortcut(this);
+    auto shortcut = new QShortcut(this);
     shortcut->setKey(Qt::Key_Escape);
     connect(shortcut, &QShortcut::activated, this, &MailSourceWebEngineViewer::close);
     shortcut = new QShortcut(this);
-    shortcut->setKey(Qt::Key_W + Qt::CTRL);
+    shortcut->setKey(Qt::Key_W | Qt::CTRL);
     connect(shortcut, &QShortcut::activated, this, &MailSourceWebEngineViewer::close);
 
     mRawBrowser->textBrowser()->setFocus();
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &MailSourceWebEngineViewer::reject);
-    connect(buttonBox->button(
-                QDialogButtonBox::Close), &QPushButton::clicked, this,
-            &MailSourceWebEngineViewer::close);
+    connect(buttonBox->button(QDialogButtonBox::Close), &QPushButton::clicked, this, &MailSourceWebEngineViewer::close);
 
     mainLayout->addWidget(buttonBox);
     readConfig();
@@ -101,7 +85,7 @@ MailSourceWebEngineViewer::~MailSourceWebEngineViewer()
 
 void MailSourceWebEngineViewer::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "MailSourceWebEngineViewer");
+    KConfigGroup group(KSharedConfig::openStateConfig(), myMailSourceWebEngineViewerConfigGroupName);
     const QSize size = group.readEntry("Size", QSize(600, 400));
     if (size.isValid()) {
         resize(size);
@@ -110,7 +94,7 @@ void MailSourceWebEngineViewer::readConfig()
 
 void MailSourceWebEngineViewer::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "MailSourceWebEngineViewer");
+    KConfigGroup group(KSharedConfig::openStateConfig(), myMailSourceWebEngineViewerConfigGroupName);
     group.writeEntry("Size", size());
     group.sync();
 }
