@@ -1,26 +1,27 @@
 /* This file is part of the KDE project
    SPDX-FileCopyrightText: 2002 Daniel Molkentin <molkentin@kde.org>
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef MESSAGEVIEWER_VCARDVIEWER_H
-#define MESSAGEVIEWER_VCARDVIEWER_H
+#pragma once
+#include <KContacts/Addressee>
 #include <QDialog>
-#include <kcontacts/addressee.h>
 
-namespace KAddressBookGrantlee {
+namespace KAddressBookGrantlee
+{
 class GrantleeContactViewer;
 }
 class QPushButton;
-namespace MessageViewer {
+namespace MessageViewer
+{
 class VCardViewer : public QDialog
 {
     Q_OBJECT
 public:
     explicit VCardViewer(QWidget *parent, const QByteArray &vCard);
-    ~VCardViewer();
+    ~VCardViewer() override;
 
 private:
     void slotUser1();
@@ -31,10 +32,9 @@ private:
 
     KContacts::Addressee::List mAddresseeList;
     int mAddresseeListIndex = 0;
-    KAddressBookGrantlee::GrantleeContactViewer *mContactViewer = nullptr;
-    QPushButton *mUser2Button = nullptr;
-    QPushButton *mUser3Button = nullptr;
+    KAddressBookGrantlee::GrantleeContactViewer *const mContactViewer;
+    QPushButton *const mUser2Button;
+    QPushButton *const mUser3Button;
 };
 }
 
-#endif // VCARDVIEWER_H
