@@ -4,20 +4,20 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MIMETREEPARSER_BODYFORAMATTER_APPLICATIONPGPENCRYPTED_H
-#define MIMETREEPARSER_BODYFORAMATTER_APPLICATIONPGPENCRYPTED_H
+#pragma once
 
-#include "interfaces/bodypartformatter.h"
 #include "interfaces/bodypart.h"
+#include "interfaces/bodypartformatter.h"
 
-namespace MimeTreeParser {
+namespace MimeTreeParser
+{
 class ApplicationPGPEncryptedBodyPartFormatter : public Interface::BodyPartFormatter
 {
     static const ApplicationPGPEncryptedBodyPartFormatter *self;
+
 public:
     MessagePartPtr process(Interface::BodyPart &part) const override;
     static const Interface::BodyPartFormatter *create();
 };
 }
 
-#endif
