@@ -1,33 +1,20 @@
 /*
-   Copyright (c) 2017 Sandro Knauß <sknauss@kde.org>
+   SPDX-FileCopyrightText: 2017 Sandro Knauß <sknauss@kde.org>
 
-   This library is free software; you can redistribute it and/or modify it
-   under the terms of the GNU Library General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or (at your
-   option) any later version.
-
-   This library is distributed in the hope that it will be useful, but WITHOUT
-   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-   License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to the
-   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-   02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "encrypted.h"
 
 #include "utils.h"
 
-#include "objecttreeparser.h"
 #include "messagepart.h"
+#include "objecttreeparser.h"
 
 #include <KMime/Content>
 
-#include <QGpgME/Protocol>
 #include <QGpgME/DataProvider>
+#include <QGpgME/Protocol>
 #include <gpgme++/data.h>
 
 #include <QTextCodec>
@@ -66,18 +53,17 @@ MessagePart::Ptr EncryptedBodyPartFormatter::process(Interface::BodyPart &part)
 
     useThisCryptProto = QGpgME::openpgp();
 
-    //TODO: Load correct crypto Proto
+    // TODO: Load correct crypto Proto
 
     part.nodeHelper()->setEncryptionState(node, KMMsgFullyEncrypted);
 
-    EncryptedMessagePart::Ptr mp(new EncryptedMessagePart(part.objectTreeParser(),
-                                                          node->decodedText(), useThisCryptProto,
-                                                          part.nodeHelper()->fromAsString(node), node));
+    EncryptedMessagePart::Ptr mp(
+        new EncryptedMessagePart(part.objectTreeParser(), node->decodedText(), useThisCryptProto, part.nodeHelper()->fromAsString(node), node));
     mp->setIsEncrypted(true);
     mp->setDecryptMessage(part.source()->decryptMessage());
     PartMetaData *messagePart(mp->partMetaData());
     if (!part.source()->decryptMessage()) {
-        part.nodeHelper()->setNodeProcessed(node, false);  // Set the data node to done to prevent it from being processed
+        part.nodeHelper()->setNodeProcessed(node, false); // Set the data node to done to prevent it from being processed
     } else if (KMime::Content *newNode = part.nodeHelper()->decryptedNodeForContent(node)) {
         // if we already have a decrypted node for part.objectTreeParser() encrypted node, don't do the decryption again
         return MessagePart::Ptr(new MimeMessagePart(part.objectTreeParser(), newNode, true));
@@ -98,9 +84,9 @@ MessagePart::Ptr EncryptedBodyPartFormatter::process(Interface::BodyPart &part)
             NodeHelper::magicSetType(tempNode);
             if (node->topLevel()->textContent() != node && node->contentDisposition(false) && !tempNode->contentDisposition(false)) {
                 tempNode->contentDisposition()->setDisposition(node->contentDisposition()->disposition());
-                const auto fname = node->contentDisposition()->filename();
+                const auto fname = node->contentDisposition(false)->filename();
                 if (!fname.isEmpty()) {
-                    tempNode->contentDisposition()->setFilename(fname);
+                    tempNode->contentDisposition(false)->setFilename(fname);
                 }
             }
 
@@ -116,7 +102,7 @@ MessagePart::Ptr EncryptedBodyPartFormatter::process(Interface::BodyPart &part)
 
             mp->parseInternal(tempNode, false);
 
-            part.nodeHelper()->setNodeProcessed(node, false);   // Set the data node to done to prevent it from being processed
+            part.nodeHelper()->setNodeProcessed(node, false); // Set the data node to done to prevent it from being processed
         }
     }
     return mp;
