@@ -4,15 +4,15 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MIMETREEPARSER_BODYFORAMATTER_UTILS_H
-#define MIMETREEPARSER_BODYFORAMATTER_UTILS_H
+#pragma once
 
 #include "interfaces/bodypart.h"
 #include "messagepart.h"
 
 #include <KMime/Content>
 
-namespace MimeTreeParser {
+namespace MimeTreeParser
+{
 /**
   1. Create a new partNode using 'content' data and Content-Description
      found in 'cntDesc'.
@@ -25,4 +25,3 @@ KMime::Content *findTypeInDirectChilds(KMime::Content *content, const QByteArray
 MessagePart::Ptr toplevelTextNode(MessagePart::Ptr messageTree);
 }
 
-#endif
