@@ -13,11 +13,11 @@
 #include "interfaces/bodypartformatter.h"
 #include "mimetreeparser_debug.h"
 
-#include <KPluginLoader>
-
-#include <QMimeDatabase>
+#include <KPluginMetaData>
 #include <QJsonArray>
+#include <QMimeDatabase>
 
+#include <QPluginLoader>
 #include <assert.h>
 
 using namespace MimeTreeParser;
@@ -29,7 +29,7 @@ BodyPartFormatterFactoryPrivate::BodyPartFormatterFactoryPrivate(BodyPartFormatt
 
 BodyPartFormatterFactoryPrivate::~BodyPartFormatterFactoryPrivate()
 {
-    QHashIterator<QString, std::vector<FormatterInfo> > i(registry);
+    QHashIterator<QString, std::vector<FormatterInfo>> i(registry);
     while (i.hasNext()) {
         i.next();
         auto formatterInfo = i.value();
@@ -81,10 +81,7 @@ BodyPartFormatterFactory::BodyPartFormatterFactory()
 {
 }
 
-BodyPartFormatterFactory::~BodyPartFormatterFactory()
-{
-    delete d;
-}
+BodyPartFormatterFactory::~BodyPartFormatterFactory() = default;
 
 BodyPartFormatterFactory *BodyPartFormatterFactory::instance()
 {
@@ -140,16 +137,16 @@ QVector<const Interface::BodyPartFormatter *> BodyPartFormatterFactory::formatte
 
 void BodyPartFormatterFactory::loadPlugins()
 {
-    KPluginLoader::forEachPlugin(QStringLiteral("messageviewer/bodypartformatter"), [this](const QString &path) {
-        QPluginLoader loader(path);
-        const auto formatterData = loader.metaData().value(QLatin1String("MetaData")).toObject().value(QLatin1String("formatter")).toArray();
+    const QVector<KPluginMetaData> plugins = KPluginMetaData::findPlugins(QStringLiteral("messageviewer/bodypartformatter"));
+    for (const auto &md : plugins) {
+        const auto formatterData = md.rawData().value(QLatin1String("formatter")).toArray();
         if (formatterData.isEmpty()) {
-            return;
+            continue;
         }
-
+        QPluginLoader loader(md.fileName());
         auto plugin = qobject_cast<MimeTreeParser::Interface::BodyPartFormatterPlugin *>(loader.instance());
         if (!plugin) {
-            return;
+            continue;
         }
 
         const MimeTreeParser::Interface::BodyPartFormatter *bfp = nullptr;
@@ -157,9 +154,7 @@ void BodyPartFormatterFactory::loadPlugins()
             const auto metaData = formatterData.at(i).toObject();
             const auto mimetype = metaData.value(QLatin1String("mimetype")).toString();
             if (mimetype.isEmpty()) {
-                qCWarning(MIMETREEPARSER_LOG) << "BodyPartFormatterFactory: plugin" << path
-                                              << "returned empty mimetype specification for index"
-                                              << i;
+                qCWarning(MIMETREEPARSER_LOG) << "BodyPartFormatterFactory: plugin" << md.fileName() << "returned empty mimetype specification for index" << i;
                 break;
             }
             // priority should always be higher than the built-in ones, otherwise what's the point?
@@ -167,5 +162,5 @@ void BodyPartFormatterFactory::loadPlugins()
             qCDebug(MIMETREEPARSER_LOG) << "plugin for " << mimetype << priority;
             insert(mimetype, bfp, priority);
         }
-    });
+    }
 }
