@@ -8,13 +8,13 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MIMETREEPARSER_BODYPARTFORMATTERFACTORY_P_H
-#define MIMETREEPARSER_BODYPARTFORMATTERFACTORY_P_H
+#pragma once
 
 #include <QHash>
 #include <vector>
 
-namespace MimeTreeParser {
+namespace MimeTreeParser
+{
 class BodyPartFormatterFactory;
 
 class BodyPartFormatterFactoryPrivate
@@ -24,7 +24,7 @@ public:
     ~BodyPartFormatterFactoryPrivate();
 
     void setup();
-    void messageviewer_create_builtin_bodypart_formatters();        //defined in bodypartformatter.cpp
+    void messageviewer_create_builtin_bodypart_formatters(); // defined in bodypartformatter.cpp
     void insert(const QString &mimeType, const Interface::BodyPartFormatter *formatter, int priority = 0);
     void appendFormattersForType(const QString &mimeType, QVector<const Interface::BodyPartFormatter *> &formatters);
 
@@ -33,8 +33,7 @@ public:
         const Interface::BodyPartFormatter *formatter = nullptr;
         int priority = 0;
     };
-    QHash<QString, std::vector<FormatterInfo> > registry;
+    QHash<QString, std::vector<FormatterInfo>> registry;
 };
 }
 
-#endif // MIMETREEPARSER_BODYPARTFORMATTERFACTORY_P_H
