@@ -13,14 +13,15 @@ using namespace MimeTreeParser;
 PGPBlockType Block::determineType() const
 {
     const QByteArray data = text();
-    if (data.startsWith("-----BEGIN PGP SIGNED")) {
+    if (data.startsWith("-----BEGIN PGP PUBLIC KEY BLOCK-----")) {
+        return NoPgpBlock;
+    } else if (data.startsWith("-----BEGIN PGP SIGNED")) {
         return ClearsignedBlock;
     } else if (data.startsWith("-----BEGIN PGP SIGNATURE")) {
         return SignatureBlock;
     } else if (data.startsWith("-----BEGIN PGP PUBLIC")) {
         return PublicKeyBlock;
-    } else if (data.startsWith("-----BEGIN PGP PRIVATE")
-               || data.startsWith("-----BEGIN PGP SECRET")) {
+    } else if (data.startsWith("-----BEGIN PGP PRIVATE") || data.startsWith("-----BEGIN PGP SECRET")) {
         return PrivateKeyBlock;
     } else if (data.startsWith("-----BEGIN PGP MESSAGE")) {
         if (data.startsWith("-----BEGIN PGP MESSAGE PART")) {
@@ -41,13 +42,16 @@ QVector<Block> MimeTreeParser::prepareMessageForDecryption(const QByteArray &msg
 {
     PGPBlockType pgpBlock = NoPgpBlock;
     QVector<Block> blocks;
-    int start = -1;   // start of the current PGP block
+    int start = -1; // start of the current PGP block
     int lastEnd = -1; // end of the last PGP block
     const int length = msg.length();
 
     if (msg.isEmpty()) {
         return blocks;
     }
+    if (msg.startsWith("-----BEGIN PGP PUBLIC KEY BLOCK-----")) {
+        return blocks;
+    }
 
     if (msg.startsWith("-----BEGIN PGP ")) {
         start = 0;
@@ -60,7 +64,8 @@ QVector<Block> MimeTreeParser::prepareMessageForDecryption(const QByteArray &msg
     }
 
     while (start != -1) {
-        int nextEnd, nextStart;
+        int nextEnd;
+        int nextStart;
 
         // is the PGP block a clearsigned block?
         if (!strncmp(msg.constData() + start + 15, "SIGNED", 6)) {
@@ -72,7 +77,7 @@ QVector<Block> MimeTreeParser::prepareMessageForDecryption(const QByteArray &msg
         nextEnd = msg.indexOf("\n-----END PGP ", start + 15);
         nextStart = msg.indexOf("\n-----BEGIN PGP ", start + 15);
 
-        if (nextEnd == -1) {        // Missing END PGP line
+        if (nextEnd == -1) { // Missing END PGP line
             if (lastEnd != -1) {
                 blocks.append(Block(msg.mid(lastEnd + 1), UnknownBlock));
             } else {
@@ -107,7 +112,7 @@ QVector<Block> MimeTreeParser::prepareMessageForDecryption(const QByteArray &msg
 
         if (start == -1) {
             if (lastEnd + 1 < length) {
-                //rest of mail is no PGP Block
+                // rest of mail is no PGP Block
                 blocks.append(Block(msg.mid(lastEnd + 1), NoPgpBlock));
             }
             break;
