@@ -4,8 +4,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MIMETREEPARSER_QGPGMEJOBEXECUTOR_H
-#define MIMETREEPARSER_QGPGMEJOBEXECUTOR_H
+#pragma once
 
 #include <gpgme++/decryptionresult.h>
 #include <gpgme++/importresult.h>
@@ -17,14 +16,16 @@
 
 class QEventLoop;
 
-namespace QGpgME {
+namespace QGpgME
+{
 class DecryptVerifyJob;
 class ImportJob;
 class VerifyDetachedJob;
 class VerifyOpaqueJob;
 }
 
-namespace MimeTreeParser {
+namespace MimeTreeParser
+{
 /**
   Helper class for synchronous execution of Kleo crypto jobs.
 */
@@ -49,7 +50,7 @@ private Q_SLOTS:
     void importResult(const GpgME::ImportResult &result);
 
 private:
-    QEventLoop *mEventLoop = nullptr;
+    QEventLoop *const mEventLoop;
     GpgME::VerificationResult mVerificationResult;
     GpgME::DecryptionResult mDecryptResult;
     GpgME::ImportResult mImportResult;
@@ -59,4 +60,3 @@ private:
 };
 }
 
-#endif
