@@ -1,21 +1,21 @@
 /*
-  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MIMETREEPARSER_CRYPTOBODYPARTMEMENTO_H
-#define MIMETREEPARSER_CRYPTOBODYPARTMEMENTO_H
+#pragma once
 
 #include <gpgme++/error.h>
 
 #include <QObject>
 #include <QString>
 
-#include "interfaces/bodypart.h"
 #include "enums.h"
+#include "interfaces/bodypart.h"
 
-namespace MimeTreeParser {
+namespace MimeTreeParser
+{
 class CryptoBodyPartMemento : public QObject, public Interface::BodyPartMemento
 {
     Q_OBJECT
@@ -32,7 +32,7 @@ public:
         return m_auditLog;
     }
 
-    GpgME::Error auditLogError() const
+    Q_REQUIRED_RESULT GpgME::Error auditLogError() const
     {
         return m_auditLogError;
     }
@@ -53,9 +53,8 @@ protected:
     void setRunning(bool running);
 
 private:
-    bool m_running;
+    bool m_running = false;
     QString m_auditLog;
     GpgME::Error m_auditLogError;
 };
 }
-#endif // MIMETREEPARSER_CRYPTOBODYPARTMEMENTO_H
