@@ -1,26 +1,27 @@
 /*
-  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MIMETREEPARSER_DECRYPTVERIFYBODYPARTMEMENTO_H
-#define MIMETREEPARSER_DECRYPTVERIFYBODYPARTMEMENTO_H
+#pragma once
 
 #include "cryptobodypartmemento.h"
 
-#include <gpgme++/verificationresult.h>
 #include <gpgme++/decryptionresult.h>
+#include <gpgme++/verificationresult.h>
 
 #include <QPointer>
 
 #include "interfaces/bodypart.h"
 
-namespace QGpgME {
+namespace QGpgME
+{
 class DecryptVerifyJob;
 }
 
-namespace MimeTreeParser {
+namespace MimeTreeParser
+{
 class DecryptVerifyBodyPartMemento : public CryptoBodyPartMemento
 {
     Q_OBJECT
@@ -28,7 +29,7 @@ public:
     explicit DecryptVerifyBodyPartMemento(QGpgME::DecryptVerifyJob *job, const QByteArray &cipherText);
     ~DecryptVerifyBodyPartMemento() override;
 
-    bool start() override;
+    Q_REQUIRED_RESULT bool start() override;
     void exec() override;
 
     const QByteArray &plainText() const
@@ -51,6 +52,7 @@ private Q_SLOTS:
 
 private:
     void saveResult(const GpgME::DecryptionResult &, const GpgME::VerificationResult &, const QByteArray &);
+
 private:
     // input:
     const QByteArray m_cipherText;
@@ -61,4 +63,3 @@ private:
     QByteArray m_plainText;
 };
 }
-#endif // MIMETREEPARSER_DECRYPTVERIFYBODYPARTMEMENTO_H
