@@ -1,31 +1,17 @@
 /*
-  Copyright (c) 2014-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "verifyopaquebodypartmemento.h"
 #include "mimetreeparser_debug.h"
 
-#include <QGpgME/VerifyOpaqueJob>
 #include <QGpgME/KeyListJob>
+#include <QGpgME/VerifyOpaqueJob>
 
 #include <gpgme++/keylistresult.h>
 
-#include <QStringList>
-
 #include <cassert>
 
 using namespace QGpgME;
@@ -64,8 +50,7 @@ bool VerifyOpaqueBodyPartMemento::start()
 #endif
         return false;
     }
-    connect(m_job.data(), &VerifyOpaqueJob::result,
-            this, &VerifyOpaqueBodyPartMemento::slotResult);
+    connect(m_job.data(), &VerifyOpaqueJob::result, this, &VerifyOpaqueBodyPartMemento::slotResult);
     setRunning(true);
     return true;
 }
@@ -86,13 +71,13 @@ void VerifyOpaqueBodyPartMemento::exec()
     m_job = nullptr;
     if (canStartKeyListJob()) {
         std::vector<GpgME::Key> keys;
-        m_keylistjob->exec(keyListPattern(), /*secretOnly=*/ false, keys);
+        m_keylistjob->exec(keyListPattern(), /*secretOnly=*/false, keys);
         if (!keys.empty()) {
             m_key = keys.back();
         }
     }
     if (m_keylistjob) {
-        m_keylistjob->deleteLater();    // exec'ed jobs don't delete themselves
+        m_keylistjob->deleteLater(); // exec'ed jobs don't delete themselves
     }
     m_keylistjob = nullptr;
     setRunning(false);
@@ -152,8 +137,7 @@ bool VerifyOpaqueBodyPartMemento::startKeyListJob()
         return false;
     }
     connect(m_keylistjob.data(), &Job::done, this, &VerifyOpaqueBodyPartMemento::slotKeyListJobDone);
-    connect(m_keylistjob.data(), &KeyListJob::nextKey,
-            this, &VerifyOpaqueBodyPartMemento::slotNextKey);
+    connect(m_keylistjob.data(), &KeyListJob::nextKey, this, &VerifyOpaqueBodyPartMemento::slotNextKey);
     return true;
 }
 
