@@ -1,42 +1,31 @@
 /*
-  Copyright (c) 2014-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MIMETREEPARSER_VERIFYOPAQUEBODYPARTMEMENTO_H
-#define MIMETREEPARSER_VERIFYOPAQUEBODYPARTMEMENTO_H
+#pragma once
 
 #include "cryptobodypartmemento.h"
-#include <gpgme++/verificationresult.h>
 #include <gpgme++/decryptionresult.h>
 #include <gpgme++/key.h>
+#include <gpgme++/verificationresult.h>
 
-#include <QString>
 #include <QPointer>
+#include <QString>
 
 #include "interfaces/bodypart.h"
 
-namespace QGpgME {
+namespace QGpgME
+{
 class VerifyOpaqueJob;
 class KeyListJob;
 }
 
-class QStringList;
+#include <QStringList>
 
-namespace MimeTreeParser {
+namespace MimeTreeParser
+{
 class VerifyOpaqueBodyPartMemento : public CryptoBodyPartMemento
 {
     Q_OBJECT
@@ -72,6 +61,7 @@ private:
     bool canStartKeyListJob() const;
     QStringList keyListPattern() const;
     bool startKeyListJob();
+
 private:
     // input:
     const QByteArray m_signature;
@@ -84,4 +74,3 @@ private:
 };
 }
 
-#endif // MIMETREEPARSER_VERIFYOPAQUEBODYPARTMEMENTO_H
