@@ -1,40 +1,27 @@
 /*
-   Copyright (c) 2015 Sandro Knauß <sknauss@kde.org>
+   SPDX-FileCopyrightText: 2015 Sandro Knauß <sknauss@kde.org>
 
-   This library is free software; you can redistribute it and/or modify it
-   under the terms of the GNU Library General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or (at your
-   option) any later version.
-
-   This library is distributed in the hope that it will be useful, but WITHOUT
-   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-   License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to the
-   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-   02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "messagepart.h"
-#include "mimetreeparser_debug.h"
 #include "cryptohelper.h"
-#include "objecttreeparser.h"
 #include "job/qgpgmejobexecutor.h"
 #include "memento/cryptobodypartmemento.h"
 #include "memento/decryptverifybodypartmemento.h"
 #include "memento/verifydetachedbodypartmemento.h"
 #include "memento/verifyopaquebodypartmemento.h"
+#include "mimetreeparser_debug.h"
+#include "objecttreeparser.h"
 
 #include "bodyformatter/utils.h"
 
 #include <KMime/Content>
 
 #include <QGpgME/DN>
-#include <QGpgME/Protocol>
 #include <QGpgME/ImportJob>
 #include <QGpgME/KeyListJob>
+#include <QGpgME/Protocol>
 #include <QGpgME/VerifyDetachedJob>
 #include <QGpgME/VerifyOpaqueJob>
 
@@ -50,7 +37,8 @@
 using namespace MimeTreeParser;
 
 //------MessagePart-----------------------
-namespace MimeTreeParser {
+namespace MimeTreeParser
+{
 class MessagePartPrivate
 {
 public:
@@ -153,8 +141,8 @@ QString MessagePart::makeLink(const QString &path) const
         return {};
     }
     return QStringLiteral("x-kmail:/bodypart/%1/%2/%3")
-           .arg(serial++).arg(content()->index().toString())
-           .arg(QString::fromLatin1(QUrl::toPercentEncoding(path, "/")));
+        .arg(serial++)
+        .arg(content()->index().toString(), QString::fromLatin1(QUrl::toPercentEncoding(path, "/")));
 }
 
 void MessagePart::setIsRoot(bool root)
@@ -198,7 +186,8 @@ void MessagePart::parseInternal(KMime::Content *node, bool onlyOneMimePart)
 {
     auto subMessagePart = mOtp->parseObjectTreeInternal(node, onlyOneMimePart);
     d->mRoot = subMessagePart->isRoot();
-    foreach (const auto &part, subMessagePart->subParts()) {
+    const QVector<MessagePart::Ptr> subParts = subMessagePart->subParts();
+    for (const auto &part : subParts) {
         appendSubPart(part);
     }
 }
@@ -206,7 +195,8 @@ void MessagePart::parseInternal(KMime::Content *node, bool onlyOneMimePart)
 QString MessagePart::renderInternalText() const
 {
     QString text;
-    foreach (const auto &mp, subParts()) {
+    const auto subPartsLst = subParts();
+    for (const auto &mp : subPartsLst) {
         text += mp->text();
     }
     return text;
@@ -214,7 +204,8 @@ QString MessagePart::renderInternalText() const
 
 void MessagePart::fix() const
 {
-    foreach (const auto &mp, subParts()) {
+    const auto subPartsLst = subParts();
+    for (const auto &mp : subPartsLst) {
         const auto m = mp.dynamicCast<MessagePart>();
         if (m) {
             m->fix();
@@ -263,18 +254,24 @@ void MessagePart::setIsImage(bool image)
     d->mIsImage = image;
 }
 
-bool MessagePart::hasHeader(const char *header) const
+bool MessagePart::hasHeader(const char *headerType) const
 {
-    Q_UNUSED(header);
+    Q_UNUSED(headerType)
     return false;
 }
 
-KMime::Headers::Base *MimeTreeParser::MessagePart::header(const char *header) const
+const KMime::Headers::Base *MimeTreeParser::MessagePart::header(const char *headerType) const
 {
-    Q_UNUSED(header);
+    Q_UNUSED(headerType)
     return nullptr;
 }
 
+QVector<KMime::Headers::Base *> MessagePart::headers(const char *headerType) const
+{
+    Q_UNUSED(headerType)
+    return QVector<KMime::Headers::Base *>();
+}
+
 //-----MessagePartList----------------------
 MessagePartList::MessagePartList(ObjectTreeParser *otp)
     : MessagePart(otp, QString())
@@ -340,7 +337,7 @@ void TextMessagePart::parseContent()
          * if one unencrypted part is at the beginning or in the middle
          * because mailmain adds an unencrypted part at the end this should not break the overall status
          *
-         * That's why we first set the tmp status and if one crypted/signed block comes afterwards, than
+         * That's why we first set the tmp status and if one encrypted/signed block comes afterwards, than
          * the status is set to unencrypted
          */
         bool fullySignedOrEncrypted = true;
@@ -394,7 +391,7 @@ void TextMessagePart::parseContent()
             }
         }
 
-        //Do we have an fully Signed/Encrypted Message?
+        // Do we have an fully Signed/Encrypted Message?
         if (fullySignedOrEncrypted) {
             if (mSignatureState == KMMsgPartiallySigned) {
                 mSignatureState = KMMsgFullySigned;
@@ -701,7 +698,11 @@ const GpgME::ImportResult &CertMessagePart::importResult() const
 }
 
 //-----SignedMessageBlock---------------------
-SignedMessagePart::SignedMessagePart(ObjectTreeParser *otp, const QString &text, const QGpgME::Protocol *cryptoProto, const QString &fromAddress, KMime::Content *node)
+SignedMessagePart::SignedMessagePart(ObjectTreeParser *otp,
+                                     const QString &text,
+                                     const QGpgME::Protocol *cryptoProto,
+                                     const QString &fromAddress,
+                                     KMime::Content *node)
     : MessagePart(otp, text)
     , mCryptoProto(cryptoProto)
     , mFromAddress(fromAddress)
@@ -752,8 +753,8 @@ bool SignedMessagePart::okVerify(const QByteArray &data, const QByteArray &signa
 
     const QByteArray _mementoName = mementoName();
 
-    CryptoBodyPartMemento *m = dynamic_cast<CryptoBodyPartMemento *>(nodeHelper->bodyPartMemento(content(), _mementoName));
-    Q_ASSERT(!m || mCryptoProto); //No CryptoPlugin and having a bodyPartMemento -> there is something completely wrong
+    auto m = dynamic_cast<CryptoBodyPartMemento *>(nodeHelper->bodyPartMemento(content(), _mementoName));
+    Q_ASSERT(!m || mCryptoProto); // No CryptoPlugin and having a bodyPartMemento -> there is something completely wrong
 
     if (!m && mCryptoProto) {
         if (!signature.isEmpty()) {
@@ -769,8 +770,7 @@ bool SignedMessagePart::okVerify(const QByteArray &data, const QByteArray &signa
         }
         if (m) {
             if (mOtp->allowAsync()) {
-                QObject::connect(m, &CryptoBodyPartMemento::update,
-                                 nodeHelper, &NodeHelper::update);
+                QObject::connect(m, &CryptoBodyPartMemento::update, nodeHelper, &NodeHelper::update);
                 if (m->start()) {
                     partMetaData()->inProgress = true;
                     mOtp->mHasPendingAsyncJobs = true;
@@ -808,19 +808,17 @@ bool SignedMessagePart::okVerify(const QByteArray &data, const QByteArray &signa
             if (cryptPlugDisplayName.isEmpty()) {
                 errorMsg = i18n("No appropriate crypto plug-in was found.");
             } else {
-                errorMsg = i18nc("%1 is either 'OpenPGP' or 'S/MIME'",
-                                 "No %1 plug-in was found.",
-                                 cryptPlugDisplayName);
+                errorMsg = i18nc("%1 is either 'OpenPGP' or 'S/MIME'", "No %1 plug-in was found.", cryptPlugDisplayName);
             }
         } else {
-            errorMsg = i18n("Crypto plug-in \"%1\" cannot verify signatures.",
-                            cryptPlugLibName);
+            errorMsg = i18n("Crypto plug-in \"%1\" cannot verify signatures.", cryptPlugLibName);
         }
-        partMetaData()->errorText = i18n("The message is signed, but the "
-                                         "validity of the signature cannot be "
-                                         "verified.<br />"
-                                         "Reason: %1",
-                                         errorMsg);
+        partMetaData()->errorText = i18n(
+            "The message is signed, but the "
+            "validity of the signature cannot be "
+            "verified.<br />"
+            "Reason: %1",
+            errorMsg);
     }
 
     return partMetaData()->isSigned;
@@ -864,7 +862,7 @@ void SignedMessagePart::sigStatusToMetaData()
         if (partMetaData()->isGoodSignature && !key.keyID()) {
             // Search for the key by its fingerprint so that we can check for
             // trust etc.
-            QGpgME::KeyListJob *job = mCryptoProto->keyListJob(false, false, false);    // local, no sigs
+            QGpgME::KeyListJob *job = mCryptoProto->keyListJob(false, false, false); // local, no sigs
             if (!job) {
                 qCDebug(MIMETREEPARSER_LOG) << "The Crypto backend does not support listing keys. ";
             } else {
@@ -952,9 +950,7 @@ void SignedMessagePart::startVerificationDetached(const QByteArray &text, KMime:
         parseInternal(textNode, false);
     }
 
-    okVerify(text, signature, textNode);
-
-    if (!partMetaData()->isSigned) {
+    if (!okVerify(text, signature, textNode)) {
         partMetaData()->creationTime = QDateTime();
     }
 }
@@ -1037,26 +1033,36 @@ QString SignedMessagePart::fromAddress() const
     return mFromAddress;
 }
 
-bool SignedMessagePart::hasHeader(const char *header) const
+bool SignedMessagePart::hasHeader(const char *headerType) const
 {
-    const auto extraContent = mOtp->nodeHelper()->decryptedNodeForContent(content());
-    if (extraContent) {
-        return extraContent->hasHeader(header);
+    if (content()) {
+        return content()->hasHeader(headerType);
     }
     return false;
 }
 
-KMime::Headers::Base *SignedMessagePart::header(const char *header) const
+const KMime::Headers::Base *MimeTreeParser::SignedMessagePart::header(const char *headerType) const
 {
-    const auto extraContent = mOtp->nodeHelper()->decryptedNodeForContent(content());
-    if (extraContent) {
-        return extraContent->headerByType(header);
+    if (content()) {
+        return content()->headerByType(headerType);
     }
     return nullptr;
 }
 
+QVector<KMime::Headers::Base *> SignedMessagePart::headers(const char *headerType) const
+{
+    if (content()) {
+        return content()->headersByType(headerType);
+    }
+    return QVector<KMime::Headers::Base *>();
+}
+
 //-----CryptMessageBlock---------------------
-EncryptedMessagePart::EncryptedMessagePart(ObjectTreeParser *otp, const QString &text, const QGpgME::Protocol *cryptoProto, const QString &fromAddress, KMime::Content *node)
+EncryptedMessagePart::EncryptedMessagePart(ObjectTreeParser *otp,
+                                           const QString &text,
+                                           const QGpgME::Protocol *cryptoProto,
+                                           const QString &fromAddress,
+                                           KMime::Content *node)
     : MessagePart(otp, text)
     , mPassphraseError(false)
     , mNoSecKey(false)
@@ -1127,7 +1133,7 @@ void EncryptedMessagePart::setMementoName(const QByteArray &name)
 
 void EncryptedMessagePart::startDecryption(const QByteArray &text, const QTextCodec *aCodec)
 {
-    KMime::Content *content = new KMime::Content;
+    auto content = new KMime::Content;
     content->setBody(text);
     content->parse();
 
@@ -1145,6 +1151,7 @@ void EncryptedMessagePart::startDecryption(const QByteArray &text, const QTextCo
             setText(aCodec->toUnicode(mDecryptedData));
         }
     }
+    delete content;
 }
 
 bool EncryptedMessagePart::okDecryptMIME(KMime::Content &data)
@@ -1162,10 +1169,9 @@ bool EncryptedMessagePart::okDecryptMIME(KMime::Content &data)
 
     const QByteArray _mementoName = mementoName();
     // Check whether the memento contains a result from last time:
-    const DecryptVerifyBodyPartMemento *m
-        = dynamic_cast<DecryptVerifyBodyPartMemento *>(nodeHelper->bodyPartMemento(&data, _mementoName));
+    const DecryptVerifyBodyPartMemento *m = dynamic_cast<DecryptVerifyBodyPartMemento *>(nodeHelper->bodyPartMemento(&data, _mementoName));
 
-    Q_ASSERT(!m || mCryptoProto); //No CryptoPlugin and having a bodyPartMemento -> there is something completely wrong
+    Q_ASSERT(!m || mCryptoProto); // No CryptoPlugin and having a bodyPartMemento -> there is something completely wrong
 
     if (!m && mCryptoProto) {
         QGpgME::DecryptVerifyJob *job = mCryptoProto->decryptVerifyJob();
@@ -1173,11 +1179,9 @@ bool EncryptedMessagePart::okDecryptMIME(KMime::Content &data)
             cannotDecrypt = true;
         } else {
             const QByteArray ciphertext = data.decodedContent();
-            DecryptVerifyBodyPartMemento *newM
-                = new DecryptVerifyBodyPartMemento(job, ciphertext);
+            auto newM = new DecryptVerifyBodyPartMemento(job, ciphertext);
             if (mOtp->allowAsync()) {
-                QObject::connect(newM, &CryptoBodyPartMemento::update,
-                                 nodeHelper, &NodeHelper::update);
+                QObject::connect(newM, &CryptoBodyPartMemento::update, nodeHelper, &NodeHelper::update);
                 if (newM->start()) {
                     partMetaData()->inProgress = true;
                     mOtp->mHasPendingAsyncJobs = true;
@@ -1211,16 +1215,16 @@ bool EncryptedMessagePart::okDecryptMIME(KMime::Content &data)
         mDecryptRecipients.clear();
         bDecryptionOk = !decryptResult.error();
 
-//         std::stringstream ss;
-//         ss << decryptResult << '\n' << verifyResult;
-//         qCDebug(MIMETREEPARSER_LOG) << ss.str().c_str();
+        //         std::stringstream ss;
+        //         ss << decryptResult << '\n' << verifyResult;
+        //         qCDebug(MIMETREEPARSER_LOG) << ss.str().c_str();
 
         for (const auto &recipient : decryptResult.recipients()) {
             if (!recipient.status()) {
                 bDecryptionOk = true;
             }
             GpgME::Key key;
-            QGpgME::KeyListJob *job = mCryptoProto->keyListJob(false, false, false);    // local, no sigs
+            QGpgME::KeyListJob *job = mCryptoProto->keyListJob(false, false, false); // local, no sigs
             if (!job) {
                 qCDebug(MIMETREEPARSER_LOG) << "The Crypto backend does not support listing keys. ";
             } else {
@@ -1245,7 +1249,7 @@ bool EncryptedMessagePart::okDecryptMIME(KMime::Content &data)
         }
 
         if (!bDecryptionOk && partMetaData()->isSigned) {
-            //Only a signed part
+            // Only a signed part
             partMetaData()->isEncrypted = false;
             bDecryptionOk = true;
             mDecryptedData = plainText;
@@ -1266,10 +1270,11 @@ bool EncryptedMessagePart::okDecryptMIME(KMime::Content &data)
                 mDecryptedData = plainText;
             } else {
                 mNoSecKey = true;
-                foreach (const GpgME::DecryptionResult::Recipient &recipient, decryptResult.recipients()) {
+                const auto decryRecipients = decryptResult.recipients();
+                for (const GpgME::DecryptionResult::Recipient &recipient : decryRecipients) {
                     mNoSecKey &= (recipient.status().code() == GPG_ERR_NO_SECKEY);
                 }
-                if (!mPassphraseError && !mNoSecKey) {          // GpgME do not detect passphrase error correctly
+                if (!mPassphraseError && !mNoSecKey) { // GpgME do not detect passphrase error correctly
                     mPassphraseError = true;
                 }
             }
@@ -1285,12 +1290,10 @@ bool EncryptedMessagePart::okDecryptMIME(KMime::Content &data)
         if (!mCryptoProto) {
             partMetaData()->errorText = i18n("No appropriate crypto plug-in was found.");
         } else if (cannotDecrypt) {
-            partMetaData()->errorText = i18n("Crypto plug-in \"%1\" cannot decrypt messages.",
-                                             cryptPlugLibName);
+            partMetaData()->errorText = i18n("Crypto plug-in \"%1\" cannot decrypt messages.", cryptPlugLibName);
         } else if (!passphraseError()) {
-            partMetaData()->errorText = i18n("Crypto plug-in \"%1\" could not decrypt the data.", cryptPlugLibName)
-                                        + QLatin1String("<br />")
-                                        + i18n("Error: %1", partMetaData()->errorText);
+            partMetaData()->errorText = i18n("Crypto plug-in \"%1\" could not decrypt the data.", cryptPlugLibName) + QLatin1String("<br />")
+                + i18n("Error: %1", partMetaData()->errorText);
         }
     }
     return bDecryptionOk;
@@ -1383,29 +1386,38 @@ QString EncryptedMessagePart::fromAddress() const
     return mFromAddress;
 }
 
-const std::vector<std::pair<GpgME::DecryptionResult::Recipient, GpgME::Key> > &EncryptedMessagePart::decryptRecipients() const
+const std::vector<std::pair<GpgME::DecryptionResult::Recipient, GpgME::Key>> &EncryptedMessagePart::decryptRecipients() const
 {
     return mDecryptRecipients;
 }
 
-bool EncryptedMessagePart::hasHeader(const char *header) const
+bool EncryptedMessagePart::hasHeader(const char *headerType) const
 {
     const auto extraContent = mOtp->nodeHelper()->decryptedNodeForContent(content());
     if (extraContent) {
-        return extraContent->hasHeader(header);
+        return nodeHelper()->hasMailHeader(headerType, extraContent);
     }
     return false;
 }
 
-KMime::Headers::Base *EncryptedMessagePart::header(const char *header) const
+const KMime::Headers::Base *EncryptedMessagePart::header(const char *headerType) const
 {
     const auto extraContent = mOtp->nodeHelper()->decryptedNodeForContent(content());
     if (extraContent) {
-        return extraContent->headerByType(header);
+        return nodeHelper()->mailHeaderAsBase(headerType, extraContent);
     }
     return nullptr;
 }
 
+QVector<KMime::Headers::Base *> EncryptedMessagePart::headers(const char *headerType) const
+{
+    const auto extraContent = mOtp->nodeHelper()->decryptedNodeForContent(content());
+    if (extraContent) {
+        return nodeHelper()->headers(headerType, extraContent);
+    }
+    return QVector<KMime::Headers::Base *>();
+}
+
 EncapsulatedRfc822MessagePart::EncapsulatedRfc822MessagePart(ObjectTreeParser *otp, KMime::Content *node, const KMime::Message::Ptr &message)
     : MessagePart(otp, QString())
     , mMessage(message)
