@@ -6,38 +6,37 @@
 */
 
 #include "nodehelper.h"
+#include "interfaces/bodypart.h"
+#include "messagepart.h"
 #include "mimetreeparser_debug.h"
 #include "partmetadata.h"
-#include "messagepart.h"
-#include "interfaces/bodypart.h"
 #include "temporaryfile/attachmenttemporaryfilesdirs.h"
 
 #include <KMime/Content>
-#include <KMime/Message>
-#include <KMime/Headers>
 
-#include <QTemporaryFile>
-#include <KLocalizedString>
 #include <KCharsets>
+#include <KLocalizedString>
+#include <QTemporaryFile>
 
-#include <QUrl>
 #include <QDir>
-#include <QTextCodec>
 #include <QRegularExpressionMatch>
+#include <QTextCodec>
+#include <QUrl>
 
-#include <string>
-#include <sstream>
-#include <algorithm>
+#include <QFileDevice>
 #include <QMimeDatabase>
 #include <QMimeType>
-#include <QFileDevice>
+#include <algorithm>
+#include <sstream>
+#include <string>
 
-namespace MimeTreeParser {
+namespace MimeTreeParser
+{
 NodeHelper::NodeHelper()
     : mAttachmentFilesDir(new AttachmentTemporaryFilesDirs())
 {
     mListAttachmentTemporaryDirs.append(mAttachmentFilesDir);
-    //TODO(Andras) add methods to modify these prefixes
+    // TODO(Andras) add methods to modify these prefixes
 
     mLocalCodec = QTextCodec::codecForLocale();
 
@@ -53,9 +52,9 @@ NodeHelper::NodeHelper()
         const QByteArray codecNameLower = mLocalCodec->name().toLower();
         if (codecNameLower == "eucjp"
 #if defined Q_OS_WIN || defined Q_OS_MACX
-            || codecNameLower == "shift-jis"     // OK?
+            || codecNameLower == "shift-jis" // OK?
 #endif
-            ) {
+        ) {
             mLocalCodec = QTextCodec::codecForName("jis7");
             // QTextCodec *cdc = QTextCodec::codecForName("jis7");
             // QTextCodec::setCodecForLocale(cdc);
@@ -98,10 +97,11 @@ void NodeHelper::setNodeUnprocessed(KMime::Content *node, bool recurse)
     }
     mProcessedNodes.removeAll(node);
 
-    //avoid double addition of extra nodes, eg. encrypted attachments
-    const QMap<KMime::Content *, QVector<KMime::Content *> >::iterator it = mExtraContents.find(node);
+    // avoid double addition of extra nodes, eg. encrypted attachments
+    const QMap<KMime::Content *, QVector<KMime::Content *>>::iterator it = mExtraContents.find(node);
     if (it != mExtraContents.end()) {
-        Q_FOREACH (KMime::Content *c, it.value()) {
+        const auto contents = it.value();
+        for (KMime::Content *c : contents) {
             KMime::Content *p = c->parent();
             if (p) {
                 p->removeContent(c);
@@ -131,9 +131,7 @@ bool NodeHelper::nodeProcessed(KMime::Content *node) const
 
 static void clearBodyPartMemento(QMap<QByteArray, Interface::BodyPartMemento *> &bodyPartMementoMap)
 {
-    for (QMap<QByteArray, Interface::BodyPartMemento *>::iterator
-         it = bodyPartMementoMap.begin(), end = bodyPartMementoMap.end();
-         it != end; ++it) {
+    for (QMap<QByteArray, Interface::BodyPartMemento *>::iterator it = bodyPartMementoMap.begin(), end = bodyPartMementoMap.end(); it != end; ++it) {
         Interface::BodyPartMemento *memento = it.value();
         memento->detach();
         delete memento;
@@ -147,13 +145,13 @@ void NodeHelper::clear()
     mEncryptionState.clear();
     mSignatureState.clear();
     mOverrideCodecs.clear();
-    std::for_each(mBodyPartMementoMap.begin(), mBodyPartMementoMap.end(),
-                  &clearBodyPartMemento);
+    std::for_each(mBodyPartMementoMap.begin(), mBodyPartMementoMap.end(), &clearBodyPartMemento);
     mBodyPartMementoMap.clear();
-    QMap<KMime::Content *, QVector<KMime::Content *> >::ConstIterator end(mExtraContents.constEnd());
+    QMap<KMime::Content *, QVector<KMime::Content *>>::ConstIterator end(mExtraContents.constEnd());
 
-    for (QMap<KMime::Content *, QVector<KMime::Content *> >::ConstIterator it = mExtraContents.constBegin(); it != end; ++it) {
-        Q_FOREACH (KMime::Content *c, it.value()) {
+    for (QMap<KMime::Content *, QVector<KMime::Content *>>::ConstIterator it = mExtraContents.constBegin(); it != end; ++it) {
+        const auto contents = it.value();
+        for (KMime::Content *c : contents) {
             KMime::Content *p = c->parent();
             if (p) {
                 p->removeContent(c);
@@ -294,7 +292,7 @@ QUrl NodeHelper::tempFileUrlFromNode(const KMime::Content *node)
 
 QString NodeHelper::createTempDir(const QString &param)
 {
-    QTemporaryFile *tempFile = new QTemporaryFile(QDir::tempPath() + QLatin1String("/messageviewer_XXXXXX") + QLatin1String(".index.") + param);
+    auto tempFile = new QTemporaryFile(QDir::tempPath() + QLatin1String("/messageviewer_XXXXXX") + QLatin1String(".index.") + param);
     tempFile->open();
     const QString fname = tempFile->fileName();
     delete tempFile;
@@ -302,10 +300,9 @@ QString NodeHelper::createTempDir(const QString &param)
     QFile fFile(fname);
     if (!(fFile.permissions() & QFileDevice::WriteUser)) {
         // Not there or not writable
-        if (!QDir().mkpath(fname)
-            || !fFile.setPermissions(QFileDevice::WriteUser | QFileDevice::ReadUser | QFileDevice::ExeUser)) {
+        if (!QDir().mkpath(fname) || !fFile.setPermissions(QFileDevice::WriteUser | QFileDevice::ReadUser | QFileDevice::ExeUser)) {
             mAttachmentFilesDir->addTempDir(fname);
-            return QString(); //failed create
+            return QString(); // failed create
         }
     }
 
@@ -324,7 +321,7 @@ void NodeHelper::forceCleanTempFiles()
 
 void NodeHelper::removeTempFiles()
 {
-    //Don't delete as it will be deleted in class
+    // Don't delete as it will be deleted in class
     if (mAttachmentFilesDir) {
         mAttachmentFilesDir->removeTempFiles();
     }
@@ -342,8 +339,8 @@ bool NodeHelper::isInEncapsulatedMessage(KMime::Content *node)
     const KMime::Content *const topLevel = node->topLevel();
     const KMime::Content *cur = node;
     while (cur && cur != topLevel) {
-        const bool parentIsMessage = cur->parent() && cur->parent()->contentType(false)
-                                     && cur->parent()->contentType(false)->mimeType().toLower() == "message/rfc822";
+        const bool parentIsMessage =
+            cur->parent() && cur->parent()->contentType(false) && cur->parent()->contentType(false)->mimeType().toLower() == "message/rfc822";
         if (parentIsMessage && cur->parent() != topLevel) {
             return true;
         }
@@ -435,7 +432,7 @@ KMMsgSignatureState NodeHelper::overallSignatureState(KMime::Content *node) cons
         contents.append(node);
     }
     int i = contents.indexOf(const_cast<KMime::Content *>(node));
-    if (i < 0) { //Be safe
+    if (i < 0) { // Be safe
         return myState;
     }
     for (; i < contents.size(); ++i) {
@@ -495,13 +492,46 @@ void NodeHelper::magicSetType(KMime::Content *node, bool aAutoDecode)
 
 bool NodeHelper::hasMailHeader(const char *header, const KMime::Content *message) const
 {
+    if (mHeaderOverwrite.contains(message)) {
+        const auto parts = mHeaderOverwrite.value(message);
+        for (const auto &messagePart : parts) {
+            if (messagePart->hasHeader(header)) {
+                return true;
+            }
+        }
+    }
     return message->hasHeader(header);
 }
 
+QVector<MessagePart::Ptr> NodeHelper::messagePartsOfMailHeader(const char *header, const KMime::Content *message) const
+{
+    QVector<MessagePart::Ptr> ret;
+    if (mHeaderOverwrite.contains(message)) {
+        const auto parts = mHeaderOverwrite.value(message);
+        for (const auto &messagePart : parts) {
+            if (messagePart->hasHeader(header)) {
+                ret << messagePart;
+            }
+        }
+    }
+    return ret;
+}
+
+QVector<KMime::Headers::Base *> NodeHelper::headers(const char *header, const KMime::Content *message)
+{
+    const auto mp = messagePartsOfMailHeader(header, message);
+    if (mp.size() > 0) {
+        return mp.value(0)->headers(header);
+    }
+
+    return message->headersByType(header);
+}
+
 KMime::Headers::Base const *NodeHelper::mailHeaderAsBase(const char *header, const KMime::Content *message) const
 {
     if (mHeaderOverwrite.contains(message)) {
-        foreach (const auto messagePart, mHeaderOverwrite.value(message)) {
+        const auto parts = mHeaderOverwrite.value(message);
+        for (const auto &messagePart : parts) {
             if (messagePart->hasHeader(header)) {
                 return messagePart->header(header); // Found.
             }
@@ -512,10 +542,12 @@ KMime::Headers::Base const *NodeHelper::mailHeaderAsBase(const char *header, con
 
 QSharedPointer<KMime::Headers::Generics::AddressList> NodeHelper::mailHeaderAsAddressList(const char *header, const KMime::Content *message) const
 {
-    QSharedPointer<KMime::Headers::Generics::AddressList> addressList(new KMime::Headers::Generics::AddressList());
     const auto hrd = mailHeaderAsBase(header, message);
-    const QByteArray &data = hrd->as7BitString(false);
-    addressList->from7BitString(data);
+    if (!hrd) {
+        return nullptr;
+    }
+    QSharedPointer<KMime::Headers::Generics::AddressList> addressList(new KMime::Headers::Generics::AddressList());
+    addressList->from7BitString(hrd->as7BitString(false));
     return addressList;
 }
 
@@ -596,28 +628,24 @@ QString NodeHelper::fileName(const KMime::Content *node)
     return name;
 }
 
-//FIXME(Andras) review it (by Marc?) to see if I got it right. This is supposed to be the partNode::internalBodyPartMemento replacement
+// FIXME(Andras) review it (by Marc?) to see if I got it right. This is supposed to be the partNode::internalBodyPartMemento replacement
 Interface::BodyPartMemento *NodeHelper::bodyPartMemento(KMime::Content *node, const QByteArray &which) const
 {
-    const QMap< QString, QMap<QByteArray, Interface::BodyPartMemento *> >::const_iterator nit
-        = mBodyPartMementoMap.find(persistentIndex(node));
+    const QMap<QString, QMap<QByteArray, Interface::BodyPartMemento *>>::const_iterator nit = mBodyPartMementoMap.find(persistentIndex(node));
     if (nit == mBodyPartMementoMap.end()) {
         return nullptr;
     }
-    const QMap<QByteArray, Interface::BodyPartMemento *>::const_iterator it
-        = nit->find(which.toLower());
+    const QMap<QByteArray, Interface::BodyPartMemento *>::const_iterator it = nit->find(which.toLower());
     return it != nit->end() ? it.value() : nullptr;
 }
 
-//FIXME(Andras) review it (by Marc?) to see if I got it right. This is supposed to be the partNode::internalSetBodyPartMemento replacement
+// FIXME(Andras) review it (by Marc?) to see if I got it right. This is supposed to be the partNode::internalSetBodyPartMemento replacement
 void NodeHelper::setBodyPartMemento(KMime::Content *node, const QByteArray &which, Interface::BodyPartMemento *memento)
 {
-    QMap<QByteArray, Interface::BodyPartMemento *> &mementos
-        = mBodyPartMementoMap[persistentIndex(node)];
+    QMap<QByteArray, Interface::BodyPartMemento *> &mementos = mBodyPartMementoMap[persistentIndex(node)];
 
     const QByteArray whichLower = which.toLower();
-    const QMap<QByteArray, Interface::BodyPartMemento *>::iterator it
-        = mementos.lowerBound(whichLower);
+    const QMap<QByteArray, Interface::BodyPartMemento *>::iterator it = mementos.lowerBound(whichLower);
 
     if (it != mementos.end() && it.key() == whichLower) {
         delete it.value();
@@ -675,7 +703,7 @@ QString NodeHelper::persistentIndex(const KMime::Content *node) const
 
     QString indexStr = node->index().toString();
     if (indexStr.isEmpty()) {
-        QMapIterator<KMime::Message::Content *, QVector<KMime::Content *> > it(mExtraContents);
+        QMapIterator<KMime::Message::Content *, QVector<KMime::Content *>> it(mExtraContents);
         while (it.hasNext()) {
             it.next();
             const auto &extraNodes = it.value();
@@ -692,8 +720,8 @@ QString NodeHelper::persistentIndex(const KMime::Content *node) const
         }
     } else {
         const KMime::Content *const topLevel = node->topLevel();
-        //if the node is an extra node, prepend the index of the extra node to the url
-        QMapIterator<KMime::Message::Content *, QVector<KMime::Content *> > it(mExtraContents);
+        // if the node is an extra node, prepend the index of the extra node to the url
+        QMapIterator<KMime::Message::Content *, QVector<KMime::Content *>> it(mExtraContents);
         while (it.hasNext()) {
             it.next();
             const QVector<KMime::Content *> &extraNodes = extraContents(it.key());
@@ -721,17 +749,13 @@ KMime::Content *NodeHelper::contentFromIndex(KMime::Content *node, const QString
     }
     KMime::Content *c = node->topLevel();
     if (c) {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        const QStringList pathParts = persistentIndex.split(QLatin1Char(':'), QString::SkipEmptyParts);
-#else
         const QStringList pathParts = persistentIndex.split(QLatin1Char(':'), Qt::SkipEmptyParts);
-#endif
         const int pathPartsSize(pathParts.size());
         for (int i = 0; i < pathPartsSize; ++i) {
             const QString &path = pathParts[i];
             if (path.startsWith(QLatin1Char('e'))) {
                 const QVector<KMime::Content *> &extraParts = mExtraContents.value(c);
-                const int idx = path.midRef(1, -1).toInt();
+                const int idx = QStringView(path).mid(1).toInt();
                 c = (idx < extraParts.size()) ? extraParts[idx] : nullptr;
             } else {
                 c = c->content(KMime::ContentIndex(path));
@@ -808,8 +832,7 @@ QStringList NodeHelper::supportedEncodings(bool usAscii)
     QStringList encodings;
     QMap<QString, bool> mimeNames;
     QStringList::ConstIterator constEnd(encodingNames.constEnd());
-    for (QStringList::ConstIterator it = encodingNames.constBegin();
-         it != constEnd; ++it) {
+    for (QStringList::ConstIterator it = encodingNames.constBegin(); it != constEnd; ++it) {
         QTextCodec *codec = KCharsets::charsets()->codecForName(*it);
         const QString mimeName = (codec) ? QString::fromLatin1(codec->name()).toLower() : (*it);
         if (!mimeNames.contains(mimeName)) {
@@ -829,10 +852,9 @@ QString NodeHelper::fromAsString(KMime::Content *node) const
     if (auto topLevel = dynamic_cast<KMime::Message *>(node->topLevel())) {
         return topLevel->from()->asUnicodeString();
     } else {
-        auto realNode = std::find_if(mExtraContents.cbegin(), mExtraContents.cend(),
-                                     [node](const QVector<KMime::Content *> &nodes) {
-                return nodes.contains(node);
-            });
+        auto realNode = std::find_if(mExtraContents.cbegin(), mExtraContents.cend(), [node](const QVector<KMime::Content *> &nodes) {
+            return nodes.contains(node);
+        });
         if (realNode != mExtraContents.cend()) {
             return fromAsString(realNode.key());
         }
@@ -853,7 +875,7 @@ void NodeHelper::cleanExtraContent(KMime::Content *topLevelNode)
     mExtraContents[topLevelNode].clear();
 }
 
-QVector< KMime::Content * > NodeHelper::extraContents(KMime::Content *topLevelnode) const
+QVector<KMime::Content *> NodeHelper::extraContents(KMime::Content *topLevelnode) const
 {
     return mExtraContents.value(topLevelnode);
 }
@@ -864,20 +886,22 @@ void NodeHelper::mergeExtraNodes(KMime::Content *node)
         return;
     }
 
-    const QVector<KMime::Content * > extraNodes = extraContents(node);
+    const QVector<KMime::Content *> extraNodes = extraContents(node);
     for (KMime::Content *extra : extraNodes) {
         if (node->bodyIsMessage()) {
             qCWarning(MIMETREEPARSER_LOG) << "Asked to attach extra content to a kmime::message, this does not make sense. Attaching to:" << node
-                                          <<node->encodedContent() << "\n====== with =======\n" <<  extra << extra->encodedContent();
+                                          << node->encodedContent() << "\n====== with =======\n"
+                                          << extra << extra->encodedContent();
             continue;
         }
-        KMime::Content *c = new KMime::Content(node);
+        auto c = new KMime::Content(node);
         c->setContent(extra->encodedContent());
         c->parse();
         node->addContent(c);
     }
 
-    Q_FOREACH (KMime::Content *child, node->contents()) {
+    const auto contents{node->contents()};
+    for (KMime::Content *child : contents) {
         mergeExtraNodes(child);
     }
 }
@@ -887,7 +911,7 @@ void NodeHelper::cleanFromExtraNodes(KMime::Content *node)
     if (!node) {
         return;
     }
-    const QVector<KMime::Content * > extraNodes = extraContents(node);
+    const QVector<KMime::Content *> extraNodes = extraContents(node);
     for (KMime::Content *extra : extraNodes) {
         QByteArray s = extra->encodedContent();
         const auto children = node->contents();
@@ -897,7 +921,8 @@ void NodeHelper::cleanFromExtraNodes(KMime::Content *node)
             }
         }
     }
-    Q_FOREACH (KMime::Content *child, node->contents()) {
+    const auto contents{node->contents()};
+    for (KMime::Content *child : contents) {
         cleanFromExtraNodes(child);
     }
 }
@@ -917,13 +942,13 @@ KMime::Message *NodeHelper::messageWithExtraContent(KMime::Content *topLevelNode
 
     mergeExtraNodes(topLevelNode);
 
-    KMime::Message *m = new KMime::Message;
+    auto m = new KMime::Message;
     m->setContent(topLevelNode->encodedContent());
     m->parse();
 
     cleanFromExtraNodes(topLevelNode);
-//   qCDebug(MIMETREEPARSER_LOG) << "MESSAGE WITH EXTRA: " << m->encodedContent();
-//   qCDebug(MIMETREEPARSER_LOG) << "MESSAGE WITHOUT EXTRA: " << topLevelNode->encodedContent();
+    //   qCDebug(MIMETREEPARSER_LOG) << "MESSAGE WITH EXTRA: " << m->encodedContent();
+    //   qCDebug(MIMETREEPARSER_LOG) << "MESSAGE WITHOUT EXTRA: " << topLevelNode->encodedContent();
 
     return m;
 }
@@ -1025,7 +1050,8 @@ bool NodeHelper::unencryptedMessage_helper(KMime::Content *node, QByteArray &res
                 resultingData += curNode->head() + '\n';
             }
             const QByteArray boundary = curNode->contentType()->boundary();
-            foreach (KMime::Content *child, curNode->contents()) {
+            const auto contents = curNode->contents();
+            for (KMime::Content *child : contents) {
                 resultingData += "\n--" + boundary + '\n';
                 const bool changed = unencryptedMessage_helper(child, resultingData, true, recursionLevel + 1);
                 if (changed) {
@@ -1080,7 +1106,8 @@ QVector<KMime::Content *> NodeHelper::attachmentsOfExtraContents() const
 {
     QVector<KMime::Content *> result;
     for (auto it = mExtraContents.begin(), end = mExtraContents.end(); it != end; ++it) {
-        foreach (auto content, it.value()) {
+        const auto contents = it.value();
+        for (auto content : contents) {
             if (KMime::isAttachment(content)) {
                 result.push_back(content);
             } else {
