@@ -2,38 +2,14 @@
     objecttreeparser.h
 
     This file is part of KMail, the KDE mail client.
-    Copyright (c) 2003      Marc Mutz <mutz@kde.org>
-    Copyright (C) 2002-2003, 2009 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-    Copyright (c) 2009 Andras Mantia <andras@kdab.net>
+    SPDX-FileCopyrightText: 2003 Marc Mutz <mutz@kde.org>
+    SPDX-FileCopyrightText: 2002-2003, 2009 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
+    SPDX-FileCopyrightText: 2009 Andras Mantia <andras@kdab.net>
 
-    KMail is free software; you can redistribute it and/or modify it
-    under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    KMail is distributed in the hope that it will be useful, but
-    WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MIMETREEPARSER_OBJECTTREEPARSER_H
-#define MIMETREEPARSER_OBJECTTREEPARSER_H
+#pragma once
 
 #include "mimetreeparser_export.h"
 
@@ -44,26 +20,31 @@
 
 class QString;
 
-namespace KMime {
+namespace KMime
+{
 class Content;
 }
 
-namespace MimeTreeParser {
+namespace MimeTreeParser
+{
 class PartMetaData;
 class ViewerPrivate;
 class NodeHelper;
 class MessagePart;
 class MimeMessagePart;
 
-typedef QSharedPointer<MessagePart> MessagePartPtr;
-typedef QSharedPointer<MimeMessagePart> MimeMessagePartPtr;
+using MessagePartPtr = QSharedPointer<MessagePart>;
+using MimeMessagePartPtr = QSharedPointer<MimeMessagePart>;
 /**
  * @brief The ProcessResult class
  */
 class MIMETREEPARSER_EXPORT ProcessResult
 {
 public:
-    explicit ProcessResult(NodeHelper *nodeHelper, KMMsgSignatureState inlineSignatureState = KMMsgNotSigned, KMMsgEncryptionState inlineEncryptionState = KMMsgNotEncrypted, bool neverDisplayInline = false)
+    explicit ProcessResult(NodeHelper *nodeHelper,
+                           KMMsgSignatureState inlineSignatureState = KMMsgNotSigned,
+                           KMMsgEncryptionState inlineEncryptionState = KMMsgNotEncrypted,
+                           bool neverDisplayInline = false)
         : mInlineSignatureState(inlineSignatureState)
         , mInlineEncryptionState(inlineEncryptionState)
         , mNeverDisplayInline(neverDisplayInline)
@@ -71,13 +52,13 @@ public:
     {
     }
 
-    KMMsgSignatureState inlineSignatureState() const;
+    Q_REQUIRED_RESULT KMMsgSignatureState inlineSignatureState() const;
     void setInlineSignatureState(KMMsgSignatureState state);
 
-    KMMsgEncryptionState inlineEncryptionState() const;
+    Q_REQUIRED_RESULT KMMsgEncryptionState inlineEncryptionState() const;
     void setInlineEncryptionState(KMMsgEncryptionState state);
 
-    bool neverDisplayInline() const;
+    Q_REQUIRED_RESULT bool neverDisplayInline() const;
     void setNeverDisplayInline(bool display);
 
     void adjustCryptoStatesOfNode(const KMime::Content *node) const;
@@ -264,9 +245,9 @@ the Viewer to scroll to the attachment.
 class MIMETREEPARSER_EXPORT ObjectTreeParser
 {
     /**
-    * @internal
-    * Copies the context of @p other, but not it's rawDecryptedBody, plainTextContent or htmlContent.
-    */
+     * @internal
+     * Copies the context of @p other, but not it's rawDecryptedBody, plainTextContent or htmlContent.
+     */
     ObjectTreeParser(const ObjectTreeParser &other);
 
 public:
@@ -281,26 +262,26 @@ public:
     bool hasPendingAsyncJobs() const;
 
     /**
-    * The text of the message, ie. what would appear in the
-    * composer's text editor if this was edited or replied to.
-    * This is usually the content of the first text/plain MIME part.
-    */
+     * The text of the message, ie. what would appear in the
+     * composer's text editor if this was edited or replied to.
+     * This is usually the content of the first text/plain MIME part.
+     */
     QString plainTextContent() const;
 
     /**
-    * Similar to plainTextContent(), but returns the HTML source of the first text/html MIME part.
-    *
-    * Not to be confused with the HTML code that the message viewer widget displays, that HTML
-    * is written out by htmlWriter() and a totally different pair of shoes.
-    */
+     * Similar to plainTextContent(), but returns the HTML source of the first text/html MIME part.
+     *
+     * Not to be confused with the HTML code that the message viewer widget displays, that HTML
+     * is written out by htmlWriter() and a totally different pair of shoes.
+     */
     QString htmlContent() const;
 
     /**
-    * The original charset of MIME part the plain text was extracted from.
-    *
-    * If there were more than one text/plain MIME parts in the mail, the this is the charset
-    * of the last MIME part processed.
-    */
+     * The original charset of MIME part the plain text was extracted from.
+     *
+     * If there were more than one text/plain MIME parts in the mail, the this is the charset
+     * of the last MIME part processed.
+     */
     QByteArray plainTextContentCharset() const;
     QByteArray htmlContentCharset() const;
 
@@ -316,14 +297,13 @@ private:
     void setPlainTextContent(const QString &plainTextContent);
 
     /**
-    * Does the actual work for parseObjectTree. Unlike parseObjectTree(), this does not change the
-    * top-level content.
-    */
+     * Does the actual work for parseObjectTree. Unlike parseObjectTree(), this does not change the
+     * top-level content.
+     */
     MessagePartPtr parseObjectTreeInternal(KMime::Content *node, bool mOnlyOneMimePart);
     MessagePartPtr processType(KMime::Content *node, MimeTreeParser::ProcessResult &processResult, const QByteArray &mimeType);
 
 private:
-
     /** ctor helper */
     void init();
 
@@ -336,7 +316,7 @@ private:
     QByteArray mHtmlContentCharset;
     QString mPlainTextContent;
     QString mHtmlContent;
-    KMime::Content *mTopLevelContent;
+    KMime::Content *mTopLevelContent = nullptr;
     MessagePartPtr mParsedPart;
 
     /// Show only one mime part means that the user has selected some node in the message structure
@@ -351,7 +331,7 @@ private:
     /// the children can be completely displayed again.
     bool mShowOnlyOneMimePart;
 
-    bool mHasPendingAsyncJobs;
+    bool mHasPendingAsyncJobs = false;
     bool mAllowAsync;
     // DataUrl Icons cache
     QString mCollapseIcon;
@@ -369,4 +349,3 @@ private:
 };
 }
 
-#endif // MIMETREEPARSER_OBJECTTREEPARSER_H
