@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -31,10 +31,7 @@ AttachmentTemporaryFilesDirs::AttachmentTemporaryFilesDirs(QObject *parent)
 {
 }
 
-AttachmentTemporaryFilesDirs::~AttachmentTemporaryFilesDirs()
-{
-    delete d;
-}
+AttachmentTemporaryFilesDirs::~AttachmentTemporaryFilesDirs() = default;
 
 void AttachmentTemporaryFilesDirs::setDelayRemoveAllInMs(int ms)
 {
@@ -63,7 +60,7 @@ void AttachmentTemporaryFilesDirs::forceCleanTempFiles()
 void AttachmentTemporaryFilesDirs::slotRemoveTempFiles()
 {
     forceCleanTempFiles();
-    //Delete it after cleaning
+    // Delete it after cleaning
     deleteLater();
 }
 
