@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef ATTACHMENTTEMPORARYFILESDIRSTEST_H
-#define ATTACHMENTTEMPORARYFILESDIRSTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,7 +13,7 @@ class AttachmentTemporaryFilesDirsTest : public QObject
     Q_OBJECT
 public:
     explicit AttachmentTemporaryFilesDirsTest(QObject *parent = nullptr);
-    ~AttachmentTemporaryFilesDirsTest();
+    ~AttachmentTemporaryFilesDirsTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldAddTemporaryFiles();
@@ -27,4 +26,3 @@ private Q_SLOTS:
     void shouldRemoveTemporaryFilesAfterTime();
 };
 
-#endif // ATTACHMENTTEMPORARYFILESDIRSTEST_H
