@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -20,7 +20,7 @@ CustomTemplatesMenuTest::~CustomTemplatesMenuTest()
 
 void CustomTemplatesMenuTest::shouldHaveDefaultValue()
 {
-    KActionCollection *collection = new KActionCollection(this);
+    auto collection = new KActionCollection(this);
     TemplateParser::CustomTemplatesMenu templateMenu(nullptr, collection);
 
     QVERIFY(templateMenu.replyActionMenu());
