@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef TEMPLATEEXTRACTTEXTFROMMAILTEST_H
-#define TEMPLATEEXTRACTTEXTFROMMAILTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,10 +13,9 @@ class TemplateExtractTextFromMailTest : public QObject
     Q_OBJECT
 public:
     explicit TemplateExtractTextFromMailTest(QObject *parent = nullptr);
-    ~TemplateExtractTextFromMailTest();
+    ~TemplateExtractTextFromMailTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldExtractHtml();
 };
 
-#endif // TEMPLATEEXTRACTTEXTFROMMAILTEST_H
