@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef TEMPLATEPARSEREMAILADDRESSREQUESTERINTERFACEWIDGETTEST_H
-#define TEMPLATEPARSEREMAILADDRESSREQUESTERINTERFACEWIDGETTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,11 +13,10 @@ class TemplateParserEmailAddressRequesterInterfaceWidgetTest : public QObject
     Q_OBJECT
 public:
     explicit TemplateParserEmailAddressRequesterInterfaceWidgetTest(QObject *parent = nullptr);
-    ~TemplateParserEmailAddressRequesterInterfaceWidgetTest() = default;
+    ~TemplateParserEmailAddressRequesterInterfaceWidgetTest() override = default;
 
 private Q_SLOTS:
     void shouldHaveDefaultValues();
     void shouldAssignValues();
 };
 
-#endif // TEMPLATEPARSEREMAILADDRESSREQUESTERINTERFACEWIDGETTEST_H
