@@ -1,15 +1,15 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "templateparseremailaddressrequesterlineedittest.h"
 #include "templateparseremailaddressrequesterlineedit.h"
-#include <QTest>
 #include <QHBoxLayout>
 #include <QLineEdit>
 #include <QSignalSpy>
+#include <QTest>
 
 TemplateParserEmailAddressRequesterLineEditTest::TemplateParserEmailAddressRequesterLineEditTest(QObject *parent)
     : QObject(parent)
@@ -20,11 +20,11 @@ void TemplateParserEmailAddressRequesterLineEditTest::shouldHaveDefaultValue()
 {
     TemplateParser::TemplateParserEmailAddressRequesterLineEdit w;
 
-    auto *mainLayout = w.findChild<QHBoxLayout *>(QStringLiteral("mainlayout"));
+    auto mainLayout = w.findChild<QHBoxLayout *>(QStringLiteral("mainlayout"));
     QVERIFY(mainLayout);
     QCOMPARE(mainLayout->contentsMargins(), QMargins(0, 0, 0, 0));
 
-    auto *mLineEdit = w.findChild<QLineEdit *>(QStringLiteral("lineedit"));
+    auto mLineEdit = w.findChild<QLineEdit *>(QStringLiteral("lineedit"));
     QVERIFY(mLineEdit);
     QVERIFY(mLineEdit->text().isEmpty());
 }
@@ -32,10 +32,8 @@ void TemplateParserEmailAddressRequesterLineEditTest::shouldHaveDefaultValue()
 void TemplateParserEmailAddressRequesterLineEditTest::shouldAssignValue()
 {
     TemplateParser::TemplateParserEmailAddressRequesterLineEdit w;
-    auto *mLineEdit = w.findChild<QLineEdit *>(QStringLiteral("lineedit"));
-    const QString str{
-        QStringLiteral("foo")
-    };
+    auto mLineEdit = w.findChild<QLineEdit *>(QStringLiteral("lineedit"));
+    const QString str{QStringLiteral("foo")};
     w.setText(str);
     QCOMPARE(w.text(), str);
     QCOMPARE(mLineEdit->text(), str);
@@ -44,10 +42,8 @@ void TemplateParserEmailAddressRequesterLineEditTest::shouldAssignValue()
 void TemplateParserEmailAddressRequesterLineEditTest::shouldClearValue()
 {
     TemplateParser::TemplateParserEmailAddressRequesterLineEdit w;
-    auto *mLineEdit = w.findChild<QLineEdit *>(QStringLiteral("lineedit"));
-    const QString str{
-        QStringLiteral("foo")
-    };
+    auto mLineEdit = w.findChild<QLineEdit *>(QStringLiteral("lineedit"));
+    const QString str{QStringLiteral("foo")};
     w.setText(str);
     QCOMPARE(w.text(), str);
     w.clear();
