@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef TEMPLATEPARSEREMAILADDRESSREQUESTERLINEEDITTEST_H
-#define TEMPLATEPARSEREMAILADDRESSREQUESTERLINEEDITTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,7 +13,7 @@ class TemplateParserEmailAddressRequesterLineEditTest : public QObject
     Q_OBJECT
 public:
     explicit TemplateParserEmailAddressRequesterLineEditTest(QObject *parent = nullptr);
-    ~TemplateParserEmailAddressRequesterLineEditTest() = default;
+    ~TemplateParserEmailAddressRequesterLineEditTest() override = default;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldAssignValue();
@@ -22,4 +21,3 @@ private Q_SLOTS:
     void shouldEmitSignal();
 };
 
-#endif // TEMPLATEPARSEREMAILADDRESSREQUESTERLINEEDITTEST_H
