@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef TEMPLATESINSERTCOMMANDACTIONTEST_H
-#define TEMPLATESINSERTCOMMANDACTIONTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,10 +13,9 @@ class TemplatesInsertCommandActionTest : public QObject
     Q_OBJECT
 public:
     explicit TemplatesInsertCommandActionTest(QObject *parent = nullptr);
-    ~TemplatesInsertCommandActionTest() = default;
+    ~TemplatesInsertCommandActionTest() override = default;
 
 private Q_SLOTS:
     void shouldHaveDefaultValue();
 };
 
-#endif // TEMPLATESINSERTCOMMANDACTIONTEST_H
