@@ -1,29 +1,18 @@
 /*
- * Copyright (C) 2006 Dmitry Morozhnikov <dmiceman@mail.ru>
- * Copyright (C) 2011-2019 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2006 Dmitry Morozhnikov <dmiceman@mail.ru>
+ * SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "customtemplates.h"
-#include "templateparser/templatesinsertcommandpushbutton.h"
 #include "customtemplates_kfg.h"
 #include "globalsettings_templateparser.h"
-#include "ui_customtemplates_base.h"
-#include "kpimtextedit/plaintexteditor.h"
+#include "templateparser/templatesinsertcommandpushbutton.h"
 #include "templateparseremailaddressrequesterinterfacewidget.h"
+#include "ui_customtemplates_base.h"
+#include <KPIMTextEdit/PlainTextEditor>
+#include <Libkdepim/LineEditCatchReturnKey>
 
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -35,9 +24,8 @@ using namespace TemplateParser;
 
 CustomTemplates::CustomTemplates(const QList<KActionCollection *> &actionCollection, QWidget *parent)
     : QWidget(parent)
-    , mBlockChangeSignal(false)
+    , mUi(new Ui_CustomTemplatesBase)
 {
-    mUi = new Ui_CustomTemplatesBase;
     mUi->setupUi(this);
 
     mUi->mAdd->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
@@ -51,24 +39,26 @@ CustomTemplates::CustomTemplates(const QList<KActionCollection *> &actionCollect
     mUi->mList->header()->setSectionsMovable(false);
     mUi->mEditFrame->setEnabled(false);
 
-    mUi->mName->setTrapReturnKey(true);
-    connect(mUi->mEdit->editor(), &QPlainTextEdit::textChanged,
-            this, &CustomTemplates::slotTextChanged);
+    new KPIM::LineEditCatchReturnKey(mUi->mName, this);
+    connect(mUi->mEdit->editor(), &QPlainTextEdit::textChanged, this, &CustomTemplates::slotTextChanged);
     connect(mUi->mToEdit, &TemplateParser::TemplateParserEmailAddressRequesterInterfaceWidget::textChanged, this, &CustomTemplates::slotTextChanged);
     connect(mUi->mCCEdit, &TemplateParser::TemplateParserEmailAddressRequesterInterfaceWidget::textChanged, this, &CustomTemplates::slotTextChanged);
 
-    connect(mUi->mName, &KLineEdit::textChanged, this, &CustomTemplates::slotNameChanged);
+    connect(mUi->mName, &QLineEdit::textChanged, this, &CustomTemplates::slotNameChanged);
 
-    connect(mUi->mName, &KLineEdit::returnPressed, this, &CustomTemplates::slotAddClicked);
+    connect(mUi->mName, &QLineEdit::returnPressed, this, &CustomTemplates::slotAddClicked);
 
-    connect(mUi->mInsertCommand, qOverload<const QString &, int>(&TemplateParser::TemplatesInsertCommandPushButton::insertCommand), this, &CustomTemplates::slotInsertCommand);
+    connect(mUi->mInsertCommand,
+            qOverload<const QString &, int>(&TemplateParser::TemplatesInsertCommandPushButton::insertCommand),
+            this,
+            &CustomTemplates::slotInsertCommand);
 
     connect(mUi->mAdd, &QPushButton::clicked, this, &CustomTemplates::slotAddClicked);
     connect(mUi->mRemove, &QPushButton::clicked, this, &CustomTemplates::slotRemoveClicked);
     connect(mUi->mDuplicate, &QPushButton::clicked, this, &CustomTemplates::slotDuplicateClicked);
     connect(mUi->mList, &QTreeWidget::currentItemChanged, this, &CustomTemplates::slotListSelectionChanged);
     connect(mUi->mList, &QTreeWidget::itemChanged, this, &CustomTemplates::slotItemChanged);
-    connect(mUi->mType, qOverload<int>(&KComboBox::activated), this, &CustomTemplates::slotTypeActivated);
+    connect(mUi->mType, qOverload<int>(&QComboBox::activated), this, &CustomTemplates::slotTypeActivated);
 
     connect(mUi->mKeySequenceWidget, &KKeySequenceWidget::keySequenceChanged, this, &CustomTemplates::slotShortcutChanged);
 
@@ -85,8 +75,7 @@ CustomTemplates::CustomTemplates(const QList<KActionCollection *> &actionCollect
     mUi->mType->addItem(mForwardPix, i18nc("Message->", "Forward"));
 
     mUi->mHelp->setText(i18n("<a href=\"whatsthis\">How does this work?</a>"));
-    connect(mUi->mHelp, &QLabel::linkActivated,
-            this, &CustomTemplates::slotHelpLinkClicked);
+    connect(mUi->mHelp, &QLabel::linkActivated, this, &CustomTemplates::slotHelpLinkClicked);
     mUi->mHelp->setContextMenuPolicy(Qt::NoContextMenu);
 
     slotNameChanged(mUi->mName->text());
@@ -94,33 +83,31 @@ CustomTemplates::CustomTemplates(const QList<KActionCollection *> &actionCollect
 
 void CustomTemplates::slotHelpLinkClicked(const QString &)
 {
-    const QString help
-        = i18n("<qt>"
-               "<p>Here you can add, edit, and delete custom message "
-               "templates to use when you compose a reply or forwarding message. "
-               "Create the custom template by typing the name into the input box "
-               "and press the '+' button. Also, you can bind a keyboard "
-               "combination to the template for faster operations.</p>"
-               "<p>Message templates support substitution commands, "
-               "by simply typing them or selecting them from the "
-               "<i>Insert command</i> menu.</p>"
-               "<p>There are four types of custom templates: used to "
-               "<i>Reply</i>, <i>Reply to All</i>, <i>Forward</i>, and "
-               "<i>Universal</i> which can be used for all kinds of operations. "
-               "You cannot bind a keyboard shortcut to <i>Universal</i> templates.</p>"
-               "</qt>");
+    const QString help = i18n(
+        "<qt>"
+        "<p>Here you can add, edit, and delete custom message "
+        "templates to use when you compose a reply or forwarding message. "
+        "Create the custom template by typing the name into the input box "
+        "and press the '+' button. Also, you can bind a keyboard "
+        "combination to the template for faster operations.</p>"
+        "<p>Message templates support substitution commands, "
+        "by simply typing them or selecting them from the "
+        "<i>Insert command</i> menu.</p>"
+        "<p>There are four types of custom templates: used to "
+        "<i>Reply</i>, <i>Reply to All</i>, <i>Forward</i>, and "
+        "<i>Universal</i> which can be used for all kinds of operations. "
+        "You cannot bind a keyboard shortcut to <i>Universal</i> templates.</p>"
+        "</qt>");
 
     QWhatsThis::showText(QCursor::pos(), help);
 }
 
 CustomTemplates::~CustomTemplates()
 {
-    disconnect(mUi->mEdit->editor(), &QPlainTextEdit::textChanged,
-               this, &CustomTemplates::slotTextChanged);
+    disconnect(mUi->mEdit->editor(), &QPlainTextEdit::textChanged, this, &CustomTemplates::slotTextChanged);
     disconnect(mUi->mToEdit, &TemplateParser::TemplateParserEmailAddressRequesterInterfaceWidget::textChanged, this, &CustomTemplates::slotTextChanged);
     disconnect(mUi->mCCEdit, &TemplateParser::TemplateParserEmailAddressRequesterInterfaceWidget::textChanged, this, &CustomTemplates::slotTextChanged);
     delete mUi;
-    mUi = nullptr;
 }
 
 void CustomTemplates::slotNameChanged(const QString &text)
@@ -158,7 +145,7 @@ void CustomTemplates::slotTextChanged()
 {
     QTreeWidgetItem *item = mUi->mList->currentItem();
     if (item) {
-        CustomTemplateItem *vitem = static_cast<CustomTemplateItem *>(item);
+        auto vitem = static_cast<CustomTemplateItem *>(item);
         vitem->setContent(mUi->mEdit->toPlainText());
         if (!mBlockChangeSignal) {
             vitem->setTo(mUi->mToEdit->text());
@@ -197,9 +184,8 @@ void CustomTemplates::load()
     for (QStringList::const_iterator it = list.constBegin(); it != end; ++it) {
         CTemplates t(*it);
         QKeySequence shortcut(t.shortcut());
-        CustomTemplates::Type type = static_cast<Type>(t.type());
-        CustomTemplateItem *item = new CustomTemplateItem(mUi->mList, *it, t.content(),
-                                                          shortcut, type, t.to(), t.cC());
+        auto type = static_cast<Type>(t.type());
+        auto item = new CustomTemplateItem(mUi->mList, *it, t.content(), shortcut, type, t.to(), t.cC());
         item->setText(1, *it);
         item->setText(0, indexToType(type));
         iconFromType(type, item);
@@ -214,7 +200,7 @@ void CustomTemplates::save()
     // Before saving the new templates, delete the old ones. That needs to be done before
     // saving, since otherwise a new template with the new name wouldn't get saved.
     KSharedConfig::Ptr config = KSharedConfig::openConfig(QStringLiteral("customtemplatesrc"), KConfig::NoGlobals);
-    for (const QString &item : qAsConst(mItemsToDelete)) {
+    for (const QString &item : std::as_const(mItemsToDelete)) {
         CTemplates t(item);
         const QString configGroup = t.currentGroup();
         config->deleteGroup(configGroup);
@@ -223,7 +209,7 @@ void CustomTemplates::save()
     QStringList list;
     QTreeWidgetItemIterator lit(mUi->mList);
     while (*lit) {
-        CustomTemplateItem *it = static_cast<CustomTemplateItem *>(*lit);
+        auto it = static_cast<CustomTemplateItem *>(*lit);
         const QString name = it->text(1);
         list.append(name);
 
@@ -263,10 +249,7 @@ bool CustomTemplates::nameAlreadyExists(const QString &str, QTreeWidgetItem *ite
     while (*lit) {
         const QString name = (*lit)->text(1);
         if ((name == str) && ((*lit) != item)) {
-            KMessageBox::error(
-                this,
-                i18n("A template with same name already exists."),
-                i18n("Cannot create template"));
+            KMessageBox::error(this, i18n("A template with same name already exists."), i18n("Cannot create template"));
             return true;
         }
         ++lit;
@@ -283,9 +266,7 @@ void CustomTemplates::slotAddClicked()
         }
 
         QKeySequence nullShortcut;
-        CustomTemplateItem *item
-            = new CustomTemplateItem(mUi->mList, str, QString(), nullShortcut, TUniversal,
-                                     QString(), QString());
+        auto item = new CustomTemplateItem(mUi->mList, str, QString(), nullShortcut, TUniversal, QString(), QString());
         item->setText(0, indexToType(TUniversal));
         item->setText(1, str);
         mUi->mList->setCurrentItem(item);
@@ -332,13 +313,11 @@ void CustomTemplates::slotDuplicateClicked()
     if (!currentItem) {
         return;
     }
-    CustomTemplateItem *origItem = static_cast<CustomTemplateItem *>(currentItem);
+    auto origItem = static_cast<CustomTemplateItem *>(currentItem);
     const QString templateName = createUniqueName(origItem->text(1));
     QKeySequence nullShortcut;
     CustomTemplates::Type type = origItem->customType();
-    CustomTemplateItem *item
-        = new CustomTemplateItem(mUi->mList, templateName, origItem->content(), nullShortcut, type,
-                                 origItem->to(), origItem->cc());
+    auto item = new CustomTemplateItem(mUi->mList, templateName, origItem->content(), nullShortcut, type, origItem->to(), origItem->cc());
     item->setText(0, indexToType(type));
     item->setText(1, templateName);
     iconFromType(type, item);
@@ -361,12 +340,12 @@ void CustomTemplates::slotRemoveClicked()
 
     const QString templateName = item->text(1);
 
-    if (KMessageBox::warningContinueCancel(
-            this,
-            i18nc("@info", "Do you really want to remove template \"%1\"?", templateName),
-            i18nc("@title:window", "Remove Template?"),
-            KStandardGuiItem::remove(),
-            KStandardGuiItem::cancel()) == KMessageBox::Continue) {
+    if (KMessageBox::warningContinueCancel(this,
+                                           i18nc("@info", "Do you really want to remove template \"%1\"?", templateName),
+                                           i18nc("@title:window", "Remove Template?"),
+                                           KStandardGuiItem::remove(),
+                                           KStandardGuiItem::cancel())
+        == KMessageBox::Continue) {
         mItemsToDelete.append(templateName);
         delete mUi->mList->takeTopLevelItem(mUi->mList->indexOfTopLevelItem(item));
         mUi->mRemove->setEnabled(mUi->mList->topLevelItemCount() > 0);
@@ -384,11 +363,10 @@ void CustomTemplates::slotListSelectionChanged()
         mUi->mEditFrame->setEnabled(true);
         mUi->mRemove->setEnabled(true);
         mUi->mDuplicate->setEnabled(true);
-        CustomTemplateItem *vitem = static_cast<CustomTemplateItem *>(item);
+        auto vitem = static_cast<CustomTemplateItem *>(item);
         mBlockChangeSignal = true;
         mUi->mEdit->setPlainText(vitem->content());
-        mUi->mKeySequenceWidget->setKeySequence(vitem->shortcut(),
-                                                KKeySequenceWidget::NoValidate);
+        mUi->mKeySequenceWidget->setKeySequence(vitem->shortcut(), KKeySequenceWidget::NoValidate);
         CustomTemplates::Type type = vitem->customType();
 
         mUi->mType->setCurrentIndex(mUi->mType->findText(indexToType(type)));
@@ -417,8 +395,8 @@ void CustomTemplates::slotTypeActivated(int index)
 {
     QTreeWidgetItem *item = mUi->mList->currentItem();
     if (item) {
-        CustomTemplateItem *vitem = static_cast<CustomTemplateItem *>(item);
-        CustomTemplates::Type customtype = static_cast<Type>(index);
+        auto vitem = static_cast<CustomTemplateItem *>(item);
+        auto customtype = static_cast<Type>(index);
         vitem->setCustomType(customtype);
         vitem->setText(0, indexToType(customtype));
 
@@ -437,7 +415,7 @@ void CustomTemplates::slotShortcutChanged(const QKeySequence &newSeq)
 {
     QTreeWidgetItem *item = mUi->mList->currentItem();
     if (item) {
-        CustomTemplateItem *vitem = static_cast<CustomTemplateItem *>(item);
+        auto vitem = static_cast<CustomTemplateItem *>(item);
         vitem->setShortcut(newSeq);
         mUi->mKeySequenceWidget->applyStealShortcut();
     }
@@ -450,7 +428,7 @@ void CustomTemplates::slotShortcutChanged(const QKeySequence &newSeq)
 void CustomTemplates::slotItemChanged(QTreeWidgetItem *item, int column)
 {
     if (item) {
-        CustomTemplateItem *vitem = static_cast<CustomTemplateItem *>(item);
+        auto vitem = static_cast<CustomTemplateItem *>(item);
         if (column == 1) {
             const QString newName = vitem->text(1).trimmed();
             if (!newName.isEmpty()) {
@@ -482,7 +460,7 @@ CustomTemplateItemDelegate::~CustomTemplateItemDelegate()
 
 void CustomTemplateItemDelegate::setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const
 {
-    KLineEdit *lineEdit = static_cast<KLineEdit *>(editor);
+    auto lineEdit = static_cast<QLineEdit *>(editor);
     const QString text = lineEdit->text();
     if (!text.isEmpty()) {
         model->setData(index, text, Qt::EditRole);
@@ -497,7 +475,13 @@ QWidget *CustomTemplateItemDelegate::createEditor(QWidget *parent, const QStyleO
     return nullptr;
 }
 
-CustomTemplateItem::CustomTemplateItem(QTreeWidget *parent, const QString &name, const QString &content, const QKeySequence &shortcut, CustomTemplates::Type type, const QString &to, const QString &cc)
+CustomTemplateItem::CustomTemplateItem(QTreeWidget *parent,
+                                       const QString &name,
+                                       const QString &content,
+                                       const QKeySequence &shortcut,
+                                       CustomTemplates::Type type,
+                                       const QString &to,
+                                       const QString &cc)
     : QTreeWidgetItem(parent)
     , mName(name)
     , mContent(content)
