@@ -1,24 +1,11 @@
 /*
- * Copyright (C) 2006 Dmitry Morozhnikov <dmiceman@mail.ru>
- * Copyright (C) 2011-2019 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2006 Dmitry Morozhnikov <dmiceman@mail.ru>
+ * SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef TEMPLATEPARSER_CUSTOMTEMPLATES_H
-#define TEMPLATEPARSER_CUSTOMTEMPLATES_H
+#pragma once
 
 #include "templateparser_export.h"
 
@@ -30,7 +17,8 @@ class KActionCollection;
 
 class Ui_CustomTemplatesBase;
 
-namespace TemplateParser {
+namespace TemplateParser
+{
 class CustomTemplateItem;
 /**
  * @brief The CustomTemplates class
@@ -39,16 +27,11 @@ class TEMPLATEPARSER_EXPORT CustomTemplates : public QWidget
 {
     Q_OBJECT
 public:
-    enum Type {
-        TUniversal,
-        TReply,
-        TReplyAll,
-        TForward
-    };
+    enum Type { TUniversal, TReply, TReplyAll, TForward };
 
 public:
     explicit CustomTemplates(const QList<KActionCollection *> &actionCollection, QWidget *parent = nullptr);
-    ~CustomTemplates();
+    ~CustomTemplates() override;
 
     void load();
     void save();
@@ -71,9 +54,9 @@ private Q_SLOTS:
     void slotDuplicateClicked();
 
 private:
-    bool nameAlreadyExists(const QString &str, QTreeWidgetItem *item = nullptr);
-    QString indexToType(int index);
-    QString createUniqueName(const QString &name) const;
+    Q_REQUIRED_RESULT bool nameAlreadyExists(const QString &str, QTreeWidgetItem *item = nullptr);
+    Q_REQUIRED_RESULT QString indexToType(int index);
+    Q_REQUIRED_RESULT QString createUniqueName(const QString &name) const;
     void iconFromType(CustomTemplates::Type type, CustomTemplateItem *item);
 
     /// These templates will be deleted when we're saving.
@@ -85,32 +68,38 @@ private:
 
     /// Whether or not to Q_EMIT the changed() signal. This is useful to disable when loading
     /// templates, which changes the UI without user action
-    bool mBlockChangeSignal;
+    bool mBlockChangeSignal = false;
 
-    Ui_CustomTemplatesBase *mUi = nullptr;
+    Ui_CustomTemplatesBase *const mUi;
 };
 
 class CustomTemplateItem : public QTreeWidgetItem
 {
 public:
-    explicit CustomTemplateItem(QTreeWidget *parent, const QString &name, const QString &content, const QKeySequence &shortcut, CustomTemplates::Type type, const QString &to, const QString &cc);
-    ~CustomTemplateItem();
+    explicit CustomTemplateItem(QTreeWidget *parent,
+                                const QString &name,
+                                const QString &content,
+                                const QKeySequence &shortcut,
+                                CustomTemplates::Type type,
+                                const QString &to,
+                                const QString &cc);
+    ~CustomTemplateItem() override;
     void setCustomType(CustomTemplates::Type type);
     CustomTemplates::Type customType() const;
 
-    QString to() const;
-    QString cc() const;
+    Q_REQUIRED_RESULT QString to() const;
+    Q_REQUIRED_RESULT QString cc() const;
 
     void setTo(const QString &);
     void setCc(const QString &);
 
-    QString content() const;
+    Q_REQUIRED_RESULT QString content() const;
     void setContent(const QString &);
 
-    QKeySequence shortcut() const;
+    Q_REQUIRED_RESULT QKeySequence shortcut() const;
     void setShortcut(const QKeySequence &);
 
-    QString oldName() const;
+    Q_REQUIRED_RESULT QString oldName() const;
     void setOldName(const QString &);
 
 private:
@@ -132,4 +121,3 @@ public:
 };
 }
 
-#endif
