@@ -1,15 +1,15 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef TEMPLATEEXTRACTTEXTFROMMAIL_H
-#define TEMPLATEEXTRACTTEXTFROMMAIL_H
+#pragma once
 
 #include "templateparser_export.h"
 #include <QObject>
-namespace TemplateParser {
+namespace TemplateParser
+{
 class TemplateWebEnginePage;
 /**
  * @brief The TemplateExtractTextFromMail class
@@ -20,7 +20,7 @@ class TEMPLATEPARSER_EXPORT TemplateExtractTextFromMail : public QObject
     Q_OBJECT
 public:
     explicit TemplateExtractTextFromMail(QObject *parent = nullptr);
-    ~TemplateExtractTextFromMail();
+    ~TemplateExtractTextFromMail() override;
 
     void setHtmlContent(const QString &html);
 
@@ -34,7 +34,6 @@ private:
     void setPlainText(const QString &plainText);
 
     QString mExtractedPlainText;
-    TemplateWebEnginePage *mPage = nullptr;
+    TemplateWebEnginePage *const mPage;
 };
 }
-#endif // TEMPLATEEXTRACTTEXTFROMMAIL_H
