@@ -1,41 +1,42 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "templateparseremailaddressrequesterinterfacewidget.h"
+#include "templateparseremailaddressrequesterlineedit.h"
+#include <KPluginFactory>
 #include <QHBoxLayout>
 #include <TemplateParser/TemplateParserEmailAddressRequesterBase>
-#include "templateparseremailaddressrequesterlineedit.h"
-#include <KPluginLoader>
-#include <KPluginFactory>
 
 using namespace TemplateParser;
 
 TemplateParserEmailAddressRequesterInterfaceWidget::TemplateParserEmailAddressRequesterInterfaceWidget(QWidget *parent)
     : QWidget(parent)
-    , mTemplateParserEmailBase(nullptr)
 {
-    QHBoxLayout *mainLayout = new QHBoxLayout(this);
+    auto mainLayout = new QHBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainlayout"));
-    mainLayout->setContentsMargins(0, 0, 0, 0);
+    mainLayout->setContentsMargins({});
     initializeEmailWidget();
     mainLayout->addWidget(mTemplateParserEmailBase);
 }
 
 void TemplateParserEmailAddressRequesterInterfaceWidget::initializeEmailWidget()
 {
-    KPluginLoader loader(QStringLiteral("templateparser/templateparseraddressrequesterplugin"));
-    KPluginFactory *factory = loader.factory();
-    if (factory) {
-        mTemplateParserEmailBase = factory->create<TemplateParser::TemplateParserEmailAddressRequesterBase>(this);
+    const KPluginMetaData editWidgetPlugin(QStringLiteral("templateparser/templateparseraddressrequesterplugin"));
+
+    const auto result = KPluginFactory::instantiatePlugin<TemplateParser::TemplateParserEmailAddressRequesterBase>(editWidgetPlugin, this);
+    if (result) {
+        mTemplateParserEmailBase = result.plugin;
     } else {
         mTemplateParserEmailBase = new TemplateParser::TemplateParserEmailAddressRequesterLineEdit(this);
     }
     mTemplateParserEmailBase->setObjectName(QStringLiteral("templateparseremailbase"));
-    connect(mTemplateParserEmailBase, &TemplateParserEmailAddressRequesterBase::textChanged,
-            this, &TemplateParserEmailAddressRequesterInterfaceWidget::textChanged);
+    connect(mTemplateParserEmailBase,
+            &TemplateParserEmailAddressRequesterBase::textChanged,
+            this,
+            &TemplateParserEmailAddressRequesterInterfaceWidget::textChanged);
 }
 
 QString TemplateParserEmailAddressRequesterInterfaceWidget::text() const
