@@ -1,16 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef TEMPLATEPARSEREMAILADDRESSREQUESTERLINEEDIT_H
-#define TEMPLATEPARSEREMAILADDRESSREQUESTERLINEEDIT_H
+#pragma once
 
-#include <TemplateParser/TemplateParserEmailAddressRequesterBase>
 #include "templateparser_private_export.h"
+#include <TemplateParser/TemplateParserEmailAddressRequesterBase>
 class QLineEdit;
-namespace TemplateParser {
+namespace TemplateParser
+{
 class TEMPLATEPARSER_TESTS_EXPORT TemplateParserEmailAddressRequesterLineEdit : public TemplateParser::TemplateParserEmailAddressRequesterBase
 {
     Q_OBJECT
@@ -21,8 +21,8 @@ public:
     Q_REQUIRED_RESULT QString text() const override;
     void setText(const QString &str) override;
     void clear() override;
+
 private:
-    QLineEdit *mLineEdit = nullptr;
+    QLineEdit *const mLineEdit;
 };
 }
-#endif // TEMPLATEPARSEREMAILADDRESSREQUESTERLINEEDIT_H
