@@ -1,44 +1,45 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "templateparserjob.h"
-#include "templateparserjob_p.h"
-#include "templateparserextracthtmlinfo.h"
-#include "globalsettings_templateparser.h"
 #include "customtemplates_kfg.h"
-#include "templatesconfiguration_kfg.h"
+#include "globalsettings_templateparser.h"
+#include "templateparserextracthtmlinfo.h"
+#include "templateparserjob_p.h"
 #include "templatesconfiguration.h"
+#include "templatesconfiguration_kfg.h"
 #include "templatesutil.h"
 #include "templatesutil_p.h"
 
 #include <MessageCore/ImageCollector>
 #include <MessageCore/StringUtil>
 
-#include <MimeTreeParser/ObjectTreeParser>
 #include <MimeTreeParser/MessagePart>
+#include <MimeTreeParser/ObjectTreeParser>
 #include <MimeTreeParser/SimpleObjectTreeSource>
 
 #include <KIdentityManagement/Identity>
 #include <KIdentityManagement/IdentityManager>
 
+#include "templateparser_debug.h"
 #include <KCharsets>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KProcess>
 #include <KShell>
-#include "templateparser_debug.h"
 
 #include <QDir>
 #include <QFile>
 #include <QFileInfo>
-#include <QTextCodec>
 #include <QLocale>
 #include <QRegularExpression>
+#include <QTextCodec>
 
-namespace {
+namespace
+{
 Q_DECL_CONSTEXPR inline int pipeTimeout()
 {
     return 15 * 1000;
@@ -69,7 +70,9 @@ static QTextCodec *selectCharset(const QStringList &charsets, const QString &tex
             return codec;
         }
     }
-    qCDebug(TEMPLATEPARSER_LOG) << "No appropriate charset found.";
+    if (!charsets.isEmpty()) {
+        qCDebug(TEMPLATEPARSER_LOG) << "No appropriate charset found.";
+    }
     return KCharsets::charsets()->codecForName(QStringLiteral("utf-8"));
 }
 }
@@ -141,7 +144,7 @@ int TemplateParserJob::parseQuotes(const QString &prefix, const QString &str, QS
 
     // Also allow the german lower double-quote sign as quote separator, not only
     // the standard ASCII quote ("). This fixes bug 166728.
-    const QList< QChar > quoteChars = {QLatin1Char('"'), 0x201C};
+    const QList<QChar> quoteChars = {QLatin1Char('"'), 0x201C};
 
     QChar prev(QChar::Null);
 
@@ -208,12 +211,14 @@ void TemplateParserJob::processWithIdentity(uint uoid, const KMime::Message::Ptr
 
 MimeTreeParser::MessagePart::Ptr toplevelTextNode(MimeTreeParser::MessagePart::Ptr messageTree)
 {
-    foreach (const auto &mp, messageTree->subParts()) {
+    const auto subParts = messageTree->subParts();
+    for (const auto &mp : subParts) {
         auto text = mp.dynamicCast<MimeTreeParser::TextMessagePart>();
         const auto attach = mp.dynamicCast<MimeTreeParser::AttachmentMessagePart>();
         if (text && !attach) {
             // TextMessagePart can have several subparts cause of PGP inline, we search for the first part with content
-            foreach (const auto &sub, mp->subParts()) {
+            const auto mpSubParts{mp->subParts()};
+            for (const auto &sub : mpSubParts) {
                 if (!sub->text().trimmed().isEmpty()) {
                     return sub;
                 }
@@ -249,16 +254,16 @@ void TemplateParserJob::processWithTemplate(const QString &tmpl)
 
     if (mp->isHtml()) {
         htmlElement = d->mOtp->htmlContent();
-        if (plainText.isEmpty()) {   //HTML-only mails
+        if (plainText.isEmpty()) { // HTML-only mails
             plainText = htmlElement;
         }
-    } else {   //plain mails only
+    } else { // plain mails only
         QString htmlReplace = plainText.toHtmlEscaped();
         htmlReplace.replace(QLatin1Char('\n'), QStringLiteral("<br />"));
         htmlElement = QStringLiteral("<html><head></head><body>%1</body></html>\n").arg(htmlReplace);
     }
 
-    TemplateParserExtractHtmlInfo *job = new TemplateParserExtractHtmlInfo(this);
+    auto job = new TemplateParserExtractHtmlInfo(this);
     connect(job, &TemplateParserExtractHtmlInfo::finished, this, &TemplateParserJob::slotExtractInfoDone);
 
     job->setHtmlForExtractingTextPlain(plainText);
@@ -312,7 +317,7 @@ void TemplateParserJob::slotExtractInfoDone(const TemplateParserExtractHtmlInfoR
                 const int len = parseQuotes(QStringLiteral("DICTIONARYLANGUAGE="), cmd, q);
                 i += len;
                 if (!q.isEmpty()) {
-                    KMime::Headers::Generic *header = new KMime::Headers::Generic("X-KMail-Dictionary");
+                    auto header = new KMime::Headers::Generic("X-KMail-Dictionary");
                     header->fromUnicodeString(q, "utf-8");
                     d->mMsg->setHeader(header);
                 }
@@ -342,10 +347,7 @@ void TemplateParserJob::slotExtractInfoDone(const TemplateParserExtractHtmlInfoR
                     const QString body = plainTextToHtml(str);
                     htmlBody.append(body);
                 } else if (d->mDebug) {
-                    KMessageBox::error(
-                        nullptr,
-                        i18nc("@info",
-                              "Cannot insert content from file %1: %2", path, file.errorString()));
+                    KMessageBox::error(nullptr, i18nc("@info", "Cannot insert content from file %1: %2", path, file.errorString()));
                 }
             } else if (cmd.startsWith(QLatin1String("SYSTEM="))) {
                 // insert content of specified file as is
@@ -366,16 +368,14 @@ void TemplateParserJob::slotExtractInfoDone(const TemplateParserExtractHtmlInfoR
                 i += len;
                 const QString pipe_cmd = q;
                 if (d->mOrigMsg) {
-                    const QString plainStr
-                        = pipe(pipe_cmd, plainMessageText(shouldStripSignature(), NoSelectionAllowed));
+                    const QString plainStr = pipe(pipe_cmd, plainMessageText(shouldStripSignature(), NoSelectionAllowed));
                     QString plainQuote = quotedPlainText(plainStr);
                     if (plainQuote.endsWith(QLatin1Char('\n'))) {
                         plainQuote.chop(1);
                     }
                     plainBody.append(plainQuote);
 
-                    const QString htmlStr
-                        = pipe(pipe_cmd, htmlMessageText(shouldStripSignature(), NoSelectionAllowed));
+                    const QString htmlStr = pipe(pipe_cmd, htmlMessageText(shouldStripSignature(), NoSelectionAllowed));
                     const QString htmlQuote = quotedHtmlText(htmlStr);
                     htmlBody.append(htmlQuote);
                 }
@@ -383,15 +383,13 @@ void TemplateParserJob::slotExtractInfoDone(const TemplateParserExtractHtmlInfoR
                 qCDebug(TEMPLATEPARSER_LOG) << "Command: QUOTE";
                 i += strlen("QUOTE");
                 if (d->mOrigMsg) {
-                    QString plainQuote
-                        = quotedPlainText(plainMessageText(shouldStripSignature(), SelectionAllowed));
+                    QString plainQuote = quotedPlainText(plainMessageText(shouldStripSignature(), SelectionAllowed));
                     if (plainQuote.endsWith(QLatin1Char('\n'))) {
                         plainQuote.chop(1);
                     }
                     plainBody.append(plainQuote);
 
-                    const QString htmlQuote
-                        = quotedHtmlText(htmlMessageText(shouldStripSignature(), SelectionAllowed));
+                    const QString htmlQuote = quotedHtmlText(htmlMessageText(shouldStripSignature(), SelectionAllowed));
                     htmlBody.append(htmlQuote);
                 }
             } else if (cmd.startsWith(QLatin1String("FORCEDPLAIN"))) {
@@ -407,15 +405,13 @@ void TemplateParserJob::slotExtractInfoDone(const TemplateParserExtractHtmlInfoR
                 i += strlen("QHEADERS");
                 if (d->mOrigMsg) {
                     const QString headerStr = QString::fromLatin1(MessageCore::StringUtil::headerAsSendableString(d->mOrigMsg));
-                    QString plainQuote
-                        = quotedPlainText(headerStr);
+                    QString plainQuote = quotedPlainText(headerStr);
                     if (plainQuote.endsWith(QLatin1Char('\n'))) {
                         plainQuote.chop(1);
                     }
                     plainBody.append(plainQuote);
 
-                    const QString htmlQuote
-                        = quotedHtmlText(headerStr);
+                    const QString htmlQuote = quotedHtmlText(headerStr);
                     const QString str = plainTextToHtml(htmlQuote);
                     htmlBody.append(str);
                 }
@@ -436,12 +432,10 @@ void TemplateParserJob::slotExtractInfoDone(const TemplateParserExtractHtmlInfoR
                 i += len;
                 const QString pipe_cmd = q;
                 if (d->mOrigMsg) {
-                    const QString plainStr
-                        = pipe(pipe_cmd, plainMessageText(shouldStripSignature(), NoSelectionAllowed));
+                    const QString plainStr = pipe(pipe_cmd, plainMessageText(shouldStripSignature(), NoSelectionAllowed));
                     plainBody.append(plainStr);
 
-                    const QString htmlStr
-                        = pipe(pipe_cmd, htmlMessageText(shouldStripSignature(), NoSelectionAllowed));
+                    const QString htmlStr = pipe(pipe_cmd, htmlMessageText(shouldStripSignature(), NoSelectionAllowed));
                     htmlBody.append(htmlStr);
                 }
             } else if (cmd.startsWith(QLatin1String("MSGPIPE="))) {
@@ -451,8 +445,7 @@ void TemplateParserJob::slotExtractInfoDone(const TemplateParserExtractHtmlInfoR
                 const int len = parseQuotes(QStringLiteral("MSGPIPE="), cmd, q);
                 i += len;
                 if (d->mOrigMsg) {
-                    QString pipe_cmd = q;
-                    const QString str = pipe(pipe_cmd, QString::fromLatin1(d->mOrigMsg->encodedContent()));
+                    const QString str = pipe(q, QString::fromLatin1(d->mOrigMsg->encodedContent()));
                     plainBody.append(str);
 
                     const QString body = plainTextToHtml(str);
@@ -465,7 +458,7 @@ void TemplateParserJob::slotExtractInfoDone(const TemplateParserExtractHtmlInfoR
                 const int len = parseQuotes(QStringLiteral("BODYPIPE="), cmd, q);
                 i += len;
                 const QString pipe_cmd = q;
-                const QString plainStr = pipe(pipe_cmd, plainBody);
+                const QString plainStr = pipe(q, plainBody);
                 plainBody.append(plainStr);
 
                 const QString htmlStr = pipe(pipe_cmd, htmlBody);
@@ -485,7 +478,7 @@ void TemplateParserJob::slotExtractInfoDone(const TemplateParserExtractHtmlInfoR
                 const QString htmlStr = pipe(pipe_cmd, htmlBody);
                 htmlBody = htmlStr;
 
-                KMime::Headers::Generic *header = new KMime::Headers::Generic("X-KMail-CursorPos");
+                auto header = new KMime::Headers::Generic("X-KMail-CursorPos");
                 header->fromUnicodeString(QString::number(0), "utf-8");
                 d->mMsg->setHeader(header);
             } else if (cmd.startsWith(QLatin1String("TEXT"))) {
@@ -535,7 +528,7 @@ void TemplateParserJob::slotExtractInfoDone(const TemplateParserExtractHtmlInfoR
                         htmlBody.append(str);
                     }
                     if (!cc.isEmpty()) {
-                        const QString ccLine = i18nc("@item:intext email CC", "CC:") + QLatin1Char(' ') +  cc;
+                        const QString ccLine = i18nc("@item:intext email CC", "CC:") + QLatin1Char(' ') + cc;
                         plainBody.append(ccLine);
                         const QString str = plainTextToHtml(ccLine);
                         htmlBody.append(str);
@@ -688,12 +681,13 @@ void TemplateParserJob::slotExtractInfoDone(const TemplateParserExtractHtmlInfoR
                 // insert specified content of header from current message
                 qCDebug(TEMPLATEPARSER_LOG) << "Command: HEADER(";
                 QRegularExpressionMatch match;
-                const int res = cmd.indexOf(QRegularExpression(QStringLiteral("^HEADER\\((.+)\\)")), 0, &match);
+                static QRegularExpression reg(QStringLiteral("^HEADER\\((.+)\\)"));
+                const int res = cmd.indexOf(reg, 0, &match);
                 if (res != 0) {
                     // something wrong
                     i += strlen("HEADER( ");
                 } else {
-                    i += match.capturedLength(0); //length of HEADER(<space> + <space>)
+                    i += match.capturedLength(0); // length of HEADER(<space> + <space>)
                     const QString hdr = match.captured(1).trimmed();
                     QString str;
                     if (auto hrdMsgOrigin = d->mOrigMsg->headerByType(hdr.toLocal8Bit().constData())) {
@@ -998,7 +992,7 @@ void TemplateParserJob::slotExtractInfoDone(const TemplateParserExtractHtmlInfoR
                 i += strlen("CLEAR");
                 plainBody.clear();
                 htmlBody.clear();
-                KMime::Headers::Generic *header = new KMime::Headers::Generic("X-KMail-CursorPos");
+                auto header = new KMime::Headers::Generic("X-KMail-CursorPos");
                 header->fromUnicodeString(QString::number(0), "utf-8");
                 d->mMsg->setHeader(header);
             } else if (cmd.startsWith(QLatin1String("DEBUGOFF"))) {
@@ -1016,20 +1010,20 @@ void TemplateParserJob::slotExtractInfoDone(const TemplateParserExtractHtmlInfoR
                 qCDebug(TEMPLATEPARSER_LOG) << "Command: CURSOR";
                 int oldI = i;
                 i += strlen("CURSOR");
-                KMime::Headers::Generic *header = new KMime::Headers::Generic("X-KMail-CursorPos");
+                auto header = new KMime::Headers::Generic("X-KMail-CursorPos");
                 header->fromUnicodeString(QString::number(plainBody.length()), "utf-8");
                 /* if template is:
-                *  FOOBAR
-                *  %CURSOR
-                *
-                * Make sure there is an empty line for the cursor otherwise it will be placed at the end of FOOBAR
-                */
-                if (oldI > 0 && tmpl[ oldI - 1 ] == QLatin1Char('\n') && i == tmpl_len - 1) {
+                 *  FOOBAR
+                 *  %CURSOR
+                 *
+                 * Make sure there is an empty line for the cursor otherwise it will be placed at the end of FOOBAR
+                 */
+                if (oldI > 0 && tmpl[oldI - 1] == QLatin1Char('\n') && i == tmpl_len - 1) {
                     plainBody.append(QLatin1Char('\n'));
                 }
                 d->mMsg->setHeader(header);
                 d->mForceCursorPosition = true;
-                //FIXME HTML part for header remaining
+                // FIXME HTML part for header remaining
             } else if (cmd.startsWith(QLatin1String("SIGNATURE"))) {
                 qCDebug(TEMPLATEPARSER_LOG) << "Command: SIGNATURE";
                 i += strlen("SIGNATURE");
@@ -1043,8 +1037,7 @@ void TemplateParserJob::slotExtractInfoDone(const TemplateParserExtractHtmlInfoR
         } else if (dnl && (c == QLatin1Char('\n') || c == QLatin1Char('\r'))) {
             // skip
             if ((tmpl.size() > i + 1)
-                && ((c == QLatin1Char('\n') && tmpl[i + 1] == QLatin1Char('\r'))
-                    || (c == QLatin1Char('\r') && tmpl[i + 1] == QLatin1Char('\n')))) {
+                && ((c == QLatin1Char('\n') && tmpl[i + 1] == QLatin1Char('\r')) || (c == QLatin1Char('\r') && tmpl[i + 1] == QLatin1Char('\n')))) {
                 // skip one more
                 i += 1;
             }
@@ -1055,8 +1048,7 @@ void TemplateParserJob::slotExtractInfoDone(const TemplateParserExtractHtmlInfoR
                 htmlBody.append(QLatin1String("<br />"));
                 htmlBody.append(c);
                 if (tmpl.size() > i + 1
-                    && ((c == QLatin1Char('\n') && tmpl[i + 1] == QLatin1Char('\r'))
-                        || (c == QLatin1Char('\r') && tmpl[i + 1] == QLatin1Char('\n')))) {
+                    && ((c == QLatin1Char('\n') && tmpl[i + 1] == QLatin1Char('\r')) || (c == QLatin1Char('\r') && tmpl[i + 1] == QLatin1Char('\n')))) {
                     htmlBody.append(tmpl[i + 1]);
                     plainBody.append(tmpl[i + 1]);
                     i += 1;
@@ -1070,10 +1062,8 @@ void TemplateParserJob::slotExtractInfoDone(const TemplateParserExtractHtmlInfoR
     // there is no use of FORCED command but a configure setting has ReplyUsingHtml disabled,
     // OR the original mail has no HTML part.
     const KMime::Content *content = d->mOrigMsg->mainBodyPart("text/html");
-    if (d->mQuotes == ReplyAsPlain
-            || (!d->mReplyAsHtml  && TemplateParserSettings::self()->replyUsingVisualFormat())
-            || !TemplateParserSettings::self()->replyUsingVisualFormat()
-            || (!content || !content->hasContent())) {
+    if (d->mQuotes == ReplyAsPlain || (!d->mReplyAsHtml && TemplateParserSettings::self()->replyUsingVisualFormat())
+        || !TemplateParserSettings::self()->replyUsingVisualFormat() || (!content || !content->hasContent())) {
         htmlBody.clear();
     } else {
         makeValidHtml(htmlBody);
@@ -1089,18 +1079,15 @@ void TemplateParserJob::slotExtractInfoDone(const TemplateParserExtractHtmlInfoR
 
 QString TemplateParserJob::getPlainSignature() const
 {
-    const KIdentityManagement::Identity &identity
-        = d->m_identityManager->identityForUoid(d->mIdentity);
+    const KIdentityManagement::Identity &identity = d->m_identityManager->identityForUoid(d->mIdentity);
 
     if (identity.isNull()) {
         return QString();
     }
 
-    KIdentityManagement::Signature signature
-        = const_cast<KIdentityManagement::Identity &>(identity).signature();
+    KIdentityManagement::Signature signature = const_cast<KIdentityManagement::Identity &>(identity).signature();
 
-    if (signature.type() == KIdentityManagement::Signature::Inlined
-        && signature.isInlinedHtml()) {
+    if (signature.type() == KIdentityManagement::Signature::Inlined && signature.isInlinedHtml()) {
         return signature.toPlainText();
     } else {
         return signature.rawText();
@@ -1112,14 +1099,12 @@ QString TemplateParserJob::getPlainSignature() const
 // There should be no two signatures.
 QString TemplateParserJob::getHtmlSignature() const
 {
-    const KIdentityManagement::Identity &identity
-        = d->m_identityManager->identityForUoid(d->mIdentity);
+    const KIdentityManagement::Identity &identity = d->m_identityManager->identityForUoid(d->mIdentity);
     if (identity.isNull()) {
         return QString();
     }
 
-    KIdentityManagement::Signature signature
-        = const_cast<KIdentityManagement::Identity &>(identity).signature();
+    KIdentityManagement::Signature signature = const_cast<KIdentityManagement::Identity &>(identity).signature();
 
     if (!signature.isInlinedHtml()) {
         signature = signature.rawText().toHtmlEscaped();
@@ -1151,11 +1136,8 @@ void TemplateParserJob::addProcessedBodyToMessage(const QString &plainBody, cons
 
     d->mMsg->contentType()->clear(); // to get rid of old boundary
 
-    //const QByteArray boundary = KMime::multiPartBoundary();
-    KMime::Content *const mainTextPart
-        = htmlBody.isEmpty()
-          ? createPlainPartContent(plainBody)
-          : createMultipartAlternativeContent(plainBody, htmlBody);
+    // const QByteArray boundary = KMime::multiPartBoundary();
+    KMime::Content *const mainTextPart = htmlBody.isEmpty() ? createPlainPartContent(plainBody) : createMultipartAlternativeContent(plainBody, htmlBody);
     mainTextPart->assemble();
 
     KMime::Content *textPart = mainTextPart;
@@ -1185,7 +1167,7 @@ void TemplateParserJob::addProcessedBodyToMessage(const QString &plainBody, cons
 
 KMime::Content *TemplateParserJob::createMultipartMixed(const QVector<KMime::Content *> &attachments, KMime::Content *textPart) const
 {
-    KMime::Content *mixedPart = new KMime::Content(d->mMsg.data());
+    auto mixedPart = new KMime::Content(d->mMsg.data());
     const QByteArray boundary = KMime::multiPartBoundary();
     auto contentType = mixedPart->contentType();
     contentType->setMimeType("multipart/mixed");
@@ -1199,10 +1181,8 @@ KMime::Content *TemplateParserJob::createMultipartMixed(const QVector<KMime::Con
         // If the content type has no name or filename parameter, add one, since otherwise the name
         // would be empty in the attachment view of the composer, which looks confusing
         if (auto ct = attachment->contentType(false)) {
-            if (!ct->hasParameter(QStringLiteral("name"))
-                && !ct->hasParameter(QStringLiteral("filename"))) {
-                ct->setParameter(
-                    QStringLiteral("name"), i18nc("@item:intext", "Attachment %1", attachmentNumber));
+            if (!ct->hasParameter(QStringLiteral("name")) && !ct->hasParameter(QStringLiteral("filename"))) {
+                ct->setParameter(QStringLiteral("name"), i18nc("@item:intext", "Attachment %1", attachmentNumber));
             }
         }
         ++attachmentNumber;
@@ -1212,7 +1192,7 @@ KMime::Content *TemplateParserJob::createMultipartMixed(const QVector<KMime::Con
 
 KMime::Content *TemplateParserJob::createMultipartRelated(const MessageCore::ImageCollector &ic, KMime::Content *mainTextPart) const
 {
-    KMime::Content *relatedPart = new KMime::Content(d->mMsg.data());
+    auto relatedPart = new KMime::Content(d->mMsg.data());
     const QByteArray boundary = KMime::multiPartBoundary();
     auto contentType = relatedPart->contentType();
     contentType->setMimeType("multipart/related");
@@ -1228,10 +1208,11 @@ KMime::Content *TemplateParserJob::createMultipartRelated(const MessageCore::Ima
 
 KMime::Content *TemplateParserJob::createPlainPartContent(const QString &plainBody) const
 {
-    KMime::Content *textPart = new KMime::Content(d->mMsg.data());
-    textPart->contentType()->setMimeType("text/plain");
+    auto textPart = new KMime::Content(d->mMsg.data());
+    auto ct = textPart->contentType(true);
+    ct->setMimeType("text/plain");
     QTextCodec *charset = selectCharset(d->mCharsets, plainBody);
-    textPart->contentType()->setCharset(charset->name());
+    ct->setCharset(charset->name());
     textPart->contentTransferEncoding()->setEncoding(KMime::Headers::CE8Bit);
     textPart->fromUnicodeString(plainBody);
     return textPart;
@@ -1239,18 +1220,18 @@ KMime::Content *TemplateParserJob::createPlainPartContent(const QString &plainBo
 
 KMime::Content *TemplateParserJob::createMultipartAlternativeContent(const QString &plainBody, const QString &htmlBody) const
 {
-    KMime::Content *multipartAlternative = new KMime::Content(d->mMsg.data());
+    auto multipartAlternative = new KMime::Content(d->mMsg.data());
     multipartAlternative->contentType()->setMimeType("multipart/alternative");
     const QByteArray boundary = KMime::multiPartBoundary();
-    multipartAlternative->contentType()->setBoundary(boundary);
+    multipartAlternative->contentType(false)->setBoundary(boundary); // Already created
 
     KMime::Content *textPart = createPlainPartContent(plainBody);
     multipartAlternative->addContent(textPart);
 
-    KMime::Content *htmlPart = new KMime::Content(d->mMsg.data());
-    htmlPart->contentType()->setMimeType("text/html");
+    auto htmlPart = new KMime::Content(d->mMsg.data());
+    htmlPart->contentType(true)->setMimeType("text/html");
     QTextCodec *charset = selectCharset(d->mCharsets, htmlBody);
-    htmlPart->contentType()->setCharset(charset->name());
+    htmlPart->contentType(false)->setCharset(charset->name()); // Already created
     htmlPart->contentTransferEncoding()->setEncoding(KMime::Headers::CE8Bit);
     htmlPart->fromUnicodeString(htmlBody);
     multipartAlternative->addContent(htmlPart);
@@ -1278,10 +1259,10 @@ QString TemplateParserJob::findTemplate()
     QString tmpl;
 
     qCDebug(TEMPLATEPARSER_LOG) << "Folder identify found:" << d->mFolder;
-    if (d->mFolder >= 0) {   // only if a folder was found
+    if (d->mFolder >= 0) { // only if a folder was found
         QString fid = QString::number(d->mFolder);
         Templates fconf(fid);
-        if (fconf.useCustomTemplates()) {     // does folder use custom templates?
+        if (fconf.useCustomTemplates()) { // does folder use custom templates?
             switch (d->mMode) {
             case NewMessage:
                 tmpl = fconf.templateNewMessage();
@@ -1301,12 +1282,12 @@ QString TemplateParserJob::findTemplate()
             }
             d->mQuoteString = fconf.quoteString();
             if (!tmpl.isEmpty()) {
-                return tmpl;  // use folder-specific template
+                return tmpl; // use folder-specific template
             }
         }
     }
 
-    if (!d->mIdentity) {   // find identity message belongs to
+    if (!d->mIdentity) { // find identity message belongs to
         d->mIdentity = identityUoid(d->mMsg);
         if (!d->mIdentity && d->mOrigMsg) {
             d->mIdentity = identityUoid(d->mOrigMsg);
@@ -1320,13 +1301,13 @@ QString TemplateParserJob::findTemplate()
 
     QString iid;
     if (d->mIdentity) {
-        iid = TemplatesConfiguration::configIdString(d->mIdentity);          // templates ID for that identity
+        iid = TemplatesConfiguration::configIdString(d->mIdentity); // templates ID for that identity
     } else {
         iid = QStringLiteral("IDENTITY_NO_IDENTITY"); // templates ID for no identity
     }
 
     Templates iconf(iid);
-    if (iconf.useCustomTemplates()) {   // does identity use custom templates?
+    if (iconf.useCustomTemplates()) { // does identity use custom templates?
         switch (d->mMode) {
         case NewMessage:
             tmpl = iconf.templateNewMessage();
@@ -1346,11 +1327,11 @@ QString TemplateParserJob::findTemplate()
         }
         d->mQuoteString = iconf.quoteString();
         if (!tmpl.isEmpty()) {
-            return tmpl;  // use identity-specific template
+            return tmpl; // use identity-specific template
         }
     }
 
-    switch (d->mMode) {  // use the global template
+    switch (d->mMode) { // use the global template
     case NewMessage:
         tmpl = TemplateParserSettings::self()->templateNewMessage();
         break;
@@ -1410,10 +1391,7 @@ QString TemplateParserJob::pipe(const QString &cmd, const QString &buf)
     }
 
     if (!success && d->mDebug) {
-        KMessageBox::error(
-            nullptr,
-            xi18nc("@info",
-                   "Pipe command <command>%1</command> failed.", cmd));
+        KMessageBox::error(nullptr, xi18nc("@info", "Pipe command <command>%1</command> failed.", cmd));
     }
 
     if (success) {
@@ -1453,21 +1431,21 @@ QString TemplateParserJob::plainMessageText(bool aStripSignature, AllowSelection
 QString TemplateParserJob::htmlMessageText(bool aStripSignature, AllowSelection isSelectionAllowed)
 {
     if (!d->mSelection.isEmpty() && (isSelectionAllowed == SelectionAllowed)) {
-        //TODO implement d->mSelection for HTML
+        // TODO implement d->mSelection for HTML
         return d->mSelection;
     }
     d->mHeadElement = d->mExtractHtmlInfoResult.mHeaderElement;
     const QString bodyElement = d->mExtractHtmlInfoResult.mBodyElement;
     if (!bodyElement.isEmpty()) {
         if (aStripSignature) {
-            //FIXME strip signature works partially for HTML mails
+            // FIXME strip signature works partially for HTML mails
             return MessageCore::StringUtil::stripSignature(bodyElement);
         }
         return bodyElement;
     }
 
     if (aStripSignature) {
-        //FIXME strip signature works partially for HTML mails
+        // FIXME strip signature works partially for HTML mails
         return MessageCore::StringUtil::stripSignature(d->mExtractHtmlInfoResult.mHtmlElement);
     }
     return d->mExtractHtmlInfoResult.mHtmlElement;
@@ -1477,8 +1455,7 @@ QString TemplateParserJob::quotedPlainText(const QString &selection) const
 {
     QString content = TemplateParser::Util::removeSpaceAtBegin(selection);
 
-    const QString indentStr
-        = MessageCore::StringUtil::formatQuotePrefix(d->mQuoteString, d->mOrigMsg->from()->displayString());
+    const QString indentStr = MessageCore::StringUtil::formatQuotePrefix(d->mQuoteString, d->mOrigMsg->from()->displayString());
     if (TemplateParserSettings::self()->smartQuote() && d->mWrap) {
         content = MessageCore::StringUtil::smartQuote(content, d->mColWrap - indentStr.length());
     }
@@ -1492,13 +1469,14 @@ QString TemplateParserJob::quotedPlainText(const QString &selection) const
 QString TemplateParserJob::quotedHtmlText(const QString &selection) const
 {
     QString content = selection;
-    //TODO 1) look for all the variations of <br>  and remove the blank lines
-    //2) implement vertical bar for quoted HTML mail.
-    //3) After vertical bar is implemented, If a user wants to edit quoted message,
+    // TODO 1) look for all the variations of <br>  and remove the blank lines
+    // 2) implement vertical bar for quoted HTML mail.
+    // 3) After vertical bar is implemented, If a user wants to edit quoted message,
     // then the <blockquote> tags below should open and close as when required.
 
-    //Add blockquote tag, so that quoted message can be differentiated from normal message
-    content = QLatin1String("<blockquote>") + content + QLatin1String("</blockquote>");
+    // Add blockquote tag, so that quoted message can be differentiated from normal message
+    // Bug 419978 remove \n by <br>
+    content = QLatin1String("<blockquote>") + content.replace(QStringLiteral("\n"), QStringLiteral("<br>")) + QLatin1String("</blockquote>");
     return content;
 }
 
@@ -1512,8 +1490,7 @@ uint TemplateParserJob::identityUoid(const KMime::Message::Ptr &msg) const
     unsigned int id = idString.toUInt(&ok);
 
     if (!ok || id == 0) {
-        id = d->m_identityManager->identityForAddress(
-            msg->to()->asUnicodeString() + QLatin1String(", ") + msg->cc()->asUnicodeString()).uoid();
+        id = d->m_identityManager->identityForAddress(msg->to()->asUnicodeString() + QLatin1String(", ") + msg->cc()->asUnicodeString()).uoid();
     }
 
     return id;
@@ -1521,15 +1498,13 @@ uint TemplateParserJob::identityUoid(const KMime::Message::Ptr &msg) const
 
 bool TemplateParserJob::isHtmlSignature() const
 {
-    const KIdentityManagement::Identity &identity
-        = d->m_identityManager->identityForUoid(d->mIdentity);
+    const KIdentityManagement::Identity &identity = d->m_identityManager->identityForUoid(d->mIdentity);
 
     if (identity.isNull()) {
         return false;
     }
 
-    const KIdentityManagement::Signature signature
-        = const_cast<KIdentityManagement::Identity &>(identity).signature();
+    const KIdentityManagement::Signature signature = const_cast<KIdentityManagement::Identity &>(identity).signature();
 
     return signature.isInlinedHtml();
 }
@@ -1544,16 +1519,19 @@ QString TemplateParserJob::plainTextToHtml(const QString &body)
 
 void TemplateParserJob::makeValidHtml(QString &body)
 {
-    QRegExp regEx;
-    regEx.setMinimal(true);
-    regEx.setPattern(QStringLiteral("<html.*>"));
+    if (body.isEmpty()) {
+        return;
+    }
 
-    if (!body.isEmpty() && !body.contains(regEx)) {
-        regEx.setPattern(QStringLiteral("<body.*>"));
+    QRegularExpression regEx;
+
+    regEx.setPattern(QStringLiteral("<html.*?>"));
+    if (!body.contains(regEx)) {
+        regEx.setPattern(QStringLiteral("<body.*?>"));
         if (!body.contains(regEx)) {
             body = QLatin1String("<body>") + body + QLatin1String("<br/></body>");
         }
-        regEx.setPattern(QStringLiteral("<head.*>"));
+        regEx.setPattern(QStringLiteral("<head.*?>"));
         if (!body.contains(regEx)) {
             body = QLatin1String("<head>") + d->mHeadElement + QLatin1String("</head>") + body;
         }
