@@ -1,17 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef TEMPLATESINSERTCOMMANDACTION_H
-#define TEMPLATESINSERTCOMMANDACTION_H
+#pragma once
 
 #include <QWidgetAction>
 #include <TemplateParser/TemplatesCommandMenu>
 
 #include "templateparser_export.h"
-namespace TemplateParser {
+namespace TemplateParser
+{
 /**
  * @brief The TemplatesInsertCommandAction class
  * @author Laurent Montel <montel@kde.org>
@@ -21,7 +21,7 @@ class TEMPLATEPARSER_EXPORT TemplatesInsertCommandAction : public QWidgetAction
     Q_OBJECT
 public:
     explicit TemplatesInsertCommandAction(QObject *parent = nullptr);
-    ~TemplatesInsertCommandAction();
+    ~TemplatesInsertCommandAction() override;
 
     Q_REQUIRED_RESULT TemplatesCommandMenu::MenuTypes type() const;
     void setType(TemplatesCommandMenu::MenuTypes type);
@@ -30,7 +30,6 @@ Q_SIGNALS:
     void insertCommand(const QString &cmd, int adjustCursor);
 
 private:
-    TemplatesCommandMenu *mMenuCommand = nullptr;
+    TemplatesCommandMenu *const mMenuCommand;
 };
 }
-#endif // TEMPLATESINSERTCOMMANDACTION_H
