@@ -1,6 +1,6 @@
 /*
  * SPDX-FileCopyrightText: 2006 Dmitry Morozhnikov <dmiceman@mail.ru>
- * SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -14,25 +14,22 @@ using namespace TemplateParser;
 
 TemplatesInsertCommandPushButton::TemplatesInsertCommandPushButton(QWidget *parent, const QString &name)
     : QPushButton(parent)
+    , mMenuCommand(new TemplatesCommandMenu(this))
 {
     setObjectName(name);
     setText(i18n("&Insert Command"));
 
-    mMenuCommand = new TemplatesCommandMenu(this);
     mMenuCommand->setObjectName(QStringLiteral("templatescommandmenu"));
     mMenuCommand->fillMenu();
     mMenuCommand->fillSubMenus();
     setMenu(mMenuCommand->menu());
     connect(mMenuCommand, qOverload<const QString &, int>(&TemplatesCommandMenu::insertCommand), this, &TemplatesInsertCommandPushButton::insertCommand);
 
-    setToolTip(
-        i18nc("@info:tooltip",
-              "Select a command to insert into the template"));
-    setWhatsThis(
-        i18nc("@info:whatsthis",
-              "Traverse this menu to find a command to insert into the current template "
-              "being edited.  The command will be inserted at the cursor location, "
-              "so you want to move your cursor to the desired insertion point first."));
+    setToolTip(i18nc("@info:tooltip", "Select a command to insert into the template"));
+    setWhatsThis(i18nc("@info:whatsthis",
+                       "Traverse this menu to find a command to insert into the current template "
+                       "being edited.  The command will be inserted at the cursor location, "
+                       "so you want to move your cursor to the desired insertion point first."));
 }
 
 TemplatesInsertCommandPushButton::~TemplatesInsertCommandPushButton()
