@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef TEST_TEMPLATEEDITOR_GUI_H
-#define TEST_TEMPLATEEDITOR_GUI_H
+#pragma once
 
 #include <QWidget>
 
@@ -14,7 +13,6 @@ class TemplateEditorTestWidget : public QWidget
     Q_OBJECT
 public:
     explicit TemplateEditorTestWidget(QWidget *parent = nullptr);
-    ~TemplateEditorTestWidget();
+    ~TemplateEditorTestWidget() override;
 };
 
-#endif
