@@ -1,12 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-
-#ifndef WEBENGINEEXPORTPDFPAGEJOBTEST_H
-#define WEBENGINEEXPORTPDFPAGEJOBTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -15,7 +13,7 @@ class WebEngineExportPdfPageJobTest : public QObject
     Q_OBJECT
 public:
     explicit WebEngineExportPdfPageJobTest(QObject *parent = nullptr);
-    ~WebEngineExportPdfPageJobTest() = default;
+    ~WebEngineExportPdfPageJobTest() override = default;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldBeAbleToExport();
@@ -23,4 +21,3 @@ private Q_SLOTS:
     void shouldEmitSignalSuccess();
 };
 
-#endif // WEBENGINEEXPORTPDFPAGEJOBTEST_H
