@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef BACKOFFMODEMANAGERTEST_H
-#define BACKOFFMODEMANAGERTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,7 +13,7 @@ class BackOffModeManagerTest : public QObject
     Q_OBJECT
 public:
     explicit BackOffModeManagerTest(QObject *parent = nullptr);
-    ~BackOffModeManagerTest();
+    ~BackOffModeManagerTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldStartBackOffMode();
@@ -22,4 +21,3 @@ private Q_SLOTS:
     void shouldIncreaseBackOff();
 };
 
-#endif // BACKOFFMODEMANAGERTEST_H
