@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef CHECKPHISHINGURLCACHETEST_H
-#define CHECKPHISHINGURLCACHETEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,7 +13,7 @@ class CheckPhishingUrlCacheTest : public QObject
     Q_OBJECT
 public:
     explicit CheckPhishingUrlCacheTest(QObject *parent = nullptr);
-    ~CheckPhishingUrlCacheTest();
+    ~CheckPhishingUrlCacheTest() override;
 private Q_SLOTS:
     void shouldNotBeAMalware();
 
@@ -24,4 +23,3 @@ private Q_SLOTS:
     void shouldStoreValues();
 };
 
-#endif // CHECKPHISHINGURLCACHETEST_H
