@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef CREATEPHISHINGURLDATABASEJOBTEST_H
-#define CREATEPHISHINGURLDATABASEJOBTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,7 +13,7 @@ class CreatePhishingUrlDataBaseJobTest : public QObject
     Q_OBJECT
 public:
     explicit CreatePhishingUrlDataBaseJobTest(QObject *parent = nullptr);
-    ~CreatePhishingUrlDataBaseJobTest();
+    ~CreatePhishingUrlDataBaseJobTest() override;
 private Q_SLOTS:
     void shouldCreateRequest_data();
     void shouldCreateRequest();
@@ -35,4 +34,3 @@ private Q_SLOTS:
     void checkRiceDeltaEncoding();
 };
 
-#endif // CREATEPHISHINGURLDATABASEJOBTEST_H
