@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef DOWNLOADLOCALDATABASETHREADTEST_H
-#define DOWNLOADLOCALDATABASETHREADTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,7 +13,6 @@ class DownloadLocalDatabaseThreadTest : public QObject
     Q_OBJECT
 public:
     explicit DownloadLocalDatabaseThreadTest(QObject *parent = nullptr);
-    ~DownloadLocalDatabaseThreadTest();
+    ~DownloadLocalDatabaseThreadTest() override;
 };
 
-#endif // DOWNLOADLOCALDATABASETHREADTEST_H
