@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -49,4 +49,4 @@ void HashCacheManagerTest::shouldAddValue()
     cache.clearCache();
 }
 
-QTEST_MAIN(HashCacheManagerTest)
+QTEST_GUILESS_MAIN(HashCacheManagerTest)
