@@ -1,17 +1,18 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef BACKOFFMODEMANAGER_H
-#define BACKOFFMODEMANAGER_H
+#pragma once
 
-#include <QObject>
 #include "webengineviewer_export.h"
-namespace WebEngineViewer {
+#include <QObject>
+#include <memory>
+namespace WebEngineViewer
+{
 class BackOffModeManagerPrivate;
-//https://developers.google.com/safe-browsing/v4/request-frequency
+// https://developers.google.com/safe-browsing/v4/request-frequency
 /**
  * @brief The BackOffModeManager class
  * @author Laurent Montel <montel@kde.org>
@@ -20,7 +21,7 @@ class WEBENGINEVIEWER_EXPORT BackOffModeManager : public QObject
 {
 public:
     explicit BackOffModeManager(QObject *parent = nullptr);
-    ~BackOffModeManager();
+    ~BackOffModeManager() override;
 
     static BackOffModeManager *self();
     bool isInBackOffMode() const;
@@ -33,8 +34,7 @@ public Q_SLOTS:
     void slotTimerFinished();
 
 private:
-    BackOffModeManagerPrivate *const d;
+    std::unique_ptr<BackOffModeManagerPrivate> const d;
 };
 }
 
-#endif // BACKOFFMODEMANAGER_H
