@@ -1,12 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "checkphishingurlcache.h"
-#include "webengineviewer_debug.h"
 #include "checkphishingurlutil.h"
+#include "webengineviewer_debug.h"
 #include <KConfig>
 #include <KConfigGroup>
 #include <QMap>
@@ -47,6 +47,7 @@ public:
     void clearCache();
     void load();
     void save();
+
 private:
     QMap<QUrl, UrlCacheInfo> mCacheCheckedUrl;
 };
@@ -137,10 +138,7 @@ CheckPhishingUrlCache::CheckPhishingUrlCache(QObject *parent)
 {
 }
 
-CheckPhishingUrlCache::~CheckPhishingUrlCache()
-{
-    delete d;
-}
+CheckPhishingUrlCache::~CheckPhishingUrlCache() = default;
 
 void CheckPhishingUrlCache::addCheckingUrlResult(const QUrl &url, bool correctUrl, uint verifyCacheAfterThisTime)
 {
