@@ -1,17 +1,18 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef CHECKPHISHINGURLCACHE_H
-#define CHECKPHISHINGURLCACHE_H
+#pragma once
 
 #include "webengineviewer_export.h"
 #include <QObject>
 #include <QUrl>
+#include <memory>
 
-namespace WebEngineViewer {
+namespace WebEngineViewer
+{
 class CheckPhishingUrlCachePrivate;
 /**
  * @brief The CheckPhishingUrlCache class
@@ -23,14 +24,10 @@ class WEBENGINEVIEWER_EXPORT CheckPhishingUrlCache : public QObject
 public:
     static CheckPhishingUrlCache *self();
 
-    enum UrlStatus {
-        UrlOk = 0,
-        MalWare = 1,
-        Unknown = 2
-    };
+    enum UrlStatus { UrlOk = 0, MalWare = 1, Unknown = 2 };
 
     explicit CheckPhishingUrlCache(QObject *parent = nullptr);
-    ~CheckPhishingUrlCache();
+    ~CheckPhishingUrlCache() override;
 
     /**
      * @brief addCheckingUrlResult cache url. If @p correctUrl is true we store as UrlOk otherwise MalWare
@@ -49,11 +46,11 @@ public:
      * @brief clearCache clear the cache and save result in config file.
      */
     void clearCache();
+
 private:
-    CheckPhishingUrlCachePrivate *const d;
+    std::unique_ptr<CheckPhishingUrlCachePrivate> const d;
 };
 }
 
 Q_DECLARE_METATYPE(WebEngineViewer::CheckPhishingUrlCache::UrlStatus)
 
-#endif // CHECKPHISHINGURLCACHE_H
