@@ -1,17 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "checkphishingurljob.h"
-#include "checkphishingurlutil.h"
-#include <QNetworkAccessManager>
 #include <PimCommon/NetworkManager>
 #include <QJsonDocument>
-#include <webengineviewer_debug.h>
+#include <QNetworkAccessManager>
 #include <QNetworkConfigurationManager>
 #include <QUrlQuery>
+#include <webengineviewer_debug.h>
 using namespace WebEngineViewer;
 
 WEBENGINEVIEWER_EXPORT bool webengineview_useCompactJson = true;
@@ -20,7 +19,6 @@ class WebEngineViewer::CheckPhishingUrlJobPrivate
 {
 public:
     CheckPhishingUrlJobPrivate()
-        : mNetworkAccessManager(nullptr)
     {
     }
 
@@ -41,10 +39,7 @@ CheckPhishingUrlJob::CheckPhishingUrlJob(QObject *parent)
     connect(d->mNetworkAccessManager, &QNetworkAccessManager::sslErrors, this, &CheckPhishingUrlJob::slotSslErrors);
 }
 
-CheckPhishingUrlJob::~CheckPhishingUrlJob()
-{
-    delete d;
-}
+CheckPhishingUrlJob::~CheckPhishingUrlJob() = default;
 
 void CheckPhishingUrlJob::slotSslErrors(QNetworkReply *reply, const QList<QSslError> &error)
 {
@@ -114,12 +109,12 @@ QByteArray CheckPhishingUrlJob::jsonRequest() const
     map.insert(QStringLiteral("client"), clientMap);
 
     QVariantMap threatMap;
-    const QVariantList platformList = { QStringLiteral("WINDOWS") };
+    const QVariantList platformList = {QStringLiteral("WINDOWS")};
     threatMap.insert(QStringLiteral("platformTypes"), platformList);
 
-    const QVariantList threatTypesList = { QStringLiteral("MALWARE") };
+    const QVariantList threatTypesList = {QStringLiteral("MALWARE")};
     threatMap.insert(QStringLiteral("threatTypes"), threatTypesList);
-    const QVariantList threatEntryTypesList = { QStringLiteral("URL") };
+    const QVariantList threatEntryTypesList = {QStringLiteral("URL")};
     threatMap.insert(QStringLiteral("threatEntryTypes"), threatEntryTypesList);
     QVariantList threatEntriesList;
     QVariantMap urlMap;
@@ -150,16 +145,12 @@ void CheckPhishingUrlJob::start()
         const QByteArray baPostData = jsonRequest();
         qCDebug(WEBENGINEVIEWER_LOG) << " postData.toJson()" << baPostData;
         Q_EMIT debugJson(baPostData);
-        //curl -H "Content-Type: application/json" -X POST -d '{"client":{"clientId":"KDE","clientVersion":"5.4.0"},"threatInfo":{"platformTypes":["WINDOWS"],"threatEntries":[{"url":"http://www.kde.org"}],"threatEntryTypes":["URL"],"threatTypes":["MALWARE"]}}' https://safebrowsing.googleapis.com/v4/threatMatches:find?key=AIzaSyBS62pXATjabbH2RM_jO2EzDg1mTMHlnyo
+        // curl -H "Content-Type: application/json" -X POST -d
+        // '{"client":{"clientId":"KDE","clientVersion":"5.4.0"},"threatInfo":{"platformTypes":["WINDOWS"],"threatEntries":[{"url":"http://www.kde.org"}],"threatEntryTypes":["URL"],"threatTypes":["MALWARE"]}}'
+        // https://safebrowsing.googleapis.com/v4/threatMatches:find?key=AIzaSyBS62pXATjabbH2RM_jO2EzDg1mTMHlnyo
 
         QNetworkReply *reply = d->mNetworkAccessManager->post(request, baPostData);
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        connect(reply, qOverload<QNetworkReply::NetworkError>(&QNetworkReply::error), this, &CheckPhishingUrlJob::slotError);
-#else
         connect(reply, qOverload<QNetworkReply::NetworkError>(&QNetworkReply::errorOccurred), this, &CheckPhishingUrlJob::slotError);
-#endif
-
-
     } else {
         Q_EMIT result(WebEngineViewer::CheckPhishingUrlUtil::InvalidUrl, d->mUrl);
         deleteLater();
@@ -168,7 +159,7 @@ void CheckPhishingUrlJob::start()
 
 void CheckPhishingUrlJob::slotError(QNetworkReply::NetworkError error)
 {
-    QNetworkReply *reply = qobject_cast<QNetworkReply *>(sender());
+    auto reply = qobject_cast<QNetworkReply *>(sender());
     qCWarning(WEBENGINEVIEWER_LOG) << " error " << error << " error string : " << reply->errorString();
     reply->deleteLater();
     deleteLater();
