@@ -1,17 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef CREATEDATABASEFILEJOB_H
-#define CREATEDATABASEFILEJOB_H
+#pragma once
 
-#include <QObject>
-#include "webengineviewer_export.h"
 #include "updatedatabaseinfo.h"
-
-namespace WebEngineViewer {
+#include "webengineviewer_export.h"
+#include <QObject>
+#include <memory>
+namespace WebEngineViewer
+{
 class CreateDatabaseFileJobPrivate;
 /**
  * @brief The CreateDatabaseFileJob class
@@ -22,18 +22,17 @@ class WEBENGINEVIEWER_EXPORT CreateDatabaseFileJob : public QObject
     Q_OBJECT
 public:
     explicit CreateDatabaseFileJob(QObject *parent = nullptr);
-    ~CreateDatabaseFileJob();
+    ~CreateDatabaseFileJob() override;
     void start();
     void setFileName(const QString &filename);
-    bool canStart() const;
+    Q_REQUIRED_RESULT bool canStart() const;
     void setUpdateDataBaseInfo(const WebEngineViewer::UpdateDataBaseInfo &infoDataBase);
 
 Q_SIGNALS:
     void finished(bool success, const QString &newStateDatabase, const QString &minimumWaitDurationStr);
 
 private:
-    CreateDatabaseFileJobPrivate *const d;
+    std::unique_ptr<CreateDatabaseFileJobPrivate> const d;
 };
 }
 
-#endif // CREATEDATABASEFILEJOB_H
