@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -10,8 +10,8 @@
 #include "webengineviewer_debug.h"
 #include <PimCommon/NetworkManager>
 
-#include <QNetworkConfigurationManager>
 #include <QJsonDocument>
+#include <QNetworkConfigurationManager>
 #include <QUrlQuery>
 
 using namespace WebEngineViewer;
@@ -21,19 +21,13 @@ WEBENGINEVIEWER_EXPORT bool webengineview_useCompactJson_CreatePhishingUrlDataBa
 class WebEngineViewer::CreatePhishingUrlDataBaseJobPrivate
 {
 public:
-    CreatePhishingUrlDataBaseJobPrivate()
-        : mContraintsCompressionType(CreatePhishingUrlDataBaseJob::RawCompression)
-        , mDataBaseDownloadNeeded(CreatePhishingUrlDataBaseJob::FullDataBase)
-    {
-    }
-
-    UpdateDataBaseInfo::CompressionType parseCompressionType(const QString &str);
-    RiceDeltaEncoding parseRiceDeltaEncoding(const QMap<QString, QVariant> &map);
-    QVector<Removal> parseRemovals(const QVariantList &lst);
-    QVector<Addition> parseAdditions(const QVariantList &lst);
+    Q_REQUIRED_RESULT UpdateDataBaseInfo::CompressionType parseCompressionType(const QString &str);
+    Q_REQUIRED_RESULT RiceDeltaEncoding parseRiceDeltaEncoding(const QMap<QString, QVariant> &map);
+    Q_REQUIRED_RESULT QVector<Removal> parseRemovals(const QVariantList &lst);
+    Q_REQUIRED_RESULT QVector<Addition> parseAdditions(const QVariantList &lst);
     QString mDataBaseState;
-    CreatePhishingUrlDataBaseJob::ContraintsCompressionType mContraintsCompressionType;
-    CreatePhishingUrlDataBaseJob::DataBaseDownloadType mDataBaseDownloadNeeded;
+    CreatePhishingUrlDataBaseJob::ContraintsCompressionType mContraintsCompressionType = CreatePhishingUrlDataBaseJob::RawCompression;
+    CreatePhishingUrlDataBaseJob::DataBaseDownloadType mDataBaseDownloadNeeded = CreatePhishingUrlDataBaseJob::FullDataBase;
     QNetworkAccessManager *mNetworkAccessManager = nullptr;
 };
 
@@ -50,10 +44,7 @@ CreatePhishingUrlDataBaseJob::CreatePhishingUrlDataBaseJob(QObject *parent)
     connect(d->mNetworkAccessManager, &QNetworkAccessManager::sslErrors, this, &CreatePhishingUrlDataBaseJob::slotSslErrors);
 }
 
-CreatePhishingUrlDataBaseJob::~CreatePhishingUrlDataBaseJob()
-{
-    delete d;
-}
+CreatePhishingUrlDataBaseJob::~CreatePhishingUrlDataBaseJob() = default;
 
 void CreatePhishingUrlDataBaseJob::slotSslErrors(QNetworkReply *reply, const QList<QSslError> &error)
 {
@@ -71,21 +62,18 @@ void CreatePhishingUrlDataBaseJob::start()
         query.addQueryItem(QStringLiteral("key"), WebEngineViewer::CheckPhishingUrlUtil::apiKey());
         QUrl safeUrl = QUrl(QStringLiteral("https://safebrowsing.googleapis.com/v4/threatListUpdates:fetch"));
         safeUrl.setQuery(query);
-        //qCDebug(WEBENGINEVIEWER_LOG) << " safeUrl" << safeUrl;
+        // qCDebug(WEBENGINEVIEWER_LOG) << " safeUrl" << safeUrl;
         QNetworkRequest request(safeUrl);
         request.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/json"));
 
         const QByteArray baPostData = jsonRequest();
         Q_EMIT debugJson(baPostData);
         qCDebug(WEBENGINEVIEWER_LOG) << " postData.toJson()" << baPostData;
-        //curl -H "Content-Type: application/json" -X POST -d '{"client":{"clientId":"KDE","clientVersion":"5.4.0"},"threatInfo":{"platformTypes":["WINDOWS"],"threatEntries":[{"url":"http://www.kde.org"}],"threatEntryTypes":["URL"],"threatTypes":["MALWARE"]}}' https://safebrowsing.googleapis.com/v4/threatMatches:find?key=AIzaSyBS62pXATjabbH2RM_jO2EzDg1mTMHlnyo
+        // curl -H "Content-Type: application/json" -X POST -d
+        // '{"client":{"clientId":"KDE","clientVersion":"5.4.0"},"threatInfo":{"platformTypes":["WINDOWS"],"threatEntries":[{"url":"http://www.kde.org"}],"threatEntryTypes":["URL"],"threatTypes":["MALWARE"]}}'
+        // https://safebrowsing.googleapis.com/v4/threatMatches:find?key=AIzaSyBS62pXATjabbH2RM_jO2EzDg1mTMHlnyo
         QNetworkReply *reply = d->mNetworkAccessManager->post(request, baPostData);
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        connect(reply, qOverload<QNetworkReply::NetworkError>(&QNetworkReply::error), this, &CreatePhishingUrlDataBaseJob::slotError);
-#else
         connect(reply, qOverload<QNetworkReply::NetworkError>(&QNetworkReply::errorOccurred), this, &CreatePhishingUrlDataBaseJob::slotError);
-#endif
-
     }
 }
 
@@ -96,7 +84,7 @@ void CreatePhishingUrlDataBaseJob::setDataBaseState(const QString &value)
 
 void CreatePhishingUrlDataBaseJob::slotError(QNetworkReply::NetworkError error)
 {
-    QNetworkReply *reply = qobject_cast<QNetworkReply *>(sender());
+    auto reply = qobject_cast<QNetworkReply *>(sender());
     qWarning() << " error " << error << " error string : " << reply->errorString();
     reply->deleteLater();
     deleteLater();
@@ -138,7 +126,7 @@ QByteArray CreatePhishingUrlDataBaseJob::jsonRequest() const
     threatMap.insert(QStringLiteral("threatType"), QStringLiteral("MALWARE"));
     threatMap.insert(QStringLiteral("threatEntryType"), QStringLiteral("URL"));
 
-    //Contrainsts
+    // Contrainsts
     QVariantMap contraintsMap;
     QVariantList contraintsCompressionList;
     QString compressionStr;
@@ -154,7 +142,7 @@ QByteArray CreatePhishingUrlDataBaseJob::jsonRequest() const
     contraintsMap.insert(QStringLiteral("supportedCompressions"), contraintsCompressionList);
     threatMap.insert(QStringLiteral("constraints"), contraintsMap);
 
-    //Define state when we want to define update database. Empty is full.
+    // Define state when we want to define update database. Empty is full.
     switch (d->mDataBaseDownloadNeeded) {
     case FullDataBase:
         qCDebug(WEBENGINEVIEWER_LOG) << " full update";
@@ -295,10 +283,10 @@ QVector<Removal> CreatePhishingUrlDataBaseJobPrivate::parseRemovals(const QVaria
                     while (rawIndicesIt.hasNext()) {
                         rawIndicesIt.next();
                         if (rawIndicesIt.key() == QLatin1String("indices")) {
-                            const QVariantList lst = rawIndicesIt.value().toList();
+                            const QVariantList rawList = rawIndicesIt.value().toList();
                             QList<quint32> indexList;
-                            indexList.reserve(lst.count());
-                            for (const QVariant &var : lst) {
+                            indexList.reserve(rawList.count());
+                            for (const QVariant &var : rawList) {
                                 indexList.append(var.toUInt());
                             }
                             tmp.indexes = indexList;
