@@ -1,25 +1,12 @@
 /*
-   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "hashcachemanager.h"
-#include "webengineviewer_debug.h"
 #include "checkphishingurlutil.h"
+#include "webengineviewer_debug.h"
 #include <KConfig>
 #include <KConfigGroup>
 
@@ -30,7 +17,7 @@ struct HashCacheInfo {
     {
     }
 
-    bool isValid() const;
+    Q_REQUIRED_RESULT bool isValid() const;
     HashCacheManager::UrlStatus status = HashCacheManager::Unknown;
     uint verifyCacheAfterThisTime = 0;
 };
@@ -52,7 +39,8 @@ public:
     void save();
     void load();
     void addHashStatus(const QByteArray &hash, HashCacheManager::UrlStatus status, uint cacheDuration);
-    HashCacheManager::UrlStatus hashStatus(const QByteArray &hash);
+    Q_REQUIRED_RESULT HashCacheManager::UrlStatus hashStatus(const QByteArray &hash);
+
 private:
     void clear();
 
@@ -190,10 +178,7 @@ HashCacheManager::HashCacheManager(QObject *parent)
 {
 }
 
-HashCacheManager::~HashCacheManager()
-{
-    delete d;
-}
+HashCacheManager::~HashCacheManager() = default;
 
 void HashCacheManager::clearCache()
 {
