@@ -1,16 +1,15 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "searchfullhashjob.h"
 
-#include "checkphishingurlutil.h"
-#include <QNetworkAccessManager>
-#include <QNetworkConfigurationManager>
 #include <PimCommon/NetworkManager>
 #include <QJsonDocument>
+#include <QNetworkAccessManager>
+#include <QNetworkConfigurationManager>
 #include <QUrlQuery>
 #include <webengineviewer_debug.h>
 
@@ -25,7 +24,7 @@ public:
     {
     }
 
-    bool foundExactHash(const QList<QByteArray> &listLongHash);
+    Q_REQUIRED_RESULT bool foundExactHash(const QList<QByteArray> &listLongHash);
     QHash<QByteArray, QByteArray> mHashs;
     QUrl mUrl;
     QStringList mDatabaseHashes;
@@ -45,10 +44,7 @@ SearchFullHashJob::SearchFullHashJob(QObject *parent)
     connect(d->mNetworkAccessManager, &QNetworkAccessManager::sslErrors, this, &SearchFullHashJob::slotSslErrors);
 }
 
-SearchFullHashJob::~SearchFullHashJob()
-{
-    delete d;
-}
+SearchFullHashJob::~SearchFullHashJob() = default;
 
 void SearchFullHashJob::slotSslErrors(QNetworkReply *reply, const QList<QSslError> &error)
 {
@@ -101,15 +97,15 @@ void SearchFullHashJob::parse(const QByteArray &replyStr)
             return;
         } else {
             const QVariantList info = answer.value(QStringLiteral("matches")).toList();
-            //TODO
-            //const QString minimumWaitDuration = answer.value(QStringLiteral("minimumWaitDuration")).toString();
-            //const QString negativeCacheDuration = answer.value(QStringLiteral("negativeCacheDuration")).toString();
-            //Implement multi match ?
+            // TODO
+            // const QString minimumWaitDuration = answer.value(QStringLiteral("minimumWaitDuration")).toString();
+            // const QString negativeCacheDuration = answer.value(QStringLiteral("negativeCacheDuration")).toString();
+            // Implement multi match ?
             if (info.count() == 1) {
                 const QVariantMap map = info.at(0).toMap();
                 const QString threatTypeStr = map[QStringLiteral("threatType")].toString();
 
-                //const QString cacheDuration = map[QStringLiteral("cacheDuration")].toString();
+                // const QString cacheDuration = map[QStringLiteral("cacheDuration")].toString();
 
                 if (threatTypeStr == QLatin1String("MALWARE")) {
                     const QVariantMap urlMap = map[QStringLiteral("threat")].toMap();
@@ -129,7 +125,7 @@ void SearchFullHashJob::parse(const QByteArray &replyStr)
                     }
                     const QVariantMap threatEntryMetadataMap = map[QStringLiteral("threatEntryMetadata")].toMap();
                     if (!threatEntryMetadataMap.isEmpty()) {
-                        //TODO
+                        // TODO
                     }
                 } else {
                     qCWarning(WEBENGINEVIEWER_LOG) << " SearchFullHashJob::parse threatTypeStr : " << threatTypeStr;
@@ -196,9 +192,9 @@ QByteArray SearchFullHashJob::jsonRequest() const
     clientMap.insert(QStringLiteral("clientVersion"), CheckPhishingUrlUtil::versionApps());
     map.insert(QStringLiteral("client"), clientMap);
 
-    //clientStates We can support multi database.
+    // clientStates We can support multi database.
     QVariantList clientStatesList;
-    for (const QString &str : qAsConst(d->mDatabaseHashes)) {
+    for (const QString &str : std::as_const(d->mDatabaseHashes)) {
         if (!str.isEmpty()) {
             clientStatesList.append(str);
         }
@@ -210,9 +206,9 @@ QByteArray SearchFullHashJob::jsonRequest() const
     platformList.append(QLatin1String("WINDOWS"));
     threatMap.insert(QStringLiteral("platformTypes"), platformList);
 
-    const QVariantList threatTypesList = { QStringLiteral("MALWARE") };
+    const QVariantList threatTypesList = {QStringLiteral("MALWARE")};
     threatMap.insert(QStringLiteral("threatTypes"), threatTypesList);
-    const QVariantList threatEntryTypesList = { QStringLiteral("URL") };
+    const QVariantList threatEntryTypesList = {QStringLiteral("URL")};
     threatMap.insert(QStringLiteral("threatEntryTypes"), threatEntryTypesList);
 
     QVariantList threatEntriesList;
@@ -248,15 +244,10 @@ void SearchFullHashJob::start()
         request.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/json"));
 
         const QByteArray baPostData = jsonRequest();
-        //qCDebug(WEBENGINEVIEWER_LOG) << " postData.toJson()" << baPostData;
+        // qCDebug(WEBENGINEVIEWER_LOG) << " postData.toJson()" << baPostData;
         Q_EMIT debugJson(baPostData);
         QNetworkReply *reply = d->mNetworkAccessManager->post(request, baPostData);
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        connect(reply, qOverload<QNetworkReply::NetworkError>(&QNetworkReply::error), this, &SearchFullHashJob::slotError);
-#else
         connect(reply, qOverload<QNetworkReply::NetworkError>(&QNetworkReply::errorOccurred), this, &SearchFullHashJob::slotError);
-#endif
-
     } else {
         Q_EMIT result(WebEngineViewer::CheckPhishingUrlUtil::InvalidUrl, d->mUrl);
         deleteLater();
@@ -265,7 +256,7 @@ void SearchFullHashJob::start()
 
 void SearchFullHashJob::slotError(QNetworkReply::NetworkError error)
 {
-    QNetworkReply *reply = qobject_cast<QNetworkReply *>(sender());
+    auto reply = qobject_cast<QNetworkReply *>(sender());
     qCWarning(WEBENGINEVIEWER_LOG) << " error " << error << " error string : " << reply->errorString();
     reply->deleteLater();
     deleteLater();
