@@ -1,14 +1,13 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef CREATEPHISHINGURLDATABASEGUI_H
-#define CREATEPHISHINGURLDATABASEGUI_H
+#pragma once
 
-#include <QWidget>
 #include "../createphishingurldatabasejob.h"
+#include <QWidget>
 class QPlainTextEdit;
 class QComboBox;
 class CreatePhisingUrlDataBaseGui : public QWidget
@@ -16,13 +15,14 @@ class CreatePhisingUrlDataBaseGui : public QWidget
     Q_OBJECT
 public:
     explicit CreatePhisingUrlDataBaseGui(QWidget *parent = nullptr);
-    ~CreatePhisingUrlDataBaseGui();
+    ~CreatePhisingUrlDataBaseGui() override;
 private Q_SLOTS:
     void slotResult(const QByteArray &data);
     void slotDownloadFullDatabase();
     void slotDebugJSon(const QByteArray &data);
     void slotDownloadPartialDatabase();
     void slotSaveResultToDisk();
+
 private:
     WebEngineViewer::CreatePhishingUrlDataBaseJob::ContraintsCompressionType compressionType();
     void clear();
@@ -31,4 +31,3 @@ private:
     QComboBox *mCompressionType;
 };
 
-#endif // CREATEPHISHINGURLDATABASEGUI_H
