@@ -1,14 +1,13 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef SEARCHFULLHASHGUI_H
-#define SEARCHFULLHASHGUI_H
+#pragma once
 
-#include <QWidget>
 #include "../searchfullhashjob.h"
+#include <QWidget>
 class QLineEdit;
 class QPlainTextEdit;
 class SearchFullHashGui : public QWidget
@@ -16,11 +15,12 @@ class SearchFullHashGui : public QWidget
     Q_OBJECT
 public:
     explicit SearchFullHashGui(QWidget *parent = nullptr);
-    ~SearchFullHashGui();
+    ~SearchFullHashGui() override;
 private Q_SLOTS:
     void slotCheckUrl();
     void slotGetResult(WebEngineViewer::CheckPhishingUrlUtil::UrlStatus result);
     void slotJSonDebug(const QByteArray &debug);
+
 private:
     QLineEdit *mCheckHashLineEdit;
     QLineEdit *mDataBaseHashLineEdit;
@@ -28,4 +28,3 @@ private:
     QPlainTextEdit *mResult;
 };
 
-#endif // SEARCHFULLHASHGUI_H
