@@ -1,17 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef WEBENGINEVIEWWITHSAFEBROWSINGSUPPORT_H
-#define WEBENGINEVIEWWITHSAFEBROWSINGSUPPORT_H
+#pragma once
 
-#include <QWidget>
 #include "../searchfullhashjob.h"
+#include <QWidget>
 #include <WebEngineViewer/LocalDataBaseManager>
 class QPlainTextEdit;
-namespace WebEngineViewer {
+namespace WebEngineViewer
+{
 class WebEngineView;
 }
 class WebEngineViewWithSafeBrowsingSupport : public QWidget
@@ -19,7 +19,7 @@ class WebEngineViewWithSafeBrowsingSupport : public QWidget
     Q_OBJECT
 public:
     explicit WebEngineViewWithSafeBrowsingSupport(QWidget *parent = nullptr);
-    ~WebEngineViewWithSafeBrowsingSupport();
+    ~WebEngineViewWithSafeBrowsingSupport() override;
 
 private Q_SLOTS:
     void slotUrlClicked(const QUrl &url);
@@ -30,4 +30,3 @@ private:
     WebEngineViewer::WebEngineView *pageView = nullptr;
 };
 
-#endif // WEBENGINEVIEWWITHSAFEBROWSINGSUPPORT_H
