@@ -1,5 +1,5 @@
 /* SPDX-FileCopyrightText: 2010 Torgny Nyblom <nyblom@kde.org>
- * SPDX-FileCopyrightText: 2010-2020 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2010-2021 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -7,29 +7,29 @@
 #include "findbarbase.h"
 #include <PimCommon/LineEditWithCompleterNg>
 
-#include <QIcon>
-#include <KLocalizedString>
-#include <QLineEdit>
 #include <KColorScheme>
+#include <KLocalizedString>
+#include <QIcon>
+#include <QLineEdit>
 
+#include <QEvent>
 #include <QHBoxLayout>
-#include <QPushButton>
-#include <QTimer>
+#include <QKeyEvent>
 #include <QLabel>
 #include <QMenu>
+#include <QPushButton>
+#include <QTimer>
 #include <QToolButton>
-#include <QEvent>
-#include <QKeyEvent>
 
 using namespace WebEngineViewer;
 
 FindBarBase::FindBarBase(QWidget *parent)
     : QWidget(parent)
 {
-    QHBoxLayout *lay = new QHBoxLayout(this);
-    lay->setContentsMargins(0, 0, 0, 0);
+    auto lay = new QHBoxLayout(this);
+    lay->setContentsMargins({});
 
-    QToolButton *closeBtn = new QToolButton(this);
+    auto closeBtn = new QToolButton(this);
     closeBtn->setIcon(QIcon::fromTheme(QStringLiteral("dialog-close")));
     closeBtn->setObjectName(QStringLiteral("close"));
     closeBtn->setIconSize(QSize(16, 16));
@@ -42,7 +42,7 @@ FindBarBase::FindBarBase(QWidget *parent)
     closeBtn->setAutoRaise(true);
     lay->addWidget(closeBtn);
 
-    QLabel *label = new QLabel(i18nc("Find text", "F&ind:"), this);
+    auto label = new QLabel(i18nc("Find text", "F&ind:"), this);
     lay->addWidget(label);
 
     mSearch = new PimCommon::LineEditWithCompleterNg(this);
@@ -64,7 +64,7 @@ FindBarBase::FindBarBase(QWidget *parent)
     lay->addWidget(mFindPrevBtn);
     mFindPrevBtn->setEnabled(false);
 
-    QPushButton *optionsBtn = new QPushButton(this);
+    auto optionsBtn = new QPushButton(this);
     optionsBtn->setText(i18n("Options"));
     optionsBtn->setToolTip(i18n("Modify search behavior"));
     mOptionsMenu = new QMenu(optionsBtn);
@@ -79,6 +79,7 @@ FindBarBase::FindBarBase(QWidget *parent)
     connect(mFindPrevBtn, &QPushButton::clicked, this, &FindBarBase::findPrev);
     connect(mCaseSensitiveAct, &QAction::toggled, this, &FindBarBase::caseSensitivityChanged);
     connect(mSearch, &QLineEdit::textChanged, this, &FindBarBase::autoSearch);
+    connect(mSearch, &QLineEdit::returnPressed, this, &FindBarBase::findNext);
 
     mStatus = new QLabel;
     mStatus->setObjectName(QStringLiteral("status"));
@@ -96,7 +97,7 @@ FindBarBase::~FindBarBase()
 {
 }
 
-QMenu *FindBarBase::optionsMenu()
+QMenu *FindBarBase::optionsMenu() const
 {
     return mOptionsMenu;
 }
@@ -109,6 +110,7 @@ QString FindBarBase::text() const
 void FindBarBase::setText(const QString &text)
 {
     mSearch->setText(text);
+    addToCompletion(text);
 }
 
 void FindBarBase::focusAndSetCursor()
@@ -152,9 +154,9 @@ void FindBarBase::setFoundMatch(bool match)
     if (!mSearch->text().isEmpty()) {
         if (mNegativeBackground.isEmpty()) {
             KStatefulBrush bgBrush(KColorScheme::View, KColorScheme::PositiveBackground);
-            mPositiveBackground = QStringLiteral("QLineEdit{ background-color:%1 }").arg(bgBrush.brush(mSearch).color().name());
+            mPositiveBackground = QStringLiteral("QLineEdit{ background-color:%1 }").arg(bgBrush.brush(mSearch->palette()).color().name());
             bgBrush = KStatefulBrush(KColorScheme::View, KColorScheme::NegativeBackground);
-            mNegativeBackground = QStringLiteral("QLineEdit{ background-color:%1 }").arg(bgBrush.brush(mSearch).color().name());
+            mNegativeBackground = QStringLiteral("QLineEdit{ background-color:%1 }").arg(bgBrush.brush(mSearch->palette()).color().name());
         }
         if (match) {
             styleSheet = mPositiveBackground;
@@ -170,8 +172,8 @@ void FindBarBase::setFoundMatch(bool match)
 
 void FindBarBase::searchText(bool backward, bool isAutoSearch)
 {
-    Q_UNUSED(backward);
-    Q_UNUSED(isAutoSearch);
+    Q_UNUSED(backward)
+    Q_UNUSED(isAutoSearch)
 }
 
 void FindBarBase::addToCompletion(const QString &text)
@@ -231,7 +233,7 @@ bool FindBarBase::event(QEvent *e)
     // With a shortcut override we can catch this before it gets to kactions.
     const bool shortCutOverride = (e->type() == QEvent::ShortcutOverride);
     if (shortCutOverride || e->type() == QEvent::KeyPress) {
-        QKeyEvent *kev = static_cast<QKeyEvent * >(e);
+        auto kev = static_cast<QKeyEvent *>(e);
         if (kev->key() == Qt::Key_Escape) {
             if (shortCutOverride) {
                 e->accept();
@@ -240,8 +242,7 @@ bool FindBarBase::event(QEvent *e)
             e->accept();
             closeBar();
             return true;
-        } else if (kev->key() == Qt::Key_Enter
-                   || kev->key() == Qt::Key_Return) {
+        } else if (kev->key() == Qt::Key_Enter || kev->key() == Qt::Key_Return) {
             e->accept();
             if (shortCutOverride) {
                 return true;
