@@ -1,22 +1,23 @@
 /* SPDX-FileCopyrightText: 2010 Torgny Nyblom <nyblom@kde.org>
- * SPDX-FileCopyrightText: 2010-2020 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2010-2021 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
-#ifndef FINDBARBASE_H
-#define FINDBARBASE_H
+#pragma once
 
-#include <QWidget>
 #include "webengineviewer_export.h"
+#include <QWidget>
 class QAction;
 class QPushButton;
 class QMenu;
 class QLabel;
-namespace PimCommon {
+namespace PimCommon
+{
 class LineEditWithCompleterNg;
 }
-namespace WebEngineViewer {
+namespace WebEngineViewer
+{
 /**
  * @brief The FindBarBase class
  */
@@ -39,7 +40,7 @@ protected:
     virtual void updateSensitivity(bool);
 
     void setFoundMatch(bool match);
-    QMenu *optionsMenu();
+    QMenu *optionsMenu() const;
 
 public Q_SLOTS:
     void findNext();
@@ -72,4 +73,3 @@ protected:
 };
 }
 
-#endif /* FINDBARBASE_H */
