@@ -1,14 +1,14 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef TESTSELECTEDTEXTWEBENGINE_H
-#define TESTSELECTEDTEXTWEBENGINE_H
+#pragma once
 
 #include <QWidget>
-namespace WebEngineViewer {
+namespace WebEngineViewer
+{
 class WebEnginePage;
 class WebEngineView;
 }
@@ -18,7 +18,7 @@ class TestSelectedTextWebEngine : public QWidget
     Q_OBJECT
 public:
     explicit TestSelectedTextWebEngine(QWidget *parent = nullptr);
-    ~TestSelectedTextWebEngine();
+    ~TestSelectedTextWebEngine() override;
 
 private Q_SLOTS:
     void slotSlowSelectedText();
@@ -28,4 +28,3 @@ private:
     WebEngineViewer::WebEngineView *pageView;
 };
 
-#endif
