@@ -1,15 +1,15 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef TestSelectionChangedWebEngine_H
-#define TestSelectionChangedWebEngine_H
+#pragma once
 
 #include <QWidget>
 
-namespace WebEngineViewer {
+namespace WebEngineViewer
+{
 class WebEngineView;
 }
 
@@ -18,11 +18,11 @@ class TestSelectionChangedEngine : public QWidget
     Q_OBJECT
 public:
     explicit TestSelectionChangedEngine(QWidget *parent = nullptr);
-    ~TestSelectionChangedEngine();
+    ~TestSelectionChangedEngine() override;
 private Q_SLOTS:
     void slotSelectionChanged();
+
 private:
     WebEngineViewer::WebEngineView *pageView;
 };
 
-#endif // TestSelectionChangedWebEngine_H
