@@ -1,24 +1,24 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "testwebengine.h"
-#include <QHBoxLayout>
 #include <QApplication>
-#include <WebEngineViewer/WebHitTestResult>
-#include <WebEngineViewer/WebEnginePage>
-#include <QDebug>
-#include <QWebEngineSettings>
 #include <QContextMenuEvent>
+#include <QDebug>
+#include <QHBoxLayout>
+#include <QWebEngineSettings>
+#include <WebEngineViewer/WebEnginePage>
+#include <WebEngineViewer/WebHitTestResult>
 #include <webengineviewer/webhittest.h>
 
 TestWebEngine::TestWebEngine(QWidget *parent)
     : QWidget(parent)
 {
-    auto *hboxLayout = new QHBoxLayout(this);
-    auto *pageView = new TestWebEngineView(this);
+    auto hboxLayout = new QHBoxLayout(this);
+    auto pageView = new TestWebEngineView(this);
     hboxLayout->addWidget(pageView);
     mEnginePage = new WebEngineViewer::WebEnginePage(this);
     pageView->setPage(mEnginePage);
@@ -62,7 +62,7 @@ int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-    auto *testWebEngine = new TestWebEngine;
+    auto testWebEngine = new TestWebEngine;
     testWebEngine->show();
     testWebEngine->resize(600, 400);
     const int ret = app.exec();
