@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,14 +8,13 @@
 #include "webenginescript.h"
 
 #include <QApplication>
-#include <QPushButton>
+#include <QComboBox>
 #include <QHBoxLayout>
+#include <QPushButton>
 #include <QTextEdit>
 #include <QWebEngineSettings>
-#include <QComboBox>
 
-template<typename Arg, typename R, typename C>
-struct InvokeWrapper {
+template<typename Arg, typename R, typename C> struct InvokeWrapper {
     R *receiver;
     void (C::*memberFunction)(Arg);
     void operator()(Arg result)
@@ -44,22 +43,25 @@ TestWebEngineScriptPage::TestWebEngineScriptPage(QObject *parent)
     settings()->setAttribute(QWebEngineSettings::JavascriptEnabled, true);
 }
 
-void TestWebEngineScriptPage::javaScriptConsoleMessage(QWebEnginePage::JavaScriptConsoleMessageLevel level, const QString &message, int lineNumber, const QString &sourceID)
+void TestWebEngineScriptPage::javaScriptConsoleMessage(QWebEnginePage::JavaScriptConsoleMessageLevel level,
+                                                       const QString &message,
+                                                       int lineNumber,
+                                                       const QString &sourceID)
 {
-    Q_UNUSED(level);
-    Q_UNUSED(lineNumber);
-    Q_UNUSED(sourceID);
+    Q_UNUSED(level)
+    Q_UNUSED(lineNumber)
+    Q_UNUSED(sourceID)
     qDebug() << "JAVASCRIPT MESSAGE : " << message;
-    //TODO improve it.
+    // TODO improve it.
     Q_EMIT showConsoleMessage(message);
 }
 
 TestWebEngineScript::TestWebEngineScript(QWidget *parent)
     : QWidget(parent)
 {
-    QVBoxLayout *vboxLayout = new QVBoxLayout(this);
+    auto vboxLayout = new QVBoxLayout(this);
     mTestWebEngine = new TestWebEngineScriptView(this);
-    TestWebEngineScriptPage *page = new TestWebEngineScriptPage(this);
+    auto page = new TestWebEngineScriptPage(this);
     mTestWebEngine->setPage(page);
     vboxLayout->addWidget(mTestWebEngine);
     mTestWebEngine->load(QUrl(QStringLiteral("http://www.kde.org")));
@@ -76,14 +78,14 @@ TestWebEngineScript::~TestWebEngineScript()
 
 void TestWebEngineScript::slotShowConsoleMessage(const QString &msg)
 {
-    Q_UNUSED(msg);
+    Q_UNUSED(msg)
 }
 
 void TestWebEngineScript::handleScript(const QVariant &res)
 {
     qDebug() << " res" << res;
-    //TODO
-    //mTestScriptWidget->setResult();
+    // TODO
+    // mTestScriptWidget->setResult();
 }
 
 void TestWebEngineScript::slotExecuteScript()
@@ -99,7 +101,7 @@ int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-    TestWebEngineScript *testWebEngine = new TestWebEngineScript;
+    auto testWebEngine = new TestWebEngineScript;
     testWebEngine->show();
     const int ret = app.exec();
     return ret;
@@ -108,9 +110,9 @@ int main(int argc, char *argv[])
 TestScriptWidget::TestScriptWidget(QWidget *parent)
     : QWidget(parent)
 {
-    QHBoxLayout *layout = new QHBoxLayout(this);
+    auto layout = new QHBoxLayout(this);
 
-    QVBoxLayout *vScriptLayout = new QVBoxLayout;
+    auto vScriptLayout = new QVBoxLayout;
     layout->addLayout(vScriptLayout);
 
     mScriptCombo = new QComboBox;
@@ -118,18 +120,17 @@ TestScriptWidget::TestScriptWidget(QWidget *parent)
     fillScriptCombo(mScriptCombo);
     connect(mScriptCombo, qOverload<int>(&QComboBox::currentIndexChanged), this, &TestScriptWidget::slotCurrentIndexChanged);
 
-
     mScriptEdit = new QTextEdit;
     mScriptEdit->setAcceptRichText(false);
     vScriptLayout->addWidget(mScriptEdit);
 
-    QVBoxLayout *vboxLayout = new QVBoxLayout;
+    auto vboxLayout = new QVBoxLayout;
     layout->addLayout(vboxLayout);
 
     mResultEdit = new QTextEdit;
     mResultEdit->setReadOnly(true);
     vboxLayout->addWidget(mResultEdit);
-    QPushButton *button = new QPushButton(QStringLiteral("Execute Script"), this);
+    auto button = new QPushButton(QStringLiteral("Execute Script"), this);
     connect(button, &QPushButton::clicked, this, &TestScriptWidget::executeScript);
     vboxLayout->addWidget(button);
 }
@@ -161,7 +162,7 @@ void TestScriptWidget::fillScriptCombo(QComboBox *scriptCombo)
     WebEngineViewer::WebEngineScript::removeStyleToElement(const QString &element);
     WebEngineViewer::WebEngineScript::replaceInnerHtml(const QString &field, const QString &html, bool doShow);
 #endif
-    //TODO
+    // TODO
 }
 
 void TestScriptWidget::setResult(const QString &res)
