@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef TESTWEBENGINEVIEWINTERCEPTOR_H
-#define TESTWEBENGINEVIEWINTERCEPTOR_H
+#pragma once
 
 #include <QWidget>
 class QWebEngineView;
@@ -14,8 +13,8 @@ class TestWebEngineViewInterceptor : public QWidget
     Q_OBJECT
 public:
     explicit TestWebEngineViewInterceptor(QWidget *parent = nullptr);
+
 private:
     QWebEngineView *mWebEngineView = nullptr;
 };
 
-#endif // TESTWEBENGINEVIEWINTERCEPTOR_H
