@@ -1,16 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MAILNETWORKPLUGINURLINTERCEPTOR_H
-#define MAILNETWORKPLUGINURLINTERCEPTOR_H
+#pragma once
 
-#include <QObject>
 #include "webengineviewer_export.h"
+#include <QObject>
 class QWebEngineView;
-namespace WebEngineViewer {
+namespace WebEngineViewer
+{
 class NetworkPluginUrlInterceptorInterface;
 /**
  * @brief The NetworkPluginUrlInterceptor class
@@ -21,10 +21,10 @@ class WEBENGINEVIEWER_EXPORT NetworkPluginUrlInterceptor : public QObject
     Q_OBJECT
 public:
     explicit NetworkPluginUrlInterceptor(QObject *parent = nullptr);
-    ~NetworkPluginUrlInterceptor();
+    ~NetworkPluginUrlInterceptor() override;
     virtual NetworkPluginUrlInterceptorInterface *createInterface(QWebEngineView *webEngine, QObject *parent = nullptr) = 0;
 
-    virtual bool hasConfigureDialog() const;
+    Q_REQUIRED_RESULT virtual bool hasConfigureDialog() const;
     virtual void showConfigureDialog(QWidget *parent = nullptr);
 
     void setIsEnabled(bool enabled);
@@ -35,4 +35,3 @@ private:
 };
 }
 
-#endif // MAILNETWORKPLUGINURLINTERCEPTOR_H
