@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -19,11 +19,11 @@ NetworkPluginUrlInterceptorInterface::~NetworkPluginUrlInterceptorInterface()
 
 void NetworkPluginUrlInterceptorInterface::createActions(KActionCollection *ac)
 {
-    Q_UNUSED(ac);
+    Q_UNUSED(ac)
 }
 
 QList<QAction *> NetworkPluginUrlInterceptorInterface::interceptorUrlActions(const WebEngineViewer::WebHitTestResult &result) const
 {
-    Q_UNUSED(result);
+    Q_UNUSED(result)
     return {};
 }
