@@ -1,11 +1,11 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include "networkpluginurlinterceptorinterface.h"
 #include "networkurlinterceptor.h"
+#include "networkpluginurlinterceptorinterface.h"
 #include "webengineviewer_debug.h"
 
 #include <QVector>
@@ -41,7 +41,7 @@ void NetworkUrlInterceptorPrivate::removeInterceptor(NetworkPluginUrlInterceptor
 
 void NetworkUrlInterceptorPrivate::interceptRequest(QWebEngineUrlRequestInfo &info)
 {
-    for (NetworkPluginUrlInterceptorInterface *inter : qAsConst(listInterceptor)) {
+    for (NetworkPluginUrlInterceptorInterface *inter : std::as_const(listInterceptor)) {
         if (inter->interceptRequest(info)) {
             info.block(true);
             break;
@@ -55,10 +55,7 @@ NetworkUrlInterceptor::NetworkUrlInterceptor(QObject *parent)
 {
 }
 
-NetworkUrlInterceptor::~NetworkUrlInterceptor()
-{
-    delete d;
-}
+NetworkUrlInterceptor::~NetworkUrlInterceptor() = default;
 
 void NetworkUrlInterceptor::interceptRequest(QWebEngineUrlRequestInfo &info)
 {
