@@ -1,19 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include "networkpluginurlinterceptor.h"
 #include "networkurlinterceptorpluginmanager.h"
+#include "networkpluginurlinterceptor.h"
 #include "webengineviewer_debug.h"
 
-#include <KPluginLoader>
 #include <KPluginFactory>
+#include <KPluginMetaData>
 #include <QFileInfo>
 #include <QVariant>
-#include <QSet>
-#include <KPluginMetaData>
 
 using namespace WebEngineViewer;
 
@@ -24,6 +22,7 @@ public:
     {
     }
 
+    KPluginMetaData data;
     QString metaDataFileNameBaseName;
     QString metaDataFileName;
     PimCommon::PluginUtilData pluginData;
@@ -31,7 +30,8 @@ public:
     bool isEnabled = false;
 };
 
-namespace {
+namespace
+{
 QString pluginVersion()
 {
     return QStringLiteral("1.0");
@@ -41,7 +41,7 @@ QString pluginVersion()
 class WebEngineViewer::NetworkUrlInterceptorPluginManagerPrivate
 {
 public:
-    NetworkUrlInterceptorPluginManagerPrivate(NetworkUrlInterceptorPluginManager *qq)
+    explicit NetworkUrlInterceptorPluginManagerPrivate(NetworkUrlInterceptorPluginManager *qq)
         : q(qq)
     {
     }
@@ -54,6 +54,7 @@ public:
     Q_REQUIRED_RESULT QString configPrefixSettingKey() const;
     Q_REQUIRED_RESULT QVector<PimCommon::PluginUtilData> pluginDataList() const;
     Q_REQUIRED_RESULT NetworkPluginUrlInterceptor *pluginFromIdentifier(const QString &id);
+
 private:
     QVector<MailNetworkUrlInterceptorPluginInfo> mPluginList;
     QVector<PimCommon::PluginUtilData> mPluginDataList;
@@ -77,11 +78,10 @@ QVector<PimCommon::PluginUtilData> NetworkUrlInterceptorPluginManagerPrivate::pl
 
 void NetworkUrlInterceptorPluginManagerPrivate::initializePluginList()
 {
-    const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("webengineviewer/urlinterceptor"));
+    const QVector<KPluginMetaData> plugins = KPluginMetaData::findPlugins(QStringLiteral("webengineviewer/urlinterceptor"));
 
     QVectorIterator<KPluginMetaData> i(plugins);
     i.toBack();
-    QSet<QString> unique;
     const QPair<QStringList, QStringList> pair = PimCommon::PluginUtil::loadPluginSetting(configGroupName(), configPrefixSettingKey());
 
     while (i.hasPrevious()) {
@@ -89,22 +89,19 @@ void NetworkUrlInterceptorPluginManagerPrivate::initializePluginList()
 
         const KPluginMetaData data = i.previous();
 
-        //1) get plugin data => name/description etc.
+        // 1) get plugin data => name/description etc.
         info.pluginData = PimCommon::PluginUtil::createPluginMetaData(data);
-        //2) look at if plugin is activated
-        const bool isPluginActivated = PimCommon::PluginUtil::isPluginActivated(pair.first, pair.second, info.pluginData.mEnableByDefault, info.pluginData.mIdentifier);
+        // 2) look at if plugin is activated
+        const bool isPluginActivated =
+            PimCommon::PluginUtil::isPluginActivated(pair.first, pair.second, info.pluginData.mEnableByDefault, info.pluginData.mIdentifier);
         info.isEnabled = isPluginActivated;
         info.metaDataFileNameBaseName = QFileInfo(data.fileName()).baseName();
         info.metaDataFileName = data.fileName();
+        info.data = data;
 
         if (pluginVersion() == data.version()) {
-            // only load plugins once, even if found multiple times!
-            if (unique.contains(info.metaDataFileNameBaseName)) {
-                continue;
-            }
             info.plugin = nullptr;
             mPluginList.push_back(info);
-            unique.insert(info.metaDataFileNameBaseName);
         } else {
             qCWarning(WEBENGINEVIEWER_LOG) << "Plugin " << data.name() << " doesn't have correction plugin version. It will not be loaded.";
         }
@@ -129,9 +126,9 @@ QVector<WebEngineViewer::NetworkPluginUrlInterceptor *> NetworkUrlInterceptorPlu
 
 void NetworkUrlInterceptorPluginManagerPrivate::loadPlugin(MailNetworkUrlInterceptorPluginInfo *item)
 {
-    KPluginLoader pluginLoader(item->metaDataFileName);
-    if (pluginLoader.factory()) {
-        item->plugin = pluginLoader.factory()->create<WebEngineViewer::NetworkPluginUrlInterceptor>(q, QVariantList() << item->metaDataFileNameBaseName);
+    if (auto plugin =
+            KPluginFactory::instantiatePlugin<WebEngineViewer::NetworkPluginUrlInterceptor>(item->data, q, QVariantList() << item->metaDataFileName).plugin) {
+        item->plugin = plugin;
         item->plugin->setIsEnabled(item->isEnabled);
         item->pluginData.mHasConfigureDialog = item->plugin->hasConfigureDialog();
         mPluginDataList.append(item->pluginData);
@@ -162,10 +159,7 @@ NetworkUrlInterceptorPluginManager::NetworkUrlInterceptorPluginManager(QObject *
     d->initializePluginList();
 }
 
-NetworkUrlInterceptorPluginManager::~NetworkUrlInterceptorPluginManager()
-{
-    delete d;
-}
+NetworkUrlInterceptorPluginManager::~NetworkUrlInterceptorPluginManager() = default;
 
 QVector<WebEngineViewer::NetworkPluginUrlInterceptor *> NetworkUrlInterceptorPluginManager::pluginsList() const
 {
