@@ -1,10 +1,9 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef MAILWEBENGINEACCESSKEYANCHORFROMHTMLTEST_H
-#define MAILWEBENGINEACCESSKEYANCHORFROMHTMLTEST_H
+#pragma once
 
 #include <QObject>
 #include <QWidget>
@@ -16,7 +15,7 @@ class TestWebEngineAccessKey : public QWidget
     Q_OBJECT
 public:
     explicit TestWebEngineAccessKey(QWidget *parent = nullptr);
-    ~TestWebEngineAccessKey();
+    ~TestWebEngineAccessKey() override;
 
     void setHtml(const QString &html);
 private Q_SLOTS:
@@ -41,4 +40,3 @@ private Q_SLOTS:
     void shouldReturnTwoAnchor();
 };
 
-#endif // MAILWEBENGINEACCESSKEYANCHORFROMHTMLTEST_H
