@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MAILWEBENGINEACCESSKEYANCHORTEST_H
-#define MAILWEBENGINEACCESSKEYANCHORTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,9 +13,8 @@ class WebEngineAccessKeyAnchorTest : public QObject
     Q_OBJECT
 public:
     explicit WebEngineAccessKeyAnchorTest(QObject *parent = nullptr);
-    ~WebEngineAccessKeyAnchorTest();
+    ~WebEngineAccessKeyAnchorTest() override;
 private Q_SLOTS:
     void shouldReturnEmptyAccessKeyAnchor();
 };
 
-#endif // MAILWEBENGINEACCESSKEYANCHORTEST_H
