@@ -1,21 +1,22 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MAILWEBENGINEACCESSKEY_H
-#define MAILWEBENGINEACCESSKEY_H
+#pragma once
 
 #include "webengineviewer_export.h"
 #include <QObject>
+#include <memory>
 
 class KActionCollection;
 class QWheelEvent;
 class QResizeEvent;
 class QKeyEvent;
 class QWebEngineView;
-namespace WebEngineViewer {
+namespace WebEngineViewer
+{
 class WebEngineAccessKeyPrivate;
 /**
  * @brief The WebEngineAccessKey class
@@ -26,7 +27,7 @@ class WEBENGINEVIEWER_EXPORT WebEngineAccessKey : public QObject
     Q_OBJECT
 public:
     explicit WebEngineAccessKey(QWebEngineView *webEngine, QObject *parent = nullptr);
-    ~WebEngineAccessKey();
+    ~WebEngineAccessKey() override;
 
     void setActionCollection(KActionCollection *ac);
 
@@ -46,8 +47,7 @@ private Q_SLOTS:
     void handleSearchAccessKey(const QVariant &res);
 
 private:
-    WebEngineAccessKeyPrivate *const d;
+    std::unique_ptr<WebEngineAccessKeyPrivate> const d;
 };
 }
 
-#endif
