@@ -1,16 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MAILWEBENGINEACCESSKEYANCHOR_H
-#define MAILWEBENGINEACCESSKEYANCHOR_H
+#pragma once
 
-#include <QVariant>
 #include <QRect>
+#include <QVariant>
 
-namespace WebEngineViewer {
+namespace WebEngineViewer
+{
 class WebEngineAccessKeyAnchor
 {
 public:
@@ -40,4 +40,3 @@ private:
 }
 
 Q_DECLARE_TYPEINFO(WebEngineViewer::WebEngineAccessKeyAnchor, Q_MOVABLE_TYPE);
-#endif // MAILWEBENGINEACCESSKEYANCHOR_H
