@@ -1,16 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef WEBENGINEEXPORTPDFPAGEJOB_H
-#define WEBENGINEEXPORTPDFPAGEJOB_H
+#pragma once
 
-#include <QObject>
 #include "webengineviewer_export.h"
+#include <QObject>
 class QWebEngineView;
-namespace WebEngineViewer {
+namespace WebEngineViewer
+{
 /**
  * @brief The WebEngineExportHtmlPageJob class
  * @author Laurent Montel <montel@kde.org>
@@ -20,7 +20,7 @@ class WEBENGINEVIEWER_EXPORT WebEngineExportPdfPageJob : public QObject
     Q_OBJECT
 public:
     explicit WebEngineExportPdfPageJob(QObject *parent = nullptr);
-    ~WebEngineExportPdfPageJob();
+    ~WebEngineExportPdfPageJob() override;
     void start();
 
     Q_REQUIRED_RESULT QWebEngineView *engineView() const;
@@ -42,4 +42,3 @@ private:
 };
 }
 
-#endif // WEBENGINEEXPORTPDFPAGEJOB_H
