@@ -1,18 +1,18 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef WEBENGINEMANAGESCRIPT_H
-#define WEBENGINEMANAGESCRIPT_H
+#pragma once
 
+#include "webengineviewer_export.h"
 #include <QObject>
 #include <QWebEngineScript>
-#include "webengineviewer_export.h"
 
 class QWebEngineProfile;
-namespace WebEngineViewer {
+namespace WebEngineViewer
+{
 /**
  * @brief The WebEngineManageScript class
  * @author Laurent Montel <montel@kde.org>
@@ -22,7 +22,7 @@ class WEBENGINEVIEWER_EXPORT WebEngineManageScript : public QObject
     Q_OBJECT
 public:
     explicit WebEngineManageScript(QObject *parent = nullptr);
-    ~WebEngineManageScript();
+    ~WebEngineManageScript() override;
     void addScript(QWebEngineProfile *profile, const QString &source, const QString &scriptName, QWebEngineScript::InjectionPoint injectionPoint);
 
     static quint32 scriptWordId()
@@ -31,4 +31,3 @@ public:
     }
 };
 }
-#endif // WEBENGINEMANAGESCRIPT_H
