@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -20,8 +20,8 @@ WebEngineNavigationRequestInterceptor::~WebEngineNavigationRequestInterceptor()
 
 bool WebEngineNavigationRequestInterceptor::acceptNavigationRequest(const QUrl &url, QWebEnginePage::NavigationType type, bool isMainFrame)
 {
-    Q_UNUSED(isMainFrame);
-    WebEnginePage *page = qobject_cast<WebEnginePage *>(mTargetPage);
+    Q_UNUSED(isMainFrame)
+    auto page = qobject_cast<WebEnginePage *>(mTargetPage);
     if (type == NavigationTypeLinkClicked && page) {
         Q_EMIT page->urlClicked(url);
         return false;
