@@ -1,32 +1,23 @@
 /*
-   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef WEBENGINEPAGE_H
-#define WEBENGINEPAGE_H
+#pragma once
 
-#include <QWebEnginePage>
 #include "webengineviewer_export.h"
+#include <QWebEnginePage>
 class QWebEngineProfile;
 class QWebEngineDownloadItem;
 class QPrinter;
-namespace WebEngineViewer {
+namespace WebEngineViewer
+{
 class WebHitTest;
+/**
+ * @brief The WebEnginePage class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class WEBENGINEVIEWER_EXPORT WebEnginePage : public QWebEnginePage
 {
     Q_OBJECT
@@ -64,14 +55,14 @@ public:
      * Destructor.  If there is a private QWebEngineProfile then it will also
      * be destroyed.
      **/
-    virtual ~WebEnginePage() override = default;
+    ~WebEnginePage() override = default;
 
     WebEngineViewer::WebHitTest *hitTestContent(const QPoint &pos);
 
     void saveHtml(QWebEngineDownloadItem *download);
     Q_REQUIRED_RESULT bool execPrintPreviewPage(QPrinter *printer, int timeout);
 
-    QPoint mapToViewport(const QPoint &pos) const;
+    Q_REQUIRED_RESULT QPoint mapToViewport(const QPoint &pos) const;
 Q_SIGNALS:
     void urlClicked(const QUrl &url);
     void showConsoleMessage(const QString &message);
@@ -85,4 +76,3 @@ private:
 };
 }
 
-#endif // WEBENGINEPAGE_H
