@@ -1,17 +1,18 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef WEBENGINESCRIPT_H
-#define WEBENGINESCRIPT_H
+#pragma once
 
-#include <QString>
-#include <QPoint>
 #include "webengineviewer_export.h"
+#include <QPoint>
+#include <QString>
 
-namespace WebEngineViewer {
-namespace WebEngineScript {
+namespace WebEngineViewer
+{
+namespace WebEngineScript
+{
 Q_REQUIRED_RESULT WEBENGINEVIEWER_EXPORT QString findAllImages();
 Q_REQUIRED_RESULT WEBENGINEVIEWER_EXPORT QString findAllScripts();
 Q_REQUIRED_RESULT WEBENGINEVIEWER_EXPORT QString findAllAnchors();
@@ -28,4 +29,3 @@ Q_REQUIRED_RESULT WEBENGINEVIEWER_EXPORT QString removeStyleToElement(const QStr
 Q_REQUIRED_RESULT WEBENGINEVIEWER_EXPORT QString isScrolledToBottom();
 }
 }
-#endif // WEBENGINESCRIPT_H
