@@ -1,39 +1,26 @@
 /*
-   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 /* ============================================================
-* QupZilla - QtWebEngine based browser
-* Copyright (C) 2015 David Rosca <nowrep@gmail.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* (at your option) any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <https://www.gnu.org/licenses/>.
-* ============================================================ */
+ * QupZilla - QtWebEngine based browser
+ * SPDX-FileCopyrightText: 2015 David Rosca <nowrep@gmail.com>
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * ============================================================ */
 #include "webhittestresult.h"
 #include <QDebug>
 
@@ -72,7 +59,7 @@ void WebHitTestResultPrivate::init(const QVariantMap &map)
     if (map.isEmpty()) {
         return;
     }
-    //qDebug()<<" void WebHitTestResult::init(const QVariantMap &map)"<<map;
+    // qDebug()<<" void WebHitTestResult::init(const QVariantMap &map)"<<map;
     mAlternateText = map.value(QStringLiteral("alternateText")).toString();
     mImageUrl = map.value(QStringLiteral("imageUrl")).toUrl();
     mIsContentEditable = map.value(QStringLiteral("contentEditable")).toBool();
@@ -117,10 +104,7 @@ WebHitTestResult::WebHitTestResult(const WebHitTestResult &other)
     (*this) = other;
 }
 
-WebHitTestResult::~WebHitTestResult()
-{
-    delete d;
-}
+WebHitTestResult::~WebHitTestResult() = default;
 
 WebHitTestResult &WebHitTestResult::operator=(const WebHitTestResult &other)
 {
