@@ -1,29 +1,17 @@
 /*
-   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "zoomactionmenu.h"
-#include <KLocalizedString>
 #include <KActionCollection>
+#include <KLocalizedString>
 
 using namespace WebEngineViewer;
-namespace {
-qreal zoomBy()
+namespace
+{
+constexpr qreal zoomBy()
 {
     return 20;
 }
@@ -32,7 +20,7 @@ qreal zoomBy()
 class WebEngineViewer::ZoomActionMenuPrivate
 {
 public:
-    ZoomActionMenuPrivate(KActionMenu *qq)
+    explicit ZoomActionMenuPrivate(KActionMenu *qq)
         : q(qq)
     {
     }
@@ -43,7 +31,7 @@ public:
     QAction *mZoomOutAction = nullptr;
     QAction *mZoomResetAction = nullptr;
     KActionCollection *mActionCollection = nullptr;
-    KActionMenu *q = nullptr;
+    KActionMenu *const q;
 };
 
 ZoomActionMenu::ZoomActionMenu(QObject *parent)
@@ -52,10 +40,7 @@ ZoomActionMenu::ZoomActionMenu(QObject *parent)
 {
 }
 
-ZoomActionMenu::~ZoomActionMenu()
-{
-    delete d;
-}
+ZoomActionMenu::~ZoomActionMenu() = default;
 
 void ZoomActionMenu::setActionCollection(KActionCollection *ac)
 {
@@ -65,20 +50,15 @@ void ZoomActionMenu::setActionCollection(KActionCollection *ac)
 void ZoomActionMenu::createZoomActions()
 {
     // Zoom actions
-    d->mZoomInAction = new QAction(QIcon::fromTheme(QStringLiteral("zoom-in")), i18n("&Zoom In"), this);
+    d->mZoomInAction = KStandardAction::zoomIn(this, &ZoomActionMenu::slotZoomIn, this);
     d->mActionCollection->addAction(QStringLiteral("zoom_in"), d->mZoomInAction);
-    connect(d->mZoomInAction, &QAction::triggered, this, &ZoomActionMenu::slotZoomIn);
-    d->mActionCollection->setDefaultShortcut(d->mZoomInAction, QKeySequence(Qt::CTRL + Qt::Key_Plus));
 
-    d->mZoomOutAction = new QAction(QIcon::fromTheme(QStringLiteral("zoom-out")), i18n("Zoom &Out"), this);
+    d->mZoomOutAction = KStandardAction::zoomOut(this, &ZoomActionMenu::slotZoomOut, this);
     d->mActionCollection->addAction(QStringLiteral("zoom_out"), d->mZoomOutAction);
-    connect(d->mZoomOutAction, &QAction::triggered, this, &ZoomActionMenu::slotZoomOut);
-    d->mActionCollection->setDefaultShortcut(d->mZoomOutAction, QKeySequence(Qt::CTRL + Qt::Key_Minus));
 
-    d->mZoomResetAction = new QAction(i18n("Reset"), this);
+    d->mZoomResetAction = KStandardAction::actualSize(this, &ZoomActionMenu::slotZoomReset, this);
     d->mActionCollection->addAction(QStringLiteral("zoom_reset"), d->mZoomResetAction);
-    connect(d->mZoomResetAction, &QAction::triggered, this, &ZoomActionMenu::slotZoomReset);
-    d->mActionCollection->setDefaultShortcut(d->mZoomResetAction, QKeySequence(Qt::CTRL + Qt::Key_0));
+
     d->createMenu();
 }
 
